;Written by Xiaoming Hu, Penn State, Jan, 2010
; contact yuanfangcan@gmail.com
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/contributed.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/wrf/WRF_contributed.ncl"

;   - Drawing an XY plot with three different Y axes
;   - Drawing a custom legend inside an XY plot
;   - Maximizing the size of several different objects on a frame
 
;*****************************************************
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"
;*****************************************************
begin
; Create variables to contain data.
;
  ncurve = 3
  npts = 129

;
; Read ASCII file xy.asc
;
  x1_y3 = readAsciiTable("TS_species.txt",17,"float",1) 
;

  Time = x1_y3(:,0) 
  O3   = x1_y3(:,2)
  Br_OH   = transpose(x1_y3(:,10:13:3))
  HO2   = x1_y3(:,16) 
  BrO   = x1_y3(:,14) 
 figurename = "TS_species_Box"
   wks_type = "png"
   wks_type@wkWidth = 1200
   wks_type@wkHeight = 1200 
  wks = gsn_open_wks(wks_type,figurename)  ; Open an X11 workstation.

  res1             = True
  res1@vpHeightF             = 0.5
  res1@vpWidthF              = 0.5
  res1@vpXF             = 0.2

  res1@gsnFrame               = False                     ; don't draw yet
  res1@gsnDraw                = False                     ; don't advance frame

  res2             = True
  res3             = True
  res1@trXMaxF = 20 
  res1@trXMinF = 4 
;  res1@gsnMaximize = True
;  res1@trXMaxF     = max(lon)    ; Control end of X axis
  res1@gsnPaperOrientation       = "landscape"
;  plot = gsn_csm_xy3(wks,Time,O3,Br_OH,BrO,res1,res2,res3)
  res1@xyLineThicknessF       = 6
  res1@xyLineColor = "red"       ; t
;  res1@tmXBMinorOn = False
  res1@tmYLMinorOn = False
  res1@tmXTOn = False            ; turn off top   labels

  res2@xyLineThicknessF       = 6
  res2@xyLineColors = (/"green","brown"/)     ; u
  res2@tmYRMinorOn = False
  res3@xyLineColor = "blue"      ; v
  res3@tmYRMinorOn = False
  res3@xyLineThicknessF       = 6
 txres               = True
  lgres                    = True
  res1@tiXAxisFontHeightF= 0.025
  res1@tiYAxisFontHeightF= 0.025
  res1@tmXBLabelFontHeightF = 0.025
  res1@tmYLLabelFontHeightF = 0.025
  res3@tmYRLabelFontHeightF = 0.025
 txres@txFontHeightF = 0.025
  lgres@txFontHeightF = 0.025 
;  res1@tmXBMinorThicknessF  = 2
;  res1@tmXBMinorLengthF= 0.01
;  res1@tmXBMinorOutwardLengthF =0.01
;  res1@tmXBMajorOutwardLengthF =0.01
  res1@tmXBMode = "Explicit"
  res1@tmXBValues     = ispan(0,24,4) 
  res1@tmXBLabels     = ispan(0,24,4) 
  res1@tmXBLabelStride =0
  res1@tmYLMinorOn = False

  res1@tmYLLabelStride =2
  res1@tmYLFormat  = "f"


  res1@tiYAxisString    = "O~B~3~N~, ppbv"
  res1@tiXAxisString    = "Time of Day, Hours"
  res2@tiYAxisString    = "Br, OH, pptv"
  res3@tiYAxisString    = "BrO, pptv"
  res3@tmYRFormat  = "f"
;  res2@tmYRFormat  = "f"
  res3@amOrthogonalPosF = 0.87   ; Move "v" axis line to right a little.

  res1@xyDashPatterns = (/4/)     ; u
  res2@xyDashPatterns = (/0,2/)     ; u
  res3@xyDashPatterns = (/16,4/)     ; u
  plot = gsn_csm_xy3(wks,Time,O3,Br_OH,BrO,res1,res2,res3)

;
; Set up resources for a customized legend.
;
  lgres@lgLineColors       = (/"red","green","brown","blue"/)
  lgres@lgDashIndexes= (/4,0,2,16,4/)       ; 0 is default (solid)
  lgres@lgItemType         = "Lines"        ; show lines only (default)
  lgres@lgLabelFontHeightF = .11            ; legend label font thickness
  lgres@vpWidthF           = 0.15           ; width of legend (NDC)
  lgres@vpHeightF          = 0.18           ; height of legend (NDC)
  lgres@lgPerimThicknessF  = 2.0            ; thicken the box perimeter
;  lgres@lgMonoDashIndex    = True
;  lgres@lgDashIndex        = 0
  lgres@lgPerimOn = False
  lgres@lgLineThicknessF       = 5

  labels = (/"O~B~3~N~","Br", "OH","BrO"/)
  nitems = dimsizes(labels)                 ; number of legend items

; Create legend
  lbid = gsn_create_legend(wks,nitems,labels,lgres)

;
; Use gsn_add_annotation to attach this legend to our existing plot.
; This way, if we resize the plot, the legend will stay with the
; plot and be resized automatically.
;
  amres                  = True

;
; Point (0,0) is the dead center of the plot. Point (0,.5) is center,
; flush bottom. Point (0.5,0.5) is flush bottom, flush right.
;
  amres@amJust           = "BottomRight"    ; Use bottom right corner of box
                                            ; for determining its location.
  amres@amParallelPosF   = 0.07              ; Move legend to right
  amres@amOrthogonalPosF = 0.48              ; Move legend down.

  annoid = gsn_add_annotation(plot,lbid,amres)  ; add legend to plot
  draw(plot)
  frame(wks)
;  system("convert -trim -resize 100% "+figurename+".eps /micromet/s1/www/htdocs/datatransfer/1999PacificOcean/"+figurename+".jpg")
;  system("mv "+figurename+".eps /micromet/s1/www/htdocs/datatransfer/1999PacificOcean/"+figurename+".eps")
;  system("convert -trim -resize 100% "+figurename+".eps "+figurename+".jpg")
  system("rm "+figurename+".eps ")
end
