MODULE racm_Integrator
 USE racm_Parameters
 USE racm_Precision
 USE racm_JacobianSP
  IMPLICIT NONE
  INTEGER, PARAMETER :: ifun=1, ijac=2, istp=3, iacc=4, &
    irej=5, idec=6, isol=7, isng=8, itexit=1, ihexit=2
  CHARACTER(LEN=50), PARAMETER, DIMENSION(-8:1) :: IERR_NAMES = (/ &
    'Matrix is repeatedly singular                     ', &
    'Step size too small                               ', &
    'No of steps exceeds maximum bound                 ', &
    'Improper tolerance values                         ', &
    'FacMin/FacMax/FacRej must be positive             ', &
    'Hmin/Hmax/Hstart must be positive                 ', &
    'Selected Rosenbrock method not implemented        ', &
    'Improper value for maximal no of steps            ', &
    '                                                  ', &
    'Success                                           ' /)
CONTAINS
SUBROUTINE racm_INTEGRATE( TIN, TOUT, &
  FIX, VAR, RCONST, ATOL, RTOL, &
  ICNTRL_U, RCNTRL_U, ISTATUS_U, RSTATUS_U, IERR_U )
   USE racm_Parameters
   IMPLICIT NONE
   REAL(kind=dp), INTENT(INOUT), DIMENSION(NFIX) :: FIX
   REAL(kind=dp), INTENT(INOUT), DIMENSION(NVAR) :: VAR
   REAL(kind=dp), INTENT(IN), DIMENSION(NSPEC) :: ATOL, RTOL
   REAL(kind=dp), INTENT(IN), DIMENSION(NREACT) :: RCONST
   REAL(kind=dp), INTENT(IN) :: TIN
   REAL(kind=dp), INTENT(IN) :: TOUT
   INTEGER, INTENT(IN), OPTIONAL :: ICNTRL_U(20)
   REAL(kind=dp), INTENT(IN), OPTIONAL :: RCNTRL_U(20)
   INTEGER, INTENT(OUT), OPTIONAL :: ISTATUS_U(20)
   REAL(kind=dp), INTENT(OUT), OPTIONAL :: RSTATUS_U(20)
   INTEGER, INTENT(OUT), OPTIONAL :: IERR_U
   REAL(kind=dp) :: STEPMIN
   INTEGER :: N_stp, N_acc, N_rej, N_sng
   SAVE N_stp, N_acc, N_rej, N_sng
   INTEGER :: i, IERR
   REAL(kind=dp) :: RCNTRL(20), RSTATUS(20)
   INTEGER :: ICNTRL(20), ISTATUS(20)
   ICNTRL(:) = 0
   RCNTRL(:) = 0.0_dp
   ISTATUS(:) = 0
   RSTATUS(:) = 0.0_dp
   IF (PRESENT(ICNTRL_U)) THEN
     WHERE(ICNTRL_U(:) > 0) ICNTRL(:) = ICNTRL_U(:)
   END IF
   IF (PRESENT(RCNTRL_U)) THEN
     WHERE(RCNTRL_U(:) > 0) RCNTRL(:) = RCNTRL_U(:)
   END IF
   CALL racm_Rosenbrock(VAR, FIX, RCONST, TIN,TOUT, &
         ATOL,RTOL, &
         RCNTRL,ICNTRL,RSTATUS,ISTATUS,IERR)
   STEPMIN = RCNTRL(ihexit)
   IF (PRESENT(ISTATUS_U)) ISTATUS_U(:) = ISTATUS(:)
   IF (PRESENT(RSTATUS_U)) RSTATUS_U(:) = RSTATUS(:)
   IF (PRESENT(IERR_U)) IERR_U = IERR
END SUBROUTINE racm_INTEGRATE
SUBROUTINE racm_Rosenbrock(Y, FIX, RCONST, Tstart,Tend, &
           AbsTol,RelTol, &
           RCNTRL,ICNTRL,RSTATUS,ISTATUS,IERR)
  USE racm_Parameters
  IMPLICIT NONE
   REAL(kind=dp), INTENT(INOUT) :: Y(NVAR)
   REAL(kind=dp), INTENT(IN), DIMENSION(NFIX) :: FIX
   REAL(kind=dp), INTENT(IN), DIMENSION(NREACT) :: RCONST
   REAL(kind=dp), INTENT(IN) :: Tstart,Tend
   REAL(kind=dp), INTENT(IN) :: AbsTol(NVAR),RelTol(NVAR)
   INTEGER, INTENT(IN) :: ICNTRL(20)
   REAL(kind=dp), INTENT(IN) :: RCNTRL(20)
   INTEGER, INTENT(INOUT) :: ISTATUS(20)
   REAL(kind=dp), INTENT(INOUT) :: RSTATUS(20)
   INTEGER, INTENT(OUT) :: IERR
   INTEGER, PARAMETER :: Smax = 6
   INTEGER :: Method, ros_S
   REAL(kind=dp), DIMENSION(Smax) :: ros_M, ros_E, ros_Alpha, ros_Gamma
   REAL(kind=dp), DIMENSION(Smax*(Smax-1)/2) :: ros_A, ros_C
   REAL(kind=dp) :: ros_ELO
   LOGICAL, DIMENSION(Smax) :: ros_NewF
   CHARACTER(LEN=12) :: ros_Name
  INTEGER :: Nfun,Njac,Nstp,Nacc,Nrej,Ndec,Nsol,Nsng
   REAL(kind=dp) :: Roundoff, FacMin, FacMax, FacRej, FacSafe
   REAL(kind=dp) :: Hmin, Hmax, Hstart, Hexit
   REAL(kind=dp) :: Texit
   INTEGER :: i, UplimTol, Max_no_steps
   LOGICAL :: Autonomous, VectorTol
   REAL(kind=dp), PARAMETER :: ZERO = 0.0_dp, ONE = 1.0_dp
   REAL(kind=dp), PARAMETER :: DeltaMin = 1.0E-5_dp
   Nfun = ISTATUS(ifun)
   Njac = ISTATUS(ijac)
   Nstp = ISTATUS(istp)
   Nacc = ISTATUS(iacc)
   Nrej = ISTATUS(irej)
   Ndec = ISTATUS(idec)
   Nsol = ISTATUS(isol)
   Nsng = ISTATUS(isng)
   Autonomous = .NOT.(ICNTRL(1) == 0)
   IF (ICNTRL(2) == 0) THEN
      VectorTol = .TRUE.
         UplimTol = NVAR
   ELSE
      VectorTol = .FALSE.
         UplimTol = 1
   END IF
   IF (ICNTRL(3) == 0) THEN
      Method = 4
   ELSEIF ( (ICNTRL(3) >= 1).AND.(ICNTRL(3) <= 5) ) THEN
      Method = ICNTRL(3)
   ELSE
      PRINT * , 'User-selected Rosenbrock method: ICNTRL(3)=', Method
      CALL racm_ros_ErrorMsg(-2,Tstart,ZERO,IERR)
      RETURN
   END IF
   IF (ICNTRL(4) == 0) THEN
      Max_no_steps = 100000
   ELSEIF (ICNTRL(4) > 0) THEN
      Max_no_steps=ICNTRL(4)
   ELSE
      PRINT * ,'User-selected max no. of steps: ICNTRL(4)=',ICNTRL(4)
      CALL racm_ros_ErrorMsg(-1,Tstart,ZERO,IERR)
      RETURN
   END IF
   Roundoff = racm_WLAMCH('E')
   IF (RCNTRL(1) == ZERO) THEN
      Hmin = ZERO
   ELSEIF (RCNTRL(1) > ZERO) THEN
      Hmin = RCNTRL(1)
   ELSE
      PRINT * , 'User-selected Hmin: RCNTRL(1)=', RCNTRL(1)
      CALL racm_ros_ErrorMsg(-3,Tstart,ZERO,IERR)
      RETURN
   END IF
   IF (RCNTRL(2) == ZERO) THEN
      Hmax = ABS(Tend-Tstart)
   ELSEIF (RCNTRL(2) > ZERO) THEN
      Hmax = MIN(ABS(RCNTRL(2)),ABS(Tend-Tstart))
   ELSE
      PRINT * , 'User-selected Hmax: RCNTRL(2)=', RCNTRL(2)
      CALL racm_ros_ErrorMsg(-3,Tstart,ZERO,IERR)
      RETURN
   END IF
   IF (RCNTRL(3) == ZERO) THEN
      Hstart = MAX(Hmin,DeltaMin)
   ELSEIF (RCNTRL(3) > ZERO) THEN
      Hstart = MIN(ABS(RCNTRL(3)),ABS(Tend-Tstart))
   ELSE
      PRINT * , 'User-selected Hstart: RCNTRL(3)=', RCNTRL(3)
      CALL racm_ros_ErrorMsg(-3,Tstart,ZERO,IERR)
      RETURN
   END IF
   IF (RCNTRL(4) == ZERO) THEN
      FacMin = 0.2_dp
   ELSEIF (RCNTRL(4) > ZERO) THEN
      FacMin = RCNTRL(4)
   ELSE
      PRINT * , 'User-selected FacMin: RCNTRL(4)=', RCNTRL(4)
      CALL racm_ros_ErrorMsg(-4,Tstart,ZERO,IERR)
      RETURN
   END IF
   IF (RCNTRL(5) == ZERO) THEN
      FacMax = 6.0_dp
   ELSEIF (RCNTRL(5) > ZERO) THEN
      FacMax = RCNTRL(5)
   ELSE
      PRINT * , 'User-selected FacMax: RCNTRL(5)=', RCNTRL(5)
      CALL racm_ros_ErrorMsg(-4,Tstart,ZERO,IERR)
      RETURN
   END IF
   IF (RCNTRL(6) == ZERO) THEN
      FacRej = 0.1_dp
   ELSEIF (RCNTRL(6) > ZERO) THEN
      FacRej = RCNTRL(6)
   ELSE
      PRINT * , 'User-selected FacRej: RCNTRL(6)=', RCNTRL(6)
      CALL racm_ros_ErrorMsg(-4,Tstart,ZERO,IERR)
      RETURN
   END IF
   IF (RCNTRL(7) == ZERO) THEN
      FacSafe = 0.9_dp
   ELSEIF (RCNTRL(7) > ZERO) THEN
      FacSafe = RCNTRL(7)
   ELSE
      PRINT * , 'User-selected FacSafe: RCNTRL(7)=', RCNTRL(7)
      CALL racm_ros_ErrorMsg(-4,Tstart,ZERO,IERR)
      RETURN
   END IF
    DO i=1,UplimTol
      IF ( (AbsTol(i) <= ZERO) .OR. (RelTol(i) <= 10.0_dp*Roundoff) &
         .OR. (RelTol(i) >= 1.0_dp) ) THEN
        PRINT * , ' AbsTol(',i,') = ',AbsTol(i)
        PRINT * , ' RelTol(',i,') = ',RelTol(i)
        CALL racm_ros_ErrorMsg(-5,Tstart,ZERO,IERR)
        RETURN
      END IF
    END DO
   SELECT CASE (Method)
     CASE (1)
       CALL racm_Ros2(ros_S, ros_A, ros_C, ros_M, ros_E, &
          ros_Alpha, ros_Gamma, ros_NewF, ros_ELO, ros_Name)
     CASE (2)
       CALL racm_Ros3(ros_S, ros_A, ros_C, ros_M, ros_E, &
          ros_Alpha, ros_Gamma, ros_NewF, ros_ELO, ros_Name)
     CASE (3)
       CALL racm_Ros4(ros_S, ros_A, ros_C, ros_M, ros_E, &
          ros_Alpha, ros_Gamma, ros_NewF, ros_ELO, ros_Name)
     CASE (4)
       CALL racm_Rodas3(ros_S, ros_A, ros_C, ros_M, ros_E, &
          ros_Alpha, ros_Gamma, ros_NewF, ros_ELO, ros_Name)
     CASE (5)
       CALL racm_Rodas4(ros_S, ros_A, ros_C, ros_M, ros_E, &
          ros_Alpha, ros_Gamma, ros_NewF, ros_ELO, ros_Name)
     CASE DEFAULT
       PRINT * , 'Unknown Rosenbrock method: ICNTRL(4)=', Method
       CALL racm_ros_ErrorMsg(-2,Tstart,ZERO,IERR)
       RETURN
   END SELECT
   CALL racm_ros_Integrator(Y,Tstart,Tend,Texit, &
        AbsTol, RelTol, &
        ros_S, ros_M, ros_E, ros_A, ros_C, &
        ros_Alpha, ros_Gamma, ros_ELO, ros_NewF, &
        Autonomous, VectorTol, Max_no_steps, &
        Roundoff, Hmin, Hmax, Hstart, Hexit, &
        FacMin, FacMax, FacRej, FacSafe, &
        IERR, &
         Nfun,Njac,Nstp,Nacc,Nrej,Ndec,Nsol,Nsng,&
         RCONST, FIX &
)
   ISTATUS(ifun) = Nfun
   ISTATUS(ijac) = Njac
   ISTATUS(istp) = Nstp
   ISTATUS(iacc) = Nacc
   ISTATUS(irej) = Nrej
   ISTATUS(idec) = Ndec
   ISTATUS(isol) = Nsol
   ISTATUS(isng) = Nsng
   RSTATUS(itexit) = Texit
   RSTATUS(ihexit) = Hexit
CONTAINS
 SUBROUTINE racm_ros_ErrorMsg(Code,T,H,IERR)
   USE racm_Precision
   REAL(kind=dp), INTENT(IN) :: T, H
   INTEGER, INTENT(IN) :: Code
   INTEGER, INTENT(OUT) :: IERR
   IERR = Code
   PRINT * , &
     'Forced exit from Rosenbrock due to the following error:'
   IF ((Code>=-8).AND.(Code<=-1)) THEN
     PRINT *, IERR_NAMES(Code)
   ELSE
     PRINT *, 'Unknown Error code: ', Code
   ENDIF
   PRINT *, "T=", T, "and H=", H
 END SUBROUTINE racm_ros_ErrorMsg
 SUBROUTINE racm_ros_Integrator (Y, Tstart, Tend, T, &
        AbsTol, RelTol, &
        ros_S, ros_M, ros_E, ros_A, ros_C, &
        ros_Alpha, ros_Gamma, ros_ELO, ros_NewF, &
        Autonomous, VectorTol, Max_no_steps, &
        Roundoff, Hmin, Hmax, Hstart, Hexit, &
        FacMin, FacMax, FacRej, FacSafe, &
        IERR, &
        Nfun,Njac,Nstp,Nacc,Nrej,Ndec,Nsol,Nsng, &
        RCONST, FIX &
 )
  IMPLICIT NONE
   REAL(kind=dp), INTENT(INOUT) :: Y(NVAR)
   REAL(kind=dp), INTENT(IN) :: Tstart,Tend
   REAL(kind=dp), INTENT(OUT) :: T
   REAL(kind=dp), INTENT(IN) :: AbsTol(NVAR), RelTol(NVAR)
   INTEGER, INTENT(IN) :: ros_S
   REAL(kind=dp), INTENT(IN) :: ros_M(ros_S), ros_E(ros_S), &
       ros_Alpha(ros_S), ros_A(ros_S*(ros_S-1)/2), &
       ros_Gamma(ros_S), ros_C(ros_S*(ros_S-1)/2), ros_ELO
   LOGICAL, INTENT(IN) :: ros_NewF(ros_S)
   LOGICAL, INTENT(IN) :: Autonomous, VectorTol
   REAL(kind=dp), INTENT(IN) :: Hstart, Hmin, Hmax
   INTEGER, INTENT(IN) :: Max_no_steps
   REAL(kind=dp), INTENT(IN) :: Roundoff, FacMin, FacMax, FacRej, FacSafe
   REAL(kind=dp), INTENT(OUT) :: Hexit
   INTEGER, INTENT(OUT) :: IERR
   REAL(kind=dp), INTENT(IN), DIMENSION(NFIX) :: FIX
   REAL(kind=dp), INTENT(IN), DIMENSION(NREACT) :: RCONST
  INTEGER, INTENT(INOUT) :: Nfun,Njac,Nstp,Nacc,Nrej,Ndec,Nsol,Nsng
   REAL(kind=dp) :: Ynew(NVAR), Fcn0(NVAR), Fcn(NVAR)
   REAL(kind=dp) :: K(NVAR*ros_S), dFdT(NVAR)
   REAL(kind=dp) :: Jac0(LU_NONZERO), Ghimj(LU_NONZERO)
   REAL(kind=dp) :: H, Hnew, HC, HG, Fac, Tau
   REAL(kind=dp) :: Err, Yerr(NVAR)
   INTEGER :: Pivot(NVAR), Direction, ioffset, j, istage
   LOGICAL :: RejectLastH, RejectMoreH, Singular
   REAL(kind=dp), PARAMETER :: ZERO = 0.0_dp, ONE = 1.0_dp
   REAL(kind=dp), PARAMETER :: DeltaMin = 1.0E-5_dp
   T = Tstart
   Hexit = 0.0_dp
   H = MIN(Hstart,Hmax)
   IF (ABS(H) <= 10.0_dp*Roundoff) H = DeltaMin
   IF (Tend >= Tstart) THEN
     Direction = +1
   ELSE
     Direction = -1
   END IF
   RejectLastH=.FALSE.
   RejectMoreH=.FALSE.
TimeLoop: DO WHILE ( (Direction > 0).AND.((T-Tend)+Roundoff <= ZERO) &
       .OR. (Direction < 0).AND.((Tend-T)+Roundoff <= ZERO) )
   IF ( Nstp > Max_no_steps ) THEN
      CALL racm_ros_ErrorMsg(-6,T,H,IERR)
      RETURN
   END IF
   IF ( ((T+0.1_dp*H) == T).OR.(H <= Roundoff) ) THEN
      CALL racm_ros_ErrorMsg(-7,T,H,IERR)
      RETURN
   END IF
   Hexit = H
   H = MIN(H,ABS(Tend-T))
   CALL racm_FunTemplate(T,Y,Fcn0, RCONST, FIX, Nfun)
   IF (.NOT.Autonomous) THEN
      CALL racm_ros_FunTimeDeriv ( T, Roundoff, Y, &
                Fcn0, dFdT, RCONST, FIX, Nfun )
   END IF
   CALL racm_JacTemplate(T,Y,Jac0, FIX, Njac, RCONST)
UntilAccepted: DO
   CALL racm_ros_PrepareMatrix(H,Direction,ros_Gamma(1), &
          Jac0,Ghimj,Pivot,Singular, Ndec, Nsng )
   IF (Singular) THEN
       CALL racm_ros_ErrorMsg(-8,T,H,IERR)
       RETURN
   END IF
Stage: DO istage = 1, ros_S
       ioffset = NVAR*(istage-1)
       IF ( istage == 1 ) THEN
         CALL racm_WCOPY(NVAR,Fcn0,1,Fcn,1)
       ELSEIF ( ros_NewF(istage) ) THEN
         CALL racm_WCOPY(NVAR,Y,1,Ynew,1)
         DO j = 1, istage-1
           CALL racm_WAXPY(NVAR,ros_A((istage-1)*(istage-2)/2+j), &
            K(NVAR*(j-1)+1),1,Ynew,1)
         END DO
         Tau = T + ros_Alpha(istage)*Direction*H
         CALL racm_FunTemplate(Tau,Ynew,Fcn, RCONST, FIX, Nfun)
       END IF
       CALL racm_WCOPY(NVAR,Fcn,1,K(ioffset+1),1)
       DO j = 1, istage-1
         HC = ros_C((istage-1)*(istage-2)/2+j)/(Direction*H)
         CALL racm_WAXPY(NVAR,HC,K(NVAR*(j-1)+1),1,K(ioffset+1),1)
       END DO
       IF ((.NOT. Autonomous).AND.(ros_Gamma(istage).NE.ZERO)) THEN
         HG = Direction*H*ros_Gamma(istage)
         CALL racm_WAXPY(NVAR,HG,dFdT,1,K(ioffset+1),1)
       END IF
       CALL racm_ros_Solve(Ghimj, Pivot, K(ioffset+1), Nsol)
   END DO Stage
   CALL racm_WCOPY(NVAR,Y,1,Ynew,1)
   DO j=1,ros_S
         CALL racm_WAXPY(NVAR,ros_M(j),K(NVAR*(j-1)+1),1,Ynew,1)
   END DO
   CALL racm_WSCAL(NVAR,ZERO,Yerr,1)
   DO j=1,ros_S
        CALL racm_WAXPY(NVAR,ros_E(j),K(NVAR*(j-1)+1),1,Yerr,1)
   END DO
   Err = racm_ros_ErrorNorm ( Y, Ynew, Yerr, AbsTol, RelTol, VectorTol )
   Fac = MIN(FacMax,MAX(FacMin,FacSafe/Err**(ONE/ros_ELO)))
   Hnew = H*Fac
   Nstp = Nstp+1
   IF ( (Err <= ONE).OR.(H <= Hmin) ) THEN
      Nacc = Nacc+1
      CALL racm_WCOPY(NVAR,Ynew,1,Y,1)
      T = T + Direction*H
      Hnew = MAX(Hmin,MIN(Hnew,Hmax))
      IF (RejectLastH) THEN
         Hnew = MIN(Hnew,H)
      END IF
      RejectLastH = .FALSE.
      RejectMoreH = .FALSE.
      H = Hnew
      EXIT UntilAccepted
   ELSE
      IF (RejectMoreH) THEN
         Hnew = H*FacRej
      END IF
      RejectMoreH = RejectLastH
      RejectLastH = .TRUE.
      H = Hnew
      IF (Nacc >= 1) THEN
         Nrej = Nrej+1
      END IF
   END IF
   END DO UntilAccepted
   END DO TimeLoop
   IERR = 1
  END SUBROUTINE racm_ros_Integrator
  REAL(kind=dp) FUNCTION racm_ros_ErrorNorm ( Y, Ynew, Yerr, &
               AbsTol, RelTol, VectorTol )
   IMPLICIT NONE
   REAL(kind=dp), INTENT(IN) :: Y(NVAR), Ynew(NVAR), &
          Yerr(NVAR), AbsTol(NVAR), RelTol(NVAR)
   LOGICAL, INTENT(IN) :: VectorTol
   REAL(kind=dp) :: Err, Scale, Ymax
   INTEGER :: i
   REAL(kind=dp), PARAMETER :: ZERO = 0.0_dp
   Err = ZERO
   DO i=1,NVAR
     Ymax = MAX(ABS(Y(i)),ABS(Ynew(i)))
     IF (VectorTol) THEN
       Scale = AbsTol(i)+RelTol(i)*Ymax
     ELSE
       Scale = AbsTol(1)+RelTol(1)*Ymax
     END IF
     Err = Err+(Yerr(i)/Scale)**2
   END DO
   Err = SQRT(Err/NVAR)
    racm_ros_ErrorNorm = Err
  END FUNCTION racm_ros_ErrorNorm
  SUBROUTINE racm_ros_FunTimeDeriv ( T, Roundoff, Y, &
                Fcn0, dFdT, RCONST, FIX, Nfun )
   IMPLICIT NONE
   REAL(kind=dp), INTENT(IN) :: T, Roundoff, Y(NVAR), Fcn0(NVAR)
   REAL(kind=dp), INTENT(IN) :: RCONST(NREACT), FIX(NFIX)
   REAL(kind=dp), INTENT(OUT) :: dFdT(NVAR)
   INTEGER, INTENT(INOUT) ::Nfun
   REAL(kind=dp) :: Delta
   REAL(kind=dp), PARAMETER :: ONE = 1.0_dp, DeltaMin = 1.0E-6_dp
   Delta = SQRT(Roundoff)*MAX(DeltaMin,ABS(T))
   CALL racm_FunTemplate(T+Delta,Y,dFdT, RCONST, FIX, Nfun)
   CALL racm_WAXPY(NVAR,(-ONE),Fcn0,1,dFdT,1)
   CALL racm_WSCAL(NVAR,(ONE/Delta),dFdT,1)
  END SUBROUTINE racm_ros_FunTimeDeriv
  SUBROUTINE racm_ros_PrepareMatrix ( H, Direction, gam, &
             Jac0, Ghimj, Pivot, Singular, Ndec, Nsng )
   IMPLICIT NONE
   REAL(kind=dp), INTENT(IN) :: Jac0(LU_NONZERO)
   REAL(kind=dp), INTENT(IN) :: gam
   INTEGER, INTENT(IN) :: Direction
   REAL(kind=dp), INTENT(OUT) :: Ghimj(LU_NONZERO)
   LOGICAL, INTENT(OUT) :: Singular
   INTEGER, INTENT(OUT) :: Pivot(NVAR)
   REAL(kind=dp), INTENT(INOUT) :: H
   INTEGER, INTENT(INOUT) :: Ndec, Nsng
   INTEGER :: i, ising, Nconsecutive
   REAL(kind=dp) :: ghinv
   REAL(kind=dp), PARAMETER :: ONE = 1.0_dp, HALF = 0.5_dp
   Nconsecutive = 0
   Singular = .TRUE.
   DO WHILE (Singular)
     CALL racm_WCOPY(LU_NONZERO,Jac0,1,Ghimj,1)
     CALL racm_WSCAL(LU_NONZERO,(-ONE),Ghimj,1)
     ghinv = ONE/(Direction*H*gam)
     DO i=1,NVAR
       Ghimj(LU_DIAG(i)) = Ghimj(LU_DIAG(i))+ghinv
     END DO
     CALL racm_ros_Decomp( Ghimj, Pivot, ising, Ndec )
     IF (ising == 0) THEN
        Singular = .FALSE.
     ELSE
        Nsng = Nsng+1
        Nconsecutive = Nconsecutive+1
        Singular = .TRUE.
        PRINT*,'Warning: LU Decomposition returned ising = ',ising
        IF (Nconsecutive <= 5) THEN
           H = H*HALF
        ELSE
           RETURN
        END IF
      END IF
   END DO
  END SUBROUTINE racm_ros_PrepareMatrix
  SUBROUTINE racm_ros_Decomp( A, Pivot, ising, Ndec )
   IMPLICIT NONE
   REAL(kind=dp), INTENT(INOUT) :: A(LU_NONZERO)
   INTEGER, INTENT(OUT) :: Pivot(NVAR), ising
   INTEGER, INTENT(INOUT) :: Ndec
CALL decomp_racm ( A, ising )
   Pivot(1) = 1
   Ndec = Ndec + 1
  END SUBROUTINE racm_ros_Decomp
  SUBROUTINE racm_ros_Solve( A, Pivot, b, Nsol )
   IMPLICIT NONE
   REAL(kind=dp), INTENT(IN) :: A(LU_NONZERO)
   INTEGER, INTENT(IN) :: Pivot(NVAR)
   INTEGER, INTENT(INOUT) :: nsol
   REAL(kind=dp), INTENT(INOUT) :: b(NVAR)
   CALL racm_KppSolve( A, b )
   Nsol = Nsol+1
  END SUBROUTINE racm_ros_Solve
  SUBROUTINE racm_Ros2 (ros_S,ros_A,ros_C,ros_M,ros_E,ros_Alpha,&
            ros_Gamma,ros_NewF,ros_ELO,ros_Name)
  IMPLICIT NONE
   INTEGER, PARAMETER :: S=2
   INTEGER, INTENT(OUT) :: ros_S
   REAL(kind=dp), DIMENSION(S), INTENT(OUT) :: ros_M,ros_E,ros_Alpha,ros_Gamma
   REAL(kind=dp), DIMENSION(S*(S-1)/2), INTENT(OUT) :: ros_A, ros_C
   REAL(kind=dp), INTENT(OUT) :: ros_ELO
   LOGICAL, DIMENSION(S), INTENT(OUT) :: ros_NewF
   CHARACTER(LEN=12), INTENT(OUT) :: ros_Name
    REAL(kind=dp) :: g
    g = 1.0_dp + 1.0_dp/SQRT(2.0_dp)
    ros_Name = 'ROS-2'
    ros_S = S
    ros_A(1) = (1.0_dp)/g
    ros_C(1) = (-2.0_dp)/g
    ros_NewF(1) = .TRUE.
    ros_NewF(2) = .TRUE.
    ros_M(1)= (3.0_dp)/(2.0_dp*g)
    ros_M(2)= (1.0_dp)/(2.0_dp*g)
    ros_E(1) = 1.0_dp/(2.0_dp*g)
    ros_E(2) = 1.0_dp/(2.0_dp*g)
    ros_ELO = 2.0_dp
    ros_Alpha(1) = 0.0_dp
    ros_Alpha(2) = 1.0_dp
    ros_Gamma(1) = g
    ros_Gamma(2) =-g
 END SUBROUTINE racm_Ros2
  SUBROUTINE racm_Ros3 (ros_S,ros_A,ros_C,ros_M,ros_E,ros_Alpha,&
           ros_Gamma,ros_NewF,ros_ELO,ros_Name)
  IMPLICIT NONE
   INTEGER, PARAMETER :: S=3
   INTEGER, INTENT(OUT) :: ros_S
   REAL(kind=dp), DIMENSION(S), INTENT(OUT) :: ros_M,ros_E,ros_Alpha,ros_Gamma
   REAL(kind=dp), DIMENSION(S*(S-1)/2), INTENT(OUT) :: ros_A, ros_C
   REAL(kind=dp), INTENT(OUT) :: ros_ELO
   LOGICAL, DIMENSION(S), INTENT(OUT) :: ros_NewF
   CHARACTER(LEN=12), INTENT(OUT) :: ros_Name
   ros_Name = 'ROS-3'
   ros_S = S
   ros_A(1)= 1.0_dp
   ros_A(2)= 1.0_dp
   ros_A(3)= 0.0_dp
   ros_C(1) = -0.10156171083877702091975600115545E+01_dp
   ros_C(2) = 0.40759956452537699824805835358067E+01_dp
   ros_C(3) = 0.92076794298330791242156818474003E+01_dp
   ros_NewF(1) = .TRUE.
   ros_NewF(2) = .TRUE.
   ros_NewF(3) = .FALSE.
   ros_M(1) = 0.1E+01_dp
   ros_M(2) = 0.61697947043828245592553615689730E+01_dp
   ros_M(3) = -0.42772256543218573326238373806514E+00_dp
   ros_E(1) = 0.5E+00_dp
   ros_E(2) = -0.29079558716805469821718236208017E+01_dp
   ros_E(3) = 0.22354069897811569627360909276199E+00_dp
   ros_ELO = 3.0_dp
   ros_Alpha(1)= 0.0E+00_dp
   ros_Alpha(2)= 0.43586652150845899941601945119356E+00_dp
   ros_Alpha(3)= 0.43586652150845899941601945119356E+00_dp
   ros_Gamma(1)= 0.43586652150845899941601945119356E+00_dp
   ros_Gamma(2)= 0.24291996454816804366592249683314E+00_dp
   ros_Gamma(3)= 0.21851380027664058511513169485832E+01_dp
  END SUBROUTINE racm_Ros3
  SUBROUTINE racm_Ros4 (ros_S,ros_A,ros_C,ros_M,ros_E,ros_Alpha,&
           ros_Gamma,ros_NewF,ros_ELO,ros_Name)
  IMPLICIT NONE
   INTEGER, PARAMETER :: S=4
   INTEGER, INTENT(OUT) :: ros_S
   REAL(kind=dp), DIMENSION(4), INTENT(OUT) :: ros_M,ros_E,ros_Alpha,ros_Gamma
   REAL(kind=dp), DIMENSION(6), INTENT(OUT) :: ros_A, ros_C
   REAL(kind=dp), INTENT(OUT) :: ros_ELO
   LOGICAL, DIMENSION(4), INTENT(OUT) :: ros_NewF
   CHARACTER(LEN=12), INTENT(OUT) :: ros_Name
   REAL(kind=dp) :: g
   ros_Name = 'ROS-4'
   ros_S = S
   ros_A(1) = 0.2000000000000000E+01_dp
   ros_A(2) = 0.1867943637803922E+01_dp
   ros_A(3) = 0.2344449711399156E+00_dp
   ros_A(4) = ros_A(2)
   ros_A(5) = ros_A(3)
   ros_A(6) = 0.0_dp
   ros_C(1) =-0.7137615036412310E+01_dp
   ros_C(2) = 0.2580708087951457E+01_dp
   ros_C(3) = 0.6515950076447975E+00_dp
   ros_C(4) =-0.2137148994382534E+01_dp
   ros_C(5) =-0.3214669691237626E+00_dp
   ros_C(6) =-0.6949742501781779E+00_dp
   ros_NewF(1) = .TRUE.
   ros_NewF(2) = .TRUE.
   ros_NewF(3) = .TRUE.
   ros_NewF(4) = .FALSE.
   ros_M(1) = 0.2255570073418735E+01_dp
   ros_M(2) = 0.2870493262186792E+00_dp
   ros_M(3) = 0.4353179431840180E+00_dp
   ros_M(4) = 0.1093502252409163E+01_dp
   ros_E(1) =-0.2815431932141155E+00_dp
   ros_E(2) =-0.7276199124938920E-01_dp
   ros_E(3) =-0.1082196201495311E+00_dp
   ros_E(4) =-0.1093502252409163E+01_dp
   ros_ELO = 4.0_dp
   ros_Alpha(1) = 0.0_dp
   ros_Alpha(2) = 0.1145640000000000E+01_dp
   ros_Alpha(3) = 0.6552168638155900E+00_dp
   ros_Alpha(4) = ros_Alpha(3)
   ros_Gamma(1) = 0.5728200000000000E+00_dp
   ros_Gamma(2) =-0.1769193891319233E+01_dp
   ros_Gamma(3) = 0.7592633437920482E+00_dp
   ros_Gamma(4) =-0.1049021087100450E+00_dp
  END SUBROUTINE racm_Ros4
  SUBROUTINE racm_Rodas3 (ros_S,ros_A,ros_C,ros_M,ros_E,ros_Alpha,&
            ros_Gamma,ros_NewF,ros_ELO,ros_Name)
  IMPLICIT NONE
   INTEGER, PARAMETER :: S=4
   INTEGER, INTENT(OUT) :: ros_S
   REAL(kind=dp), DIMENSION(S), INTENT(OUT) :: ros_M,ros_E,ros_Alpha,ros_Gamma
   REAL(kind=dp), DIMENSION(S*(S-1)/2), INTENT(OUT) :: ros_A, ros_C
   REAL(kind=dp), INTENT(OUT) :: ros_ELO
   LOGICAL, DIMENSION(S), INTENT(OUT) :: ros_NewF
   CHARACTER(LEN=12), INTENT(OUT) :: ros_Name
   REAL(kind=dp) :: g
   ros_Name = 'RODAS-3'
   ros_S = S
   ros_A(1) = 0.0E+00_dp
   ros_A(2) = 2.0E+00_dp
   ros_A(3) = 0.0E+00_dp
   ros_A(4) = 2.0E+00_dp
   ros_A(5) = 0.0E+00_dp
   ros_A(6) = 1.0E+00_dp
   ros_C(1) = 4.0E+00_dp
   ros_C(2) = 1.0E+00_dp
   ros_C(3) =-1.0E+00_dp
   ros_C(4) = 1.0E+00_dp
   ros_C(5) =-1.0E+00_dp
   ros_C(6) =-(8.0E+00_dp/3.0E+00_dp)
   ros_NewF(1) = .TRUE.
   ros_NewF(2) = .FALSE.
   ros_NewF(3) = .TRUE.
   ros_NewF(4) = .TRUE.
   ros_M(1) = 2.0E+00_dp
   ros_M(2) = 0.0E+00_dp
   ros_M(3) = 1.0E+00_dp
   ros_M(4) = 1.0E+00_dp
   ros_E(1) = 0.0E+00_dp
   ros_E(2) = 0.0E+00_dp
   ros_E(3) = 0.0E+00_dp
   ros_E(4) = 1.0E+00_dp
   ros_ELO = 3.0E+00_dp
   ros_Alpha(1) = 0.0E+00_dp
   ros_Alpha(2) = 0.0E+00_dp
   ros_Alpha(3) = 1.0E+00_dp
   ros_Alpha(4) = 1.0E+00_dp
   ros_Gamma(1) = 0.5E+00_dp
   ros_Gamma(2) = 1.5E+00_dp
   ros_Gamma(3) = 0.0E+00_dp
   ros_Gamma(4) = 0.0E+00_dp
  END SUBROUTINE racm_Rodas3
  SUBROUTINE racm_Rodas4 (ros_S,ros_A,ros_C,ros_M,ros_E,ros_Alpha,&
             ros_Gamma,ros_NewF,ros_ELO,ros_Name)
  IMPLICIT NONE
   INTEGER, PARAMETER :: S=6
   INTEGER, INTENT(OUT) :: ros_S
   REAL(kind=dp), DIMENSION(S), INTENT(OUT) :: ros_M,ros_E,ros_Alpha,ros_Gamma
   REAL(kind=dp), DIMENSION(S*(S-1)/2), INTENT(OUT) :: ros_A, ros_C
   REAL(kind=dp), INTENT(OUT) :: ros_ELO
   LOGICAL, DIMENSION(S), INTENT(OUT) :: ros_NewF
   CHARACTER(LEN=12), INTENT(OUT) :: ros_Name
    REAL(kind=dp) :: g
    ros_Name = 'RODAS-4'
    ros_S = 6
    ros_Alpha(1) = 0.000_dp
    ros_Alpha(2) = 0.386_dp
    ros_Alpha(3) = 0.210_dp
    ros_Alpha(4) = 0.630_dp
    ros_Alpha(5) = 1.000_dp
    ros_Alpha(6) = 1.000_dp
    ros_Gamma(1) = 0.2500000000000000E+00_dp
    ros_Gamma(2) =-0.1043000000000000E+00_dp
    ros_Gamma(3) = 0.1035000000000000E+00_dp
    ros_Gamma(4) =-0.3620000000000023E-01_dp
    ros_Gamma(5) = 0.0_dp
    ros_Gamma(6) = 0.0_dp
    ros_A(1) = 0.1544000000000000E+01_dp
    ros_A(2) = 0.9466785280815826E+00_dp
    ros_A(3) = 0.2557011698983284E+00_dp
    ros_A(4) = 0.3314825187068521E+01_dp
    ros_A(5) = 0.2896124015972201E+01_dp
    ros_A(6) = 0.9986419139977817E+00_dp
    ros_A(7) = 0.1221224509226641E+01_dp
    ros_A(8) = 0.6019134481288629E+01_dp
    ros_A(9) = 0.1253708332932087E+02_dp
    ros_A(10) =-0.6878860361058950E+00_dp
    ros_A(11) = ros_A(7)
    ros_A(12) = ros_A(8)
    ros_A(13) = ros_A(9)
    ros_A(14) = ros_A(10)
    ros_A(15) = 1.0E+00_dp
    ros_C(1) =-0.5668800000000000E+01_dp
    ros_C(2) =-0.2430093356833875E+01_dp
    ros_C(3) =-0.2063599157091915E+00_dp
    ros_C(4) =-0.1073529058151375E+00_dp
    ros_C(5) =-0.9594562251023355E+01_dp
    ros_C(6) =-0.2047028614809616E+02_dp
    ros_C(7) = 0.7496443313967647E+01_dp
    ros_C(8) =-0.1024680431464352E+02_dp
    ros_C(9) =-0.3399990352819905E+02_dp
    ros_C(10) = 0.1170890893206160E+02_dp
    ros_C(11) = 0.8083246795921522E+01_dp
    ros_C(12) =-0.7981132988064893E+01_dp
    ros_C(13) =-0.3152159432874371E+02_dp
    ros_C(14) = 0.1631930543123136E+02_dp
    ros_C(15) =-0.6058818238834054E+01_dp
    ros_M(1) = ros_A(7)
    ros_M(2) = ros_A(8)
    ros_M(3) = ros_A(9)
    ros_M(4) = ros_A(10)
    ros_M(5) = 1.0E+00_dp
    ros_M(6) = 1.0E+00_dp
    ros_E(1) = 0.0E+00_dp
    ros_E(2) = 0.0E+00_dp
    ros_E(3) = 0.0E+00_dp
    ros_E(4) = 0.0E+00_dp
    ros_E(5) = 0.0E+00_dp
    ros_E(6) = 1.0E+00_dp
    ros_NewF(1) = .TRUE.
    ros_NewF(2) = .TRUE.
    ros_NewF(3) = .TRUE.
    ros_NewF(4) = .TRUE.
    ros_NewF(5) = .TRUE.
    ros_NewF(6) = .TRUE.
    ros_ELO = 4.0_dp
  END SUBROUTINE racm_Rodas4
END SUBROUTINE racm_Rosenbrock
SUBROUTINE racm_FunTemplate( T, Y, Ydot, RCONST, FIX, Nfun )
   USE racm_Parameters
   REAL(kind=dp) :: T, Y(NVAR)
   REAL(kind=dp) :: RCONST(NREACT)
   REAL(kind=dp) :: FIX(NFIX)
   REAL(kind=dp) :: Ydot(NVAR)
   INTEGER :: Nfun
   CALL racm_Fun( Y, FIX, RCONST, Ydot )
   Nfun = Nfun+1
END SUBROUTINE racm_FunTemplate
SUBROUTINE racm_JacTemplate( T, Y, Jcb, FIX, Njac, RCONST )
 USE racm_Parameters
 USE racm_Jacobian
    REAL(kind=dp) :: T, Y(NVAR)
    REAL(kind=dp) :: FIX(NFIX)
    REAL(kind=dp) :: RCONST(NREACT)
    INTEGER :: Njac
    REAL(kind=dp) :: Jcb(LU_NONZERO)
    REAL(kind=dp) :: Told
    CALL racm_Jac_SP( Y, FIX, RCONST, Jcb )
    Njac = Njac+1
END SUBROUTINE racm_JacTemplate
SUBROUTINE racm_Fun ( V, F, RCT, Vdot )
  REAL(kind=dp) :: V(NVAR)
  REAL(kind=dp) :: F(NFIX)
  REAL(kind=dp) :: RCT(NREACT)
  REAL(kind=dp) :: Vdot(NVAR)
  REAL(kind=dp) :: A(NREACT)
  A(1) = RCT(1)*V(78)
  A(2) = RCT(2)*V(75)
  A(3) = RCT(3)*V(75)
  A(4) = RCT(4)*V(21)
  A(5) = RCT(5)*V(31)
  A(6) = RCT(6)*V(19)
  A(7) = RCT(7)*V(74)
  A(8) = RCT(8)*V(74)
  A(9) = RCT(9)*V(22)
  A(10) = RCT(10)*V(63)
  A(11) = RCT(11)*V(63)
  A(12) = RCT(12)*V(58)
  A(13) = RCT(13)*V(20)
  A(14) = RCT(14)*V(70)
  A(15) = RCT(15)*V(30)
  A(16) = RCT(16)*V(47)
  A(17) = RCT(17)*V(39)
  A(18) = RCT(18)*V(39)
  A(19) = RCT(19)*V(45)
  A(20) = RCT(20)*V(64)
  A(21) = RCT(21)*V(55)
  A(22) = RCT(22)*V(56)
  A(23) = RCT(23)*V(26)
  A(24) = RCT(24)*V(12)
  A(25) = RCT(25)*V(5)
  A(26) = RCT(26)*V(29)
  A(27) = RCT(27)*V(71)*F(2)
  A(28) = RCT(28)*V(71)*V(75)
  A(29) = RCT(29)*V(7)*F(2)
  A(30) = RCT(30)*V(7)*F(2)
  A(31) = RCT(31)*V(7)*F(1)
  A(32) = RCT(32)*V(75)*V(76)
  A(33) = RCT(33)*V(69)*V(75)
  A(34) = RCT(34)*V(69)*V(76)
  A(35) = RCT(35)*V(22)*V(76)
  A(36) = RCT(36)*V(69)*V(69)
  A(37) = RCT(37)*V(69)*V(69)*F(1)
  A(38) = RCT(38)*V(71)*V(77)
  A(39) = RCT(39)*V(71)*V(78)
  A(40) = RCT(40)*V(71)*V(78)
  A(41) = RCT(41)*V(76)*V(77)
  A(42) = RCT(42)*V(76)*V(78)
  A(43) = RCT(43)*V(74)*V(76)
  A(44) = RCT(44)*V(69)*V(77)
  A(45) = RCT(45)*V(69)*V(78)
  A(46) = RCT(46)*V(19)
  A(47) = RCT(47)*V(69)*V(74)
  A(48) = RCT(48)*V(21)*V(76)
  A(49) = RCT(49)*V(31)*V(76)
  A(50) = RCT(50)*V(19)*V(76)
  A(51) = RCT(51)*V(75)*V(77)
  A(52) = RCT(52)*V(75)*V(78)
  A(53) = RCT(53)*V(77)*V(77)*F(2)
  A(54) = RCT(54)*V(74)*V(77)
  A(55) = RCT(55)*V(74)*V(78)
  A(56) = RCT(56)*V(74)*V(78)
  A(57) = RCT(57)*V(8)
  A(58) = RCT(58)*V(74)*V(74)
  A(59) = RCT(59)*V(76)*F(2)
  A(60) = RCT(60)*V(6)*V(76)
  A(61) = RCT(61)*V(33)*V(76)
  A(62) = RCT(62)*V(42)*V(71)
  A(63) = RCT(63)*V(56)*V(71)
  A(64) = RCT(64)*V(17)*V(76)
  A(65) = RCT(65)*V(15)*V(76)
  A(66) = RCT(66)*V(14)*V(76)
  A(67) = RCT(67)*V(9)*V(76)
  A(68) = RCT(68)*V(13)*V(76)
  A(69) = RCT(69)*V(27)*V(76)
  A(70) = RCT(70)*V(59)*V(76)
  A(71) = RCT(71)*V(60)*V(76)
  A(72) = RCT(72)*V(37)*V(76)
  A(73) = RCT(73)*V(42)*V(76)
  A(74) = RCT(74)*V(34)*V(76)
  A(75) = RCT(75)*V(36)*V(76)
  A(76) = RCT(76)*V(10)*V(76)
  A(77) = RCT(77)*V(11)*V(76)
  A(78) = RCT(78)*V(38)*V(76)
  A(79) = RCT(79)*V(63)*V(76)
  A(80) = RCT(80)*V(58)*V(76)
  A(81) = RCT(81)*V(47)*V(76)
  A(82) = RCT(82)*V(26)*V(76)
  A(83) = RCT(83)*V(39)*V(76)
  A(84) = RCT(84)*V(45)*V(76)
  A(85) = RCT(85)*V(56)*V(76)
  A(86) = RCT(86)*V(64)*V(76)
  A(87) = RCT(87)*V(16)*V(76)
  A(88) = RCT(88)*V(20)*V(76)
  A(89) = RCT(89)*V(70)*V(76)
  A(90) = RCT(90)*V(30)*V(76)
  A(91) = RCT(91)*V(32)*V(76)
  A(92) = RCT(92)*V(40)*V(76)
  A(93) = RCT(93)*V(55)*V(76)
  A(94) = RCT(94)*V(63)*V(74)
  A(95) = RCT(95)*V(58)*V(74)
  A(96) = RCT(96)*V(39)*V(74)
  A(97) = RCT(97)*V(45)*V(74)
  A(98) = RCT(98)*V(56)*V(74)
  A(99) = RCT(99)*V(64)*V(74)
  A(100) = RCT(100)*V(38)*V(74)
  A(101) = RCT(101)*V(27)*V(74)
  A(102) = RCT(102)*V(59)*V(74)
  A(103) = RCT(103)*V(60)*V(74)
  A(104) = RCT(104)*V(37)*V(74)
  A(105) = RCT(105)*V(42)*V(74)
  A(106) = RCT(106)*V(34)*V(74)
  A(107) = RCT(107)*V(36)*V(74)
  A(108) = RCT(108)*V(40)*V(74)
  A(109) = RCT(109)*V(27)*V(75)
  A(110) = RCT(110)*V(59)*V(75)
  A(111) = RCT(111)*V(60)*V(75)
  A(112) = RCT(112)*V(37)*V(75)
  A(113) = RCT(113)*V(42)*V(75)
  A(114) = RCT(114)*V(34)*V(75)
  A(115) = RCT(115)*V(36)*V(75)
  A(116) = RCT(116)*V(56)*V(75)
  A(117) = RCT(117)*V(64)*V(75)
  A(118) = RCT(118)*V(40)*V(75)
  A(119) = RCT(119)*V(23)*V(78)
  A(120) = RCT(120)*V(23)*V(69)
  A(121) = RCT(121)*V(24)*V(78)
  A(122) = RCT(122)*V(24)*F(2)
  A(123) = RCT(123)*V(24)*V(75)
  A(124) = RCT(124)*V(25)*V(78)
  A(125) = RCT(125)*V(25)*F(2)
  A(126) = RCT(126)*V(25)*V(75)
  A(127) = RCT(127)*V(28)*V(78)
  A(128) = RCT(128)*V(28)*F(2)
  A(129) = RCT(129)*V(28)*V(75)
  A(130) = RCT(130)*V(68)*V(78)
  A(131) = RCT(131)*V(32)
  A(132) = RCT(132)*V(65)*V(78)
  A(133) = RCT(133)*V(40)
  A(134) = RCT(134)*V(72)*V(77)
  A(135) = RCT(135)*V(66)*V(77)
  A(136) = RCT(136)*V(73)*V(77)
  A(137) = RCT(137)*V(49)*V(77)
  A(138) = RCT(138)*V(50)*V(77)
  A(139) = RCT(139)*V(41)*V(77)
  A(140) = RCT(140)*V(43)*V(77)
  A(141) = RCT(141)*V(44)*V(77)
  A(142) = RCT(142)*V(54)*V(77)
  A(143) = RCT(143)*V(53)*V(77)
  A(144) = RCT(144)*V(48)*V(77)
  A(145) = RCT(145)*V(51)*V(77)
  A(146) = RCT(146)*V(52)*V(77)
  A(147) = RCT(147)*V(46)*V(77)
  A(148) = RCT(148)*V(68)*V(77)
  A(149) = RCT(149)*V(65)*V(77)
  A(150) = RCT(150)*V(67)*V(77)
  A(151) = RCT(151)*V(61)*V(77)
  A(152) = RCT(152)*V(62)*V(77)
  A(153) = RCT(153)*V(69)*V(72)
  A(154) = RCT(154)*V(66)*V(69)
  A(155) = RCT(155)*V(69)*V(73)
  A(156) = RCT(156)*V(49)*V(69)
  A(157) = RCT(157)*V(50)*V(69)
  A(158) = RCT(158)*V(41)*V(69)
  A(159) = RCT(159)*V(43)*V(69)
  A(160) = RCT(160)*V(44)*V(69)
  A(161) = RCT(161)*V(54)*V(69)
  A(162) = RCT(162)*V(53)*V(69)
  A(163) = RCT(163)*V(48)*V(69)
  A(164) = RCT(164)*V(51)*V(69)
  A(165) = RCT(165)*V(52)*V(69)
  A(166) = RCT(166)*V(46)*V(69)
  A(167) = RCT(167)*V(68)*V(69)
  A(168) = RCT(168)*V(68)*V(69)
  A(169) = RCT(169)*V(65)*V(69)
  A(170) = RCT(170)*V(65)*V(69)
  A(171) = RCT(171)*V(67)*V(69)
  A(172) = RCT(172)*V(61)*V(69)
  A(173) = RCT(173)*V(62)*V(69)
  A(174) = RCT(174)*V(72)*V(72)
  A(175) = RCT(175)*V(66)*V(72)
  A(176) = RCT(176)*V(72)*V(73)
  A(177) = RCT(177)*V(49)*V(72)
  A(178) = RCT(178)*V(50)*V(72)
  A(179) = RCT(179)*V(41)*V(72)
  A(180) = RCT(180)*V(43)*V(72)
  A(181) = RCT(181)*V(44)*V(72)
  A(182) = RCT(182)*V(54)*V(72)
  A(183) = RCT(183)*V(53)*V(72)
  A(184) = RCT(184)*V(48)*V(72)
  A(185) = RCT(185)*V(51)*V(72)
  A(186) = RCT(186)*V(52)*V(72)
  A(187) = RCT(187)*V(46)*V(72)
  A(188) = RCT(188)*V(68)*V(72)
  A(189) = RCT(189)*V(68)*V(72)
  A(190) = RCT(190)*V(65)*V(72)
  A(191) = RCT(191)*V(65)*V(72)
  A(192) = RCT(192)*V(67)*V(72)
  A(193) = RCT(193)*V(61)*V(72)
  A(194) = RCT(194)*V(62)*V(72)
  A(195) = RCT(195)*V(66)*V(68)
  A(196) = RCT(196)*V(68)*V(73)
  A(197) = RCT(197)*V(49)*V(68)
  A(198) = RCT(198)*V(50)*V(68)
  A(199) = RCT(199)*V(41)*V(68)
  A(200) = RCT(200)*V(43)*V(68)
  A(201) = RCT(201)*V(44)*V(68)
  A(202) = RCT(202)*V(54)*V(68)
  A(203) = RCT(203)*V(53)*V(68)
  A(204) = RCT(204)*V(48)*V(68)
  A(205) = RCT(205)*V(51)*V(68)
  A(206) = RCT(206)*V(52)*V(68)
  A(207) = RCT(207)*V(46)*V(68)
  A(208) = RCT(208)*V(68)*V(68)
  A(209) = RCT(209)*V(65)*V(68)
  A(210) = RCT(210)*V(67)*V(68)
  A(211) = RCT(211)*V(61)*V(68)
  A(212) = RCT(212)*V(62)*V(68)
  A(213) = RCT(213)*V(61)*V(61)
  A(214) = RCT(214)*V(61)*V(62)
  A(215) = RCT(215)*V(62)*V(62)
  A(216) = RCT(216)*V(72)*V(74)
  A(217) = RCT(217)*V(66)*V(74)
  A(218) = RCT(218)*V(73)*V(74)
  A(219) = RCT(219)*V(49)*V(74)
  A(220) = RCT(220)*V(50)*V(74)
  A(221) = RCT(221)*V(41)*V(74)
  A(222) = RCT(222)*V(43)*V(74)
  A(223) = RCT(223)*V(44)*V(74)
  A(224) = RCT(224)*V(54)*V(74)
  A(225) = RCT(225)*V(53)*V(74)
  A(226) = RCT(226)*V(48)*V(74)
  A(227) = RCT(227)*V(51)*V(74)
  A(228) = RCT(228)*V(52)*V(74)
  A(229) = RCT(229)*V(46)*V(74)
  A(230) = RCT(230)*V(68)*V(74)
  A(231) = RCT(231)*V(65)*V(74)
  A(232) = RCT(232)*V(67)*V(74)
  A(233) = RCT(233)*V(61)*V(74)
  A(234) = RCT(234)*V(62)*V(74)
  A(235) = RCT(235)*V(57)*V(69)
  A(236) = RCT(236)*V(57)*V(72)
  A(237) = RCT(237)*V(57)*V(68)
  A(238) = RCT(238)*V(57)*V(57)
  A(239) = RCT(239)*V(57)*V(77)
  A(240) = RCT(240)*V(57)*V(74)
  A(241) = RCT(241)*V(35)*V(75)
  A(242) = RCT(242)*V(29)*V(75)
  A(243) = RCT(243)*V(29)*V(69)
  A(244) = RCT(244)*V(35)*V(69)
  A(245) = RCT(245)*V(18)*V(76)
  A(246) = RCT(246)*V(29)*V(77)
  A(247) = RCT(247)*V(29)*V(29)
  A(248) = RCT(248)*V(29)*V(29)
  A(249) = RCT(249)*V(35)*V(63)
  Vdot(1) = A(60)
  Vdot(2) = A(61)
  Vdot(3) = 0.036*A(66)+0.37*A(109)+0.14*A(110)+0.15*A(112)+0.15*A(113)+0.01*A(115)+0.22*A(116)+0.11*A(117)+0.11*A(118)
  Vdot(4) = 0.1*A(110)+0.14*A(111)+0.07*A(115)+0.13*A(116)+0.21*A(117)+A(168)+A(170)+A(189)+A(191)+0.5*A(195)+0.499&
              &*A(196)+0.495*A(197)+0.495*A(198)+0.5*A(199)+0.499*A(200)+0.49*A(201)+0.494*A(202)+0.5*A(210)+0.5*A(211)&
              &+0.484*A(212)
  Vdot(5) = -A(25)+A(248)
  Vdot(6) = -A(60)
  Vdot(7) = A(2)-A(29)-A(30)-A(31)
  Vdot(8) = A(56)-A(57)
  Vdot(9) = -A(67)
  Vdot(10) = -A(76)
  Vdot(11) = -A(77)
  Vdot(12) = -A(24)+A(243)
  Vdot(13) = -A(68)
  Vdot(14) = -A(66)
  Vdot(15) = -A(65)+0.03*A(110)+0.06*A(111)
  Vdot(16) = 0.35*A(86)-A(87)
  Vdot(17) = -A(64)+0.06*A(110)+0.07*A(111)
  Vdot(18) = A(244)-A(245)+A(249)
  Vdot(19) = -A(6)+A(45)-A(46)-A(50)
  Vdot(20) = -A(13)-A(88)+A(153)
  Vdot(21) = -A(4)+A(41)-A(48)+A(121)+A(124)+A(127)
  Vdot(22) = -A(9)-A(35)+A(36)+A(37)+0.006*A(110)+0.011*A(111)+0.001*A(112)+0.001*A(113)+0.02*A(114)+0.02*A(115)
  Vdot(23) = 0.1*A(78)+A(100)-A(119)-A(120)
  Vdot(24) = 0.9*A(76)-A(121)-A(122)-A(123)
  Vdot(25) = 0.9*A(77)-A(124)-A(125)-A(126)
  Vdot(26) = -A(23)+0.024*A(68)-A(82)+0.41*A(85)+0.6*A(92)+0.3*A(192)
  Vdot(27) = -A(69)-A(101)-A(109)
  Vdot(28) = 0.85*A(78)-A(127)-A(128)-A(129)
  Vdot(29) = -A(26)+A(241)-A(242)-A(243)-A(246)-2*A(247)-2*A(248)
  Vdot(30) = -A(15)-A(90)+0.11*A(117)+A(167)
  Vdot(31) = -A(5)+A(42)+0.3*A(47)-A(49)+A(94)+A(95)+A(96)+A(97)+0.2*A(98)+0.5*A(99)+A(100)
  Vdot(32) = -A(91)+0.4*A(92)+0.4*A(108)+0.3*A(118)+A(130)-A(131)
  Vdot(33) = A(10)+A(11)+A(12)+1.87*A(17)+1.55*A(18)+A(19)+A(22)-A(61)+0.01*A(62)+0.036*A(66)+A(79)+2*A(83)+A(84)+0.41&
               &*A(85)+A(94)+2*A(96)+A(97)+0.8*A(98)+0.43*A(109)+0.37*A(110)+0.3*A(111)+0.36*A(112)+0.36*A(113)+0.14*A(114)&
               &+0.14*A(115)+0.54*A(116)+0.66*A(117)+0.13*A(118)+A(249)
  Vdot(34) = -A(74)-A(106)-A(114)
  Vdot(35) = A(24)+2*A(25)+A(26)-A(241)+A(242)-A(244)+A(245)+A(246)+2*A(247)-A(249)
  Vdot(36) = -A(75)-A(107)-A(115)
  Vdot(37) = -A(72)-A(104)-A(112)
  Vdot(38) = -A(78)-A(100)+0.1*A(119)+A(120)+A(121)+0.02*A(122)+A(123)+A(124)+0.02*A(125)+A(126)+A(127)+0.02*A(128)&
               &+A(129)
  Vdot(39) = -A(17)-A(18)+0.036*A(66)-A(83)+0.15*A(86)-A(96)+0.25*A(99)+0.5*A(117)+0.063*A(136)+1.2*A(145)+0.35*A(146)&
               &+A(147)+0.119*A(176)+0.65*A(185)+0.37*A(186)+A(187)+0.1*A(196)+0.65*A(205)+0.37*A(206)+A(207)+0.063*A(218)&
               &+1.3*A(227)+0.74*A(228)+A(229)
  Vdot(40) = -A(92)-A(108)-A(118)+A(132)-A(133)
  Vdot(41) = A(69)-A(139)-A(158)-A(179)-A(199)-A(221)
  Vdot(42) = -A(62)-A(73)-A(105)-A(113)
  Vdot(43) = A(70)-A(140)-A(159)-A(180)-A(200)-A(222)
  Vdot(44) = A(71)-A(141)-A(160)-A(181)-A(201)-A(223)
  Vdot(45) = -A(19)+A(82)-A(84)+0.08*A(85)+0.15*A(86)-A(97)+0.25*A(99)+0.6*A(116)+0.62*A(117)+0.65*A(145)+0.6*A(146)&
               &+A(147)+0.54*A(150)+0.005*A(176)+0.35*A(185)+0.63*A(186)+A(187)+0.4*A(192)+0.004*A(196)+0.35*A(205)+0.63&
               &*A(206)+A(207)+0.54*A(210)+0.7*A(227)+1.26*A(228)+A(229)+0.54*A(232)
  Vdot(46) = 0.98*A(128)-A(147)-A(166)-A(187)-A(207)-A(229)
  Vdot(47) = -A(16)+0.8*A(21)+0.25*A(67)-A(81)+0.12*A(87)+0.41*A(89)+0.03*A(99)+0.03*A(110)+0.16*A(111)+0.53*A(114)&
               &+0.623*A(136)+0.722*A(137)+0.642*A(138)+0.06*A(140)+0.29*A(141)+0.8*A(143)+0.464*A(152)+0.018*A(176)+0.24&
               &*A(177)+0.419*A(178)+0.081*A(180)+0.313*A(181)+A(183)+0.149*A(194)+0.127*A(196)+0.33*A(197)+0.581*A(198)&
               &+0.141*A(200)+0.569*A(201)+A(203)+0.11*A(210)+0.167*A(212)+0.149*A(214)+0.285*A(215)+0.67*A(218)+0.828&
               &*A(219)+0.88*A(220)+0.06*A(222)+0.29*A(223)+A(225)+0.469*A(234)
  Vdot(48) = A(75)-A(144)-A(163)-A(184)-A(204)-A(226)
  Vdot(49) = 0.75*A(67)-A(137)-A(156)-A(177)-A(197)-A(219)
  Vdot(50) = 0.9511*A(68)-A(138)-A(157)-A(178)-A(198)-A(220)
  Vdot(51) = 0.98*A(122)-A(145)-A(164)-A(185)-A(205)-A(227)
  Vdot(52) = 0.98*A(125)-A(146)-A(165)-A(186)-A(206)-A(228)
  Vdot(53) = A(74)-A(143)-A(162)-A(183)-A(203)-A(225)
  Vdot(54) = A(72)+A(73)-A(142)-A(161)-A(182)-A(202)-A(224)
  Vdot(55) = -A(21)-A(93)+0.6*A(108)+A(119)+0.059*A(136)+0.124*A(137)+0.261*A(138)+0.153*A(142)+0.2*A(143)+0.35*A(144)&
               &+0.05*A(145)+0.05*A(146)+A(151)+A(172)+A(173)+A(193)+0.5*A(194)+A(211)+0.484*A(212)+2*A(213)+1.5*A(214)&
               &+A(215)+A(233)
  Vdot(56) = -A(22)-A(63)-A(85)-A(98)+0.9*A(104)+0.9*A(105)+0.39*A(112)+0.39*A(113)+0.79*A(115)-A(116)+0.446*A(142)+0.4&
               &*A(144)+0.55*A(182)+0.6*A(184)+0.771*A(202)+0.6*A(204)+0.6*A(224)+0.6*A(226)
  Vdot(57) = 0.15*A(62)+0.1*A(76)+0.1*A(77)+0.05*A(78)+0.49*A(85)+0.5*A(86)+0.07*A(89)+0.35*A(90)+A(91)+A(92)+0.5*A(99)&
               &+A(108)+0.13*A(112)+0.13*A(113)+0.048*A(136)+0.334*A(137)+0.416*A(138)+0.16*A(150)+0.085*A(176)+0.245*A(177)&
               &+0.322*A(178)+0.08*A(192)+0.071*A(196)+0.237*A(197)+0.318*A(198)+0.08*A(210)+0.051*A(218)+0.391*A(219)+0.587&
               &*A(220)+0.16*A(232)-A(235)-A(236)-A(237)-2*A(238)-A(239)-A(240)
  Vdot(58) = -A(12)+A(14)+0.2*A(21)+A(63)+0.335*A(66)+0.025*A(68)-A(80)+0.88*A(87)+0.08*A(89)-A(95)+0.25*A(99)+0.44&
               &*A(110)+0.99*A(111)+0.65*A(114)+0.16*A(117)+A(135)+0.233*A(136)+0.211*A(137)+0.15*A(138)+0.2*A(139)+0.94&
               &*A(140)+1.71*A(141)+0.8*A(143)+0.46*A(150)+1.24*A(152)+0.75*A(175)+0.58*A(176)+0.523*A(177)+0.411*A(178)&
               &+0.35*A(179)+0.669*A(180)+0.932*A(181)+A(183)+0.3*A(192)+0.64*A(194)+A(195)+0.724*A(196)+0.677*A(197)+0.497&
               &*A(198)+0.6*A(199)+0.859*A(200)+0.941*A(201)+A(203)+0.35*A(210)+0.65*A(212)+0.64*A(214)+1.21*A(215)+A(217)&
               &+0.243*A(218)+0.239*A(219)+0.187*A(220)+0.2*A(221)+0.94*A(222)+1.71*A(223)+A(225)+0.46*A(232)+1.24*A(234)
  Vdot(59) = 0.86*A(62)-A(70)-A(102)-A(110)+0.35*A(112)+0.35*A(113)+0.46*A(115)+0.354*A(142)+0.37*A(182)+0.229*A(202)&
               &+0.4*A(224)
  Vdot(60) = -A(71)-A(103)-A(111)+0.25*A(144)+0.08*A(182)+0.4*A(184)+0.4*A(204)+0.4*A(226)
  Vdot(61) = 0.8*A(98)+0.8*A(101)+0.43*A(102)+0.11*A(103)+0.9*A(104)+0.9*A(105)+0.1*A(106)+0.13*A(107)-A(151)-A(172)&
               &-A(193)-A(211)-2*A(213)-A(214)-A(233)
  Vdot(62) = 0.2*A(101)+0.57*A(102)+0.89*A(103)+0.1*A(104)+0.1*A(105)+0.9*A(106)+0.87*A(107)-A(152)-A(173)-A(194)-A(212)&
               &-A(214)-2*A(215)-A(234)
  Vdot(63) = -A(10)-A(11)+A(13)+0.13*A(17)+0.45*A(18)+A(22)+A(23)+0.05*A(62)+0.01*A(66)-A(79)+0.08*A(85)+0.35*A(88)+0.35&
               &*A(90)+A(91)+0.4*A(92)-A(94)+0.4*A(108)+A(109)+0.64*A(110)+0.02*A(111)+0.9*A(112)+0.9*A(113)+0.04*A(115)+0.4&
               &*A(116)+0.7*A(118)+A(134)+0.047*A(136)+0.021*A(137)+1.6*A(139)+A(140)+0.606*A(142)+0.25*A(144)+A(149)+0.287&
               &*A(152)+1.33*A(174)+0.75*A(175)+0.81*A(176)+0.829*A(177)+0.753*A(178)+1.55*A(179)+1.25*A(180)+0.755*A(181)&
               &+1.09*A(182)+A(183)+1.4*A(184)+A(185)+A(186)+A(187)+A(188)+A(189)+2*A(190)+A(191)+0.75*A(192)+0.75*A(193)&
               &+0.96*A(194)+0.091*A(196)+0.076*A(197)+0.8*A(199)+0.501*A(200)+0.34*A(202)+0.4*A(204)+A(209)+0.207*A(212)&
               &+0.202*A(214)+0.504*A(215)+A(216)+0.048*A(218)+0.021*A(219)+1.6*A(221)+A(222)+0.686*A(224)+0.4*A(226)+A(231)&
               &+0.28*A(234)+A(236)-A(249)
  Vdot(64) = -A(20)+0.13*A(62)-A(86)-A(99)-A(117)+0.5*A(145)+0.95*A(146)+A(185)+A(186)+A(205)+A(206)+0.5*A(227)+A(228)
  Vdot(65) = A(20)+0.51*A(85)+0.5*A(86)+0.2*A(98)+0.5*A(99)-A(132)+A(133)-A(149)-A(169)-A(170)-A(190)-A(191)-A(209)&
               &-A(231)
  Vdot(66) = A(16)+A(65)+0.1*A(110)+0.18*A(111)+0.2*A(114)+0.16*A(115)-A(135)+0.048*A(136)+0.245*A(137)+0.133*A(138)&
               &-A(154)-A(175)+0.014*A(177)+0.013*A(178)-A(195)+0.006*A(196)+0.018*A(197)+0.015*A(198)-A(217)+0.053*A(218)&
               &+0.262*A(219)+0.155*A(220)
  Vdot(67) = A(81)+0.03*A(110)+0.12*A(111)+0.02*A(112)+0.02*A(113)+0.42*A(114)+0.42*A(115)-A(150)-A(171)-A(192)-A(210)&
               &-A(232)
  Vdot(68) = A(16)+A(19)+A(22)+A(23)+A(80)+A(84)+0.65*A(90)+A(95)+A(97)+0.15*A(112)+0.15*A(113)+0.13*A(116)+0.28*A(117)&
               &+0.7*A(118)-A(130)+A(131)-A(148)+A(149)+0.23*A(150)-A(167)-A(168)-A(188)-A(189)+A(190)+0.12*A(192)-A(195)&
               &-A(196)-A(197)-A(198)-A(199)-A(200)-A(201)-A(202)-A(203)-A(204)-A(205)-A(206)-A(207)-2*A(208)-0.88*A(210)&
               &-A(211)-A(212)-A(230)+A(231)+0.23*A(232)-A(237)
  Vdot(69) = 0.65*A(6)+2*A(11)+A(12)+A(13)+A(14)+0.8*A(18)+A(19)+A(20)+A(21)+A(22)+A(23)+A(32)-A(33)-A(34)+A(35)-2*A(36)&
               &-2*A(37)+A(43)-A(44)-A(45)+A(46)-A(47)+A(59)+A(60)+A(61)+0.28*A(62)+0.381*A(66)+0.25*A(67)+0.049*A(68)+0.1&
               &*A(76)+0.1*A(77)+0.05*A(78)+A(79)+A(82)+A(83)+0.49*A(85)+0.5*A(86)+A(87)+0.35*A(90)+0.4*A(92)+A(94)+A(96)&
               &+0.5*A(99)+0.26*A(109)+0.25*A(110)+0.22*A(111)+0.3*A(112)+0.3*A(113)+0.1*A(114)+0.1*A(115)+0.29*A(116)+0.29&
               &*A(117)+0.08*A(118)-A(120)+0.02*A(122)+0.02*A(125)+0.02*A(128)+A(134)+A(135)+0.742*A(136)+0.599*A(137)+0.606&
               &*A(138)+A(139)+A(140)+A(141)+0.847*A(142)+0.8*A(143)+0.65*A(144)+0.95*A(145)+0.95*A(146)+A(147)+0.77*A(150)&
               &+A(151)-A(153)-A(154)-A(155)-A(156)-A(157)-A(158)-A(159)-A(160)-A(161)-A(162)-A(163)-A(164)-A(165)-A(166)&
               &-A(167)-A(168)-A(169)-A(170)-A(171)-A(172)-A(173)+0.66*A(174)+A(175)+0.992*A(176)+0.946*A(177)+0.993*A(178)&
               &+A(179)+A(180)+A(181)+A(182)+2*A(183)+2*A(184)+A(185)+A(186)+2*A(187)+A(188)+A(190)+0.88*A(192)+A(193)+0.5&
               &*A(194)+0.5*A(195)+0.488*A(196)+0.438*A(197)+0.489*A(198)+0.5*A(199)+0.501*A(200)+0.51*A(201)+0.506*A(202)&
               &+A(203)+A(204)+A(205)+A(206)+A(207)+0.38*A(210)+0.5*A(211)+A(213)+0.5*A(214)+A(216)+A(217)+0.792*A(218)&
               &+0.699*A(219)+0.845*A(220)+A(221)+A(222)+A(223)+A(224)+A(225)+A(226)+A(227)+A(228)+A(229)+0.77*A(232)+A(233)&
               &-A(235)+A(236)-A(243)-A(244)+A(249)
  Vdot(70) = -A(14)-A(89)+0.13*A(116)+A(154)+A(155)+A(156)+A(157)+A(158)+A(159)+A(160)+A(161)+A(162)+A(163)+A(164)&
               &+A(165)+A(166)+A(169)+A(171)+A(235)
  Vdot(71) = A(1)+A(3)+A(8)+A(26)-A(27)-A(28)+A(30)-A(38)-A(39)-A(40)-A(62)-A(63)+0.09*A(112)+0.09*A(113)
  Vdot(72) = A(12)+A(15)+A(64)+0.65*A(88)+0.19*A(110)+0.23*A(111)+0.03*A(112)+0.03*A(113)-A(134)+0.15*A(136)+0.031&
               &*A(137)+A(148)-A(153)-2*A(174)-A(175)-0.993*A(176)-0.951*A(177)-A(178)-A(179)-A(180)-A(181)-A(182)-A(183)&
               &-A(184)-A(185)-A(186)-A(187)-A(189)-A(190)-A(191)-A(192)-A(193)-A(194)+0.5*A(195)+0.508*A(196)+0.554*A(197)&
               &+0.507*A(198)+0.5*A(199)+0.501*A(200)+0.51*A(201)+0.506*A(202)+A(203)+A(204)+A(205)+A(206)+A(207)+2*A(208)&
               &+A(209)+0.5*A(210)+0.5*A(211)+0.516*A(212)-A(216)+0.155*A(218)+0.04*A(219)+A(230)-A(236)+A(237)
  Vdot(73) = 0.583*A(66)+0.44*A(89)+A(93)-A(136)-A(155)-A(176)-A(196)-A(218)
  Vdot(74) = 0.35*A(6)-A(7)-A(8)+A(40)-A(43)-A(47)+A(49)+A(52)-A(54)-A(55)-A(56)+A(57)-2*A(58)+A(91)+0.6*A(92)-A(94)&
               &-A(95)-A(96)-A(97)-A(98)-A(99)-A(100)-A(101)-A(102)-A(103)-A(104)-A(105)-A(106)-A(107)-0.4*A(108)-A(216)&
               &-A(217)-A(218)-A(219)-A(220)-A(221)-A(222)-A(223)-A(224)-A(225)-A(226)-A(227)-A(228)-A(229)-A(230)-A(231)&
               &-A(232)-A(233)-A(234)-A(240)
  Vdot(75) = -A(2)-A(3)+A(27)-A(28)+A(29)-A(32)-A(33)-A(51)-A(52)-A(109)-A(110)-A(111)-A(112)-A(113)-A(114)-A(115)&
               &-A(116)-A(117)-A(118)-A(123)-A(126)-A(129)+A(168)+A(170)-A(241)-A(242)
  Vdot(76) = A(4)+A(5)+0.35*A(6)+2*A(9)+A(13)+A(14)+A(15)+A(24)+2*A(31)-A(32)+A(33)-A(34)-A(35)-A(41)-A(42)-A(43)+A(44)&
               &+0.7*A(47)-A(48)-A(49)-A(50)-A(59)-A(60)-A(61)+0.02*A(62)-A(64)-A(65)-0.964*A(66)-A(67)-A(68)-A(69)-A(70)&
               &-A(71)-A(72)-A(73)-A(74)-A(75)-A(76)-A(77)-A(78)-A(79)-A(80)-A(81)-A(82)-A(83)-A(84)-A(85)-A(86)-A(87)-0.65&
               &*A(88)-0.51*A(89)-A(90)-A(91)-A(92)-A(93)+0.12*A(109)+0.4*A(110)+0.63*A(111)+0.28*A(112)+0.28*A(113)+0.85&
               &*A(114)+0.85*A(115)+0.07*A(116)+0.21*A(117)+0.036*A(118)+A(123)+A(126)+A(129)-A(245)
  Vdot(77) = A(1)+A(4)+A(7)-A(38)+A(39)-A(41)-A(44)-A(51)-2*A(53)-A(54)+A(55)-A(134)-A(135)-A(136)-A(137)-A(138)-A(139)&
               &-A(140)-A(141)-A(142)-A(143)-A(144)-A(145)-A(146)-A(147)-A(148)-A(149)-A(150)-A(151)-A(152)-A(239)-A(246)
  Vdot(78) = -A(1)+A(5)+0.65*A(6)+A(8)+A(21)+A(38)-A(39)-A(40)-A(42)+A(43)+A(44)-A(45)+A(46)+0.7*A(47)+A(48)+A(50)+A(51)&
               &-A(52)+2*A(53)+2*A(54)-A(56)+A(57)+2*A(58)+A(93)+0.5*A(99)+0.4*A(108)+0.7*A(118)-A(119)-A(121)-A(124)-A(127)&
               &-A(130)+A(131)-A(132)+A(133)+A(134)+A(135)+0.941*A(136)+0.876*A(137)+0.739*A(138)+A(139)+A(140)+A(141)+0.847&
               &*A(142)+0.8*A(143)+0.65*A(144)+0.95*A(145)+0.95*A(146)+A(147)+A(148)+A(149)+A(150)+A(151)+2*A(152)+0.5&
               &*A(194)+0.516*A(212)+0.5*A(214)+A(215)+A(216)+A(217)+A(218)+A(219)+A(220)+A(221)+A(222)+A(223)+A(224)+A(225)&
               &+A(226)+A(227)+A(228)+A(229)+A(230)+A(231)+A(232)+A(233)+2*A(234)+A(239)+A(240)+A(246)
END SUBROUTINE racm_Fun
SUBROUTINE racm_Jac_SP ( V, F, RCT, JVS )
  REAL(kind=dp) :: V(NVAR)
  REAL(kind=dp) :: F(NFIX)
  REAL(kind=dp) :: RCT(NREACT)
  REAL(kind=dp) :: JVS(LU_NONZERO)
  REAL(kind=dp) :: B(459)
  B(1) = RCT(1)
  B(2) = RCT(2)
  B(3) = RCT(3)
  B(4) = RCT(4)
  B(5) = RCT(5)
  B(6) = RCT(6)
  B(7) = RCT(7)
  B(8) = RCT(8)
  B(9) = RCT(9)
  B(10) = RCT(10)
  B(11) = RCT(11)
  B(12) = RCT(12)
  B(13) = RCT(13)
  B(14) = RCT(14)
  B(15) = RCT(15)
  B(16) = RCT(16)
  B(17) = RCT(17)
  B(18) = RCT(18)
  B(19) = RCT(19)
  B(20) = RCT(20)
  B(21) = RCT(21)
  B(22) = RCT(22)
  B(23) = RCT(23)
  B(24) = RCT(24)
  B(25) = RCT(25)
  B(26) = RCT(26)
  B(27) = RCT(27)*F(2)
  B(29) = RCT(28)*V(75)
  B(30) = RCT(28)*V(71)
  B(31) = RCT(29)*F(2)
  B(33) = RCT(30)*F(2)
  B(35) = RCT(31)*F(1)
  B(37) = RCT(32)*V(76)
  B(38) = RCT(32)*V(75)
  B(39) = RCT(33)*V(75)
  B(40) = RCT(33)*V(69)
  B(41) = RCT(34)*V(76)
  B(42) = RCT(34)*V(69)
  B(43) = RCT(35)*V(76)
  B(44) = RCT(35)*V(22)
  B(45) = RCT(36)*2*V(69)
  B(46) = RCT(37)*2*V(69)*F(1)
  B(48) = RCT(38)*V(77)
  B(49) = RCT(38)*V(71)
  B(50) = RCT(39)*V(78)
  B(51) = RCT(39)*V(71)
  B(52) = RCT(40)*V(78)
  B(53) = RCT(40)*V(71)
  B(54) = RCT(41)*V(77)
  B(55) = RCT(41)*V(76)
  B(56) = RCT(42)*V(78)
  B(57) = RCT(42)*V(76)
  B(58) = RCT(43)*V(76)
  B(59) = RCT(43)*V(74)
  B(60) = RCT(44)*V(77)
  B(61) = RCT(44)*V(69)
  B(62) = RCT(45)*V(78)
  B(63) = RCT(45)*V(69)
  B(64) = RCT(46)
  B(65) = RCT(47)*V(74)
  B(66) = RCT(47)*V(69)
  B(67) = RCT(48)*V(76)
  B(68) = RCT(48)*V(21)
  B(69) = RCT(49)*V(76)
  B(70) = RCT(49)*V(31)
  B(71) = RCT(50)*V(76)
  B(72) = RCT(50)*V(19)
  B(73) = RCT(51)*V(77)
  B(74) = RCT(51)*V(75)
  B(75) = RCT(52)*V(78)
  B(76) = RCT(52)*V(75)
  B(77) = RCT(53)*2*V(77)*F(2)
  B(79) = RCT(54)*V(77)
  B(80) = RCT(54)*V(74)
  B(81) = RCT(55)*V(78)
  B(82) = RCT(55)*V(74)
  B(83) = RCT(56)*V(78)
  B(84) = RCT(56)*V(74)
  B(85) = RCT(57)
  B(86) = RCT(58)*2*V(74)
  B(87) = RCT(59)*F(2)
  B(89) = RCT(60)*V(76)
  B(90) = RCT(60)*V(6)
  B(91) = RCT(61)*V(76)
  B(92) = RCT(61)*V(33)
  B(93) = RCT(62)*V(71)
  B(94) = RCT(62)*V(42)
  B(95) = RCT(63)*V(71)
  B(96) = RCT(63)*V(56)
  B(97) = RCT(64)*V(76)
  B(98) = RCT(64)*V(17)
  B(99) = RCT(65)*V(76)
  B(100) = RCT(65)*V(15)
  B(101) = RCT(66)*V(76)
  B(102) = RCT(66)*V(14)
  B(103) = RCT(67)*V(76)
  B(104) = RCT(67)*V(9)
  B(105) = RCT(68)*V(76)
  B(106) = RCT(68)*V(13)
  B(107) = RCT(69)*V(76)
  B(108) = RCT(69)*V(27)
  B(109) = RCT(70)*V(76)
  B(110) = RCT(70)*V(59)
  B(111) = RCT(71)*V(76)
  B(112) = RCT(71)*V(60)
  B(113) = RCT(72)*V(76)
  B(114) = RCT(72)*V(37)
  B(115) = RCT(73)*V(76)
  B(116) = RCT(73)*V(42)
  B(117) = RCT(74)*V(76)
  B(118) = RCT(74)*V(34)
  B(119) = RCT(75)*V(76)
  B(120) = RCT(75)*V(36)
  B(121) = RCT(76)*V(76)
  B(122) = RCT(76)*V(10)
  B(123) = RCT(77)*V(76)
  B(124) = RCT(77)*V(11)
  B(125) = RCT(78)*V(76)
  B(126) = RCT(78)*V(38)
  B(127) = RCT(79)*V(76)
  B(128) = RCT(79)*V(63)
  B(129) = RCT(80)*V(76)
  B(130) = RCT(80)*V(58)
  B(131) = RCT(81)*V(76)
  B(132) = RCT(81)*V(47)
  B(133) = RCT(82)*V(76)
  B(134) = RCT(82)*V(26)
  B(135) = RCT(83)*V(76)
  B(136) = RCT(83)*V(39)
  B(137) = RCT(84)*V(76)
  B(138) = RCT(84)*V(45)
  B(139) = RCT(85)*V(76)
  B(140) = RCT(85)*V(56)
  B(141) = RCT(86)*V(76)
  B(142) = RCT(86)*V(64)
  B(143) = RCT(87)*V(76)
  B(144) = RCT(87)*V(16)
  B(145) = RCT(88)*V(76)
  B(146) = RCT(88)*V(20)
  B(147) = RCT(89)*V(76)
  B(148) = RCT(89)*V(70)
  B(149) = RCT(90)*V(76)
  B(150) = RCT(90)*V(30)
  B(151) = RCT(91)*V(76)
  B(152) = RCT(91)*V(32)
  B(153) = RCT(92)*V(76)
  B(154) = RCT(92)*V(40)
  B(155) = RCT(93)*V(76)
  B(156) = RCT(93)*V(55)
  B(157) = RCT(94)*V(74)
  B(158) = RCT(94)*V(63)
  B(159) = RCT(95)*V(74)
  B(160) = RCT(95)*V(58)
  B(161) = RCT(96)*V(74)
  B(162) = RCT(96)*V(39)
  B(163) = RCT(97)*V(74)
  B(164) = RCT(97)*V(45)
  B(165) = RCT(98)*V(74)
  B(166) = RCT(98)*V(56)
  B(167) = RCT(99)*V(74)
  B(168) = RCT(99)*V(64)
  B(169) = RCT(100)*V(74)
  B(170) = RCT(100)*V(38)
  B(171) = RCT(101)*V(74)
  B(172) = RCT(101)*V(27)
  B(173) = RCT(102)*V(74)
  B(174) = RCT(102)*V(59)
  B(175) = RCT(103)*V(74)
  B(176) = RCT(103)*V(60)
  B(177) = RCT(104)*V(74)
  B(178) = RCT(104)*V(37)
  B(179) = RCT(105)*V(74)
  B(180) = RCT(105)*V(42)
  B(181) = RCT(106)*V(74)
  B(182) = RCT(106)*V(34)
  B(183) = RCT(107)*V(74)
  B(184) = RCT(107)*V(36)
  B(185) = RCT(108)*V(74)
  B(186) = RCT(108)*V(40)
  B(187) = RCT(109)*V(75)
  B(188) = RCT(109)*V(27)
  B(189) = RCT(110)*V(75)
  B(190) = RCT(110)*V(59)
  B(191) = RCT(111)*V(75)
  B(192) = RCT(111)*V(60)
  B(193) = RCT(112)*V(75)
  B(194) = RCT(112)*V(37)
  B(195) = RCT(113)*V(75)
  B(196) = RCT(113)*V(42)
  B(197) = RCT(114)*V(75)
  B(198) = RCT(114)*V(34)
  B(199) = RCT(115)*V(75)
  B(200) = RCT(115)*V(36)
  B(201) = RCT(116)*V(75)
  B(202) = RCT(116)*V(56)
  B(203) = RCT(117)*V(75)
  B(204) = RCT(117)*V(64)
  B(205) = RCT(118)*V(75)
  B(206) = RCT(118)*V(40)
  B(207) = RCT(119)*V(78)
  B(208) = RCT(119)*V(23)
  B(209) = RCT(120)*V(69)
  B(210) = RCT(120)*V(23)
  B(211) = RCT(121)*V(78)
  B(212) = RCT(121)*V(24)
  B(213) = RCT(122)*F(2)
  B(215) = RCT(123)*V(75)
  B(216) = RCT(123)*V(24)
  B(217) = RCT(124)*V(78)
  B(218) = RCT(124)*V(25)
  B(219) = RCT(125)*F(2)
  B(221) = RCT(126)*V(75)
  B(222) = RCT(126)*V(25)
  B(223) = RCT(127)*V(78)
  B(224) = RCT(127)*V(28)
  B(225) = RCT(128)*F(2)
  B(227) = RCT(129)*V(75)
  B(228) = RCT(129)*V(28)
  B(229) = RCT(130)*V(78)
  B(230) = RCT(130)*V(68)
  B(231) = RCT(131)
  B(232) = RCT(132)*V(78)
  B(233) = RCT(132)*V(65)
  B(234) = RCT(133)
  B(235) = RCT(134)*V(77)
  B(236) = RCT(134)*V(72)
  B(237) = RCT(135)*V(77)
  B(238) = RCT(135)*V(66)
  B(239) = RCT(136)*V(77)
  B(240) = RCT(136)*V(73)
  B(241) = RCT(137)*V(77)
  B(242) = RCT(137)*V(49)
  B(243) = RCT(138)*V(77)
  B(244) = RCT(138)*V(50)
  B(245) = RCT(139)*V(77)
  B(246) = RCT(139)*V(41)
  B(247) = RCT(140)*V(77)
  B(248) = RCT(140)*V(43)
  B(249) = RCT(141)*V(77)
  B(250) = RCT(141)*V(44)
  B(251) = RCT(142)*V(77)
  B(252) = RCT(142)*V(54)
  B(253) = RCT(143)*V(77)
  B(254) = RCT(143)*V(53)
  B(255) = RCT(144)*V(77)
  B(256) = RCT(144)*V(48)
  B(257) = RCT(145)*V(77)
  B(258) = RCT(145)*V(51)
  B(259) = RCT(146)*V(77)
  B(260) = RCT(146)*V(52)
  B(261) = RCT(147)*V(77)
  B(262) = RCT(147)*V(46)
  B(263) = RCT(148)*V(77)
  B(264) = RCT(148)*V(68)
  B(265) = RCT(149)*V(77)
  B(266) = RCT(149)*V(65)
  B(267) = RCT(150)*V(77)
  B(268) = RCT(150)*V(67)
  B(269) = RCT(151)*V(77)
  B(270) = RCT(151)*V(61)
  B(271) = RCT(152)*V(77)
  B(272) = RCT(152)*V(62)
  B(273) = RCT(153)*V(72)
  B(274) = RCT(153)*V(69)
  B(275) = RCT(154)*V(69)
  B(276) = RCT(154)*V(66)
  B(277) = RCT(155)*V(73)
  B(278) = RCT(155)*V(69)
  B(279) = RCT(156)*V(69)
  B(280) = RCT(156)*V(49)
  B(281) = RCT(157)*V(69)
  B(282) = RCT(157)*V(50)
  B(283) = RCT(158)*V(69)
  B(284) = RCT(158)*V(41)
  B(285) = RCT(159)*V(69)
  B(286) = RCT(159)*V(43)
  B(287) = RCT(160)*V(69)
  B(288) = RCT(160)*V(44)
  B(289) = RCT(161)*V(69)
  B(290) = RCT(161)*V(54)
  B(291) = RCT(162)*V(69)
  B(292) = RCT(162)*V(53)
  B(293) = RCT(163)*V(69)
  B(294) = RCT(163)*V(48)
  B(295) = RCT(164)*V(69)
  B(296) = RCT(164)*V(51)
  B(297) = RCT(165)*V(69)
  B(298) = RCT(165)*V(52)
  B(299) = RCT(166)*V(69)
  B(300) = RCT(166)*V(46)
  B(301) = RCT(167)*V(69)
  B(302) = RCT(167)*V(68)
  B(303) = RCT(168)*V(69)
  B(304) = RCT(168)*V(68)
  B(305) = RCT(169)*V(69)
  B(306) = RCT(169)*V(65)
  B(307) = RCT(170)*V(69)
  B(308) = RCT(170)*V(65)
  B(309) = RCT(171)*V(69)
  B(310) = RCT(171)*V(67)
  B(311) = RCT(172)*V(69)
  B(312) = RCT(172)*V(61)
  B(313) = RCT(173)*V(69)
  B(314) = RCT(173)*V(62)
  B(315) = RCT(174)*2*V(72)
  B(316) = RCT(175)*V(72)
  B(317) = RCT(175)*V(66)
  B(318) = RCT(176)*V(73)
  B(319) = RCT(176)*V(72)
  B(320) = RCT(177)*V(72)
  B(321) = RCT(177)*V(49)
  B(322) = RCT(178)*V(72)
  B(323) = RCT(178)*V(50)
  B(324) = RCT(179)*V(72)
  B(325) = RCT(179)*V(41)
  B(326) = RCT(180)*V(72)
  B(327) = RCT(180)*V(43)
  B(328) = RCT(181)*V(72)
  B(329) = RCT(181)*V(44)
  B(330) = RCT(182)*V(72)
  B(331) = RCT(182)*V(54)
  B(332) = RCT(183)*V(72)
  B(333) = RCT(183)*V(53)
  B(334) = RCT(184)*V(72)
  B(335) = RCT(184)*V(48)
  B(336) = RCT(185)*V(72)
  B(337) = RCT(185)*V(51)
  B(338) = RCT(186)*V(72)
  B(339) = RCT(186)*V(52)
  B(340) = RCT(187)*V(72)
  B(341) = RCT(187)*V(46)
  B(342) = RCT(188)*V(72)
  B(343) = RCT(188)*V(68)
  B(344) = RCT(189)*V(72)
  B(345) = RCT(189)*V(68)
  B(346) = RCT(190)*V(72)
  B(347) = RCT(190)*V(65)
  B(348) = RCT(191)*V(72)
  B(349) = RCT(191)*V(65)
  B(350) = RCT(192)*V(72)
  B(351) = RCT(192)*V(67)
  B(352) = RCT(193)*V(72)
  B(353) = RCT(193)*V(61)
  B(354) = RCT(194)*V(72)
  B(355) = RCT(194)*V(62)
  B(356) = RCT(195)*V(68)
  B(357) = RCT(195)*V(66)
  B(358) = RCT(196)*V(73)
  B(359) = RCT(196)*V(68)
  B(360) = RCT(197)*V(68)
  B(361) = RCT(197)*V(49)
  B(362) = RCT(198)*V(68)
  B(363) = RCT(198)*V(50)
  B(364) = RCT(199)*V(68)
  B(365) = RCT(199)*V(41)
  B(366) = RCT(200)*V(68)
  B(367) = RCT(200)*V(43)
  B(368) = RCT(201)*V(68)
  B(369) = RCT(201)*V(44)
  B(370) = RCT(202)*V(68)
  B(371) = RCT(202)*V(54)
  B(372) = RCT(203)*V(68)
  B(373) = RCT(203)*V(53)
  B(374) = RCT(204)*V(68)
  B(375) = RCT(204)*V(48)
  B(376) = RCT(205)*V(68)
  B(377) = RCT(205)*V(51)
  B(378) = RCT(206)*V(68)
  B(379) = RCT(206)*V(52)
  B(380) = RCT(207)*V(68)
  B(381) = RCT(207)*V(46)
  B(382) = RCT(208)*2*V(68)
  B(383) = RCT(209)*V(68)
  B(384) = RCT(209)*V(65)
  B(385) = RCT(210)*V(68)
  B(386) = RCT(210)*V(67)
  B(387) = RCT(211)*V(68)
  B(388) = RCT(211)*V(61)
  B(389) = RCT(212)*V(68)
  B(390) = RCT(212)*V(62)
  B(391) = RCT(213)*2*V(61)
  B(392) = RCT(214)*V(62)
  B(393) = RCT(214)*V(61)
  B(394) = RCT(215)*2*V(62)
  B(395) = RCT(216)*V(74)
  B(396) = RCT(216)*V(72)
  B(397) = RCT(217)*V(74)
  B(398) = RCT(217)*V(66)
  B(399) = RCT(218)*V(74)
  B(400) = RCT(218)*V(73)
  B(401) = RCT(219)*V(74)
  B(402) = RCT(219)*V(49)
  B(403) = RCT(220)*V(74)
  B(404) = RCT(220)*V(50)
  B(405) = RCT(221)*V(74)
  B(406) = RCT(221)*V(41)
  B(407) = RCT(222)*V(74)
  B(408) = RCT(222)*V(43)
  B(409) = RCT(223)*V(74)
  B(410) = RCT(223)*V(44)
  B(411) = RCT(224)*V(74)
  B(412) = RCT(224)*V(54)
  B(413) = RCT(225)*V(74)
  B(414) = RCT(225)*V(53)
  B(415) = RCT(226)*V(74)
  B(416) = RCT(226)*V(48)
  B(417) = RCT(227)*V(74)
  B(418) = RCT(227)*V(51)
  B(419) = RCT(228)*V(74)
  B(420) = RCT(228)*V(52)
  B(421) = RCT(229)*V(74)
  B(422) = RCT(229)*V(46)
  B(423) = RCT(230)*V(74)
  B(424) = RCT(230)*V(68)
  B(425) = RCT(231)*V(74)
  B(426) = RCT(231)*V(65)
  B(427) = RCT(232)*V(74)
  B(428) = RCT(232)*V(67)
  B(429) = RCT(233)*V(74)
  B(430) = RCT(233)*V(61)
  B(431) = RCT(234)*V(74)
  B(432) = RCT(234)*V(62)
  B(433) = RCT(235)*V(69)
  B(434) = RCT(235)*V(57)
  B(435) = RCT(236)*V(72)
  B(436) = RCT(236)*V(57)
  B(437) = RCT(237)*V(68)
  B(438) = RCT(237)*V(57)
  B(439) = RCT(238)*2*V(57)
  B(440) = RCT(239)*V(77)
  B(441) = RCT(239)*V(57)
  B(442) = RCT(240)*V(74)
  B(443) = RCT(240)*V(57)
  B(444) = RCT(241)*V(75)
  B(445) = RCT(241)*V(35)
  B(446) = RCT(242)*V(75)
  B(447) = RCT(242)*V(29)
  B(448) = RCT(243)*V(69)
  B(449) = RCT(243)*V(29)
  B(450) = RCT(244)*V(69)
  B(451) = RCT(244)*V(35)
  B(452) = RCT(245)*V(76)
  B(453) = RCT(245)*V(18)
  B(454) = RCT(246)*V(77)
  B(455) = RCT(246)*V(29)
  B(456) = RCT(247)*2*V(29)
  B(457) = RCT(248)*2*V(29)
  B(458) = RCT(249)*V(63)
  B(459) = RCT(249)*V(35)
  JVS(1) = 0
  JVS(2) = B(89)
  JVS(3) = B(90)
  JVS(4) = 0
  JVS(5) = B(91)
  JVS(6) = B(92)
  JVS(7) = 0
  JVS(8) = 0.036*B(101)
  JVS(9) = 0.37*B(187)
  JVS(10) = 0.01*B(199)
  JVS(11) = 0.15*B(193)
  JVS(12) = 0.11*B(205)
  JVS(13) = 0.15*B(195)
  JVS(14) = 0.22*B(201)
  JVS(15) = 0.14*B(189)
  JVS(16) = 0.11*B(203)
  JVS(17) = 0.37*B(188)+0.14*B(190)+0.15*B(194)+0.15*B(196)+0.01*B(200)+0.22*B(202)+0.11*B(204)+0.11*B(206)
  JVS(18) = 0.036*B(102)
  JVS(19) = 0
  JVS(20) = 0.07*B(199)
  JVS(21) = 0.5*B(364)
  JVS(22) = 0.499*B(366)
  JVS(23) = 0.49*B(368)
  JVS(24) = 0.495*B(360)
  JVS(25) = 0.495*B(362)
  JVS(26) = 0.494*B(370)
  JVS(27) = 0.13*B(201)
  JVS(28) = 0.1*B(189)
  JVS(29) = 0.14*B(191)
  JVS(30) = 0.5*B(387)
  JVS(31) = 0.484*B(389)
  JVS(32) = 0.21*B(203)
  JVS(33) = B(307)+B(348)
  JVS(34) = 0.5*B(356)
  JVS(35) = 0.5*B(385)
  JVS(36) = B(303)+B(344)+0.5*B(357)+0.499*B(358)+0.495*B(361)+0.495*B(363)+0.5*B(365)+0.499*B(367)+0.49*B(369)+0.494&
              &*B(371)+0.5*B(386)+0.5*B(388)+0.484*B(390)
  JVS(37) = B(304)+B(308)
  JVS(38) = B(345)+B(349)
  JVS(39) = 0.499*B(359)
  JVS(40) = 0.1*B(190)+0.14*B(192)+0.07*B(200)+0.13*B(202)+0.21*B(204)
  JVS(41) = -B(25)
  JVS(42) = B(457)
  JVS(43) = -B(89)
  JVS(44) = -B(90)
  JVS(45) = -B(31)-B(33)-B(35)
  JVS(46) = B(2)
  JVS(47) = -B(85)
  JVS(48) = B(83)
  JVS(49) = B(84)
  JVS(50) = -B(103)
  JVS(51) = -B(104)
  JVS(52) = -B(121)
  JVS(53) = -B(122)
  JVS(54) = -B(123)
  JVS(55) = -B(124)
  JVS(56) = -B(24)
  JVS(57) = B(448)
  JVS(58) = B(449)
  JVS(59) = -B(105)
  JVS(60) = -B(106)
  JVS(61) = -B(101)
  JVS(62) = -B(102)
  JVS(63) = -B(99)
  JVS(64) = 0.03*B(189)
  JVS(65) = 0.06*B(191)
  JVS(66) = 0.03*B(190)+0.06*B(192)
  JVS(67) = -B(100)
  JVS(68) = -B(143)
  JVS(69) = 0.35*B(141)
  JVS(70) = 0.35*B(142)-B(144)
  JVS(71) = -B(97)
  JVS(72) = 0.06*B(189)
  JVS(73) = 0.07*B(191)
  JVS(74) = 0.06*B(190)+0.07*B(192)
  JVS(75) = -B(98)
  JVS(76) = -B(452)
  JVS(77) = B(450)+B(458)
  JVS(78) = B(459)
  JVS(79) = B(451)
  JVS(80) = -B(453)
  JVS(81) = -B(6)-B(64)-B(71)
  JVS(82) = B(62)
  JVS(83) = -B(72)
  JVS(84) = B(63)
  JVS(85) = -B(13)-B(145)
  JVS(86) = B(273)
  JVS(87) = B(274)
  JVS(88) = -B(146)
  JVS(89) = -B(4)-B(67)
  JVS(90) = B(211)
  JVS(91) = B(217)
  JVS(92) = B(223)
  JVS(93) = B(54)-B(68)
  JVS(94) = B(55)
  JVS(95) = B(212)+B(218)+B(224)
  JVS(96) = -B(9)-B(43)
  JVS(97) = 0.02*B(197)
  JVS(98) = 0.02*B(199)
  JVS(99) = 0.001*B(193)
  JVS(100) = 0.001*B(195)
  JVS(101) = 0.006*B(189)
  JVS(102) = 0.011*B(191)
  JVS(103) = B(45)+B(46)
  JVS(104) = 0.006*B(190)+0.011*B(192)+0.001*B(194)+0.001*B(196)+0.02*B(198)+0.02*B(200)
  JVS(105) = -B(44)
  JVS(106) = -B(207)-B(209)
  JVS(107) = 0.1*B(125)+B(169)
  JVS(108) = -B(210)
  JVS(109) = B(170)
  JVS(110) = 0.1*B(126)
  JVS(111) = -B(208)
  JVS(112) = 0.9*B(121)
  JVS(113) = -B(211)-B(213)-B(215)
  JVS(114) = -B(216)
  JVS(115) = 0.9*B(122)
  JVS(116) = -B(212)
  JVS(117) = 0.9*B(123)
  JVS(118) = -B(217)-B(219)-B(221)
  JVS(119) = -B(222)
  JVS(120) = 0.9*B(124)
  JVS(121) = -B(218)
  JVS(122) = 0.024*B(105)
  JVS(123) = -B(23)-B(133)
  JVS(124) = 0.6*B(153)
  JVS(125) = 0.41*B(139)
  JVS(126) = 0.3*B(350)
  JVS(127) = 0.3*B(351)
  JVS(128) = 0.024*B(106)-B(134)+0.41*B(140)+0.6*B(154)
  JVS(129) = -B(107)-B(171)-B(187)
  JVS(130) = -B(172)
  JVS(131) = -B(188)
  JVS(132) = -B(108)
  JVS(133) = -B(223)-B(225)-B(227)
  JVS(134) = 0.85*B(125)
  JVS(135) = -B(228)
  JVS(136) = 0.85*B(126)
  JVS(137) = -B(224)
  JVS(138) = -B(26)-B(446)-B(448)-B(454)-2*B(456)-2*B(457)
  JVS(139) = B(444)
  JVS(140) = -B(449)
  JVS(141) = B(445)-B(447)
  JVS(142) = -B(455)
  JVS(143) = -B(15)-B(149)
  JVS(144) = 0.11*B(203)
  JVS(145) = B(301)
  JVS(146) = B(302)
  JVS(147) = 0.11*B(204)
  JVS(148) = -B(150)
  JVS(149) = -B(5)-B(69)
  JVS(150) = B(169)
  JVS(151) = B(161)
  JVS(152) = B(163)
  JVS(153) = 0.2*B(165)
  JVS(154) = B(159)
  JVS(155) = B(157)
  JVS(156) = 0.5*B(167)
  JVS(157) = 0.3*B(65)
  JVS(158) = 0.3*B(66)+B(158)+B(160)+B(162)+B(164)+0.2*B(166)+0.5*B(168)+B(170)
  JVS(159) = B(56)-B(70)
  JVS(160) = B(57)
  JVS(161) = -B(151)-B(231)
  JVS(162) = 0.4*B(153)+0.4*B(185)+0.3*B(205)
  JVS(163) = B(229)
  JVS(164) = 0.4*B(186)
  JVS(165) = 0.3*B(206)
  JVS(166) = -B(152)+0.4*B(154)
  JVS(167) = B(230)
  JVS(168) = 0.036*B(101)
  JVS(169) = 0.43*B(187)
  JVS(170) = -B(91)
  JVS(171) = 0.14*B(197)
  JVS(172) = B(458)
  JVS(173) = 0.14*B(199)
  JVS(174) = 0.36*B(193)
  JVS(175) = 1.87*B(17)+1.55*B(18)+2*B(135)+2*B(161)
  JVS(176) = 0.13*B(205)
  JVS(177) = 0.01*B(93)+0.36*B(195)
  JVS(178) = B(19)+B(137)+B(163)
  JVS(179) = B(22)+0.41*B(139)+0.8*B(165)+0.54*B(201)
  JVS(180) = B(12)
  JVS(181) = 0.37*B(189)
  JVS(182) = 0.3*B(191)
  JVS(183) = B(10)+B(11)+B(127)+B(157)+B(459)
  JVS(184) = 0.66*B(203)
  JVS(185) = 0.01*B(94)
  JVS(186) = B(158)+2*B(162)+B(164)+0.8*B(166)
  JVS(187) = 0.43*B(188)+0.37*B(190)+0.3*B(192)+0.36*B(194)+0.36*B(196)+0.14*B(198)+0.14*B(200)+0.54*B(202)+0.66*B(204)&
               &+0.13*B(206)
  JVS(188) = -B(92)+0.036*B(102)+B(128)+2*B(136)+B(138)+0.41*B(140)
  JVS(189) = -B(117)-B(181)-B(197)
  JVS(190) = -B(182)
  JVS(191) = -B(198)
  JVS(192) = -B(118)
  JVS(193) = 2*B(25)
  JVS(194) = B(24)
  JVS(195) = B(452)
  JVS(196) = B(26)+B(446)+B(454)+2*B(456)
  JVS(197) = -B(444)-B(450)-B(458)
  JVS(198) = -B(459)
  JVS(199) = -B(451)
  JVS(200) = -B(445)+B(447)
  JVS(201) = B(453)
  JVS(202) = B(455)
  JVS(203) = -B(119)-B(183)-B(199)
  JVS(204) = -B(184)
  JVS(205) = -B(200)
  JVS(206) = -B(120)
  JVS(207) = -B(113)-B(177)-B(193)
  JVS(208) = -B(178)
  JVS(209) = -B(194)
  JVS(210) = -B(114)
  JVS(211) = 0.1*B(207)+B(209)
  JVS(212) = B(211)+0.02*B(213)+B(215)
  JVS(213) = B(217)+0.02*B(219)+B(221)
  JVS(214) = B(223)+0.02*B(225)+B(227)
  JVS(215) = -B(125)-B(169)
  JVS(216) = B(210)
  JVS(217) = -B(170)
  JVS(218) = B(216)+B(222)+B(228)
  JVS(219) = -B(126)
  JVS(220) = 0.1*B(208)+B(212)+B(218)+B(224)
  JVS(221) = 0.036*B(101)
  JVS(222) = -B(17)-B(18)-B(135)-B(161)
  JVS(223) = B(261)+B(340)+B(380)+B(421)
  JVS(224) = 1.2*B(257)+0.65*B(336)+0.65*B(376)+1.3*B(417)
  JVS(225) = 0.35*B(259)+0.37*B(338)+0.37*B(378)+0.74*B(419)
  JVS(226) = 0.15*B(141)+0.25*B(167)+0.5*B(203)
  JVS(227) = 0.1*B(358)+0.65*B(377)+0.37*B(379)+B(381)
  JVS(228) = 0.119*B(318)+0.65*B(337)+0.37*B(339)+B(341)
  JVS(229) = 0.063*B(239)+0.119*B(319)+0.1*B(359)+0.063*B(399)
  JVS(230) = -B(162)+0.25*B(168)+0.063*B(400)+1.3*B(418)+0.74*B(420)+B(422)
  JVS(231) = 0.5*B(204)
  JVS(232) = 0.036*B(102)-B(136)+0.15*B(142)
  JVS(233) = 0.063*B(240)+1.2*B(258)+0.35*B(260)+B(262)
  JVS(234) = -B(153)-B(185)-B(205)-B(234)
  JVS(235) = B(232)
  JVS(236) = -B(186)
  JVS(237) = -B(206)
  JVS(238) = -B(154)
  JVS(239) = B(233)
  JVS(240) = B(107)
  JVS(241) = -B(245)-B(283)-B(324)-B(364)-B(405)
  JVS(242) = -B(365)
  JVS(243) = -B(284)
  JVS(244) = -B(325)
  JVS(245) = -B(406)
  JVS(246) = 0
  JVS(247) = B(108)
  JVS(248) = -B(246)
  JVS(249) = -B(93)-B(115)-B(179)-B(195)
  JVS(250) = -B(94)
  JVS(251) = -B(180)
  JVS(252) = -B(196)
  JVS(253) = -B(116)
  JVS(254) = -B(247)-B(285)-B(326)-B(366)-B(407)
  JVS(255) = B(109)
  JVS(256) = -B(367)
  JVS(257) = -B(286)
  JVS(258) = -B(327)
  JVS(259) = -B(408)
  JVS(260) = B(110)
  JVS(261) = -B(248)
  JVS(262) = -B(249)-B(287)-B(328)-B(368)-B(409)
  JVS(263) = B(111)
  JVS(264) = -B(369)
  JVS(265) = -B(288)
  JVS(266) = -B(329)
  JVS(267) = -B(410)
  JVS(268) = B(112)
  JVS(269) = -B(250)
  JVS(270) = B(133)
  JVS(271) = 0
  JVS(272) = -B(19)-B(137)-B(163)
  JVS(273) = B(261)+B(340)+B(380)+B(421)
  JVS(274) = 0.65*B(257)+0.35*B(336)+0.35*B(376)+0.7*B(417)
  JVS(275) = 0.6*B(259)+0.63*B(338)+0.63*B(378)+1.26*B(419)
  JVS(276) = 0.08*B(139)+0.6*B(201)
  JVS(277) = 0.15*B(141)+0.25*B(167)+0.62*B(203)
  JVS(278) = 0
  JVS(279) = 0.54*B(267)+0.4*B(350)+0.54*B(385)+0.54*B(427)
  JVS(280) = 0.004*B(358)+0.35*B(377)+0.63*B(379)+B(381)+0.54*B(386)
  JVS(281) = 0.005*B(318)+0.35*B(337)+0.63*B(339)+B(341)+0.4*B(351)
  JVS(282) = 0.005*B(319)+0.004*B(359)
  JVS(283) = -B(164)+0.25*B(168)+0.7*B(418)+1.26*B(420)+B(422)+0.54*B(428)
  JVS(284) = 0.6*B(202)+0.62*B(204)
  JVS(285) = B(134)-B(138)+0.08*B(140)+0.15*B(142)
  JVS(286) = 0.65*B(258)+0.6*B(260)+B(262)+0.54*B(268)
  JVS(287) = 0
  JVS(288) = 0.98*B(225)
  JVS(289) = 0
  JVS(290) = -B(261)-B(299)-B(340)-B(380)-B(421)
  JVS(291) = -B(381)
  JVS(292) = -B(300)
  JVS(293) = -B(341)
  JVS(294) = -B(422)
  JVS(295) = 0
  JVS(296) = 0
  JVS(297) = -B(262)
  JVS(298) = 0
  JVS(299) = 0.25*B(103)
  JVS(300) = 0.12*B(143)
  JVS(301) = 0.53*B(197)
  JVS(302) = 0.06*B(247)+0.081*B(326)+0.141*B(366)+0.06*B(407)
  JVS(303) = 0.29*B(249)+0.313*B(328)+0.569*B(368)+0.29*B(409)
  JVS(304) = -B(16)-B(131)
  JVS(305) = 0.722*B(241)+0.24*B(320)+0.33*B(360)+0.828*B(401)
  JVS(306) = 0.642*B(243)+0.419*B(322)+0.581*B(362)+0.88*B(403)
  JVS(307) = 0.8*B(253)+B(332)+B(372)+B(413)
  JVS(308) = 0.8*B(21)
  JVS(309) = 0.03*B(189)
  JVS(310) = 0.16*B(191)
  JVS(311) = 0.149*B(392)
  JVS(312) = 0.464*B(271)+0.149*B(354)+0.167*B(389)+0.149*B(393)+0.285*B(394)+0.469*B(431)
  JVS(313) = 0.03*B(167)
  JVS(314) = 0.11*B(385)
  JVS(315) = 0.127*B(358)+0.33*B(361)+0.581*B(363)+0.141*B(367)+0.569*B(369)+B(373)+0.11*B(386)+0.167*B(390)
  JVS(316) = 0
  JVS(317) = 0.41*B(147)
  JVS(318) = 0.018*B(318)+0.24*B(321)+0.419*B(323)+0.081*B(327)+0.313*B(329)+B(333)+0.149*B(355)
  JVS(319) = 0.623*B(239)+0.018*B(319)+0.127*B(359)+0.67*B(399)
  JVS(320) = 0.03*B(168)+0.67*B(400)+0.828*B(402)+0.88*B(404)+0.06*B(408)+0.29*B(410)+B(414)+0.469*B(432)
  JVS(321) = 0.03*B(190)+0.16*B(192)+0.53*B(198)
  JVS(322) = 0.25*B(104)-B(132)+0.12*B(144)+0.41*B(148)
  JVS(323) = 0.623*B(240)+0.722*B(242)+0.642*B(244)+0.06*B(248)+0.29*B(250)+0.8*B(254)+0.464*B(272)
  JVS(324) = B(119)
  JVS(325) = -B(255)-B(293)-B(334)-B(374)-B(415)
  JVS(326) = -B(375)
  JVS(327) = -B(294)
  JVS(328) = -B(335)
  JVS(329) = -B(416)
  JVS(330) = 0
  JVS(331) = B(120)
  JVS(332) = -B(256)
  JVS(333) = 0.75*B(103)
  JVS(334) = -B(241)-B(279)-B(320)-B(360)-B(401)
  JVS(335) = -B(361)
  JVS(336) = -B(280)
  JVS(337) = -B(321)
  JVS(338) = -B(402)
  JVS(339) = 0.75*B(104)
  JVS(340) = -B(242)
  JVS(341) = 0.9511*B(105)
  JVS(342) = -B(243)-B(281)-B(322)-B(362)-B(403)
  JVS(343) = -B(363)
  JVS(344) = -B(282)
  JVS(345) = -B(323)
  JVS(346) = -B(404)
  JVS(347) = 0.9511*B(106)
  JVS(348) = -B(244)
  JVS(349) = 0.98*B(213)
  JVS(350) = -B(257)-B(295)-B(336)-B(376)-B(417)
  JVS(351) = -B(377)
  JVS(352) = -B(296)
  JVS(353) = -B(337)
  JVS(354) = -B(418)
  JVS(355) = 0
  JVS(356) = 0
  JVS(357) = -B(258)
  JVS(358) = 0
  JVS(359) = 0.98*B(219)
  JVS(360) = -B(259)-B(297)-B(338)-B(378)-B(419)
  JVS(361) = -B(379)
  JVS(362) = -B(298)
  JVS(363) = -B(339)
  JVS(364) = -B(420)
  JVS(365) = 0
  JVS(366) = 0
  JVS(367) = -B(260)
  JVS(368) = 0
  JVS(369) = B(117)
  JVS(370) = -B(253)-B(291)-B(332)-B(372)-B(413)
  JVS(371) = -B(373)
  JVS(372) = -B(292)
  JVS(373) = -B(333)
  JVS(374) = -B(414)
  JVS(375) = 0
  JVS(376) = B(118)
  JVS(377) = -B(254)
  JVS(378) = B(113)
  JVS(379) = B(115)
  JVS(380) = -B(251)-B(289)-B(330)-B(370)-B(411)
  JVS(381) = -B(371)
  JVS(382) = -B(290)
  JVS(383) = 0
  JVS(384) = -B(331)
  JVS(385) = -B(412)
  JVS(386) = 0
  JVS(387) = B(114)+B(116)
  JVS(388) = -B(252)
  JVS(389) = B(207)
  JVS(390) = 0
  JVS(391) = 0.6*B(185)
  JVS(392) = 0.35*B(255)
  JVS(393) = 0.124*B(241)
  JVS(394) = 0.261*B(243)
  JVS(395) = 0.05*B(257)
  JVS(396) = 0.05*B(259)
  JVS(397) = 0.2*B(253)
  JVS(398) = 0.153*B(251)
  JVS(399) = -B(21)-B(155)
  JVS(400) = B(269)+B(311)+B(352)+B(387)+2*B(391)+1.5*B(392)+B(429)
  JVS(401) = B(313)+0.5*B(354)+0.484*B(389)+1.5*B(393)+B(394)
  JVS(402) = 0
  JVS(403) = B(388)+0.484*B(390)
  JVS(404) = B(312)+B(314)
  JVS(405) = 0
  JVS(406) = B(353)+0.5*B(355)
  JVS(407) = 0.059*B(239)
  JVS(408) = 0.6*B(186)+B(430)
  JVS(409) = 0
  JVS(410) = -B(156)
  JVS(411) = 0.059*B(240)+0.124*B(242)+0.261*B(244)+0.153*B(252)+0.2*B(254)+0.35*B(256)+0.05*B(258)+0.05*B(260)+B(270)
  JVS(412) = B(208)
  JVS(413) = 0.79*B(199)
  JVS(414) = 0.9*B(177)+0.39*B(193)
  JVS(415) = 0.9*B(179)+0.39*B(195)
  JVS(416) = 0.4*B(255)+0.6*B(334)+0.6*B(374)+0.6*B(415)
  JVS(417) = 0.446*B(251)+0.55*B(330)+0.771*B(370)+0.6*B(411)
  JVS(418) = -B(22)-B(95)-B(139)-B(165)-B(201)
  JVS(419) = 0.771*B(371)+0.6*B(375)
  JVS(420) = 0
  JVS(421) = -B(96)
  JVS(422) = 0.55*B(331)+0.6*B(335)
  JVS(423) = -B(166)+0.9*B(178)+0.9*B(180)+0.6*B(412)+0.6*B(416)
  JVS(424) = 0.39*B(194)+0.39*B(196)+0.79*B(200)-B(202)
  JVS(425) = -B(140)
  JVS(426) = 0.446*B(252)+0.4*B(256)
  JVS(427) = 0.1*B(121)
  JVS(428) = 0.1*B(123)
  JVS(429) = 0.35*B(149)
  JVS(430) = B(151)
  JVS(431) = 0.13*B(193)
  JVS(432) = 0.05*B(125)
  JVS(433) = B(153)+B(185)
  JVS(434) = 0.15*B(93)+0.13*B(195)
  JVS(435) = 0.334*B(241)+0.245*B(320)+0.237*B(360)+0.391*B(401)
  JVS(436) = 0.416*B(243)+0.322*B(322)+0.318*B(362)+0.587*B(403)
  JVS(437) = 0.49*B(139)
  JVS(438) = -B(433)-B(435)-B(437)-2*B(439)-B(440)-B(442)
  JVS(439) = 0.5*B(141)+0.5*B(167)
  JVS(440) = 0
  JVS(441) = 0.16*B(267)+0.08*B(350)+0.08*B(385)+0.16*B(427)
  JVS(442) = 0.071*B(358)+0.237*B(361)+0.318*B(363)+0.08*B(386)-B(438)
  JVS(443) = -B(434)
  JVS(444) = 0.07*B(147)
  JVS(445) = 0.15*B(94)
  JVS(446) = 0.085*B(318)+0.245*B(321)+0.322*B(323)+0.08*B(351)-B(436)
  JVS(447) = 0.048*B(239)+0.085*B(319)+0.071*B(359)+0.051*B(399)
  JVS(448) = 0.5*B(168)+B(186)+0.051*B(400)+0.391*B(402)+0.587*B(404)+0.16*B(428)-B(443)
  JVS(449) = 0.13*B(194)+0.13*B(196)
  JVS(450) = 0.1*B(122)+0.1*B(124)+0.05*B(126)+0.49*B(140)+0.5*B(142)+0.07*B(148)+0.35*B(150)+B(152)+B(154)
  JVS(451) = 0.048*B(240)+0.334*B(242)+0.416*B(244)+0.16*B(268)-B(441)
  JVS(452) = 0
  JVS(453) = 0.025*B(105)
  JVS(454) = 0.335*B(101)
  JVS(455) = 0.88*B(143)
  JVS(456) = 0.65*B(197)
  JVS(457) = 0.2*B(245)+0.35*B(324)+0.6*B(364)+0.2*B(405)
  JVS(458) = 0.94*B(247)+0.669*B(326)+0.859*B(366)+0.94*B(407)
  JVS(459) = 1.71*B(249)+0.932*B(328)+0.941*B(368)+1.71*B(409)
  JVS(460) = 0.211*B(241)+0.523*B(320)+0.677*B(360)+0.239*B(401)
  JVS(461) = 0.15*B(243)+0.411*B(322)+0.497*B(362)+0.187*B(403)
  JVS(462) = 0.8*B(253)+B(332)+B(372)+B(413)
  JVS(463) = 0.2*B(21)
  JVS(464) = B(95)
  JVS(465) = -B(12)-B(129)-B(159)
  JVS(466) = 0.44*B(189)
  JVS(467) = 0.99*B(191)
  JVS(468) = 0.64*B(392)
  JVS(469) = 1.24*B(271)+0.64*B(354)+0.65*B(389)+0.64*B(393)+1.21*B(394)+1.24*B(431)
  JVS(470) = 0.25*B(167)+0.16*B(203)
  JVS(471) = 0
  JVS(472) = B(237)+0.75*B(316)+B(356)+B(397)
  JVS(473) = 0.46*B(267)+0.3*B(350)+0.35*B(385)+0.46*B(427)
  JVS(474) = B(357)+0.724*B(358)+0.677*B(361)+0.497*B(363)+0.6*B(365)+0.859*B(367)+0.941*B(369)+B(373)+0.35*B(386)+0.65&
               &*B(390)
  JVS(475) = 0
  JVS(476) = B(14)+0.08*B(147)
  JVS(477) = B(96)
  JVS(478) = 0.75*B(317)+0.58*B(318)+0.523*B(321)+0.411*B(323)+0.35*B(325)+0.669*B(327)+0.932*B(329)+B(333)+0.3*B(351)&
               &+0.64*B(355)
  JVS(479) = 0.233*B(239)+0.58*B(319)+0.724*B(359)+0.243*B(399)
  JVS(480) = -B(160)+0.25*B(168)+B(398)+0.243*B(400)+0.239*B(402)+0.187*B(404)+0.2*B(406)+0.94*B(408)+1.71*B(410)+B(414)&
               &+0.46*B(428)+1.24*B(432)
  JVS(481) = 0.44*B(190)+0.99*B(192)+0.65*B(198)+0.16*B(204)
  JVS(482) = 0.335*B(102)+0.025*B(106)-B(130)+0.88*B(144)+0.08*B(148)
  JVS(483) = B(238)+0.233*B(240)+0.211*B(242)+0.15*B(244)+0.2*B(246)+0.94*B(248)+1.71*B(250)+0.8*B(254)+0.46*B(268)+1.24&
               &*B(272)
  JVS(484) = 0
  JVS(485) = 0.46*B(199)
  JVS(486) = 0.35*B(193)
  JVS(487) = 0.86*B(93)+0.35*B(195)
  JVS(488) = 0.354*B(251)+0.37*B(330)+0.229*B(370)+0.4*B(411)
  JVS(489) = -B(109)-B(173)-B(189)
  JVS(490) = 0.229*B(371)
  JVS(491) = 0
  JVS(492) = 0.86*B(94)
  JVS(493) = 0.37*B(331)
  JVS(494) = -B(174)+0.4*B(412)
  JVS(495) = -B(190)+0.35*B(194)+0.35*B(196)+0.46*B(200)
  JVS(496) = -B(110)
  JVS(497) = 0.354*B(252)
  JVS(498) = 0.25*B(255)+0.4*B(334)+0.4*B(374)+0.4*B(415)
  JVS(499) = 0.08*B(330)
  JVS(500) = -B(111)-B(175)-B(191)
  JVS(501) = 0.4*B(375)
  JVS(502) = 0
  JVS(503) = 0
  JVS(504) = 0.08*B(331)+0.4*B(335)
  JVS(505) = -B(176)+0.4*B(416)
  JVS(506) = -B(192)
  JVS(507) = -B(112)
  JVS(508) = 0.25*B(256)
  JVS(509) = 0.8*B(171)
  JVS(510) = 0.1*B(181)
  JVS(511) = 0.13*B(183)
  JVS(512) = 0.9*B(177)
  JVS(513) = 0.9*B(179)
  JVS(514) = 0.8*B(165)
  JVS(515) = 0.43*B(173)
  JVS(516) = 0.11*B(175)
  JVS(517) = -B(269)-B(311)-B(352)-B(387)-2*B(391)-B(392)-B(429)
  JVS(518) = -B(393)
  JVS(519) = -B(388)
  JVS(520) = -B(312)
  JVS(521) = 0
  JVS(522) = -B(353)
  JVS(523) = 0.8*B(166)+0.8*B(172)+0.43*B(174)+0.11*B(176)+0.9*B(178)+0.9*B(180)+0.1*B(182)+0.13*B(184)-B(430)
  JVS(524) = 0
  JVS(525) = 0
  JVS(526) = -B(270)
  JVS(527) = 0.2*B(171)
  JVS(528) = 0.9*B(181)
  JVS(529) = 0.87*B(183)
  JVS(530) = 0.1*B(177)
  JVS(531) = 0.1*B(179)
  JVS(532) = 0.57*B(173)
  JVS(533) = 0.89*B(175)
  JVS(534) = -B(392)
  JVS(535) = -B(271)-B(313)-B(354)-B(389)-B(393)-2*B(394)-B(431)
  JVS(536) = -B(390)
  JVS(537) = -B(314)
  JVS(538) = 0
  JVS(539) = -B(355)
  JVS(540) = 0.2*B(172)+0.57*B(174)+0.89*B(176)+0.1*B(178)+0.1*B(180)+0.9*B(182)+0.87*B(184)-B(432)
  JVS(541) = 0
  JVS(542) = 0
  JVS(543) = -B(272)
  JVS(544) = 0.01*B(101)
  JVS(545) = B(13)+0.35*B(145)
  JVS(546) = B(23)
  JVS(547) = B(187)
  JVS(548) = 0.35*B(149)
  JVS(549) = B(151)
  JVS(550) = -B(458)
  JVS(551) = 0.04*B(199)
  JVS(552) = 0.9*B(193)
  JVS(553) = 0.13*B(17)+0.45*B(18)
  JVS(554) = 0.4*B(153)+0.4*B(185)+0.7*B(205)
  JVS(555) = 1.6*B(245)+1.55*B(324)+0.8*B(364)+1.6*B(405)
  JVS(556) = 0.05*B(93)+0.9*B(195)
  JVS(557) = B(247)+1.25*B(326)+0.501*B(366)+B(407)
  JVS(558) = 0.755*B(328)
  JVS(559) = B(340)
  JVS(560) = 0.25*B(255)+1.4*B(334)+0.4*B(374)+0.4*B(415)
  JVS(561) = 0.021*B(241)+0.829*B(320)+0.076*B(360)+0.021*B(401)
  JVS(562) = 0.753*B(322)
  JVS(563) = B(336)
  JVS(564) = B(338)
  JVS(565) = B(332)
  JVS(566) = 0.606*B(251)+1.09*B(330)+0.34*B(370)+0.686*B(411)
  JVS(567) = B(22)+0.08*B(139)+0.4*B(201)
  JVS(568) = B(435)
  JVS(569) = 0.64*B(189)
  JVS(570) = 0.02*B(191)
  JVS(571) = 0.75*B(352)+0.202*B(392)
  JVS(572) = 0.287*B(271)+0.96*B(354)+0.207*B(389)+0.202*B(393)+0.504*B(394)+0.28*B(431)
  JVS(573) = -B(10)-B(11)-B(127)-B(157)-B(459)
  JVS(574) = 0
  JVS(575) = B(265)+2*B(346)+B(348)+B(383)+B(425)
  JVS(576) = 0.75*B(316)
  JVS(577) = 0.75*B(350)
  JVS(578) = B(342)+B(344)+0.091*B(358)+0.076*B(361)+0.8*B(365)+0.501*B(367)+0.34*B(371)+0.4*B(375)+B(384)+0.207*B(390)
  JVS(579) = 0
  JVS(580) = 0
  JVS(581) = 0.05*B(94)
  JVS(582) = B(235)+1.33*B(315)+0.75*B(317)+0.81*B(318)+0.829*B(321)+0.753*B(323)+1.55*B(325)+1.25*B(327)+0.755*B(329)&
               &+1.09*B(331)+B(333)+1.4*B(335)+B(337)+B(339)+B(341)+B(343)+B(345)+2*B(347)+B(349)+0.75*B(351)+0.75*B(353)&
               &+0.96*B(355)+B(395)+B(436)
  JVS(583) = 0.047*B(239)+0.81*B(319)+0.091*B(359)+0.048*B(399)
  JVS(584) = -B(158)+0.4*B(186)+B(396)+0.048*B(400)+0.021*B(402)+1.6*B(406)+B(408)+0.686*B(412)+0.4*B(416)+B(426)+0.28&
               &*B(432)
  JVS(585) = B(188)+0.64*B(190)+0.02*B(192)+0.9*B(194)+0.9*B(196)+0.04*B(200)+0.4*B(202)+0.7*B(206)
  JVS(586) = 0.01*B(102)-B(128)+0.08*B(140)+0.35*B(146)+0.35*B(150)+B(152)+0.4*B(154)
  JVS(587) = B(236)+0.047*B(240)+0.021*B(242)+1.6*B(246)+B(248)+0.606*B(252)+0.25*B(256)+B(266)+0.287*B(272)
  JVS(588) = 0
  JVS(589) = 0.13*B(93)
  JVS(590) = 0.5*B(257)+B(336)+B(376)+0.5*B(417)
  JVS(591) = 0.95*B(259)+B(338)+B(378)+B(419)
  JVS(592) = -B(20)-B(141)-B(167)-B(203)
  JVS(593) = B(377)+B(379)
  JVS(594) = 0
  JVS(595) = 0.13*B(94)
  JVS(596) = B(337)+B(339)
  JVS(597) = -B(168)+0.5*B(418)+B(420)
  JVS(598) = -B(204)
  JVS(599) = -B(142)
  JVS(600) = 0.5*B(258)+0.95*B(260)
  JVS(601) = 0
  JVS(602) = B(234)
  JVS(603) = 0.51*B(139)+0.2*B(165)
  JVS(604) = B(20)+0.5*B(141)+0.5*B(167)
  JVS(605) = -B(232)-B(265)-B(305)-B(307)-B(346)-B(348)-B(383)-B(425)
  JVS(606) = -B(384)
  JVS(607) = -B(306)-B(308)
  JVS(608) = 0
  JVS(609) = -B(347)-B(349)
  JVS(610) = 0.2*B(166)+0.5*B(168)-B(426)
  JVS(611) = 0
  JVS(612) = 0.51*B(140)+0.5*B(142)
  JVS(613) = -B(266)
  JVS(614) = -B(233)
  JVS(615) = B(99)
  JVS(616) = 0.2*B(197)
  JVS(617) = 0.16*B(199)
  JVS(618) = B(16)
  JVS(619) = 0.245*B(241)+0.014*B(320)+0.018*B(360)+0.262*B(401)
  JVS(620) = 0.133*B(243)+0.013*B(322)+0.015*B(362)+0.155*B(403)
  JVS(621) = 0
  JVS(622) = 0
  JVS(623) = 0.1*B(189)
  JVS(624) = 0.18*B(191)
  JVS(625) = 0
  JVS(626) = 0
  JVS(627) = 0
  JVS(628) = 0
  JVS(629) = -B(237)-B(275)-B(316)-B(356)-B(397)
  JVS(630) = 0
  JVS(631) = -B(357)+0.006*B(358)+0.018*B(361)+0.015*B(363)
  JVS(632) = -B(276)
  JVS(633) = 0
  JVS(634) = 0
  JVS(635) = -B(317)+0.014*B(321)+0.013*B(323)
  JVS(636) = 0.048*B(239)+0.006*B(359)+0.053*B(399)
  JVS(637) = -B(398)+0.053*B(400)+0.262*B(402)+0.155*B(404)
  JVS(638) = 0.1*B(190)+0.18*B(192)+0.2*B(198)+0.16*B(200)
  JVS(639) = B(100)
  JVS(640) = -B(238)+0.048*B(240)+0.245*B(242)+0.133*B(244)
  JVS(641) = 0
  JVS(642) = 0.42*B(197)
  JVS(643) = 0.42*B(199)
  JVS(644) = 0.02*B(193)
  JVS(645) = 0.02*B(195)
  JVS(646) = B(131)
  JVS(647) = 0
  JVS(648) = 0
  JVS(649) = 0
  JVS(650) = 0
  JVS(651) = 0.03*B(189)
  JVS(652) = 0.12*B(191)
  JVS(653) = 0
  JVS(654) = 0
  JVS(655) = 0
  JVS(656) = 0
  JVS(657) = -B(267)-B(309)-B(350)-B(385)-B(427)
  JVS(658) = -B(386)
  JVS(659) = -B(310)
  JVS(660) = 0
  JVS(661) = 0
  JVS(662) = -B(351)
  JVS(663) = 0
  JVS(664) = -B(428)
  JVS(665) = 0.03*B(190)+0.12*B(192)+0.02*B(194)+0.02*B(196)+0.42*B(198)+0.42*B(200)
  JVS(666) = B(132)
  JVS(667) = -B(268)
  JVS(668) = 0
  JVS(669) = B(23)
  JVS(670) = 0.65*B(149)
  JVS(671) = B(231)
  JVS(672) = 0.15*B(193)
  JVS(673) = 0.7*B(205)
  JVS(674) = -B(364)
  JVS(675) = 0.15*B(195)
  JVS(676) = -B(366)
  JVS(677) = -B(368)
  JVS(678) = B(19)+B(137)+B(163)
  JVS(679) = -B(380)
  JVS(680) = B(16)
  JVS(681) = -B(374)
  JVS(682) = -B(360)
  JVS(683) = -B(362)
  JVS(684) = -B(376)
  JVS(685) = -B(378)
  JVS(686) = -B(372)
  JVS(687) = -B(370)
  JVS(688) = 0
  JVS(689) = B(22)+0.13*B(201)
  JVS(690) = -B(437)
  JVS(691) = B(129)+B(159)
  JVS(692) = 0
  JVS(693) = 0
  JVS(694) = -B(387)
  JVS(695) = -B(389)
  JVS(696) = 0.28*B(203)
  JVS(697) = B(265)+B(346)+B(425)
  JVS(698) = -B(356)
  JVS(699) = 0.23*B(267)+0.12*B(350)-0.88*B(385)+0.23*B(427)
  JVS(700) = -B(229)-B(263)-B(301)-B(303)-B(342)-B(344)-B(357)-B(358)-B(361)-B(363)-B(365)-B(367)-B(369)-B(371)-B(373)&
               &-B(375)-B(377)-B(379)-B(381)-2*B(382)-0.88*B(386)-B(388)-B(390)-B(423)-B(438)
  JVS(701) = -B(302)-B(304)
  JVS(702) = 0
  JVS(703) = 0
  JVS(704) = -B(343)-B(345)+B(347)+0.12*B(351)
  JVS(705) = -B(359)
  JVS(706) = B(160)+B(164)-B(424)+B(426)+0.23*B(428)
  JVS(707) = 0.15*B(194)+0.15*B(196)+0.13*B(202)+0.28*B(204)+0.7*B(206)
  JVS(708) = B(130)+B(138)+0.65*B(150)
  JVS(709) = -B(264)+B(266)+0.23*B(268)
  JVS(710) = -B(230)
  JVS(711) = B(89)
  JVS(712) = 0.25*B(103)
  JVS(713) = 0.1*B(121)
  JVS(714) = 0.1*B(123)
  JVS(715) = 0.049*B(105)
  JVS(716) = 0.381*B(101)
  JVS(717) = B(143)
  JVS(718) = 0.65*B(6)+B(64)
  JVS(719) = B(13)
  JVS(720) = B(43)
  JVS(721) = -B(209)
  JVS(722) = 0.02*B(213)
  JVS(723) = 0.02*B(219)
  JVS(724) = B(23)+B(133)
  JVS(725) = 0.26*B(187)
  JVS(726) = 0.02*B(225)
  JVS(727) = -B(448)
  JVS(728) = 0.35*B(149)
  JVS(729) = B(91)
  JVS(730) = 0.1*B(197)
  JVS(731) = -B(450)+B(458)
  JVS(732) = 0.1*B(199)
  JVS(733) = 0.3*B(193)
  JVS(734) = 0.05*B(125)
  JVS(735) = 0.8*B(18)+B(135)+B(161)
  JVS(736) = 0.4*B(153)+0.08*B(205)
  JVS(737) = B(245)-B(283)+B(324)+0.5*B(364)+B(405)
  JVS(738) = 0.28*B(93)+0.3*B(195)
  JVS(739) = B(247)-B(285)+B(326)+0.501*B(366)+B(407)
  JVS(740) = B(249)-B(287)+B(328)+0.51*B(368)+B(409)
  JVS(741) = B(19)
  JVS(742) = B(261)-B(299)+2*B(340)+B(380)+B(421)
  JVS(743) = 0.65*B(255)-B(293)+2*B(334)+B(374)+B(415)
  JVS(744) = 0.599*B(241)-B(279)+0.946*B(320)+0.438*B(360)+0.699*B(401)
  JVS(745) = 0.606*B(243)-B(281)+0.993*B(322)+0.489*B(362)+0.845*B(403)
  JVS(746) = 0.95*B(257)-B(295)+B(336)+B(376)+B(417)
  JVS(747) = 0.95*B(259)-B(297)+B(338)+B(378)+B(419)
  JVS(748) = 0.8*B(253)-B(291)+2*B(332)+B(372)+B(413)
  JVS(749) = 0.847*B(251)-B(289)+B(330)+0.506*B(370)+B(411)
  JVS(750) = B(21)
  JVS(751) = B(22)+0.49*B(139)+0.29*B(201)
  JVS(752) = -B(433)+B(435)
  JVS(753) = B(12)
  JVS(754) = 0.25*B(189)
  JVS(755) = 0.22*B(191)
  JVS(756) = B(269)-B(311)+B(352)+0.5*B(387)+B(391)+0.5*B(392)+B(429)
  JVS(757) = -B(313)+0.5*B(354)+0.5*B(393)
  JVS(758) = 2*B(11)+B(127)+B(157)+B(459)
  JVS(759) = B(20)+0.5*B(141)+0.5*B(167)+0.29*B(203)
  JVS(760) = -B(305)-B(307)+B(346)
  JVS(761) = B(237)-B(275)+B(316)+0.5*B(356)+B(397)
  JVS(762) = 0.77*B(267)-B(309)+0.88*B(350)+0.38*B(385)+0.77*B(427)
  JVS(763) = -B(301)-B(303)+B(342)+0.5*B(357)+0.488*B(358)+0.438*B(361)+0.489*B(363)+0.5*B(365)+0.501*B(367)+0.51*B(369)&
               &+0.506*B(371)+B(373)+B(375)+B(377)+B(379)+B(381)+0.38*B(386)+0.5*B(388)
  JVS(764) = -B(39)-B(41)-2*B(45)-2*B(46)-B(60)-B(62)-B(65)-B(210)-B(273)-B(276)-B(277)-B(280)-B(282)-B(284)-B(286)&
               &-B(288)-B(290)-B(292)-B(294)-B(296)-B(298)-B(300)-B(302)-B(304)-B(306)-B(308)-B(310)-B(312)-B(314)-B(434)&
               &-B(449)-B(451)
  JVS(765) = B(14)
  JVS(766) = 0.28*B(94)
  JVS(767) = B(235)-B(274)+0.66*B(315)+B(317)+0.992*B(318)+0.946*B(321)+0.993*B(323)+B(325)+B(327)+B(329)+B(331)+2&
               &*B(333)+2*B(335)+B(337)+B(339)+2*B(341)+B(343)+B(347)+0.88*B(351)+B(353)+0.5*B(355)+B(395)+B(436)
  JVS(768) = 0.742*B(239)-B(278)+0.992*B(319)+0.488*B(359)+0.792*B(399)
  JVS(769) = B(58)-B(66)+B(158)+B(162)+0.5*B(168)+B(396)+B(398)+0.792*B(400)+0.699*B(402)+0.845*B(404)+B(406)+B(408)&
               &+B(410)+B(412)+B(414)+B(416)+B(418)+B(420)+B(422)+0.77*B(428)+B(430)
  JVS(770) = B(37)-B(40)+0.26*B(188)+0.25*B(190)+0.22*B(192)+0.3*B(194)+0.3*B(196)+0.1*B(198)+0.1*B(200)+0.29*B(202)&
               &+0.29*B(204)+0.08*B(206)
  JVS(771) = B(38)-B(42)+B(44)+B(59)+B(87)+B(90)+B(92)+0.381*B(102)+0.25*B(104)+0.049*B(106)+0.1*B(122)+0.1*B(124)+0.05&
               &*B(126)+B(128)+B(134)+B(136)+0.49*B(140)+0.5*B(142)+B(144)+0.35*B(150)+0.4*B(154)
  JVS(772) = -B(61)+B(236)+B(238)+0.742*B(240)+0.599*B(242)+0.606*B(244)+B(246)+B(248)+B(250)+0.847*B(252)+0.8*B(254)&
               &+0.65*B(256)+0.95*B(258)+0.95*B(260)+B(262)+0.77*B(268)+B(270)
  JVS(773) = -B(63)
  JVS(774) = B(283)
  JVS(775) = B(285)
  JVS(776) = B(287)
  JVS(777) = B(299)
  JVS(778) = B(293)
  JVS(779) = B(279)
  JVS(780) = B(281)
  JVS(781) = B(295)
  JVS(782) = B(297)
  JVS(783) = B(291)
  JVS(784) = B(289)
  JVS(785) = 0.13*B(201)
  JVS(786) = B(433)
  JVS(787) = 0
  JVS(788) = 0
  JVS(789) = 0
  JVS(790) = B(305)
  JVS(791) = B(275)
  JVS(792) = B(309)
  JVS(793) = 0
  JVS(794) = B(276)+B(277)+B(280)+B(282)+B(284)+B(286)+B(288)+B(290)+B(292)+B(294)+B(296)+B(298)+B(300)+B(306)+B(310)&
               &+B(434)
  JVS(795) = -B(14)-B(147)
  JVS(796) = 0
  JVS(797) = 0
  JVS(798) = B(278)
  JVS(799) = 0
  JVS(800) = 0.13*B(202)
  JVS(801) = -B(148)
  JVS(802) = 0
  JVS(803) = 0
  JVS(804) = B(33)
  JVS(805) = B(26)
  JVS(806) = 0
  JVS(807) = 0.09*B(193)
  JVS(808) = -B(93)+0.09*B(195)
  JVS(809) = -B(95)
  JVS(810) = 0
  JVS(811) = 0
  JVS(812) = 0
  JVS(813) = 0
  JVS(814) = 0
  JVS(815) = 0
  JVS(816) = 0
  JVS(817) = 0
  JVS(818) = -B(27)-B(29)-B(48)-B(50)-B(52)-B(94)-B(96)
  JVS(819) = 0
  JVS(820) = 0
  JVS(821) = B(8)
  JVS(822) = B(3)-B(30)+0.09*B(194)+0.09*B(196)
  JVS(823) = 0
  JVS(824) = -B(49)
  JVS(825) = B(1)-B(51)-B(53)
  JVS(826) = B(97)
  JVS(827) = 0.65*B(145)
  JVS(828) = B(15)
  JVS(829) = 0.03*B(193)
  JVS(830) = -B(324)+0.5*B(364)
  JVS(831) = 0.03*B(195)
  JVS(832) = -B(326)+0.501*B(366)
  JVS(833) = -B(328)+0.51*B(368)
  JVS(834) = -B(340)+B(380)
  JVS(835) = -B(334)+B(374)
  JVS(836) = 0.031*B(241)-0.951*B(320)+0.554*B(360)+0.04*B(401)
  JVS(837) = -B(322)+0.507*B(362)
  JVS(838) = -B(336)+B(376)
  JVS(839) = -B(338)+B(378)
  JVS(840) = -B(332)+B(372)
  JVS(841) = -B(330)+0.506*B(370)
  JVS(842) = -B(435)+B(437)
  JVS(843) = B(12)
  JVS(844) = 0.19*B(189)
  JVS(845) = 0.23*B(191)
  JVS(846) = -B(352)+0.5*B(387)
  JVS(847) = -B(354)+0.516*B(389)
  JVS(848) = 0
  JVS(849) = -B(346)-B(348)+B(383)
  JVS(850) = -B(316)+0.5*B(356)
  JVS(851) = -B(350)+0.5*B(385)
  JVS(852) = B(263)-B(344)+0.5*B(357)+0.508*B(358)+0.554*B(361)+0.507*B(363)+0.5*B(365)+0.501*B(367)+0.51*B(369)+0.506&
               &*B(371)+B(373)+B(375)+B(377)+B(379)+B(381)+2*B(382)+B(384)+0.5*B(386)+0.5*B(388)+0.516*B(390)+B(423)+B(438)
  JVS(853) = -B(273)
  JVS(854) = 0
  JVS(855) = 0
  JVS(856) = -B(235)-B(274)-2*B(315)-B(317)-0.993*B(318)-0.951*B(321)-B(323)-B(325)-B(327)-B(329)-B(331)-B(333)-B(335)&
               &-B(337)-B(339)-B(341)-B(345)-B(347)-B(349)-B(351)-B(353)-B(355)-B(395)-B(436)
  JVS(857) = 0.15*B(239)-0.993*B(319)+0.508*B(359)+0.155*B(399)
  JVS(858) = -B(396)+0.155*B(400)+0.04*B(402)+B(424)
  JVS(859) = 0.19*B(190)+0.23*B(192)+0.03*B(194)+0.03*B(196)
  JVS(860) = B(98)+0.65*B(146)
  JVS(861) = -B(236)+0.15*B(240)+0.031*B(242)+B(264)
  JVS(862) = 0
  JVS(863) = 0.583*B(101)
  JVS(864) = B(155)
  JVS(865) = 0
  JVS(866) = 0
  JVS(867) = 0
  JVS(868) = -B(358)
  JVS(869) = -B(277)
  JVS(870) = 0.44*B(147)
  JVS(871) = 0
  JVS(872) = -B(318)
  JVS(873) = -B(239)-B(278)-B(319)-B(359)-B(399)
  JVS(874) = -B(400)
  JVS(875) = 0
  JVS(876) = 0.583*B(102)+0.44*B(148)+B(156)
  JVS(877) = -B(240)
  JVS(878) = 0
  JVS(879) = B(85)
  JVS(880) = 0.35*B(6)
  JVS(881) = -B(171)
  JVS(882) = B(69)
  JVS(883) = B(151)
  JVS(884) = -B(181)
  JVS(885) = -B(183)
  JVS(886) = -B(177)
  JVS(887) = -B(169)
  JVS(888) = -B(161)
  JVS(889) = 0.6*B(153)-0.4*B(185)
  JVS(890) = -B(405)
  JVS(891) = -B(179)
  JVS(892) = -B(407)
  JVS(893) = -B(409)
  JVS(894) = -B(163)
  JVS(895) = -B(421)
  JVS(896) = -B(415)
  JVS(897) = -B(401)
  JVS(898) = -B(403)
  JVS(899) = -B(417)
  JVS(900) = -B(419)
  JVS(901) = -B(413)
  JVS(902) = -B(411)
  JVS(903) = -B(165)
  JVS(904) = -B(442)
  JVS(905) = -B(159)
  JVS(906) = -B(173)
  JVS(907) = -B(175)
  JVS(908) = -B(429)
  JVS(909) = -B(431)
  JVS(910) = -B(157)
  JVS(911) = -B(167)
  JVS(912) = -B(425)
  JVS(913) = -B(397)
  JVS(914) = -B(427)
  JVS(915) = -B(423)
  JVS(916) = -B(65)
  JVS(917) = 0
  JVS(918) = B(52)
  JVS(919) = -B(395)
  JVS(920) = -B(399)
  JVS(921) = -B(7)-B(8)-B(58)-B(66)-B(79)-B(81)-B(83)-2*B(86)-B(158)-B(160)-B(162)-B(164)-B(166)-B(168)-B(170)-B(172)&
               &-B(174)-B(176)-B(178)-B(180)-B(182)-B(184)-0.4*B(186)-B(396)-B(398)-B(400)-B(402)-B(404)-B(406)-B(408)&
               &-B(410)-B(412)-B(414)-B(416)-B(418)-B(420)-B(422)-B(424)-B(426)-B(428)-B(430)-B(432)-B(443)
  JVS(922) = B(75)
  JVS(923) = -B(59)+B(70)+B(152)+0.6*B(154)
  JVS(924) = -B(80)
  JVS(925) = B(53)+B(76)-B(82)-B(84)
  JVS(926) = B(31)
  JVS(927) = -B(215)
  JVS(928) = -B(221)
  JVS(929) = -B(187)
  JVS(930) = -B(227)
  JVS(931) = -B(446)
  JVS(932) = -B(197)
  JVS(933) = -B(444)
  JVS(934) = -B(199)
  JVS(935) = -B(193)
  JVS(936) = 0
  JVS(937) = -B(205)
  JVS(938) = -B(195)
  JVS(939) = -B(201)
  JVS(940) = -B(189)
  JVS(941) = -B(191)
  JVS(942) = 0
  JVS(943) = -B(203)
  JVS(944) = B(307)
  JVS(945) = 0
  JVS(946) = 0
  JVS(947) = B(303)
  JVS(948) = -B(39)+B(304)+B(308)
  JVS(949) = 0
  JVS(950) = B(27)-B(29)
  JVS(951) = 0
  JVS(952) = 0
  JVS(953) = 0
  JVS(954) = -B(2)-B(3)-B(30)-B(37)-B(40)-B(73)-B(75)-B(188)-B(190)-B(192)-B(194)-B(196)-B(198)-B(200)-B(202)-B(204)&
               &-B(206)-B(216)-B(222)-B(228)-B(445)-B(447)
  JVS(955) = -B(38)
  JVS(956) = -B(74)
  JVS(957) = -B(76)
  JVS(958) = -B(89)
  JVS(959) = 2*B(35)
  JVS(960) = -B(103)
  JVS(961) = -B(121)
  JVS(962) = -B(123)
  JVS(963) = B(24)
  JVS(964) = -B(105)
  JVS(965) = -0.964*B(101)
  JVS(966) = -B(99)
  JVS(967) = -B(143)
  JVS(968) = -B(97)
  JVS(969) = -B(452)
  JVS(970) = 0.35*B(6)-B(71)
  JVS(971) = B(13)-0.65*B(145)
  JVS(972) = B(4)-B(67)
  JVS(973) = 2*B(9)-B(43)
  JVS(974) = B(215)
  JVS(975) = B(221)
  JVS(976) = -B(133)
  JVS(977) = -B(107)+0.12*B(187)
  JVS(978) = B(227)
  JVS(979) = 0
  JVS(980) = B(15)-B(149)
  JVS(981) = B(5)-B(69)
  JVS(982) = -B(151)
  JVS(983) = -B(91)
  JVS(984) = -B(117)+0.85*B(197)
  JVS(985) = 0
  JVS(986) = -B(119)+0.85*B(199)
  JVS(987) = -B(113)+0.28*B(193)
  JVS(988) = -B(125)
  JVS(989) = -B(135)
  JVS(990) = -B(153)+0.036*B(205)
  JVS(991) = 0.02*B(93)-B(115)+0.28*B(195)
  JVS(992) = -B(137)
  JVS(993) = 0
  JVS(994) = -B(131)
  JVS(995) = 0
  JVS(996) = 0
  JVS(997) = 0
  JVS(998) = 0
  JVS(999) = 0
  JVS(1000) = -B(155)
  JVS(1001) = -B(139)+0.07*B(201)
  JVS(1002) = -B(129)
  JVS(1003) = -B(109)+0.4*B(189)
  JVS(1004) = -B(111)+0.63*B(191)
  JVS(1005) = 0
  JVS(1006) = 0
  JVS(1007) = -B(127)
  JVS(1008) = -B(141)+0.21*B(203)
  JVS(1009) = 0
  JVS(1010) = 0
  JVS(1011) = 0
  JVS(1012) = 0
  JVS(1013) = B(39)-B(41)+B(60)+0.7*B(65)
  JVS(1014) = B(14)-0.51*B(147)
  JVS(1015) = 0.02*B(94)
  JVS(1016) = 0
  JVS(1017) = 0
  JVS(1018) = -B(58)+0.7*B(66)
  JVS(1019) = -B(37)+B(40)+0.12*B(188)+0.4*B(190)+0.63*B(192)+0.28*B(194)+0.28*B(196)+0.85*B(198)+0.85*B(200)+0.07&
                &*B(202)+0.21*B(204)+0.036*B(206)+B(216)+B(222)+B(228)
  JVS(1020) = -B(38)-B(42)-B(44)-B(54)-B(56)-B(59)-B(68)-B(70)-B(72)-B(87)-B(90)-B(92)-B(98)-B(100)-0.964*B(102)-B(104)&
                &-B(106)-B(108)-B(110)-B(112)-B(114)-B(116)-B(118)-B(120)-B(122)-B(124)-B(126)-B(128)-B(130)-B(132)-B(134)&
                &-B(136)-B(138)-B(140)-B(142)-B(144)-0.65*B(146)-0.51*B(148)-B(150)-B(152)-B(154)-B(156)-B(453)
  JVS(1021) = -B(55)+B(61)
  JVS(1022) = -B(57)
  JVS(1023) = B(4)
  JVS(1024) = 0
  JVS(1025) = 0
  JVS(1026) = 0
  JVS(1027) = -B(454)
  JVS(1028) = 0
  JVS(1029) = 0
  JVS(1030) = -B(245)
  JVS(1031) = -B(247)
  JVS(1032) = -B(249)
  JVS(1033) = -B(261)
  JVS(1034) = -B(255)
  JVS(1035) = -B(241)
  JVS(1036) = -B(243)
  JVS(1037) = -B(257)
  JVS(1038) = -B(259)
  JVS(1039) = -B(253)
  JVS(1040) = -B(251)
  JVS(1041) = -B(440)
  JVS(1042) = 0
  JVS(1043) = 0
  JVS(1044) = -B(269)
  JVS(1045) = -B(271)
  JVS(1046) = 0
  JVS(1047) = 0
  JVS(1048) = -B(265)
  JVS(1049) = -B(237)
  JVS(1050) = -B(267)
  JVS(1051) = -B(263)
  JVS(1052) = -B(60)
  JVS(1053) = 0
  JVS(1054) = -B(48)+B(50)
  JVS(1055) = -B(235)
  JVS(1056) = -B(239)
  JVS(1057) = B(7)-B(79)+B(81)
  JVS(1058) = -B(73)
  JVS(1059) = -B(54)
  JVS(1060) = -B(49)-B(55)-B(61)-B(74)-2*B(77)-B(80)-B(236)-B(238)-B(240)-B(242)-B(244)-B(246)-B(248)-B(250)-B(252)&
                &-B(254)-B(256)-B(258)-B(260)-B(262)-B(264)-B(266)-B(268)-B(270)-B(272)-B(441)-B(455)
  JVS(1061) = B(1)+B(51)+B(82)
  JVS(1062) = B(85)
  JVS(1063) = 0.65*B(6)+B(64)+B(71)
  JVS(1064) = B(67)
  JVS(1065) = -B(207)
  JVS(1066) = -B(211)
  JVS(1067) = -B(217)
  JVS(1068) = -B(223)
  JVS(1069) = B(454)
  JVS(1070) = B(5)
  JVS(1071) = B(231)
  JVS(1072) = 0
  JVS(1073) = 0
  JVS(1074) = 0
  JVS(1075) = 0.4*B(185)+0.7*B(205)+B(234)
  JVS(1076) = B(245)+B(405)
  JVS(1077) = B(247)+B(407)
  JVS(1078) = B(249)+B(409)
  JVS(1079) = 0
  JVS(1080) = B(261)+B(421)
  JVS(1081) = 0.65*B(255)+B(415)
  JVS(1082) = 0.876*B(241)+B(401)
  JVS(1083) = 0.739*B(243)+B(403)
  JVS(1084) = 0.95*B(257)+B(417)
  JVS(1085) = 0.95*B(259)+B(419)
  JVS(1086) = 0.8*B(253)+B(413)
  JVS(1087) = 0.847*B(251)+B(411)
  JVS(1088) = B(21)+B(155)
  JVS(1089) = 0
  JVS(1090) = B(440)+B(442)
  JVS(1091) = 0
  JVS(1092) = 0
  JVS(1093) = 0
  JVS(1094) = B(269)+0.5*B(392)+B(429)
  JVS(1095) = 2*B(271)+0.5*B(354)+0.516*B(389)+0.5*B(393)+B(394)+2*B(431)
  JVS(1096) = 0
  JVS(1097) = 0.5*B(167)
  JVS(1098) = -B(232)+B(265)+B(425)
  JVS(1099) = B(237)+B(397)
  JVS(1100) = B(267)+B(427)
  JVS(1101) = -B(229)+B(263)+0.516*B(390)+B(423)
  JVS(1102) = B(60)-B(62)+0.7*B(65)
  JVS(1103) = 0
  JVS(1104) = B(48)-B(50)-B(52)
  JVS(1105) = B(235)+0.5*B(355)+B(395)
  JVS(1106) = 0.941*B(239)+B(399)
  JVS(1107) = B(8)+B(58)+0.7*B(66)+2*B(79)-B(83)+2*B(86)+0.5*B(168)+0.4*B(186)+B(396)+B(398)+B(400)+B(402)+B(404)+B(406)&
                &+B(408)+B(410)+B(412)+B(414)+B(416)+B(418)+B(420)+B(422)+B(424)+B(426)+B(428)+B(430)+2*B(432)+B(443)
  JVS(1108) = B(73)-B(75)+0.7*B(206)
  JVS(1109) = -B(56)+B(59)+B(68)+B(72)+B(156)
  JVS(1110) = B(49)+B(61)+B(74)+2*B(77)+2*B(80)+B(236)+B(238)+0.941*B(240)+0.876*B(242)+0.739*B(244)+B(246)+B(248)&
                &+B(250)+0.847*B(252)+0.8*B(254)+0.65*B(256)+0.95*B(258)+0.95*B(260)+B(262)+B(264)+B(266)+B(268)+B(270)+2&
                &*B(272)+B(441)+B(455)
  JVS(1111) = -B(1)-B(51)-B(53)-B(57)-B(63)-B(76)-B(84)-B(208)-B(212)-B(218)-B(224)-B(230)-B(233)
END SUBROUTINE racm_Jac_SP
SUBROUTINE racm_KppDecomp( JVS, IER )
      INTEGER :: IER
      REAL(kind=dp) :: JVS(1111), W(78), a
      INTEGER :: k, kk, j, jj
      a = 0.
      IER = 0
      DO k=1,NVAR
        IF ( ABS(JVS(LU_DIAG(k))) < TINY(a) ) THEN
            IER = k
            RETURN
        END IF
        DO kk = LU_CROW(k), LU_CROW(k+1)-1
              W( LU_ICOL(kk) ) = JVS(kk)
        END DO
        DO kk = LU_CROW(k), LU_DIAG(k)-1
            j = LU_ICOL(kk)
            a = -W(j) / JVS( LU_DIAG(j) )
            W(j) = -a
            DO jj = LU_DIAG(j)+1, LU_CROW(j+1)-1
               W( LU_ICOL(jj) ) = W( LU_ICOL(jj) ) + a*JVS(jj)
            END DO
         END DO
         DO kk = LU_CROW(k), LU_CROW(k+1)-1
            JVS(kk) = W( LU_ICOL(kk) )
         END DO
      END DO
END SUBROUTINE racm_KppDecomp
SUBROUTINE racm_KppDecompCmplx( JVS, IER )
      INTEGER :: IER
      DOUBLE COMPLEX :: JVS(1111), W(78), a
      INTEGER :: k, kk, j, jj
      IER = 0
      DO k=1,NVAR
        IF ( JVS( LU_DIAG(k) ) .EQ. 0. ) THEN
            IER = k
            RETURN
        END IF
        DO kk = LU_CROW(k), LU_CROW(k+1)-1
              W( LU_ICOL(kk) ) = JVS(kk)
        END DO
        DO kk = LU_CROW(k), LU_DIAG(k)-1
            j = LU_ICOL(kk)
            a = -W(j) / JVS( LU_DIAG(j) )
            W(j) = -a
            DO jj = LU_DIAG(j)+1, LU_CROW(j+1)-1
               W( LU_ICOL(jj) ) = W( LU_ICOL(jj) ) + a*JVS(jj)
            END DO
         END DO
         DO kk = LU_CROW(k), LU_CROW(k+1)-1
            JVS(kk) = W( LU_ICOL(kk) )
         END DO
      END DO
END SUBROUTINE racm_KppDecompCmplx
SUBROUTINE racm_KppSolveIndirect( JVS, X )
      INTEGER i, j
      REAL(kind=dp) JVS(1111), X(78), sum
      DO i=1,NVAR
         DO j = LU_CROW(i), LU_DIAG(i)-1
             X(i) = X(i) - JVS(j)*X(LU_ICOL(j));
         END DO
      END DO
      DO i=NVAR,1,-1
        sum = X(i);
        DO j = LU_DIAG(i)+1, LU_CROW(i+1)-1
          sum = sum - JVS(j)*X(LU_ICOL(j));
        END DO
        X(i) = sum/JVS(LU_DIAG(i));
      END DO
END SUBROUTINE racm_KppSolveIndirect
SUBROUTINE racm_KppSolveCmplx( JVS, X )
      INTEGER i, j
      DOUBLE COMPLEX JVS(1111), X(78), sum
      DO i=1,NVAR
         DO j = LU_CROW(i), LU_DIAG(i)-1
             X(i) = X(i) - JVS(j)*X(LU_ICOL(j));
         END DO
      END DO
      DO i=NVAR,1,-1
        sum = X(i);
        DO j = LU_DIAG(i)+1, LU_CROW(i+1)-1
          sum = sum - JVS(j)*X(LU_ICOL(j));
        END DO
        X(i) = sum/JVS(LU_DIAG(i));
      END DO
END SUBROUTINE racm_KppSolveCmplx
SUBROUTINE racm_KppSolve ( JVS, X )
  REAL(kind=dp) :: JVS(LU_NONZERO)
  REAL(kind=dp) :: X(NVAR)
  X(24) = X(24)-JVS(112)*X(10)
  X(25) = X(25)-JVS(117)*X(11)
  X(26) = X(26)-JVS(122)*X(13)
  X(33) = X(33)-JVS(168)*X(14)-JVS(169)*X(27)
  X(35) = X(35)-JVS(193)*X(5)-JVS(194)*X(12)-JVS(195)*X(18)-JVS(196)*X(29)
  X(38) = X(38)-JVS(211)*X(23)-JVS(212)*X(24)-JVS(213)*X(25)-JVS(214)*X(28)
  X(39) = X(39)-JVS(221)*X(14)
  X(41) = X(41)-JVS(240)*X(27)
  X(45) = X(45)-JVS(270)*X(26)-JVS(271)*X(40)
  X(46) = X(46)-JVS(288)*X(28)-JVS(289)*X(38)
  X(47) = X(47)-JVS(299)*X(9)-JVS(300)*X(16)-JVS(301)*X(34)-JVS(302)*X(43)-JVS(303)*X(44)
  X(48) = X(48)-JVS(324)*X(36)
  X(49) = X(49)-JVS(333)*X(9)
  X(50) = X(50)-JVS(341)*X(13)
  X(51) = X(51)-JVS(349)*X(24)
  X(52) = X(52)-JVS(359)*X(25)
  X(53) = X(53)-JVS(369)*X(34)
  X(54) = X(54)-JVS(378)*X(37)-JVS(379)*X(42)
  X(55) = X(55)-JVS(389)*X(23)-JVS(390)*X(38)-JVS(391)*X(40)-JVS(392)*X(48)-JVS(393)*X(49)-JVS(394)*X(50)-JVS(395)*X(51)&
            &-JVS(396)*X(52)-JVS(397)*X(53)-JVS(398)*X(54)
  X(56) = X(56)-JVS(413)*X(36)-JVS(414)*X(37)-JVS(415)*X(42)-JVS(416)*X(48)-JVS(417)*X(54)
  X(57) = X(57)-JVS(427)*X(10)-JVS(428)*X(11)-JVS(429)*X(30)-JVS(430)*X(32)-JVS(431)*X(37)-JVS(432)*X(38)-JVS(433)*X(40)&
            &-JVS(434)*X(42)-JVS(435)*X(49)-JVS(436)*X(50)-JVS(437)*X(56)
  X(58) = X(58)-JVS(453)*X(13)-JVS(454)*X(14)-JVS(455)*X(16)-JVS(456)*X(34)-JVS(457)*X(41)-JVS(458)*X(43)-JVS(459)*X(44)&
            &-JVS(460)*X(49)-JVS(461)*X(50)-JVS(462)*X(53)-JVS(463)*X(55)-JVS(464)*X(56)
  X(59) = X(59)-JVS(485)*X(36)-JVS(486)*X(37)-JVS(487)*X(42)-JVS(488)*X(54)
  X(60) = X(60)-JVS(498)*X(48)-JVS(499)*X(54)
  X(61) = X(61)-JVS(509)*X(27)-JVS(510)*X(34)-JVS(511)*X(36)-JVS(512)*X(37)-JVS(513)*X(42)-JVS(514)*X(56)-JVS(515)*X(59)&
            &-JVS(516)*X(60)
  X(62) = X(62)-JVS(527)*X(27)-JVS(528)*X(34)-JVS(529)*X(36)-JVS(530)*X(37)-JVS(531)*X(42)-JVS(532)*X(59)-JVS(533)*X(60)&
            &-JVS(534)*X(61)
  X(63) = X(63)-JVS(544)*X(14)-JVS(545)*X(20)-JVS(546)*X(26)-JVS(547)*X(27)-JVS(548)*X(30)-JVS(549)*X(32)-JVS(550)*X(35)&
            &-JVS(551)*X(36)-JVS(552)*X(37)-JVS(553)*X(39)-JVS(554)*X(40)-JVS(555)*X(41)-JVS(556)*X(42)-JVS(557)*X(43)&
            &-JVS(558)*X(44)-JVS(559)*X(46)-JVS(560)*X(48)-JVS(561)*X(49)-JVS(562)*X(50)-JVS(563)*X(51)-JVS(564)*X(52)&
            &-JVS(565)*X(53)-JVS(566)*X(54)-JVS(567)*X(56)-JVS(568)*X(57)-JVS(569)*X(59)-JVS(570)*X(60)-JVS(571)*X(61)&
            &-JVS(572)*X(62)
  X(64) = X(64)-JVS(589)*X(42)-JVS(590)*X(51)-JVS(591)*X(52)
  X(65) = X(65)-JVS(602)*X(40)-JVS(603)*X(56)-JVS(604)*X(64)
  X(66) = X(66)-JVS(615)*X(15)-JVS(616)*X(34)-JVS(617)*X(36)-JVS(618)*X(47)-JVS(619)*X(49)-JVS(620)*X(50)-JVS(621)*X(53)&
            &-JVS(622)*X(55)-JVS(623)*X(59)-JVS(624)*X(60)-JVS(625)*X(61)-JVS(626)*X(62)-JVS(627)*X(64)-JVS(628)*X(65)
  X(67) = X(67)-JVS(642)*X(34)-JVS(643)*X(36)-JVS(644)*X(37)-JVS(645)*X(42)-JVS(646)*X(47)-JVS(647)*X(49)-JVS(648)*X(50)&
            &-JVS(649)*X(53)-JVS(650)*X(55)-JVS(651)*X(59)-JVS(652)*X(60)-JVS(653)*X(61)-JVS(654)*X(62)-JVS(655)*X(64)&
            &-JVS(656)*X(65)
  X(68) = X(68)-JVS(669)*X(26)-JVS(670)*X(30)-JVS(671)*X(32)-JVS(672)*X(37)-JVS(673)*X(40)-JVS(674)*X(41)-JVS(675)*X(42)&
            &-JVS(676)*X(43)-JVS(677)*X(44)-JVS(678)*X(45)-JVS(679)*X(46)-JVS(680)*X(47)-JVS(681)*X(48)-JVS(682)*X(49)&
            &-JVS(683)*X(50)-JVS(684)*X(51)-JVS(685)*X(52)-JVS(686)*X(53)-JVS(687)*X(54)-JVS(688)*X(55)-JVS(689)*X(56)&
            &-JVS(690)*X(57)-JVS(691)*X(58)-JVS(692)*X(59)-JVS(693)*X(60)-JVS(694)*X(61)-JVS(695)*X(62)-JVS(696)*X(64)&
            &-JVS(697)*X(65)-JVS(698)*X(66)-JVS(699)*X(67)
  X(69) = X(69)-JVS(711)*X(6)-JVS(712)*X(9)-JVS(713)*X(10)-JVS(714)*X(11)-JVS(715)*X(13)-JVS(716)*X(14)-JVS(717)*X(16)&
            &-JVS(718)*X(19)-JVS(719)*X(20)-JVS(720)*X(22)-JVS(721)*X(23)-JVS(722)*X(24)-JVS(723)*X(25)-JVS(724)*X(26)&
            &-JVS(725)*X(27)-JVS(726)*X(28)-JVS(727)*X(29)-JVS(728)*X(30)-JVS(729)*X(33)-JVS(730)*X(34)-JVS(731)*X(35)&
            &-JVS(732)*X(36)-JVS(733)*X(37)-JVS(734)*X(38)-JVS(735)*X(39)-JVS(736)*X(40)-JVS(737)*X(41)-JVS(738)*X(42)&
            &-JVS(739)*X(43)-JVS(740)*X(44)-JVS(741)*X(45)-JVS(742)*X(46)-JVS(743)*X(48)-JVS(744)*X(49)-JVS(745)*X(50)&
            &-JVS(746)*X(51)-JVS(747)*X(52)-JVS(748)*X(53)-JVS(749)*X(54)-JVS(750)*X(55)-JVS(751)*X(56)-JVS(752)*X(57)&
            &-JVS(753)*X(58)-JVS(754)*X(59)-JVS(755)*X(60)-JVS(756)*X(61)-JVS(757)*X(62)-JVS(758)*X(63)-JVS(759)*X(64)&
            &-JVS(760)*X(65)-JVS(761)*X(66)-JVS(762)*X(67)-JVS(763)*X(68)
  X(70) = X(70)-JVS(774)*X(41)-JVS(775)*X(43)-JVS(776)*X(44)-JVS(777)*X(46)-JVS(778)*X(48)-JVS(779)*X(49)-JVS(780)*X(50)&
            &-JVS(781)*X(51)-JVS(782)*X(52)-JVS(783)*X(53)-JVS(784)*X(54)-JVS(785)*X(56)-JVS(786)*X(57)-JVS(787)*X(59)&
            &-JVS(788)*X(60)-JVS(789)*X(64)-JVS(790)*X(65)-JVS(791)*X(66)-JVS(792)*X(67)-JVS(793)*X(68)-JVS(794)*X(69)
  X(71) = X(71)-JVS(804)*X(7)-JVS(805)*X(29)-JVS(806)*X(35)-JVS(807)*X(37)-JVS(808)*X(42)-JVS(809)*X(56)-JVS(810)*X(63)&
            &-JVS(811)*X(64)-JVS(812)*X(65)-JVS(813)*X(66)-JVS(814)*X(67)-JVS(815)*X(68)-JVS(816)*X(69)-JVS(817)*X(70)
  X(72) = X(72)-JVS(826)*X(17)-JVS(827)*X(20)-JVS(828)*X(30)-JVS(829)*X(37)-JVS(830)*X(41)-JVS(831)*X(42)-JVS(832)*X(43)&
            &-JVS(833)*X(44)-JVS(834)*X(46)-JVS(835)*X(48)-JVS(836)*X(49)-JVS(837)*X(50)-JVS(838)*X(51)-JVS(839)*X(52)&
            &-JVS(840)*X(53)-JVS(841)*X(54)-JVS(842)*X(57)-JVS(843)*X(58)-JVS(844)*X(59)-JVS(845)*X(60)-JVS(846)*X(61)&
            &-JVS(847)*X(62)-JVS(848)*X(64)-JVS(849)*X(65)-JVS(850)*X(66)-JVS(851)*X(67)-JVS(852)*X(68)-JVS(853)*X(69)&
            &-JVS(854)*X(70)-JVS(855)*X(71)
  X(73) = X(73)-JVS(863)*X(14)-JVS(864)*X(55)-JVS(865)*X(61)-JVS(866)*X(62)-JVS(867)*X(65)-JVS(868)*X(68)-JVS(869)*X(69)&
            &-JVS(870)*X(70)-JVS(871)*X(71)-JVS(872)*X(72)
  X(74) = X(74)-JVS(879)*X(8)-JVS(880)*X(19)-JVS(881)*X(27)-JVS(882)*X(31)-JVS(883)*X(32)-JVS(884)*X(34)-JVS(885)*X(36)&
            &-JVS(886)*X(37)-JVS(887)*X(38)-JVS(888)*X(39)-JVS(889)*X(40)-JVS(890)*X(41)-JVS(891)*X(42)-JVS(892)*X(43)&
            &-JVS(893)*X(44)-JVS(894)*X(45)-JVS(895)*X(46)-JVS(896)*X(48)-JVS(897)*X(49)-JVS(898)*X(50)-JVS(899)*X(51)&
            &-JVS(900)*X(52)-JVS(901)*X(53)-JVS(902)*X(54)-JVS(903)*X(56)-JVS(904)*X(57)-JVS(905)*X(58)-JVS(906)*X(59)&
            &-JVS(907)*X(60)-JVS(908)*X(61)-JVS(909)*X(62)-JVS(910)*X(63)-JVS(911)*X(64)-JVS(912)*X(65)-JVS(913)*X(66)&
            &-JVS(914)*X(67)-JVS(915)*X(68)-JVS(916)*X(69)-JVS(917)*X(70)-JVS(918)*X(71)-JVS(919)*X(72)-JVS(920)*X(73)
  X(75) = X(75)-JVS(926)*X(7)-JVS(927)*X(24)-JVS(928)*X(25)-JVS(929)*X(27)-JVS(930)*X(28)-JVS(931)*X(29)-JVS(932)*X(34)&
            &-JVS(933)*X(35)-JVS(934)*X(36)-JVS(935)*X(37)-JVS(936)*X(38)-JVS(937)*X(40)-JVS(938)*X(42)-JVS(939)*X(56)&
            &-JVS(940)*X(59)-JVS(941)*X(60)-JVS(942)*X(63)-JVS(943)*X(64)-JVS(944)*X(65)-JVS(945)*X(66)-JVS(946)*X(67)&
            &-JVS(947)*X(68)-JVS(948)*X(69)-JVS(949)*X(70)-JVS(950)*X(71)-JVS(951)*X(72)-JVS(952)*X(73)-JVS(953)*X(74)
  X(76) = X(76)-JVS(958)*X(6)-JVS(959)*X(7)-JVS(960)*X(9)-JVS(961)*X(10)-JVS(962)*X(11)-JVS(963)*X(12)-JVS(964)*X(13)&
            &-JVS(965)*X(14)-JVS(966)*X(15)-JVS(967)*X(16)-JVS(968)*X(17)-JVS(969)*X(18)-JVS(970)*X(19)-JVS(971)*X(20)&
            &-JVS(972)*X(21)-JVS(973)*X(22)-JVS(974)*X(24)-JVS(975)*X(25)-JVS(976)*X(26)-JVS(977)*X(27)-JVS(978)*X(28)&
            &-JVS(979)*X(29)-JVS(980)*X(30)-JVS(981)*X(31)-JVS(982)*X(32)-JVS(983)*X(33)-JVS(984)*X(34)-JVS(985)*X(35)&
            &-JVS(986)*X(36)-JVS(987)*X(37)-JVS(988)*X(38)-JVS(989)*X(39)-JVS(990)*X(40)-JVS(991)*X(42)-JVS(992)*X(45)&
            &-JVS(993)*X(46)-JVS(994)*X(47)-JVS(995)*X(49)-JVS(996)*X(50)-JVS(997)*X(51)-JVS(998)*X(52)-JVS(999)*X(53)&
            &-JVS(1000)*X(55)-JVS(1001)*X(56)-JVS(1002)*X(58)-JVS(1003)*X(59)-JVS(1004)*X(60)-JVS(1005)*X(61)-JVS(1006)&
            &*X(62)-JVS(1007)*X(63)-JVS(1008)*X(64)-JVS(1009)*X(65)-JVS(1010)*X(66)-JVS(1011)*X(67)-JVS(1012)*X(68)&
            &-JVS(1013)*X(69)-JVS(1014)*X(70)-JVS(1015)*X(71)-JVS(1016)*X(72)-JVS(1017)*X(73)-JVS(1018)*X(74)-JVS(1019)&
            &*X(75)
  X(77) = X(77)-JVS(1023)*X(21)-JVS(1024)*X(24)-JVS(1025)*X(25)-JVS(1026)*X(28)-JVS(1027)*X(29)-JVS(1028)*X(35)&
            &-JVS(1029)*X(38)-JVS(1030)*X(41)-JVS(1031)*X(43)-JVS(1032)*X(44)-JVS(1033)*X(46)-JVS(1034)*X(48)-JVS(1035)&
            &*X(49)-JVS(1036)*X(50)-JVS(1037)*X(51)-JVS(1038)*X(52)-JVS(1039)*X(53)-JVS(1040)*X(54)-JVS(1041)*X(57)&
            &-JVS(1042)*X(59)-JVS(1043)*X(60)-JVS(1044)*X(61)-JVS(1045)*X(62)-JVS(1046)*X(63)-JVS(1047)*X(64)-JVS(1048)&
            &*X(65)-JVS(1049)*X(66)-JVS(1050)*X(67)-JVS(1051)*X(68)-JVS(1052)*X(69)-JVS(1053)*X(70)-JVS(1054)*X(71)&
            &-JVS(1055)*X(72)-JVS(1056)*X(73)-JVS(1057)*X(74)-JVS(1058)*X(75)-JVS(1059)*X(76)
  X(78) = X(78)-JVS(1062)*X(8)-JVS(1063)*X(19)-JVS(1064)*X(21)-JVS(1065)*X(23)-JVS(1066)*X(24)-JVS(1067)*X(25)-JVS(1068)&
            &*X(28)-JVS(1069)*X(29)-JVS(1070)*X(31)-JVS(1071)*X(32)-JVS(1072)*X(35)-JVS(1073)*X(38)-JVS(1074)*X(39)&
            &-JVS(1075)*X(40)-JVS(1076)*X(41)-JVS(1077)*X(43)-JVS(1078)*X(44)-JVS(1079)*X(45)-JVS(1080)*X(46)-JVS(1081)&
            &*X(48)-JVS(1082)*X(49)-JVS(1083)*X(50)-JVS(1084)*X(51)-JVS(1085)*X(52)-JVS(1086)*X(53)-JVS(1087)*X(54)&
            &-JVS(1088)*X(55)-JVS(1089)*X(56)-JVS(1090)*X(57)-JVS(1091)*X(58)-JVS(1092)*X(59)-JVS(1093)*X(60)-JVS(1094)&
            &*X(61)-JVS(1095)*X(62)-JVS(1096)*X(63)-JVS(1097)*X(64)-JVS(1098)*X(65)-JVS(1099)*X(66)-JVS(1100)*X(67)&
            &-JVS(1101)*X(68)-JVS(1102)*X(69)-JVS(1103)*X(70)-JVS(1104)*X(71)-JVS(1105)*X(72)-JVS(1106)*X(73)-JVS(1107)&
            &*X(74)-JVS(1108)*X(75)-JVS(1109)*X(76)-JVS(1110)*X(77)
  X(78) = X(78)/JVS(1111)
  X(77) = (X(77)-JVS(1061)*X(78))/(JVS(1060))
  X(76) = (X(76)-JVS(1021)*X(77)-JVS(1022)*X(78))/(JVS(1020))
  X(75) = (X(75)-JVS(955)*X(76)-JVS(956)*X(77)-JVS(957)*X(78))/(JVS(954))
  X(74) = (X(74)-JVS(922)*X(75)-JVS(923)*X(76)-JVS(924)*X(77)-JVS(925)*X(78))/(JVS(921))
  X(73) = (X(73)-JVS(874)*X(74)-JVS(875)*X(75)-JVS(876)*X(76)-JVS(877)*X(77)-JVS(878)*X(78))/(JVS(873))
  X(72) = (X(72)-JVS(857)*X(73)-JVS(858)*X(74)-JVS(859)*X(75)-JVS(860)*X(76)-JVS(861)*X(77)-JVS(862)*X(78))/(JVS(856))
  X(71) = (X(71)-JVS(819)*X(72)-JVS(820)*X(73)-JVS(821)*X(74)-JVS(822)*X(75)-JVS(823)*X(76)-JVS(824)*X(77)-JVS(825)&
            &*X(78))/(JVS(818))
  X(70) = (X(70)-JVS(796)*X(71)-JVS(797)*X(72)-JVS(798)*X(73)-JVS(799)*X(74)-JVS(800)*X(75)-JVS(801)*X(76)-JVS(802)&
            &*X(77)-JVS(803)*X(78))/(JVS(795))
  X(69) = (X(69)-JVS(765)*X(70)-JVS(766)*X(71)-JVS(767)*X(72)-JVS(768)*X(73)-JVS(769)*X(74)-JVS(770)*X(75)-JVS(771)&
            &*X(76)-JVS(772)*X(77)-JVS(773)*X(78))/(JVS(764))
  X(68) = (X(68)-JVS(701)*X(69)-JVS(702)*X(70)-JVS(703)*X(71)-JVS(704)*X(72)-JVS(705)*X(73)-JVS(706)*X(74)-JVS(707)&
            &*X(75)-JVS(708)*X(76)-JVS(709)*X(77)-JVS(710)*X(78))/(JVS(700))
  X(67) = (X(67)-JVS(658)*X(68)-JVS(659)*X(69)-JVS(660)*X(70)-JVS(661)*X(71)-JVS(662)*X(72)-JVS(663)*X(73)-JVS(664)&
            &*X(74)-JVS(665)*X(75)-JVS(666)*X(76)-JVS(667)*X(77)-JVS(668)*X(78))/(JVS(657))
  X(66) = (X(66)-JVS(630)*X(67)-JVS(631)*X(68)-JVS(632)*X(69)-JVS(633)*X(70)-JVS(634)*X(71)-JVS(635)*X(72)-JVS(636)&
            &*X(73)-JVS(637)*X(74)-JVS(638)*X(75)-JVS(639)*X(76)-JVS(640)*X(77)-JVS(641)*X(78))/(JVS(629))
  X(65) = (X(65)-JVS(606)*X(68)-JVS(607)*X(69)-JVS(608)*X(71)-JVS(609)*X(72)-JVS(610)*X(74)-JVS(611)*X(75)-JVS(612)&
            &*X(76)-JVS(613)*X(77)-JVS(614)*X(78))/(JVS(605))
  X(64) = (X(64)-JVS(593)*X(68)-JVS(594)*X(69)-JVS(595)*X(71)-JVS(596)*X(72)-JVS(597)*X(74)-JVS(598)*X(75)-JVS(599)&
            &*X(76)-JVS(600)*X(77)-JVS(601)*X(78))/(JVS(592))
  X(63) = (X(63)-JVS(574)*X(64)-JVS(575)*X(65)-JVS(576)*X(66)-JVS(577)*X(67)-JVS(578)*X(68)-JVS(579)*X(69)-JVS(580)&
            &*X(70)-JVS(581)*X(71)-JVS(582)*X(72)-JVS(583)*X(73)-JVS(584)*X(74)-JVS(585)*X(75)-JVS(586)*X(76)-JVS(587)*X(77)&
            &-JVS(588)*X(78))/(JVS(573))
  X(62) = (X(62)-JVS(536)*X(68)-JVS(537)*X(69)-JVS(538)*X(71)-JVS(539)*X(72)-JVS(540)*X(74)-JVS(541)*X(75)-JVS(542)&
            &*X(76)-JVS(543)*X(77))/(JVS(535))
  X(61) = (X(61)-JVS(518)*X(62)-JVS(519)*X(68)-JVS(520)*X(69)-JVS(521)*X(71)-JVS(522)*X(72)-JVS(523)*X(74)-JVS(524)&
            &*X(75)-JVS(525)*X(76)-JVS(526)*X(77))/(JVS(517))
  X(60) = (X(60)-JVS(501)*X(68)-JVS(502)*X(69)-JVS(503)*X(71)-JVS(504)*X(72)-JVS(505)*X(74)-JVS(506)*X(75)-JVS(507)&
            &*X(76)-JVS(508)*X(77))/(JVS(500))
  X(59) = (X(59)-JVS(490)*X(68)-JVS(491)*X(69)-JVS(492)*X(71)-JVS(493)*X(72)-JVS(494)*X(74)-JVS(495)*X(75)-JVS(496)&
            &*X(76)-JVS(497)*X(77))/(JVS(489))
  X(58) = (X(58)-JVS(466)*X(59)-JVS(467)*X(60)-JVS(468)*X(61)-JVS(469)*X(62)-JVS(470)*X(64)-JVS(471)*X(65)-JVS(472)&
            &*X(66)-JVS(473)*X(67)-JVS(474)*X(68)-JVS(475)*X(69)-JVS(476)*X(70)-JVS(477)*X(71)-JVS(478)*X(72)-JVS(479)*X(73)&
            &-JVS(480)*X(74)-JVS(481)*X(75)-JVS(482)*X(76)-JVS(483)*X(77)-JVS(484)*X(78))/(JVS(465))
  X(57) = (X(57)-JVS(439)*X(64)-JVS(440)*X(65)-JVS(441)*X(67)-JVS(442)*X(68)-JVS(443)*X(69)-JVS(444)*X(70)-JVS(445)&
            &*X(71)-JVS(446)*X(72)-JVS(447)*X(73)-JVS(448)*X(74)-JVS(449)*X(75)-JVS(450)*X(76)-JVS(451)*X(77)-JVS(452)&
            &*X(78))/(JVS(438))
  X(56) = (X(56)-JVS(419)*X(68)-JVS(420)*X(69)-JVS(421)*X(71)-JVS(422)*X(72)-JVS(423)*X(74)-JVS(424)*X(75)-JVS(425)&
            &*X(76)-JVS(426)*X(77))/(JVS(418))
  X(55) = (X(55)-JVS(400)*X(61)-JVS(401)*X(62)-JVS(402)*X(65)-JVS(403)*X(68)-JVS(404)*X(69)-JVS(405)*X(71)-JVS(406)&
            &*X(72)-JVS(407)*X(73)-JVS(408)*X(74)-JVS(409)*X(75)-JVS(410)*X(76)-JVS(411)*X(77)-JVS(412)*X(78))/(JVS(399))
  X(54) = (X(54)-JVS(381)*X(68)-JVS(382)*X(69)-JVS(383)*X(71)-JVS(384)*X(72)-JVS(385)*X(74)-JVS(386)*X(75)-JVS(387)&
            &*X(76)-JVS(388)*X(77))/(JVS(380))
  X(53) = (X(53)-JVS(371)*X(68)-JVS(372)*X(69)-JVS(373)*X(72)-JVS(374)*X(74)-JVS(375)*X(75)-JVS(376)*X(76)-JVS(377)&
            &*X(77))/(JVS(370))
  X(52) = (X(52)-JVS(361)*X(68)-JVS(362)*X(69)-JVS(363)*X(72)-JVS(364)*X(74)-JVS(365)*X(75)-JVS(366)*X(76)-JVS(367)&
            &*X(77)-JVS(368)*X(78))/(JVS(360))
  X(51) = (X(51)-JVS(351)*X(68)-JVS(352)*X(69)-JVS(353)*X(72)-JVS(354)*X(74)-JVS(355)*X(75)-JVS(356)*X(76)-JVS(357)&
            &*X(77)-JVS(358)*X(78))/(JVS(350))
  X(50) = (X(50)-JVS(343)*X(68)-JVS(344)*X(69)-JVS(345)*X(72)-JVS(346)*X(74)-JVS(347)*X(76)-JVS(348)*X(77))/(JVS(342))
  X(49) = (X(49)-JVS(335)*X(68)-JVS(336)*X(69)-JVS(337)*X(72)-JVS(338)*X(74)-JVS(339)*X(76)-JVS(340)*X(77))/(JVS(334))
  X(48) = (X(48)-JVS(326)*X(68)-JVS(327)*X(69)-JVS(328)*X(72)-JVS(329)*X(74)-JVS(330)*X(75)-JVS(331)*X(76)-JVS(332)&
            &*X(77))/(JVS(325))
  X(47) = (X(47)-JVS(305)*X(49)-JVS(306)*X(50)-JVS(307)*X(53)-JVS(308)*X(55)-JVS(309)*X(59)-JVS(310)*X(60)-JVS(311)&
            &*X(61)-JVS(312)*X(62)-JVS(313)*X(64)-JVS(314)*X(67)-JVS(315)*X(68)-JVS(316)*X(69)-JVS(317)*X(70)-JVS(318)*X(72)&
            &-JVS(319)*X(73)-JVS(320)*X(74)-JVS(321)*X(75)-JVS(322)*X(76)-JVS(323)*X(77))/(JVS(304))
  X(46) = (X(46)-JVS(291)*X(68)-JVS(292)*X(69)-JVS(293)*X(72)-JVS(294)*X(74)-JVS(295)*X(75)-JVS(296)*X(76)-JVS(297)&
            &*X(77)-JVS(298)*X(78))/(JVS(290))
  X(45) = (X(45)-JVS(273)*X(46)-JVS(274)*X(51)-JVS(275)*X(52)-JVS(276)*X(56)-JVS(277)*X(64)-JVS(278)*X(65)-JVS(279)&
            &*X(67)-JVS(280)*X(68)-JVS(281)*X(72)-JVS(282)*X(73)-JVS(283)*X(74)-JVS(284)*X(75)-JVS(285)*X(76)-JVS(286)*X(77)&
            &-JVS(287)*X(78))/(JVS(272))
  X(44) = (X(44)-JVS(263)*X(60)-JVS(264)*X(68)-JVS(265)*X(69)-JVS(266)*X(72)-JVS(267)*X(74)-JVS(268)*X(76)-JVS(269)&
            &*X(77))/(JVS(262))
  X(43) = (X(43)-JVS(255)*X(59)-JVS(256)*X(68)-JVS(257)*X(69)-JVS(258)*X(72)-JVS(259)*X(74)-JVS(260)*X(76)-JVS(261)&
            &*X(77))/(JVS(254))
  X(42) = (X(42)-JVS(250)*X(71)-JVS(251)*X(74)-JVS(252)*X(75)-JVS(253)*X(76))/(JVS(249))
  X(41) = (X(41)-JVS(242)*X(68)-JVS(243)*X(69)-JVS(244)*X(72)-JVS(245)*X(74)-JVS(246)*X(75)-JVS(247)*X(76)-JVS(248)&
            &*X(77))/(JVS(241))
  X(40) = (X(40)-JVS(235)*X(65)-JVS(236)*X(74)-JVS(237)*X(75)-JVS(238)*X(76)-JVS(239)*X(78))/(JVS(234))
  X(39) = (X(39)-JVS(223)*X(46)-JVS(224)*X(51)-JVS(225)*X(52)-JVS(226)*X(64)-JVS(227)*X(68)-JVS(228)*X(72)-JVS(229)&
            &*X(73)-JVS(230)*X(74)-JVS(231)*X(75)-JVS(232)*X(76)-JVS(233)*X(77))/(JVS(222))
  X(38) = (X(38)-JVS(216)*X(69)-JVS(217)*X(74)-JVS(218)*X(75)-JVS(219)*X(76)-JVS(220)*X(78))/(JVS(215))
  X(37) = (X(37)-JVS(208)*X(74)-JVS(209)*X(75)-JVS(210)*X(76))/(JVS(207))
  X(36) = (X(36)-JVS(204)*X(74)-JVS(205)*X(75)-JVS(206)*X(76))/(JVS(203))
  X(35) = (X(35)-JVS(198)*X(63)-JVS(199)*X(69)-JVS(200)*X(75)-JVS(201)*X(76)-JVS(202)*X(77))/(JVS(197))
  X(34) = (X(34)-JVS(190)*X(74)-JVS(191)*X(75)-JVS(192)*X(76))/(JVS(189))
  X(33) = (X(33)-JVS(171)*X(34)-JVS(172)*X(35)-JVS(173)*X(36)-JVS(174)*X(37)-JVS(175)*X(39)-JVS(176)*X(40)-JVS(177)&
            &*X(42)-JVS(178)*X(45)-JVS(179)*X(56)-JVS(180)*X(58)-JVS(181)*X(59)-JVS(182)*X(60)-JVS(183)*X(63)-JVS(184)*X(64)&
            &-JVS(185)*X(71)-JVS(186)*X(74)-JVS(187)*X(75)-JVS(188)*X(76))/(JVS(170))
  X(32) = (X(32)-JVS(162)*X(40)-JVS(163)*X(68)-JVS(164)*X(74)-JVS(165)*X(75)-JVS(166)*X(76)-JVS(167)*X(78))/(JVS(161))
  X(31) = (X(31)-JVS(150)*X(38)-JVS(151)*X(39)-JVS(152)*X(45)-JVS(153)*X(56)-JVS(154)*X(58)-JVS(155)*X(63)-JVS(156)&
            &*X(64)-JVS(157)*X(69)-JVS(158)*X(74)-JVS(159)*X(76)-JVS(160)*X(78))/(JVS(149))
  X(30) = (X(30)-JVS(144)*X(64)-JVS(145)*X(68)-JVS(146)*X(69)-JVS(147)*X(75)-JVS(148)*X(76))/(JVS(143))
  X(29) = (X(29)-JVS(139)*X(35)-JVS(140)*X(69)-JVS(141)*X(75)-JVS(142)*X(77))/(JVS(138))
  X(28) = (X(28)-JVS(134)*X(38)-JVS(135)*X(75)-JVS(136)*X(76)-JVS(137)*X(78))/(JVS(133))
  X(27) = (X(27)-JVS(130)*X(74)-JVS(131)*X(75)-JVS(132)*X(76))/(JVS(129))
  X(26) = (X(26)-JVS(124)*X(40)-JVS(125)*X(56)-JVS(126)*X(67)-JVS(127)*X(72)-JVS(128)*X(76))/(JVS(123))
  X(25) = (X(25)-JVS(119)*X(75)-JVS(120)*X(76)-JVS(121)*X(78))/(JVS(118))
  X(24) = (X(24)-JVS(114)*X(75)-JVS(115)*X(76)-JVS(116)*X(78))/(JVS(113))
  X(23) = (X(23)-JVS(107)*X(38)-JVS(108)*X(69)-JVS(109)*X(74)-JVS(110)*X(76)-JVS(111)*X(78))/(JVS(106))
  X(22) = (X(22)-JVS(97)*X(34)-JVS(98)*X(36)-JVS(99)*X(37)-JVS(100)*X(42)-JVS(101)*X(59)-JVS(102)*X(60)-JVS(103)*X(69)&
            &-JVS(104)*X(75)-JVS(105)*X(76))/(JVS(96))
  X(21) = (X(21)-JVS(90)*X(24)-JVS(91)*X(25)-JVS(92)*X(28)-JVS(93)*X(76)-JVS(94)*X(77)-JVS(95)*X(78))/(JVS(89))
  X(20) = (X(20)-JVS(86)*X(69)-JVS(87)*X(72)-JVS(88)*X(76))/(JVS(85))
  X(19) = (X(19)-JVS(82)*X(69)-JVS(83)*X(76)-JVS(84)*X(78))/(JVS(81))
  X(18) = (X(18)-JVS(77)*X(35)-JVS(78)*X(63)-JVS(79)*X(69)-JVS(80)*X(76))/(JVS(76))
  X(17) = (X(17)-JVS(72)*X(59)-JVS(73)*X(60)-JVS(74)*X(75)-JVS(75)*X(76))/(JVS(71))
  X(16) = (X(16)-JVS(69)*X(64)-JVS(70)*X(76))/(JVS(68))
  X(15) = (X(15)-JVS(64)*X(59)-JVS(65)*X(60)-JVS(66)*X(75)-JVS(67)*X(76))/(JVS(63))
  X(14) = (X(14)-JVS(62)*X(76))/(JVS(61))
  X(13) = (X(13)-JVS(60)*X(76))/(JVS(59))
  X(12) = (X(12)-JVS(57)*X(29)-JVS(58)*X(69))/(JVS(56))
  X(11) = (X(11)-JVS(55)*X(76))/(JVS(54))
  X(10) = (X(10)-JVS(53)*X(76))/(JVS(52))
  X(9) = (X(9)-JVS(51)*X(76))/(JVS(50))
  X(8) = (X(8)-JVS(48)*X(74)-JVS(49)*X(78))/(JVS(47))
  X(7) = (X(7)-JVS(46)*X(75))/(JVS(45))
  X(6) = (X(6)-JVS(44)*X(76))/(JVS(43))
  X(5) = (X(5)-JVS(42)*X(29))/(JVS(41))
  X(4) = (X(4)-JVS(20)*X(36)-JVS(21)*X(41)-JVS(22)*X(43)-JVS(23)*X(44)-JVS(24)*X(49)-JVS(25)*X(50)-JVS(26)*X(54)-JVS(27)&
           &*X(56)-JVS(28)*X(59)-JVS(29)*X(60)-JVS(30)*X(61)-JVS(31)*X(62)-JVS(32)*X(64)-JVS(33)*X(65)-JVS(34)*X(66)-JVS(35)&
           &*X(67)-JVS(36)*X(68)-JVS(37)*X(69)-JVS(38)*X(72)-JVS(39)*X(73)-JVS(40)*X(75))/(JVS(19))
  X(3) = (X(3)-JVS(8)*X(14)-JVS(9)*X(27)-JVS(10)*X(36)-JVS(11)*X(37)-JVS(12)*X(40)-JVS(13)*X(42)-JVS(14)*X(56)-JVS(15)&
           &*X(59)-JVS(16)*X(64)-JVS(17)*X(75)-JVS(18)*X(76))/(JVS(7))
  X(2) = (X(2)-JVS(5)*X(33)-JVS(6)*X(76))/(JVS(4))
  X(1) = (X(1)-JVS(2)*X(6)-JVS(3)*X(76))/(JVS(1))
END SUBROUTINE racm_KppSolve
      SUBROUTINE racm_WCOPY(N,X,incX,Y,incY)
      INTEGER i,incX,incY,M,MP1,N
      REAL(kind=dp) X(N),Y(N)
      IF (N.LE.0) RETURN
      M = MOD(N,8)
      IF( M .NE. 0 ) THEN
        DO i = 1,M
          Y(i) = X(i)
        END DO
        IF( N .LT. 8 ) RETURN
      END IF
      MP1 = M+1
      DO i = MP1,N,8
        Y(i) = X(i)
        Y(i + 1) = X(i + 1)
        Y(i + 2) = X(i + 2)
        Y(i + 3) = X(i + 3)
        Y(i + 4) = X(i + 4)
        Y(i + 5) = X(i + 5)
        Y(i + 6) = X(i + 6)
        Y(i + 7) = X(i + 7)
      END DO
      END SUBROUTINE racm_WCOPY
      SUBROUTINE racm_WAXPY(N,Alpha,X,incX,Y,incY)
      INTEGER i,incX,incY,M,MP1,N
      REAL(kind=dp) X(N),Y(N),Alpha
      REAL(kind=dp) ZERO
      PARAMETER( ZERO = 0.0_dp )
      IF (Alpha .EQ. ZERO) RETURN
      IF (N .LE. 0) RETURN
      M = MOD(N,4)
      IF( M .NE. 0 ) THEN
        DO i = 1,M
          Y(i) = Y(i) + Alpha*X(i)
        END DO
        IF( N .LT. 4 ) RETURN
      END IF
      MP1 = M + 1
      DO i = MP1,N,4
        Y(i) = Y(i) + Alpha*X(i)
        Y(i + 1) = Y(i + 1) + Alpha*X(i + 1)
        Y(i + 2) = Y(i + 2) + Alpha*X(i + 2)
        Y(i + 3) = Y(i + 3) + Alpha*X(i + 3)
      END DO
      END SUBROUTINE racm_WAXPY
      SUBROUTINE racm_WSCAL(N,Alpha,X,incX)
      INTEGER i,incX,M,MP1,N
      REAL(kind=dp) X(N),Alpha
      REAL(kind=dp) ZERO, ONE
      PARAMETER( ZERO = 0.0_dp )
      PARAMETER( ONE = 1.0_dp )
      IF (Alpha .EQ. ONE) RETURN
      IF (N .LE. 0) RETURN
      M = MOD(N,5)
      IF( M .NE. 0 ) THEN
        IF (Alpha .EQ. (-ONE)) THEN
          DO i = 1,M
            X(i) = -X(i)
          END DO
        ELSEIF (Alpha .EQ. ZERO) THEN
          DO i = 1,M
            X(i) = ZERO
          END DO
        ELSE
          DO i = 1,M
            X(i) = Alpha*X(i)
          END DO
        END IF
        IF( N .LT. 5 ) RETURN
      END IF
      MP1 = M + 1
      IF (Alpha .EQ. (-ONE)) THEN
        DO i = MP1,N,5
          X(i) = -X(i)
          X(i + 1) = -X(i + 1)
          X(i + 2) = -X(i + 2)
          X(i + 3) = -X(i + 3)
          X(i + 4) = -X(i + 4)
        END DO
      ELSEIF (Alpha .EQ. ZERO) THEN
        DO i = MP1,N,5
          X(i) = ZERO
          X(i + 1) = ZERO
          X(i + 2) = ZERO
          X(i + 3) = ZERO
          X(i + 4) = ZERO
        END DO
      ELSE
        DO i = MP1,N,5
          X(i) = Alpha*X(i)
          X(i + 1) = Alpha*X(i + 1)
          X(i + 2) = Alpha*X(i + 2)
          X(i + 3) = Alpha*X(i + 3)
          X(i + 4) = Alpha*X(i + 4)
        END DO
      END IF
      END SUBROUTINE racm_WSCAL
      REAL(kind=dp) FUNCTION racm_WLAMCH( C )
      CHARACTER C
      INTEGER i
      REAL(kind=dp) ONE, HALF, Eps, Sum
      PARAMETER (ONE = 1.0_dp)
      PARAMETER (HALF = 0.5_dp)
      LOGICAL First
      SAVE First, Eps
      DATA First /.TRUE./
      IF (First) THEN
        First = .FALSE.
        Eps = HALF**(16)
        DO i = 17, 80
          Eps = Eps*HALF
          CALL racm_WLAMCH_ADD(ONE,Eps,Sum)
          IF (Sum.LE.ONE) GOTO 10
        END DO
        PRINT*,'ERROR IN WLAMCH. EPS < ',Eps
        RETURN
10 Eps = Eps*2
        i = i-1
      END IF
      racm_WLAMCH = Eps
      END FUNCTION racm_WLAMCH
      SUBROUTINE racm_WLAMCH_ADD( A, B, Sum )
      REAL(kind=dp) A, B, Sum
      Sum = A + B
      END SUBROUTINE racm_WLAMCH_ADD
      SUBROUTINE racm_SET2ZERO(N,Y)
      INTEGER :: i,M,MP1,N
      REAL(kind=dp) :: Y(N)
      REAL(kind=dp), PARAMETER :: ZERO = 0.0d0
      IF (N.LE.0) RETURN
      M = MOD(N,8)
      IF( M .NE. 0 ) THEN
        DO i = 1,M
          Y(i) = ZERO
        END DO
        IF( N .LT. 8 ) RETURN
      END IF
      MP1 = M+1
      DO i = MP1,N,8
        Y(i) = ZERO
        Y(i + 1) = ZERO
        Y(i + 2) = ZERO
        Y(i + 3) = ZERO
        Y(i + 4) = ZERO
        Y(i + 5) = ZERO
        Y(i + 6) = ZERO
        Y(i + 7) = ZERO
      END DO
      END SUBROUTINE racm_SET2ZERO
      REAL(kind=dp) FUNCTION racm_WDOT (N, DX, incX, DY, incY)
      IMPLICIT NONE
      INTEGER :: N, incX, incY
      REAL(kind=dp) :: DX(N), DY(N)
      INTEGER :: i, IX, IY, M, MP1, NS
      racm_WDOT = 0.0D0
      IF (N .LE. 0) RETURN
      IF (incX .EQ. incY) IF (incX-1) 5,20,60
    5 IX = 1
      IY = 1
      IF (incX .LT. 0) IX = (-N+1)*incX + 1
      IF (incY .LT. 0) IY = (-N+1)*incY + 1
      DO i = 1,N
        racm_WDOT = racm_WDOT + DX(IX)*DY(IY)
        IX = IX + incX
        IY = IY + incY
      END DO
      RETURN
   20 M = MOD(N,5)
      IF (M .EQ. 0) GO TO 40
      DO i = 1,M
         racm_WDOT = racm_WDOT + DX(i)*DY(i)
      END DO
      IF (N .LT. 5) RETURN
   40 MP1 = M + 1
      DO i = MP1,N,5
          racm_WDOT = racm_WDOT + DX(i)*DY(i) + DX(i+1)*DY(i+1) +&
                   DX(i+2)*DY(i+2) + &
                   DX(i+3)*DY(i+3) + DX(i+4)*DY(i+4)
      END DO
      RETURN
   60 NS = N*incX
      DO i = 1,NS,incX
        racm_WDOT = racm_WDOT + DX(i)*DY(i)
      END DO
      END FUNCTION racm_WDOT
   SUBROUTINE decomp_racm( JVS, IER )
     IMPLICIT NONE
      INTEGER :: IER
      REAL(kind=dp) :: JVS(LU_NONZERO), W(NVAR), a
  a = 0._dp
  ier = 0
  IF ( ABS( JVS( 1 )) < TINY(a) ) THEN
         IER = 1
         RETURN
  END IF
   W( 1 ) = JVS( 1 )
   W( 6 ) = JVS( 2 )
   W( 76 ) = JVS( 3 )
  JVS( 1) = W( 1 )
  JVS( 2) = W( 6 )
  JVS( 3) = W( 76 )
  IF ( ABS( JVS( 4 )) < TINY(a) ) THEN
         IER = 2
         RETURN
  END IF
   W( 2 ) = JVS( 4 )
   W( 33 ) = JVS( 5 )
   W( 76 ) = JVS( 6 )
  JVS( 4) = W( 2 )
  JVS( 5) = W( 33 )
  JVS( 6) = W( 76 )
  IF ( ABS( JVS( 7 )) < TINY(a) ) THEN
         IER = 3
         RETURN
  END IF
   W( 3 ) = JVS( 7 )
   W( 14 ) = JVS( 8 )
   W( 27 ) = JVS( 9 )
   W( 36 ) = JVS( 10 )
   W( 37 ) = JVS( 11 )
   W( 40 ) = JVS( 12 )
   W( 42 ) = JVS( 13 )
   W( 56 ) = JVS( 14 )
   W( 59 ) = JVS( 15 )
   W( 64 ) = JVS( 16 )
   W( 75 ) = JVS( 17 )
   W( 76 ) = JVS( 18 )
  JVS( 7) = W( 3 )
  JVS( 8) = W( 14 )
  JVS( 9) = W( 27 )
  JVS( 10) = W( 36 )
  JVS( 11) = W( 37 )
  JVS( 12) = W( 40 )
  JVS( 13) = W( 42 )
  JVS( 14) = W( 56 )
  JVS( 15) = W( 59 )
  JVS( 16) = W( 64 )
  JVS( 17) = W( 75 )
  JVS( 18) = W( 76 )
  IF ( ABS( JVS( 19 )) < TINY(a) ) THEN
         IER = 4
         RETURN
  END IF
   W( 4 ) = JVS( 19 )
   W( 36 ) = JVS( 20 )
   W( 41 ) = JVS( 21 )
   W( 43 ) = JVS( 22 )
   W( 44 ) = JVS( 23 )
   W( 49 ) = JVS( 24 )
   W( 50 ) = JVS( 25 )
   W( 54 ) = JVS( 26 )
   W( 56 ) = JVS( 27 )
   W( 59 ) = JVS( 28 )
   W( 60 ) = JVS( 29 )
   W( 61 ) = JVS( 30 )
   W( 62 ) = JVS( 31 )
   W( 64 ) = JVS( 32 )
   W( 65 ) = JVS( 33 )
   W( 66 ) = JVS( 34 )
   W( 67 ) = JVS( 35 )
   W( 68 ) = JVS( 36 )
   W( 69 ) = JVS( 37 )
   W( 72 ) = JVS( 38 )
   W( 73 ) = JVS( 39 )
   W( 75 ) = JVS( 40 )
  JVS( 19) = W( 4 )
  JVS( 20) = W( 36 )
  JVS( 21) = W( 41 )
  JVS( 22) = W( 43 )
  JVS( 23) = W( 44 )
  JVS( 24) = W( 49 )
  JVS( 25) = W( 50 )
  JVS( 26) = W( 54 )
  JVS( 27) = W( 56 )
  JVS( 28) = W( 59 )
  JVS( 29) = W( 60 )
  JVS( 30) = W( 61 )
  JVS( 31) = W( 62 )
  JVS( 32) = W( 64 )
  JVS( 33) = W( 65 )
  JVS( 34) = W( 66 )
  JVS( 35) = W( 67 )
  JVS( 36) = W( 68 )
  JVS( 37) = W( 69 )
  JVS( 38) = W( 72 )
  JVS( 39) = W( 73 )
  JVS( 40) = W( 75 )
  IF ( ABS( JVS( 41 )) < TINY(a) ) THEN
         IER = 5
         RETURN
  END IF
   W( 5 ) = JVS( 41 )
   W( 29 ) = JVS( 42 )
  JVS( 41) = W( 5 )
  JVS( 42) = W( 29 )
  IF ( ABS( JVS( 43 )) < TINY(a) ) THEN
         IER = 6
         RETURN
  END IF
   W( 6 ) = JVS( 43 )
   W( 76 ) = JVS( 44 )
  JVS( 43) = W( 6 )
  JVS( 44) = W( 76 )
  IF ( ABS( JVS( 45 )) < TINY(a) ) THEN
         IER = 7
         RETURN
  END IF
   W( 7 ) = JVS( 45 )
   W( 75 ) = JVS( 46 )
  JVS( 45) = W( 7 )
  JVS( 46) = W( 75 )
  IF ( ABS( JVS( 47 )) < TINY(a) ) THEN
         IER = 8
         RETURN
  END IF
   W( 8 ) = JVS( 47 )
   W( 74 ) = JVS( 48 )
   W( 78 ) = JVS( 49 )
  JVS( 47) = W( 8 )
  JVS( 48) = W( 74 )
  JVS( 49) = W( 78 )
  IF ( ABS( JVS( 50 )) < TINY(a) ) THEN
         IER = 9
         RETURN
  END IF
   W( 9 ) = JVS( 50 )
   W( 76 ) = JVS( 51 )
  JVS( 50) = W( 9 )
  JVS( 51) = W( 76 )
  IF ( ABS( JVS( 52 )) < TINY(a) ) THEN
         IER = 10
         RETURN
  END IF
   W( 10 ) = JVS( 52 )
   W( 76 ) = JVS( 53 )
  JVS( 52) = W( 10 )
  JVS( 53) = W( 76 )
  IF ( ABS( JVS( 54 )) < TINY(a) ) THEN
         IER = 11
         RETURN
  END IF
   W( 11 ) = JVS( 54 )
   W( 76 ) = JVS( 55 )
  JVS( 54) = W( 11 )
  JVS( 55) = W( 76 )
  IF ( ABS( JVS( 56 )) < TINY(a) ) THEN
         IER = 12
         RETURN
  END IF
   W( 12 ) = JVS( 56 )
   W( 29 ) = JVS( 57 )
   W( 69 ) = JVS( 58 )
  JVS( 56) = W( 12 )
  JVS( 57) = W( 29 )
  JVS( 58) = W( 69 )
  IF ( ABS( JVS( 59 )) < TINY(a) ) THEN
         IER = 13
         RETURN
  END IF
   W( 13 ) = JVS( 59 )
   W( 76 ) = JVS( 60 )
  JVS( 59) = W( 13 )
  JVS( 60) = W( 76 )
  IF ( ABS( JVS( 61 )) < TINY(a) ) THEN
         IER = 14
         RETURN
  END IF
   W( 14 ) = JVS( 61 )
   W( 76 ) = JVS( 62 )
  JVS( 61) = W( 14 )
  JVS( 62) = W( 76 )
  IF ( ABS( JVS( 63 )) < TINY(a) ) THEN
         IER = 15
         RETURN
  END IF
   W( 15 ) = JVS( 63 )
   W( 59 ) = JVS( 64 )
   W( 60 ) = JVS( 65 )
   W( 75 ) = JVS( 66 )
   W( 76 ) = JVS( 67 )
  JVS( 63) = W( 15 )
  JVS( 64) = W( 59 )
  JVS( 65) = W( 60 )
  JVS( 66) = W( 75 )
  JVS( 67) = W( 76 )
  IF ( ABS( JVS( 68 )) < TINY(a) ) THEN
         IER = 16
         RETURN
  END IF
   W( 16 ) = JVS( 68 )
   W( 64 ) = JVS( 69 )
   W( 76 ) = JVS( 70 )
  JVS( 68) = W( 16 )
  JVS( 69) = W( 64 )
  JVS( 70) = W( 76 )
  IF ( ABS( JVS( 71 )) < TINY(a) ) THEN
         IER = 17
         RETURN
  END IF
   W( 17 ) = JVS( 71 )
   W( 59 ) = JVS( 72 )
   W( 60 ) = JVS( 73 )
   W( 75 ) = JVS( 74 )
   W( 76 ) = JVS( 75 )
  JVS( 71) = W( 17 )
  JVS( 72) = W( 59 )
  JVS( 73) = W( 60 )
  JVS( 74) = W( 75 )
  JVS( 75) = W( 76 )
  IF ( ABS( JVS( 76 )) < TINY(a) ) THEN
         IER = 18
         RETURN
  END IF
   W( 18 ) = JVS( 76 )
   W( 35 ) = JVS( 77 )
   W( 63 ) = JVS( 78 )
   W( 69 ) = JVS( 79 )
   W( 76 ) = JVS( 80 )
  JVS( 76) = W( 18 )
  JVS( 77) = W( 35 )
  JVS( 78) = W( 63 )
  JVS( 79) = W( 69 )
  JVS( 80) = W( 76 )
  IF ( ABS( JVS( 81 )) < TINY(a) ) THEN
         IER = 19
         RETURN
  END IF
   W( 19 ) = JVS( 81 )
   W( 69 ) = JVS( 82 )
   W( 76 ) = JVS( 83 )
   W( 78 ) = JVS( 84 )
  JVS( 81) = W( 19 )
  JVS( 82) = W( 69 )
  JVS( 83) = W( 76 )
  JVS( 84) = W( 78 )
  IF ( ABS( JVS( 85 )) < TINY(a) ) THEN
         IER = 20
         RETURN
  END IF
   W( 20 ) = JVS( 85 )
   W( 69 ) = JVS( 86 )
   W( 72 ) = JVS( 87 )
   W( 76 ) = JVS( 88 )
  JVS( 85) = W( 20 )
  JVS( 86) = W( 69 )
  JVS( 87) = W( 72 )
  JVS( 88) = W( 76 )
  IF ( ABS( JVS( 89 )) < TINY(a) ) THEN
         IER = 21
         RETURN
  END IF
   W( 21 ) = JVS( 89 )
   W( 24 ) = JVS( 90 )
   W( 25 ) = JVS( 91 )
   W( 28 ) = JVS( 92 )
   W( 76 ) = JVS( 93 )
   W( 77 ) = JVS( 94 )
   W( 78 ) = JVS( 95 )
  JVS( 89) = W( 21 )
  JVS( 90) = W( 24 )
  JVS( 91) = W( 25 )
  JVS( 92) = W( 28 )
  JVS( 93) = W( 76 )
  JVS( 94) = W( 77 )
  JVS( 95) = W( 78 )
  IF ( ABS( JVS( 96 )) < TINY(a) ) THEN
         IER = 22
         RETURN
  END IF
   W( 22 ) = JVS( 96 )
   W( 34 ) = JVS( 97 )
   W( 36 ) = JVS( 98 )
   W( 37 ) = JVS( 99 )
   W( 42 ) = JVS( 100 )
   W( 59 ) = JVS( 101 )
   W( 60 ) = JVS( 102 )
   W( 69 ) = JVS( 103 )
   W( 75 ) = JVS( 104 )
   W( 76 ) = JVS( 105 )
  JVS( 96) = W( 22 )
  JVS( 97) = W( 34 )
  JVS( 98) = W( 36 )
  JVS( 99) = W( 37 )
  JVS( 100) = W( 42 )
  JVS( 101) = W( 59 )
  JVS( 102) = W( 60 )
  JVS( 103) = W( 69 )
  JVS( 104) = W( 75 )
  JVS( 105) = W( 76 )
  IF ( ABS( JVS( 106 )) < TINY(a) ) THEN
         IER = 23
         RETURN
  END IF
   W( 23 ) = JVS( 106 )
   W( 38 ) = JVS( 107 )
   W( 69 ) = JVS( 108 )
   W( 74 ) = JVS( 109 )
   W( 76 ) = JVS( 110 )
   W( 78 ) = JVS( 111 )
  JVS( 106) = W( 23 )
  JVS( 107) = W( 38 )
  JVS( 108) = W( 69 )
  JVS( 109) = W( 74 )
  JVS( 110) = W( 76 )
  JVS( 111) = W( 78 )
  IF ( ABS( JVS( 113 )) < TINY(a) ) THEN
         IER = 24
         RETURN
  END IF
   W( 10 ) = JVS( 112 )
   W( 24 ) = JVS( 113 )
   W( 75 ) = JVS( 114 )
   W( 76 ) = JVS( 115 )
   W( 78 ) = JVS( 116 )
  a = -W( 10 ) / JVS( 52 )
  W( 10 ) = -a
  W( 76 ) = W( 76 ) + a*JVS( 53 )
  JVS( 112) = W( 10 )
  JVS( 113) = W( 24 )
  JVS( 114) = W( 75 )
  JVS( 115) = W( 76 )
  JVS( 116) = W( 78 )
  IF ( ABS( JVS( 118 )) < TINY(a) ) THEN
         IER = 25
         RETURN
  END IF
   W( 11 ) = JVS( 117 )
   W( 25 ) = JVS( 118 )
   W( 75 ) = JVS( 119 )
   W( 76 ) = JVS( 120 )
   W( 78 ) = JVS( 121 )
  a = -W( 11 ) / JVS( 54 )
  W( 11 ) = -a
  W( 76 ) = W( 76 ) + a*JVS( 55 )
  JVS( 117) = W( 11 )
  JVS( 118) = W( 25 )
  JVS( 119) = W( 75 )
  JVS( 120) = W( 76 )
  JVS( 121) = W( 78 )
  IF ( ABS( JVS( 123 )) < TINY(a) ) THEN
         IER = 26
         RETURN
  END IF
   W( 13 ) = JVS( 122 )
   W( 26 ) = JVS( 123 )
   W( 40 ) = JVS( 124 )
   W( 56 ) = JVS( 125 )
   W( 67 ) = JVS( 126 )
   W( 72 ) = JVS( 127 )
   W( 76 ) = JVS( 128 )
  a = -W( 13 ) / JVS( 59 )
  W( 13 ) = -a
  W( 76 ) = W( 76 ) + a*JVS( 60 )
  JVS( 122) = W( 13 )
  JVS( 123) = W( 26 )
  JVS( 124) = W( 40 )
  JVS( 125) = W( 56 )
  JVS( 126) = W( 67 )
  JVS( 127) = W( 72 )
  JVS( 128) = W( 76 )
  IF ( ABS( JVS( 129 )) < TINY(a) ) THEN
         IER = 27
         RETURN
  END IF
   W( 27 ) = JVS( 129 )
   W( 74 ) = JVS( 130 )
   W( 75 ) = JVS( 131 )
   W( 76 ) = JVS( 132 )
  JVS( 129) = W( 27 )
  JVS( 130) = W( 74 )
  JVS( 131) = W( 75 )
  JVS( 132) = W( 76 )
  IF ( ABS( JVS( 133 )) < TINY(a) ) THEN
         IER = 28
         RETURN
  END IF
   W( 28 ) = JVS( 133 )
   W( 38 ) = JVS( 134 )
   W( 75 ) = JVS( 135 )
   W( 76 ) = JVS( 136 )
   W( 78 ) = JVS( 137 )
  JVS( 133) = W( 28 )
  JVS( 134) = W( 38 )
  JVS( 135) = W( 75 )
  JVS( 136) = W( 76 )
  JVS( 137) = W( 78 )
  IF ( ABS( JVS( 138 )) < TINY(a) ) THEN
         IER = 29
         RETURN
  END IF
   W( 29 ) = JVS( 138 )
   W( 35 ) = JVS( 139 )
   W( 69 ) = JVS( 140 )
   W( 75 ) = JVS( 141 )
   W( 77 ) = JVS( 142 )
  JVS( 138) = W( 29 )
  JVS( 139) = W( 35 )
  JVS( 140) = W( 69 )
  JVS( 141) = W( 75 )
  JVS( 142) = W( 77 )
  IF ( ABS( JVS( 143 )) < TINY(a) ) THEN
         IER = 30
         RETURN
  END IF
   W( 30 ) = JVS( 143 )
   W( 64 ) = JVS( 144 )
   W( 68 ) = JVS( 145 )
   W( 69 ) = JVS( 146 )
   W( 75 ) = JVS( 147 )
   W( 76 ) = JVS( 148 )
  JVS( 143) = W( 30 )
  JVS( 144) = W( 64 )
  JVS( 145) = W( 68 )
  JVS( 146) = W( 69 )
  JVS( 147) = W( 75 )
  JVS( 148) = W( 76 )
  IF ( ABS( JVS( 149 )) < TINY(a) ) THEN
         IER = 31
         RETURN
  END IF
   W( 31 ) = JVS( 149 )
   W( 38 ) = JVS( 150 )
   W( 39 ) = JVS( 151 )
   W( 45 ) = JVS( 152 )
   W( 56 ) = JVS( 153 )
   W( 58 ) = JVS( 154 )
   W( 63 ) = JVS( 155 )
   W( 64 ) = JVS( 156 )
   W( 69 ) = JVS( 157 )
   W( 74 ) = JVS( 158 )
   W( 76 ) = JVS( 159 )
   W( 78 ) = JVS( 160 )
  JVS( 149) = W( 31 )
  JVS( 150) = W( 38 )
  JVS( 151) = W( 39 )
  JVS( 152) = W( 45 )
  JVS( 153) = W( 56 )
  JVS( 154) = W( 58 )
  JVS( 155) = W( 63 )
  JVS( 156) = W( 64 )
  JVS( 157) = W( 69 )
  JVS( 158) = W( 74 )
  JVS( 159) = W( 76 )
  JVS( 160) = W( 78 )
  IF ( ABS( JVS( 161 )) < TINY(a) ) THEN
         IER = 32
         RETURN
  END IF
   W( 32 ) = JVS( 161 )
   W( 40 ) = JVS( 162 )
   W( 68 ) = JVS( 163 )
   W( 74 ) = JVS( 164 )
   W( 75 ) = JVS( 165 )
   W( 76 ) = JVS( 166 )
   W( 78 ) = JVS( 167 )
  JVS( 161) = W( 32 )
  JVS( 162) = W( 40 )
  JVS( 163) = W( 68 )
  JVS( 164) = W( 74 )
  JVS( 165) = W( 75 )
  JVS( 166) = W( 76 )
  JVS( 167) = W( 78 )
  IF ( ABS( JVS( 170 )) < TINY(a) ) THEN
         IER = 33
         RETURN
  END IF
   W( 14 ) = JVS( 168 )
   W( 27 ) = JVS( 169 )
   W( 33 ) = JVS( 170 )
   W( 34 ) = JVS( 171 )
   W( 35 ) = JVS( 172 )
   W( 36 ) = JVS( 173 )
   W( 37 ) = JVS( 174 )
   W( 39 ) = JVS( 175 )
   W( 40 ) = JVS( 176 )
   W( 42 ) = JVS( 177 )
   W( 45 ) = JVS( 178 )
   W( 56 ) = JVS( 179 )
   W( 58 ) = JVS( 180 )
   W( 59 ) = JVS( 181 )
   W( 60 ) = JVS( 182 )
   W( 63 ) = JVS( 183 )
   W( 64 ) = JVS( 184 )
   W( 71 ) = JVS( 185 )
   W( 74 ) = JVS( 186 )
   W( 75 ) = JVS( 187 )
   W( 76 ) = JVS( 188 )
  a = -W( 14 ) / JVS( 61 )
  W( 14 ) = -a
  W( 76 ) = W( 76 ) + a*JVS( 62 )
  a = -W( 27 ) / JVS( 129 )
  W( 27 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 130 )
  W( 75 ) = W( 75 ) + a*JVS( 131 )
  W( 76 ) = W( 76 ) + a*JVS( 132 )
  JVS( 168) = W( 14 )
  JVS( 169) = W( 27 )
  JVS( 170) = W( 33 )
  JVS( 171) = W( 34 )
  JVS( 172) = W( 35 )
  JVS( 173) = W( 36 )
  JVS( 174) = W( 37 )
  JVS( 175) = W( 39 )
  JVS( 176) = W( 40 )
  JVS( 177) = W( 42 )
  JVS( 178) = W( 45 )
  JVS( 179) = W( 56 )
  JVS( 180) = W( 58 )
  JVS( 181) = W( 59 )
  JVS( 182) = W( 60 )
  JVS( 183) = W( 63 )
  JVS( 184) = W( 64 )
  JVS( 185) = W( 71 )
  JVS( 186) = W( 74 )
  JVS( 187) = W( 75 )
  JVS( 188) = W( 76 )
  IF ( ABS( JVS( 189 )) < TINY(a) ) THEN
         IER = 34
         RETURN
  END IF
   W( 34 ) = JVS( 189 )
   W( 74 ) = JVS( 190 )
   W( 75 ) = JVS( 191 )
   W( 76 ) = JVS( 192 )
  JVS( 189) = W( 34 )
  JVS( 190) = W( 74 )
  JVS( 191) = W( 75 )
  JVS( 192) = W( 76 )
  IF ( ABS( JVS( 197 )) < TINY(a) ) THEN
         IER = 35
         RETURN
  END IF
   W( 5 ) = JVS( 193 )
   W( 12 ) = JVS( 194 )
   W( 18 ) = JVS( 195 )
   W( 29 ) = JVS( 196 )
   W( 35 ) = JVS( 197 )
   W( 63 ) = JVS( 198 )
   W( 69 ) = JVS( 199 )
   W( 75 ) = JVS( 200 )
   W( 76 ) = JVS( 201 )
   W( 77 ) = JVS( 202 )
  a = -W( 5 ) / JVS( 41 )
  W( 5 ) = -a
  W( 29 ) = W( 29 ) + a*JVS( 42 )
  a = -W( 12 ) / JVS( 56 )
  W( 12 ) = -a
  W( 29 ) = W( 29 ) + a*JVS( 57 )
  W( 69 ) = W( 69 ) + a*JVS( 58 )
  a = -W( 18 ) / JVS( 76 )
  W( 18 ) = -a
  W( 35 ) = W( 35 ) + a*JVS( 77 )
  W( 63 ) = W( 63 ) + a*JVS( 78 )
  W( 69 ) = W( 69 ) + a*JVS( 79 )
  W( 76 ) = W( 76 ) + a*JVS( 80 )
  a = -W( 29 ) / JVS( 138 )
  W( 29 ) = -a
  W( 35 ) = W( 35 ) + a*JVS( 139 )
  W( 69 ) = W( 69 ) + a*JVS( 140 )
  W( 75 ) = W( 75 ) + a*JVS( 141 )
  W( 77 ) = W( 77 ) + a*JVS( 142 )
  JVS( 193) = W( 5 )
  JVS( 194) = W( 12 )
  JVS( 195) = W( 18 )
  JVS( 196) = W( 29 )
  JVS( 197) = W( 35 )
  JVS( 198) = W( 63 )
  JVS( 199) = W( 69 )
  JVS( 200) = W( 75 )
  JVS( 201) = W( 76 )
  JVS( 202) = W( 77 )
  IF ( ABS( JVS( 203 )) < TINY(a) ) THEN
         IER = 36
         RETURN
  END IF
   W( 36 ) = JVS( 203 )
   W( 74 ) = JVS( 204 )
   W( 75 ) = JVS( 205 )
   W( 76 ) = JVS( 206 )
  JVS( 203) = W( 36 )
  JVS( 204) = W( 74 )
  JVS( 205) = W( 75 )
  JVS( 206) = W( 76 )
  IF ( ABS( JVS( 207 )) < TINY(a) ) THEN
         IER = 37
         RETURN
  END IF
   W( 37 ) = JVS( 207 )
   W( 74 ) = JVS( 208 )
   W( 75 ) = JVS( 209 )
   W( 76 ) = JVS( 210 )
  JVS( 207) = W( 37 )
  JVS( 208) = W( 74 )
  JVS( 209) = W( 75 )
  JVS( 210) = W( 76 )
  IF ( ABS( JVS( 215 )) < TINY(a) ) THEN
         IER = 38
         RETURN
  END IF
   W( 23 ) = JVS( 211 )
   W( 24 ) = JVS( 212 )
   W( 25 ) = JVS( 213 )
   W( 28 ) = JVS( 214 )
   W( 38 ) = JVS( 215 )
   W( 69 ) = JVS( 216 )
   W( 74 ) = JVS( 217 )
   W( 75 ) = JVS( 218 )
   W( 76 ) = JVS( 219 )
   W( 78 ) = JVS( 220 )
  a = -W( 23 ) / JVS( 106 )
  W( 23 ) = -a
  W( 38 ) = W( 38 ) + a*JVS( 107 )
  W( 69 ) = W( 69 ) + a*JVS( 108 )
  W( 74 ) = W( 74 ) + a*JVS( 109 )
  W( 76 ) = W( 76 ) + a*JVS( 110 )
  W( 78 ) = W( 78 ) + a*JVS( 111 )
  a = -W( 24 ) / JVS( 113 )
  W( 24 ) = -a
  W( 75 ) = W( 75 ) + a*JVS( 114 )
  W( 76 ) = W( 76 ) + a*JVS( 115 )
  W( 78 ) = W( 78 ) + a*JVS( 116 )
  a = -W( 25 ) / JVS( 118 )
  W( 25 ) = -a
  W( 75 ) = W( 75 ) + a*JVS( 119 )
  W( 76 ) = W( 76 ) + a*JVS( 120 )
  W( 78 ) = W( 78 ) + a*JVS( 121 )
  a = -W( 28 ) / JVS( 133 )
  W( 28 ) = -a
  W( 38 ) = W( 38 ) + a*JVS( 134 )
  W( 75 ) = W( 75 ) + a*JVS( 135 )
  W( 76 ) = W( 76 ) + a*JVS( 136 )
  W( 78 ) = W( 78 ) + a*JVS( 137 )
  JVS( 211) = W( 23 )
  JVS( 212) = W( 24 )
  JVS( 213) = W( 25 )
  JVS( 214) = W( 28 )
  JVS( 215) = W( 38 )
  JVS( 216) = W( 69 )
  JVS( 217) = W( 74 )
  JVS( 218) = W( 75 )
  JVS( 219) = W( 76 )
  JVS( 220) = W( 78 )
  IF ( ABS( JVS( 222 )) < TINY(a) ) THEN
         IER = 39
         RETURN
  END IF
   W( 14 ) = JVS( 221 )
   W( 39 ) = JVS( 222 )
   W( 46 ) = JVS( 223 )
   W( 51 ) = JVS( 224 )
   W( 52 ) = JVS( 225 )
   W( 64 ) = JVS( 226 )
   W( 68 ) = JVS( 227 )
   W( 72 ) = JVS( 228 )
   W( 73 ) = JVS( 229 )
   W( 74 ) = JVS( 230 )
   W( 75 ) = JVS( 231 )
   W( 76 ) = JVS( 232 )
   W( 77 ) = JVS( 233 )
  a = -W( 14 ) / JVS( 61 )
  W( 14 ) = -a
  W( 76 ) = W( 76 ) + a*JVS( 62 )
  JVS( 221) = W( 14 )
  JVS( 222) = W( 39 )
  JVS( 223) = W( 46 )
  JVS( 224) = W( 51 )
  JVS( 225) = W( 52 )
  JVS( 226) = W( 64 )
  JVS( 227) = W( 68 )
  JVS( 228) = W( 72 )
  JVS( 229) = W( 73 )
  JVS( 230) = W( 74 )
  JVS( 231) = W( 75 )
  JVS( 232) = W( 76 )
  JVS( 233) = W( 77 )
  IF ( ABS( JVS( 234 )) < TINY(a) ) THEN
         IER = 40
         RETURN
  END IF
   W( 40 ) = JVS( 234 )
   W( 65 ) = JVS( 235 )
   W( 74 ) = JVS( 236 )
   W( 75 ) = JVS( 237 )
   W( 76 ) = JVS( 238 )
   W( 78 ) = JVS( 239 )
  JVS( 234) = W( 40 )
  JVS( 235) = W( 65 )
  JVS( 236) = W( 74 )
  JVS( 237) = W( 75 )
  JVS( 238) = W( 76 )
  JVS( 239) = W( 78 )
  IF ( ABS( JVS( 241 )) < TINY(a) ) THEN
         IER = 41
         RETURN
  END IF
   W( 27 ) = JVS( 240 )
   W( 41 ) = JVS( 241 )
   W( 68 ) = JVS( 242 )
   W( 69 ) = JVS( 243 )
   W( 72 ) = JVS( 244 )
   W( 74 ) = JVS( 245 )
   W( 75 ) = JVS( 246 )
   W( 76 ) = JVS( 247 )
   W( 77 ) = JVS( 248 )
  a = -W( 27 ) / JVS( 129 )
  W( 27 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 130 )
  W( 75 ) = W( 75 ) + a*JVS( 131 )
  W( 76 ) = W( 76 ) + a*JVS( 132 )
  JVS( 240) = W( 27 )
  JVS( 241) = W( 41 )
  JVS( 242) = W( 68 )
  JVS( 243) = W( 69 )
  JVS( 244) = W( 72 )
  JVS( 245) = W( 74 )
  JVS( 246) = W( 75 )
  JVS( 247) = W( 76 )
  JVS( 248) = W( 77 )
  IF ( ABS( JVS( 249 )) < TINY(a) ) THEN
         IER = 42
         RETURN
  END IF
   W( 42 ) = JVS( 249 )
   W( 71 ) = JVS( 250 )
   W( 74 ) = JVS( 251 )
   W( 75 ) = JVS( 252 )
   W( 76 ) = JVS( 253 )
  JVS( 249) = W( 42 )
  JVS( 250) = W( 71 )
  JVS( 251) = W( 74 )
  JVS( 252) = W( 75 )
  JVS( 253) = W( 76 )
  IF ( ABS( JVS( 254 )) < TINY(a) ) THEN
         IER = 43
         RETURN
  END IF
   W( 43 ) = JVS( 254 )
   W( 59 ) = JVS( 255 )
   W( 68 ) = JVS( 256 )
   W( 69 ) = JVS( 257 )
   W( 72 ) = JVS( 258 )
   W( 74 ) = JVS( 259 )
   W( 76 ) = JVS( 260 )
   W( 77 ) = JVS( 261 )
  JVS( 254) = W( 43 )
  JVS( 255) = W( 59 )
  JVS( 256) = W( 68 )
  JVS( 257) = W( 69 )
  JVS( 258) = W( 72 )
  JVS( 259) = W( 74 )
  JVS( 260) = W( 76 )
  JVS( 261) = W( 77 )
  IF ( ABS( JVS( 262 )) < TINY(a) ) THEN
         IER = 44
         RETURN
  END IF
   W( 44 ) = JVS( 262 )
   W( 60 ) = JVS( 263 )
   W( 68 ) = JVS( 264 )
   W( 69 ) = JVS( 265 )
   W( 72 ) = JVS( 266 )
   W( 74 ) = JVS( 267 )
   W( 76 ) = JVS( 268 )
   W( 77 ) = JVS( 269 )
  JVS( 262) = W( 44 )
  JVS( 263) = W( 60 )
  JVS( 264) = W( 68 )
  JVS( 265) = W( 69 )
  JVS( 266) = W( 72 )
  JVS( 267) = W( 74 )
  JVS( 268) = W( 76 )
  JVS( 269) = W( 77 )
  IF ( ABS( JVS( 272 )) < TINY(a) ) THEN
         IER = 45
         RETURN
  END IF
   W( 26 ) = JVS( 270 )
   W( 40 ) = JVS( 271 )
   W( 45 ) = JVS( 272 )
   W( 46 ) = JVS( 273 )
   W( 51 ) = JVS( 274 )
   W( 52 ) = JVS( 275 )
   W( 56 ) = JVS( 276 )
   W( 64 ) = JVS( 277 )
   W( 65 ) = JVS( 278 )
   W( 67 ) = JVS( 279 )
   W( 68 ) = JVS( 280 )
   W( 72 ) = JVS( 281 )
   W( 73 ) = JVS( 282 )
   W( 74 ) = JVS( 283 )
   W( 75 ) = JVS( 284 )
   W( 76 ) = JVS( 285 )
   W( 77 ) = JVS( 286 )
   W( 78 ) = JVS( 287 )
  a = -W( 26 ) / JVS( 123 )
  W( 26 ) = -a
  W( 40 ) = W( 40 ) + a*JVS( 124 )
  W( 56 ) = W( 56 ) + a*JVS( 125 )
  W( 67 ) = W( 67 ) + a*JVS( 126 )
  W( 72 ) = W( 72 ) + a*JVS( 127 )
  W( 76 ) = W( 76 ) + a*JVS( 128 )
  a = -W( 40 ) / JVS( 234 )
  W( 40 ) = -a
  W( 65 ) = W( 65 ) + a*JVS( 235 )
  W( 74 ) = W( 74 ) + a*JVS( 236 )
  W( 75 ) = W( 75 ) + a*JVS( 237 )
  W( 76 ) = W( 76 ) + a*JVS( 238 )
  W( 78 ) = W( 78 ) + a*JVS( 239 )
  JVS( 270) = W( 26 )
  JVS( 271) = W( 40 )
  JVS( 272) = W( 45 )
  JVS( 273) = W( 46 )
  JVS( 274) = W( 51 )
  JVS( 275) = W( 52 )
  JVS( 276) = W( 56 )
  JVS( 277) = W( 64 )
  JVS( 278) = W( 65 )
  JVS( 279) = W( 67 )
  JVS( 280) = W( 68 )
  JVS( 281) = W( 72 )
  JVS( 282) = W( 73 )
  JVS( 283) = W( 74 )
  JVS( 284) = W( 75 )
  JVS( 285) = W( 76 )
  JVS( 286) = W( 77 )
  JVS( 287) = W( 78 )
  IF ( ABS( JVS( 290 )) < TINY(a) ) THEN
         IER = 46
         RETURN
  END IF
   W( 28 ) = JVS( 288 )
   W( 38 ) = JVS( 289 )
   W( 46 ) = JVS( 290 )
   W( 68 ) = JVS( 291 )
   W( 69 ) = JVS( 292 )
   W( 72 ) = JVS( 293 )
   W( 74 ) = JVS( 294 )
   W( 75 ) = JVS( 295 )
   W( 76 ) = JVS( 296 )
   W( 77 ) = JVS( 297 )
   W( 78 ) = JVS( 298 )
  a = -W( 28 ) / JVS( 133 )
  W( 28 ) = -a
  W( 38 ) = W( 38 ) + a*JVS( 134 )
  W( 75 ) = W( 75 ) + a*JVS( 135 )
  W( 76 ) = W( 76 ) + a*JVS( 136 )
  W( 78 ) = W( 78 ) + a*JVS( 137 )
  a = -W( 38 ) / JVS( 215 )
  W( 38 ) = -a
  W( 69 ) = W( 69 ) + a*JVS( 216 )
  W( 74 ) = W( 74 ) + a*JVS( 217 )
  W( 75 ) = W( 75 ) + a*JVS( 218 )
  W( 76 ) = W( 76 ) + a*JVS( 219 )
  W( 78 ) = W( 78 ) + a*JVS( 220 )
  JVS( 288) = W( 28 )
  JVS( 289) = W( 38 )
  JVS( 290) = W( 46 )
  JVS( 291) = W( 68 )
  JVS( 292) = W( 69 )
  JVS( 293) = W( 72 )
  JVS( 294) = W( 74 )
  JVS( 295) = W( 75 )
  JVS( 296) = W( 76 )
  JVS( 297) = W( 77 )
  JVS( 298) = W( 78 )
  IF ( ABS( JVS( 304 )) < TINY(a) ) THEN
         IER = 47
         RETURN
  END IF
   W( 9 ) = JVS( 299 )
   W( 16 ) = JVS( 300 )
   W( 34 ) = JVS( 301 )
   W( 43 ) = JVS( 302 )
   W( 44 ) = JVS( 303 )
   W( 47 ) = JVS( 304 )
   W( 49 ) = JVS( 305 )
   W( 50 ) = JVS( 306 )
   W( 53 ) = JVS( 307 )
   W( 55 ) = JVS( 308 )
   W( 59 ) = JVS( 309 )
   W( 60 ) = JVS( 310 )
   W( 61 ) = JVS( 311 )
   W( 62 ) = JVS( 312 )
   W( 64 ) = JVS( 313 )
   W( 67 ) = JVS( 314 )
   W( 68 ) = JVS( 315 )
   W( 69 ) = JVS( 316 )
   W( 70 ) = JVS( 317 )
   W( 72 ) = JVS( 318 )
   W( 73 ) = JVS( 319 )
   W( 74 ) = JVS( 320 )
   W( 75 ) = JVS( 321 )
   W( 76 ) = JVS( 322 )
   W( 77 ) = JVS( 323 )
  a = -W( 9 ) / JVS( 50 )
  W( 9 ) = -a
  W( 76 ) = W( 76 ) + a*JVS( 51 )
  a = -W( 16 ) / JVS( 68 )
  W( 16 ) = -a
  W( 64 ) = W( 64 ) + a*JVS( 69 )
  W( 76 ) = W( 76 ) + a*JVS( 70 )
  a = -W( 34 ) / JVS( 189 )
  W( 34 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 190 )
  W( 75 ) = W( 75 ) + a*JVS( 191 )
  W( 76 ) = W( 76 ) + a*JVS( 192 )
  a = -W( 43 ) / JVS( 254 )
  W( 43 ) = -a
  W( 59 ) = W( 59 ) + a*JVS( 255 )
  W( 68 ) = W( 68 ) + a*JVS( 256 )
  W( 69 ) = W( 69 ) + a*JVS( 257 )
  W( 72 ) = W( 72 ) + a*JVS( 258 )
  W( 74 ) = W( 74 ) + a*JVS( 259 )
  W( 76 ) = W( 76 ) + a*JVS( 260 )
  W( 77 ) = W( 77 ) + a*JVS( 261 )
  a = -W( 44 ) / JVS( 262 )
  W( 44 ) = -a
  W( 60 ) = W( 60 ) + a*JVS( 263 )
  W( 68 ) = W( 68 ) + a*JVS( 264 )
  W( 69 ) = W( 69 ) + a*JVS( 265 )
  W( 72 ) = W( 72 ) + a*JVS( 266 )
  W( 74 ) = W( 74 ) + a*JVS( 267 )
  W( 76 ) = W( 76 ) + a*JVS( 268 )
  W( 77 ) = W( 77 ) + a*JVS( 269 )
  JVS( 299) = W( 9 )
  JVS( 300) = W( 16 )
  JVS( 301) = W( 34 )
  JVS( 302) = W( 43 )
  JVS( 303) = W( 44 )
  JVS( 304) = W( 47 )
  JVS( 305) = W( 49 )
  JVS( 306) = W( 50 )
  JVS( 307) = W( 53 )
  JVS( 308) = W( 55 )
  JVS( 309) = W( 59 )
  JVS( 310) = W( 60 )
  JVS( 311) = W( 61 )
  JVS( 312) = W( 62 )
  JVS( 313) = W( 64 )
  JVS( 314) = W( 67 )
  JVS( 315) = W( 68 )
  JVS( 316) = W( 69 )
  JVS( 317) = W( 70 )
  JVS( 318) = W( 72 )
  JVS( 319) = W( 73 )
  JVS( 320) = W( 74 )
  JVS( 321) = W( 75 )
  JVS( 322) = W( 76 )
  JVS( 323) = W( 77 )
  IF ( ABS( JVS( 325 )) < TINY(a) ) THEN
         IER = 48
         RETURN
  END IF
   W( 36 ) = JVS( 324 )
   W( 48 ) = JVS( 325 )
   W( 68 ) = JVS( 326 )
   W( 69 ) = JVS( 327 )
   W( 72 ) = JVS( 328 )
   W( 74 ) = JVS( 329 )
   W( 75 ) = JVS( 330 )
   W( 76 ) = JVS( 331 )
   W( 77 ) = JVS( 332 )
  a = -W( 36 ) / JVS( 203 )
  W( 36 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 204 )
  W( 75 ) = W( 75 ) + a*JVS( 205 )
  W( 76 ) = W( 76 ) + a*JVS( 206 )
  JVS( 324) = W( 36 )
  JVS( 325) = W( 48 )
  JVS( 326) = W( 68 )
  JVS( 327) = W( 69 )
  JVS( 328) = W( 72 )
  JVS( 329) = W( 74 )
  JVS( 330) = W( 75 )
  JVS( 331) = W( 76 )
  JVS( 332) = W( 77 )
  IF ( ABS( JVS( 334 )) < TINY(a) ) THEN
         IER = 49
         RETURN
  END IF
   W( 9 ) = JVS( 333 )
   W( 49 ) = JVS( 334 )
   W( 68 ) = JVS( 335 )
   W( 69 ) = JVS( 336 )
   W( 72 ) = JVS( 337 )
   W( 74 ) = JVS( 338 )
   W( 76 ) = JVS( 339 )
   W( 77 ) = JVS( 340 )
  a = -W( 9 ) / JVS( 50 )
  W( 9 ) = -a
  W( 76 ) = W( 76 ) + a*JVS( 51 )
  JVS( 333) = W( 9 )
  JVS( 334) = W( 49 )
  JVS( 335) = W( 68 )
  JVS( 336) = W( 69 )
  JVS( 337) = W( 72 )
  JVS( 338) = W( 74 )
  JVS( 339) = W( 76 )
  JVS( 340) = W( 77 )
  IF ( ABS( JVS( 342 )) < TINY(a) ) THEN
         IER = 50
         RETURN
  END IF
   W( 13 ) = JVS( 341 )
   W( 50 ) = JVS( 342 )
   W( 68 ) = JVS( 343 )
   W( 69 ) = JVS( 344 )
   W( 72 ) = JVS( 345 )
   W( 74 ) = JVS( 346 )
   W( 76 ) = JVS( 347 )
   W( 77 ) = JVS( 348 )
  a = -W( 13 ) / JVS( 59 )
  W( 13 ) = -a
  W( 76 ) = W( 76 ) + a*JVS( 60 )
  JVS( 341) = W( 13 )
  JVS( 342) = W( 50 )
  JVS( 343) = W( 68 )
  JVS( 344) = W( 69 )
  JVS( 345) = W( 72 )
  JVS( 346) = W( 74 )
  JVS( 347) = W( 76 )
  JVS( 348) = W( 77 )
  IF ( ABS( JVS( 350 )) < TINY(a) ) THEN
         IER = 51
         RETURN
  END IF
   W( 24 ) = JVS( 349 )
   W( 51 ) = JVS( 350 )
   W( 68 ) = JVS( 351 )
   W( 69 ) = JVS( 352 )
   W( 72 ) = JVS( 353 )
   W( 74 ) = JVS( 354 )
   W( 75 ) = JVS( 355 )
   W( 76 ) = JVS( 356 )
   W( 77 ) = JVS( 357 )
   W( 78 ) = JVS( 358 )
  a = -W( 24 ) / JVS( 113 )
  W( 24 ) = -a
  W( 75 ) = W( 75 ) + a*JVS( 114 )
  W( 76 ) = W( 76 ) + a*JVS( 115 )
  W( 78 ) = W( 78 ) + a*JVS( 116 )
  JVS( 349) = W( 24 )
  JVS( 350) = W( 51 )
  JVS( 351) = W( 68 )
  JVS( 352) = W( 69 )
  JVS( 353) = W( 72 )
  JVS( 354) = W( 74 )
  JVS( 355) = W( 75 )
  JVS( 356) = W( 76 )
  JVS( 357) = W( 77 )
  JVS( 358) = W( 78 )
  IF ( ABS( JVS( 360 )) < TINY(a) ) THEN
         IER = 52
         RETURN
  END IF
   W( 25 ) = JVS( 359 )
   W( 52 ) = JVS( 360 )
   W( 68 ) = JVS( 361 )
   W( 69 ) = JVS( 362 )
   W( 72 ) = JVS( 363 )
   W( 74 ) = JVS( 364 )
   W( 75 ) = JVS( 365 )
   W( 76 ) = JVS( 366 )
   W( 77 ) = JVS( 367 )
   W( 78 ) = JVS( 368 )
  a = -W( 25 ) / JVS( 118 )
  W( 25 ) = -a
  W( 75 ) = W( 75 ) + a*JVS( 119 )
  W( 76 ) = W( 76 ) + a*JVS( 120 )
  W( 78 ) = W( 78 ) + a*JVS( 121 )
  JVS( 359) = W( 25 )
  JVS( 360) = W( 52 )
  JVS( 361) = W( 68 )
  JVS( 362) = W( 69 )
  JVS( 363) = W( 72 )
  JVS( 364) = W( 74 )
  JVS( 365) = W( 75 )
  JVS( 366) = W( 76 )
  JVS( 367) = W( 77 )
  JVS( 368) = W( 78 )
  IF ( ABS( JVS( 370 )) < TINY(a) ) THEN
         IER = 53
         RETURN
  END IF
   W( 34 ) = JVS( 369 )
   W( 53 ) = JVS( 370 )
   W( 68 ) = JVS( 371 )
   W( 69 ) = JVS( 372 )
   W( 72 ) = JVS( 373 )
   W( 74 ) = JVS( 374 )
   W( 75 ) = JVS( 375 )
   W( 76 ) = JVS( 376 )
   W( 77 ) = JVS( 377 )
  a = -W( 34 ) / JVS( 189 )
  W( 34 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 190 )
  W( 75 ) = W( 75 ) + a*JVS( 191 )
  W( 76 ) = W( 76 ) + a*JVS( 192 )
  JVS( 369) = W( 34 )
  JVS( 370) = W( 53 )
  JVS( 371) = W( 68 )
  JVS( 372) = W( 69 )
  JVS( 373) = W( 72 )
  JVS( 374) = W( 74 )
  JVS( 375) = W( 75 )
  JVS( 376) = W( 76 )
  JVS( 377) = W( 77 )
  IF ( ABS( JVS( 380 )) < TINY(a) ) THEN
         IER = 54
         RETURN
  END IF
   W( 37 ) = JVS( 378 )
   W( 42 ) = JVS( 379 )
   W( 54 ) = JVS( 380 )
   W( 68 ) = JVS( 381 )
   W( 69 ) = JVS( 382 )
   W( 71 ) = JVS( 383 )
   W( 72 ) = JVS( 384 )
   W( 74 ) = JVS( 385 )
   W( 75 ) = JVS( 386 )
   W( 76 ) = JVS( 387 )
   W( 77 ) = JVS( 388 )
  a = -W( 37 ) / JVS( 207 )
  W( 37 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 208 )
  W( 75 ) = W( 75 ) + a*JVS( 209 )
  W( 76 ) = W( 76 ) + a*JVS( 210 )
  a = -W( 42 ) / JVS( 249 )
  W( 42 ) = -a
  W( 71 ) = W( 71 ) + a*JVS( 250 )
  W( 74 ) = W( 74 ) + a*JVS( 251 )
  W( 75 ) = W( 75 ) + a*JVS( 252 )
  W( 76 ) = W( 76 ) + a*JVS( 253 )
  JVS( 378) = W( 37 )
  JVS( 379) = W( 42 )
  JVS( 380) = W( 54 )
  JVS( 381) = W( 68 )
  JVS( 382) = W( 69 )
  JVS( 383) = W( 71 )
  JVS( 384) = W( 72 )
  JVS( 385) = W( 74 )
  JVS( 386) = W( 75 )
  JVS( 387) = W( 76 )
  JVS( 388) = W( 77 )
  IF ( ABS( JVS( 399 )) < TINY(a) ) THEN
         IER = 55
         RETURN
  END IF
   W( 23 ) = JVS( 389 )
   W( 38 ) = JVS( 390 )
   W( 40 ) = JVS( 391 )
   W( 48 ) = JVS( 392 )
   W( 49 ) = JVS( 393 )
   W( 50 ) = JVS( 394 )
   W( 51 ) = JVS( 395 )
   W( 52 ) = JVS( 396 )
   W( 53 ) = JVS( 397 )
   W( 54 ) = JVS( 398 )
   W( 55 ) = JVS( 399 )
   W( 61 ) = JVS( 400 )
   W( 62 ) = JVS( 401 )
   W( 65 ) = JVS( 402 )
   W( 68 ) = JVS( 403 )
   W( 69 ) = JVS( 404 )
   W( 71 ) = JVS( 405 )
   W( 72 ) = JVS( 406 )
   W( 73 ) = JVS( 407 )
   W( 74 ) = JVS( 408 )
   W( 75 ) = JVS( 409 )
   W( 76 ) = JVS( 410 )
   W( 77 ) = JVS( 411 )
   W( 78 ) = JVS( 412 )
  a = -W( 23 ) / JVS( 106 )
  W( 23 ) = -a
  W( 38 ) = W( 38 ) + a*JVS( 107 )
  W( 69 ) = W( 69 ) + a*JVS( 108 )
  W( 74 ) = W( 74 ) + a*JVS( 109 )
  W( 76 ) = W( 76 ) + a*JVS( 110 )
  W( 78 ) = W( 78 ) + a*JVS( 111 )
  a = -W( 38 ) / JVS( 215 )
  W( 38 ) = -a
  W( 69 ) = W( 69 ) + a*JVS( 216 )
  W( 74 ) = W( 74 ) + a*JVS( 217 )
  W( 75 ) = W( 75 ) + a*JVS( 218 )
  W( 76 ) = W( 76 ) + a*JVS( 219 )
  W( 78 ) = W( 78 ) + a*JVS( 220 )
  a = -W( 40 ) / JVS( 234 )
  W( 40 ) = -a
  W( 65 ) = W( 65 ) + a*JVS( 235 )
  W( 74 ) = W( 74 ) + a*JVS( 236 )
  W( 75 ) = W( 75 ) + a*JVS( 237 )
  W( 76 ) = W( 76 ) + a*JVS( 238 )
  W( 78 ) = W( 78 ) + a*JVS( 239 )
  a = -W( 48 ) / JVS( 325 )
  W( 48 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 326 )
  W( 69 ) = W( 69 ) + a*JVS( 327 )
  W( 72 ) = W( 72 ) + a*JVS( 328 )
  W( 74 ) = W( 74 ) + a*JVS( 329 )
  W( 75 ) = W( 75 ) + a*JVS( 330 )
  W( 76 ) = W( 76 ) + a*JVS( 331 )
  W( 77 ) = W( 77 ) + a*JVS( 332 )
  a = -W( 49 ) / JVS( 334 )
  W( 49 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 335 )
  W( 69 ) = W( 69 ) + a*JVS( 336 )
  W( 72 ) = W( 72 ) + a*JVS( 337 )
  W( 74 ) = W( 74 ) + a*JVS( 338 )
  W( 76 ) = W( 76 ) + a*JVS( 339 )
  W( 77 ) = W( 77 ) + a*JVS( 340 )
  a = -W( 50 ) / JVS( 342 )
  W( 50 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 343 )
  W( 69 ) = W( 69 ) + a*JVS( 344 )
  W( 72 ) = W( 72 ) + a*JVS( 345 )
  W( 74 ) = W( 74 ) + a*JVS( 346 )
  W( 76 ) = W( 76 ) + a*JVS( 347 )
  W( 77 ) = W( 77 ) + a*JVS( 348 )
  a = -W( 51 ) / JVS( 350 )
  W( 51 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 351 )
  W( 69 ) = W( 69 ) + a*JVS( 352 )
  W( 72 ) = W( 72 ) + a*JVS( 353 )
  W( 74 ) = W( 74 ) + a*JVS( 354 )
  W( 75 ) = W( 75 ) + a*JVS( 355 )
  W( 76 ) = W( 76 ) + a*JVS( 356 )
  W( 77 ) = W( 77 ) + a*JVS( 357 )
  W( 78 ) = W( 78 ) + a*JVS( 358 )
  a = -W( 52 ) / JVS( 360 )
  W( 52 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 361 )
  W( 69 ) = W( 69 ) + a*JVS( 362 )
  W( 72 ) = W( 72 ) + a*JVS( 363 )
  W( 74 ) = W( 74 ) + a*JVS( 364 )
  W( 75 ) = W( 75 ) + a*JVS( 365 )
  W( 76 ) = W( 76 ) + a*JVS( 366 )
  W( 77 ) = W( 77 ) + a*JVS( 367 )
  W( 78 ) = W( 78 ) + a*JVS( 368 )
  a = -W( 53 ) / JVS( 370 )
  W( 53 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 371 )
  W( 69 ) = W( 69 ) + a*JVS( 372 )
  W( 72 ) = W( 72 ) + a*JVS( 373 )
  W( 74 ) = W( 74 ) + a*JVS( 374 )
  W( 75 ) = W( 75 ) + a*JVS( 375 )
  W( 76 ) = W( 76 ) + a*JVS( 376 )
  W( 77 ) = W( 77 ) + a*JVS( 377 )
  a = -W( 54 ) / JVS( 380 )
  W( 54 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 381 )
  W( 69 ) = W( 69 ) + a*JVS( 382 )
  W( 71 ) = W( 71 ) + a*JVS( 383 )
  W( 72 ) = W( 72 ) + a*JVS( 384 )
  W( 74 ) = W( 74 ) + a*JVS( 385 )
  W( 75 ) = W( 75 ) + a*JVS( 386 )
  W( 76 ) = W( 76 ) + a*JVS( 387 )
  W( 77 ) = W( 77 ) + a*JVS( 388 )
  JVS( 389) = W( 23 )
  JVS( 390) = W( 38 )
  JVS( 391) = W( 40 )
  JVS( 392) = W( 48 )
  JVS( 393) = W( 49 )
  JVS( 394) = W( 50 )
  JVS( 395) = W( 51 )
  JVS( 396) = W( 52 )
  JVS( 397) = W( 53 )
  JVS( 398) = W( 54 )
  JVS( 399) = W( 55 )
  JVS( 400) = W( 61 )
  JVS( 401) = W( 62 )
  JVS( 402) = W( 65 )
  JVS( 403) = W( 68 )
  JVS( 404) = W( 69 )
  JVS( 405) = W( 71 )
  JVS( 406) = W( 72 )
  JVS( 407) = W( 73 )
  JVS( 408) = W( 74 )
  JVS( 409) = W( 75 )
  JVS( 410) = W( 76 )
  JVS( 411) = W( 77 )
  JVS( 412) = W( 78 )
  IF ( ABS( JVS( 418 )) < TINY(a) ) THEN
         IER = 56
         RETURN
  END IF
   W( 36 ) = JVS( 413 )
   W( 37 ) = JVS( 414 )
   W( 42 ) = JVS( 415 )
   W( 48 ) = JVS( 416 )
   W( 54 ) = JVS( 417 )
   W( 56 ) = JVS( 418 )
   W( 68 ) = JVS( 419 )
   W( 69 ) = JVS( 420 )
   W( 71 ) = JVS( 421 )
   W( 72 ) = JVS( 422 )
   W( 74 ) = JVS( 423 )
   W( 75 ) = JVS( 424 )
   W( 76 ) = JVS( 425 )
   W( 77 ) = JVS( 426 )
  a = -W( 36 ) / JVS( 203 )
  W( 36 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 204 )
  W( 75 ) = W( 75 ) + a*JVS( 205 )
  W( 76 ) = W( 76 ) + a*JVS( 206 )
  a = -W( 37 ) / JVS( 207 )
  W( 37 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 208 )
  W( 75 ) = W( 75 ) + a*JVS( 209 )
  W( 76 ) = W( 76 ) + a*JVS( 210 )
  a = -W( 42 ) / JVS( 249 )
  W( 42 ) = -a
  W( 71 ) = W( 71 ) + a*JVS( 250 )
  W( 74 ) = W( 74 ) + a*JVS( 251 )
  W( 75 ) = W( 75 ) + a*JVS( 252 )
  W( 76 ) = W( 76 ) + a*JVS( 253 )
  a = -W( 48 ) / JVS( 325 )
  W( 48 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 326 )
  W( 69 ) = W( 69 ) + a*JVS( 327 )
  W( 72 ) = W( 72 ) + a*JVS( 328 )
  W( 74 ) = W( 74 ) + a*JVS( 329 )
  W( 75 ) = W( 75 ) + a*JVS( 330 )
  W( 76 ) = W( 76 ) + a*JVS( 331 )
  W( 77 ) = W( 77 ) + a*JVS( 332 )
  a = -W( 54 ) / JVS( 380 )
  W( 54 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 381 )
  W( 69 ) = W( 69 ) + a*JVS( 382 )
  W( 71 ) = W( 71 ) + a*JVS( 383 )
  W( 72 ) = W( 72 ) + a*JVS( 384 )
  W( 74 ) = W( 74 ) + a*JVS( 385 )
  W( 75 ) = W( 75 ) + a*JVS( 386 )
  W( 76 ) = W( 76 ) + a*JVS( 387 )
  W( 77 ) = W( 77 ) + a*JVS( 388 )
  JVS( 413) = W( 36 )
  JVS( 414) = W( 37 )
  JVS( 415) = W( 42 )
  JVS( 416) = W( 48 )
  JVS( 417) = W( 54 )
  JVS( 418) = W( 56 )
  JVS( 419) = W( 68 )
  JVS( 420) = W( 69 )
  JVS( 421) = W( 71 )
  JVS( 422) = W( 72 )
  JVS( 423) = W( 74 )
  JVS( 424) = W( 75 )
  JVS( 425) = W( 76 )
  JVS( 426) = W( 77 )
  IF ( ABS( JVS( 438 )) < TINY(a) ) THEN
         IER = 57
         RETURN
  END IF
   W( 10 ) = JVS( 427 )
   W( 11 ) = JVS( 428 )
   W( 30 ) = JVS( 429 )
   W( 32 ) = JVS( 430 )
   W( 37 ) = JVS( 431 )
   W( 38 ) = JVS( 432 )
   W( 40 ) = JVS( 433 )
   W( 42 ) = JVS( 434 )
   W( 49 ) = JVS( 435 )
   W( 50 ) = JVS( 436 )
   W( 56 ) = JVS( 437 )
   W( 57 ) = JVS( 438 )
   W( 64 ) = JVS( 439 )
   W( 65 ) = JVS( 440 )
   W( 67 ) = JVS( 441 )
   W( 68 ) = JVS( 442 )
   W( 69 ) = JVS( 443 )
   W( 70 ) = JVS( 444 )
   W( 71 ) = JVS( 445 )
   W( 72 ) = JVS( 446 )
   W( 73 ) = JVS( 447 )
   W( 74 ) = JVS( 448 )
   W( 75 ) = JVS( 449 )
   W( 76 ) = JVS( 450 )
   W( 77 ) = JVS( 451 )
   W( 78 ) = JVS( 452 )
  a = -W( 10 ) / JVS( 52 )
  W( 10 ) = -a
  W( 76 ) = W( 76 ) + a*JVS( 53 )
  a = -W( 11 ) / JVS( 54 )
  W( 11 ) = -a
  W( 76 ) = W( 76 ) + a*JVS( 55 )
  a = -W( 30 ) / JVS( 143 )
  W( 30 ) = -a
  W( 64 ) = W( 64 ) + a*JVS( 144 )
  W( 68 ) = W( 68 ) + a*JVS( 145 )
  W( 69 ) = W( 69 ) + a*JVS( 146 )
  W( 75 ) = W( 75 ) + a*JVS( 147 )
  W( 76 ) = W( 76 ) + a*JVS( 148 )
  a = -W( 32 ) / JVS( 161 )
  W( 32 ) = -a
  W( 40 ) = W( 40 ) + a*JVS( 162 )
  W( 68 ) = W( 68 ) + a*JVS( 163 )
  W( 74 ) = W( 74 ) + a*JVS( 164 )
  W( 75 ) = W( 75 ) + a*JVS( 165 )
  W( 76 ) = W( 76 ) + a*JVS( 166 )
  W( 78 ) = W( 78 ) + a*JVS( 167 )
  a = -W( 37 ) / JVS( 207 )
  W( 37 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 208 )
  W( 75 ) = W( 75 ) + a*JVS( 209 )
  W( 76 ) = W( 76 ) + a*JVS( 210 )
  a = -W( 38 ) / JVS( 215 )
  W( 38 ) = -a
  W( 69 ) = W( 69 ) + a*JVS( 216 )
  W( 74 ) = W( 74 ) + a*JVS( 217 )
  W( 75 ) = W( 75 ) + a*JVS( 218 )
  W( 76 ) = W( 76 ) + a*JVS( 219 )
  W( 78 ) = W( 78 ) + a*JVS( 220 )
  a = -W( 40 ) / JVS( 234 )
  W( 40 ) = -a
  W( 65 ) = W( 65 ) + a*JVS( 235 )
  W( 74 ) = W( 74 ) + a*JVS( 236 )
  W( 75 ) = W( 75 ) + a*JVS( 237 )
  W( 76 ) = W( 76 ) + a*JVS( 238 )
  W( 78 ) = W( 78 ) + a*JVS( 239 )
  a = -W( 42 ) / JVS( 249 )
  W( 42 ) = -a
  W( 71 ) = W( 71 ) + a*JVS( 250 )
  W( 74 ) = W( 74 ) + a*JVS( 251 )
  W( 75 ) = W( 75 ) + a*JVS( 252 )
  W( 76 ) = W( 76 ) + a*JVS( 253 )
  a = -W( 49 ) / JVS( 334 )
  W( 49 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 335 )
  W( 69 ) = W( 69 ) + a*JVS( 336 )
  W( 72 ) = W( 72 ) + a*JVS( 337 )
  W( 74 ) = W( 74 ) + a*JVS( 338 )
  W( 76 ) = W( 76 ) + a*JVS( 339 )
  W( 77 ) = W( 77 ) + a*JVS( 340 )
  a = -W( 50 ) / JVS( 342 )
  W( 50 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 343 )
  W( 69 ) = W( 69 ) + a*JVS( 344 )
  W( 72 ) = W( 72 ) + a*JVS( 345 )
  W( 74 ) = W( 74 ) + a*JVS( 346 )
  W( 76 ) = W( 76 ) + a*JVS( 347 )
  W( 77 ) = W( 77 ) + a*JVS( 348 )
  a = -W( 56 ) / JVS( 418 )
  W( 56 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 419 )
  W( 69 ) = W( 69 ) + a*JVS( 420 )
  W( 71 ) = W( 71 ) + a*JVS( 421 )
  W( 72 ) = W( 72 ) + a*JVS( 422 )
  W( 74 ) = W( 74 ) + a*JVS( 423 )
  W( 75 ) = W( 75 ) + a*JVS( 424 )
  W( 76 ) = W( 76 ) + a*JVS( 425 )
  W( 77 ) = W( 77 ) + a*JVS( 426 )
  JVS( 427) = W( 10 )
  JVS( 428) = W( 11 )
  JVS( 429) = W( 30 )
  JVS( 430) = W( 32 )
  JVS( 431) = W( 37 )
  JVS( 432) = W( 38 )
  JVS( 433) = W( 40 )
  JVS( 434) = W( 42 )
  JVS( 435) = W( 49 )
  JVS( 436) = W( 50 )
  JVS( 437) = W( 56 )
  JVS( 438) = W( 57 )
  JVS( 439) = W( 64 )
  JVS( 440) = W( 65 )
  JVS( 441) = W( 67 )
  JVS( 442) = W( 68 )
  JVS( 443) = W( 69 )
  JVS( 444) = W( 70 )
  JVS( 445) = W( 71 )
  JVS( 446) = W( 72 )
  JVS( 447) = W( 73 )
  JVS( 448) = W( 74 )
  JVS( 449) = W( 75 )
  JVS( 450) = W( 76 )
  JVS( 451) = W( 77 )
  JVS( 452) = W( 78 )
  IF ( ABS( JVS( 465 )) < TINY(a) ) THEN
         IER = 58
         RETURN
  END IF
   W( 13 ) = JVS( 453 )
   W( 14 ) = JVS( 454 )
   W( 16 ) = JVS( 455 )
   W( 34 ) = JVS( 456 )
   W( 41 ) = JVS( 457 )
   W( 43 ) = JVS( 458 )
   W( 44 ) = JVS( 459 )
   W( 49 ) = JVS( 460 )
   W( 50 ) = JVS( 461 )
   W( 53 ) = JVS( 462 )
   W( 55 ) = JVS( 463 )
   W( 56 ) = JVS( 464 )
   W( 58 ) = JVS( 465 )
   W( 59 ) = JVS( 466 )
   W( 60 ) = JVS( 467 )
   W( 61 ) = JVS( 468 )
   W( 62 ) = JVS( 469 )
   W( 64 ) = JVS( 470 )
   W( 65 ) = JVS( 471 )
   W( 66 ) = JVS( 472 )
   W( 67 ) = JVS( 473 )
   W( 68 ) = JVS( 474 )
   W( 69 ) = JVS( 475 )
   W( 70 ) = JVS( 476 )
   W( 71 ) = JVS( 477 )
   W( 72 ) = JVS( 478 )
   W( 73 ) = JVS( 479 )
   W( 74 ) = JVS( 480 )
   W( 75 ) = JVS( 481 )
   W( 76 ) = JVS( 482 )
   W( 77 ) = JVS( 483 )
   W( 78 ) = JVS( 484 )
  a = -W( 13 ) / JVS( 59 )
  W( 13 ) = -a
  W( 76 ) = W( 76 ) + a*JVS( 60 )
  a = -W( 14 ) / JVS( 61 )
  W( 14 ) = -a
  W( 76 ) = W( 76 ) + a*JVS( 62 )
  a = -W( 16 ) / JVS( 68 )
  W( 16 ) = -a
  W( 64 ) = W( 64 ) + a*JVS( 69 )
  W( 76 ) = W( 76 ) + a*JVS( 70 )
  a = -W( 34 ) / JVS( 189 )
  W( 34 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 190 )
  W( 75 ) = W( 75 ) + a*JVS( 191 )
  W( 76 ) = W( 76 ) + a*JVS( 192 )
  a = -W( 41 ) / JVS( 241 )
  W( 41 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 242 )
  W( 69 ) = W( 69 ) + a*JVS( 243 )
  W( 72 ) = W( 72 ) + a*JVS( 244 )
  W( 74 ) = W( 74 ) + a*JVS( 245 )
  W( 75 ) = W( 75 ) + a*JVS( 246 )
  W( 76 ) = W( 76 ) + a*JVS( 247 )
  W( 77 ) = W( 77 ) + a*JVS( 248 )
  a = -W( 43 ) / JVS( 254 )
  W( 43 ) = -a
  W( 59 ) = W( 59 ) + a*JVS( 255 )
  W( 68 ) = W( 68 ) + a*JVS( 256 )
  W( 69 ) = W( 69 ) + a*JVS( 257 )
  W( 72 ) = W( 72 ) + a*JVS( 258 )
  W( 74 ) = W( 74 ) + a*JVS( 259 )
  W( 76 ) = W( 76 ) + a*JVS( 260 )
  W( 77 ) = W( 77 ) + a*JVS( 261 )
  a = -W( 44 ) / JVS( 262 )
  W( 44 ) = -a
  W( 60 ) = W( 60 ) + a*JVS( 263 )
  W( 68 ) = W( 68 ) + a*JVS( 264 )
  W( 69 ) = W( 69 ) + a*JVS( 265 )
  W( 72 ) = W( 72 ) + a*JVS( 266 )
  W( 74 ) = W( 74 ) + a*JVS( 267 )
  W( 76 ) = W( 76 ) + a*JVS( 268 )
  W( 77 ) = W( 77 ) + a*JVS( 269 )
  a = -W( 49 ) / JVS( 334 )
  W( 49 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 335 )
  W( 69 ) = W( 69 ) + a*JVS( 336 )
  W( 72 ) = W( 72 ) + a*JVS( 337 )
  W( 74 ) = W( 74 ) + a*JVS( 338 )
  W( 76 ) = W( 76 ) + a*JVS( 339 )
  W( 77 ) = W( 77 ) + a*JVS( 340 )
  a = -W( 50 ) / JVS( 342 )
  W( 50 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 343 )
  W( 69 ) = W( 69 ) + a*JVS( 344 )
  W( 72 ) = W( 72 ) + a*JVS( 345 )
  W( 74 ) = W( 74 ) + a*JVS( 346 )
  W( 76 ) = W( 76 ) + a*JVS( 347 )
  W( 77 ) = W( 77 ) + a*JVS( 348 )
  a = -W( 53 ) / JVS( 370 )
  W( 53 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 371 )
  W( 69 ) = W( 69 ) + a*JVS( 372 )
  W( 72 ) = W( 72 ) + a*JVS( 373 )
  W( 74 ) = W( 74 ) + a*JVS( 374 )
  W( 75 ) = W( 75 ) + a*JVS( 375 )
  W( 76 ) = W( 76 ) + a*JVS( 376 )
  W( 77 ) = W( 77 ) + a*JVS( 377 )
  a = -W( 55 ) / JVS( 399 )
  W( 55 ) = -a
  W( 61 ) = W( 61 ) + a*JVS( 400 )
  W( 62 ) = W( 62 ) + a*JVS( 401 )
  W( 65 ) = W( 65 ) + a*JVS( 402 )
  W( 68 ) = W( 68 ) + a*JVS( 403 )
  W( 69 ) = W( 69 ) + a*JVS( 404 )
  W( 71 ) = W( 71 ) + a*JVS( 405 )
  W( 72 ) = W( 72 ) + a*JVS( 406 )
  W( 73 ) = W( 73 ) + a*JVS( 407 )
  W( 74 ) = W( 74 ) + a*JVS( 408 )
  W( 75 ) = W( 75 ) + a*JVS( 409 )
  W( 76 ) = W( 76 ) + a*JVS( 410 )
  W( 77 ) = W( 77 ) + a*JVS( 411 )
  W( 78 ) = W( 78 ) + a*JVS( 412 )
  a = -W( 56 ) / JVS( 418 )
  W( 56 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 419 )
  W( 69 ) = W( 69 ) + a*JVS( 420 )
  W( 71 ) = W( 71 ) + a*JVS( 421 )
  W( 72 ) = W( 72 ) + a*JVS( 422 )
  W( 74 ) = W( 74 ) + a*JVS( 423 )
  W( 75 ) = W( 75 ) + a*JVS( 424 )
  W( 76 ) = W( 76 ) + a*JVS( 425 )
  W( 77 ) = W( 77 ) + a*JVS( 426 )
  JVS( 453) = W( 13 )
  JVS( 454) = W( 14 )
  JVS( 455) = W( 16 )
  JVS( 456) = W( 34 )
  JVS( 457) = W( 41 )
  JVS( 458) = W( 43 )
  JVS( 459) = W( 44 )
  JVS( 460) = W( 49 )
  JVS( 461) = W( 50 )
  JVS( 462) = W( 53 )
  JVS( 463) = W( 55 )
  JVS( 464) = W( 56 )
  JVS( 465) = W( 58 )
  JVS( 466) = W( 59 )
  JVS( 467) = W( 60 )
  JVS( 468) = W( 61 )
  JVS( 469) = W( 62 )
  JVS( 470) = W( 64 )
  JVS( 471) = W( 65 )
  JVS( 472) = W( 66 )
  JVS( 473) = W( 67 )
  JVS( 474) = W( 68 )
  JVS( 475) = W( 69 )
  JVS( 476) = W( 70 )
  JVS( 477) = W( 71 )
  JVS( 478) = W( 72 )
  JVS( 479) = W( 73 )
  JVS( 480) = W( 74 )
  JVS( 481) = W( 75 )
  JVS( 482) = W( 76 )
  JVS( 483) = W( 77 )
  JVS( 484) = W( 78 )
  IF ( ABS( JVS( 489 )) < TINY(a) ) THEN
         IER = 59
         RETURN
  END IF
   W( 36 ) = JVS( 485 )
   W( 37 ) = JVS( 486 )
   W( 42 ) = JVS( 487 )
   W( 54 ) = JVS( 488 )
   W( 59 ) = JVS( 489 )
   W( 68 ) = JVS( 490 )
   W( 69 ) = JVS( 491 )
   W( 71 ) = JVS( 492 )
   W( 72 ) = JVS( 493 )
   W( 74 ) = JVS( 494 )
   W( 75 ) = JVS( 495 )
   W( 76 ) = JVS( 496 )
   W( 77 ) = JVS( 497 )
  a = -W( 36 ) / JVS( 203 )
  W( 36 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 204 )
  W( 75 ) = W( 75 ) + a*JVS( 205 )
  W( 76 ) = W( 76 ) + a*JVS( 206 )
  a = -W( 37 ) / JVS( 207 )
  W( 37 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 208 )
  W( 75 ) = W( 75 ) + a*JVS( 209 )
  W( 76 ) = W( 76 ) + a*JVS( 210 )
  a = -W( 42 ) / JVS( 249 )
  W( 42 ) = -a
  W( 71 ) = W( 71 ) + a*JVS( 250 )
  W( 74 ) = W( 74 ) + a*JVS( 251 )
  W( 75 ) = W( 75 ) + a*JVS( 252 )
  W( 76 ) = W( 76 ) + a*JVS( 253 )
  a = -W( 54 ) / JVS( 380 )
  W( 54 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 381 )
  W( 69 ) = W( 69 ) + a*JVS( 382 )
  W( 71 ) = W( 71 ) + a*JVS( 383 )
  W( 72 ) = W( 72 ) + a*JVS( 384 )
  W( 74 ) = W( 74 ) + a*JVS( 385 )
  W( 75 ) = W( 75 ) + a*JVS( 386 )
  W( 76 ) = W( 76 ) + a*JVS( 387 )
  W( 77 ) = W( 77 ) + a*JVS( 388 )
  JVS( 485) = W( 36 )
  JVS( 486) = W( 37 )
  JVS( 487) = W( 42 )
  JVS( 488) = W( 54 )
  JVS( 489) = W( 59 )
  JVS( 490) = W( 68 )
  JVS( 491) = W( 69 )
  JVS( 492) = W( 71 )
  JVS( 493) = W( 72 )
  JVS( 494) = W( 74 )
  JVS( 495) = W( 75 )
  JVS( 496) = W( 76 )
  JVS( 497) = W( 77 )
  IF ( ABS( JVS( 500 )) < TINY(a) ) THEN
         IER = 60
         RETURN
  END IF
   W( 48 ) = JVS( 498 )
   W( 54 ) = JVS( 499 )
   W( 60 ) = JVS( 500 )
   W( 68 ) = JVS( 501 )
   W( 69 ) = JVS( 502 )
   W( 71 ) = JVS( 503 )
   W( 72 ) = JVS( 504 )
   W( 74 ) = JVS( 505 )
   W( 75 ) = JVS( 506 )
   W( 76 ) = JVS( 507 )
   W( 77 ) = JVS( 508 )
  a = -W( 48 ) / JVS( 325 )
  W( 48 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 326 )
  W( 69 ) = W( 69 ) + a*JVS( 327 )
  W( 72 ) = W( 72 ) + a*JVS( 328 )
  W( 74 ) = W( 74 ) + a*JVS( 329 )
  W( 75 ) = W( 75 ) + a*JVS( 330 )
  W( 76 ) = W( 76 ) + a*JVS( 331 )
  W( 77 ) = W( 77 ) + a*JVS( 332 )
  a = -W( 54 ) / JVS( 380 )
  W( 54 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 381 )
  W( 69 ) = W( 69 ) + a*JVS( 382 )
  W( 71 ) = W( 71 ) + a*JVS( 383 )
  W( 72 ) = W( 72 ) + a*JVS( 384 )
  W( 74 ) = W( 74 ) + a*JVS( 385 )
  W( 75 ) = W( 75 ) + a*JVS( 386 )
  W( 76 ) = W( 76 ) + a*JVS( 387 )
  W( 77 ) = W( 77 ) + a*JVS( 388 )
  JVS( 498) = W( 48 )
  JVS( 499) = W( 54 )
  JVS( 500) = W( 60 )
  JVS( 501) = W( 68 )
  JVS( 502) = W( 69 )
  JVS( 503) = W( 71 )
  JVS( 504) = W( 72 )
  JVS( 505) = W( 74 )
  JVS( 506) = W( 75 )
  JVS( 507) = W( 76 )
  JVS( 508) = W( 77 )
  IF ( ABS( JVS( 517 )) < TINY(a) ) THEN
         IER = 61
         RETURN
  END IF
   W( 27 ) = JVS( 509 )
   W( 34 ) = JVS( 510 )
   W( 36 ) = JVS( 511 )
   W( 37 ) = JVS( 512 )
   W( 42 ) = JVS( 513 )
   W( 56 ) = JVS( 514 )
   W( 59 ) = JVS( 515 )
   W( 60 ) = JVS( 516 )
   W( 61 ) = JVS( 517 )
   W( 62 ) = JVS( 518 )
   W( 68 ) = JVS( 519 )
   W( 69 ) = JVS( 520 )
   W( 71 ) = JVS( 521 )
   W( 72 ) = JVS( 522 )
   W( 74 ) = JVS( 523 )
   W( 75 ) = JVS( 524 )
   W( 76 ) = JVS( 525 )
   W( 77 ) = JVS( 526 )
  a = -W( 27 ) / JVS( 129 )
  W( 27 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 130 )
  W( 75 ) = W( 75 ) + a*JVS( 131 )
  W( 76 ) = W( 76 ) + a*JVS( 132 )
  a = -W( 34 ) / JVS( 189 )
  W( 34 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 190 )
  W( 75 ) = W( 75 ) + a*JVS( 191 )
  W( 76 ) = W( 76 ) + a*JVS( 192 )
  a = -W( 36 ) / JVS( 203 )
  W( 36 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 204 )
  W( 75 ) = W( 75 ) + a*JVS( 205 )
  W( 76 ) = W( 76 ) + a*JVS( 206 )
  a = -W( 37 ) / JVS( 207 )
  W( 37 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 208 )
  W( 75 ) = W( 75 ) + a*JVS( 209 )
  W( 76 ) = W( 76 ) + a*JVS( 210 )
  a = -W( 42 ) / JVS( 249 )
  W( 42 ) = -a
  W( 71 ) = W( 71 ) + a*JVS( 250 )
  W( 74 ) = W( 74 ) + a*JVS( 251 )
  W( 75 ) = W( 75 ) + a*JVS( 252 )
  W( 76 ) = W( 76 ) + a*JVS( 253 )
  a = -W( 56 ) / JVS( 418 )
  W( 56 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 419 )
  W( 69 ) = W( 69 ) + a*JVS( 420 )
  W( 71 ) = W( 71 ) + a*JVS( 421 )
  W( 72 ) = W( 72 ) + a*JVS( 422 )
  W( 74 ) = W( 74 ) + a*JVS( 423 )
  W( 75 ) = W( 75 ) + a*JVS( 424 )
  W( 76 ) = W( 76 ) + a*JVS( 425 )
  W( 77 ) = W( 77 ) + a*JVS( 426 )
  a = -W( 59 ) / JVS( 489 )
  W( 59 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 490 )
  W( 69 ) = W( 69 ) + a*JVS( 491 )
  W( 71 ) = W( 71 ) + a*JVS( 492 )
  W( 72 ) = W( 72 ) + a*JVS( 493 )
  W( 74 ) = W( 74 ) + a*JVS( 494 )
  W( 75 ) = W( 75 ) + a*JVS( 495 )
  W( 76 ) = W( 76 ) + a*JVS( 496 )
  W( 77 ) = W( 77 ) + a*JVS( 497 )
  a = -W( 60 ) / JVS( 500 )
  W( 60 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 501 )
  W( 69 ) = W( 69 ) + a*JVS( 502 )
  W( 71 ) = W( 71 ) + a*JVS( 503 )
  W( 72 ) = W( 72 ) + a*JVS( 504 )
  W( 74 ) = W( 74 ) + a*JVS( 505 )
  W( 75 ) = W( 75 ) + a*JVS( 506 )
  W( 76 ) = W( 76 ) + a*JVS( 507 )
  W( 77 ) = W( 77 ) + a*JVS( 508 )
  JVS( 509) = W( 27 )
  JVS( 510) = W( 34 )
  JVS( 511) = W( 36 )
  JVS( 512) = W( 37 )
  JVS( 513) = W( 42 )
  JVS( 514) = W( 56 )
  JVS( 515) = W( 59 )
  JVS( 516) = W( 60 )
  JVS( 517) = W( 61 )
  JVS( 518) = W( 62 )
  JVS( 519) = W( 68 )
  JVS( 520) = W( 69 )
  JVS( 521) = W( 71 )
  JVS( 522) = W( 72 )
  JVS( 523) = W( 74 )
  JVS( 524) = W( 75 )
  JVS( 525) = W( 76 )
  JVS( 526) = W( 77 )
  IF ( ABS( JVS( 535 )) < TINY(a) ) THEN
         IER = 62
         RETURN
  END IF
   W( 27 ) = JVS( 527 )
   W( 34 ) = JVS( 528 )
   W( 36 ) = JVS( 529 )
   W( 37 ) = JVS( 530 )
   W( 42 ) = JVS( 531 )
   W( 59 ) = JVS( 532 )
   W( 60 ) = JVS( 533 )
   W( 61 ) = JVS( 534 )
   W( 62 ) = JVS( 535 )
   W( 68 ) = JVS( 536 )
   W( 69 ) = JVS( 537 )
   W( 71 ) = JVS( 538 )
   W( 72 ) = JVS( 539 )
   W( 74 ) = JVS( 540 )
   W( 75 ) = JVS( 541 )
   W( 76 ) = JVS( 542 )
   W( 77 ) = JVS( 543 )
  a = -W( 27 ) / JVS( 129 )
  W( 27 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 130 )
  W( 75 ) = W( 75 ) + a*JVS( 131 )
  W( 76 ) = W( 76 ) + a*JVS( 132 )
  a = -W( 34 ) / JVS( 189 )
  W( 34 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 190 )
  W( 75 ) = W( 75 ) + a*JVS( 191 )
  W( 76 ) = W( 76 ) + a*JVS( 192 )
  a = -W( 36 ) / JVS( 203 )
  W( 36 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 204 )
  W( 75 ) = W( 75 ) + a*JVS( 205 )
  W( 76 ) = W( 76 ) + a*JVS( 206 )
  a = -W( 37 ) / JVS( 207 )
  W( 37 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 208 )
  W( 75 ) = W( 75 ) + a*JVS( 209 )
  W( 76 ) = W( 76 ) + a*JVS( 210 )
  a = -W( 42 ) / JVS( 249 )
  W( 42 ) = -a
  W( 71 ) = W( 71 ) + a*JVS( 250 )
  W( 74 ) = W( 74 ) + a*JVS( 251 )
  W( 75 ) = W( 75 ) + a*JVS( 252 )
  W( 76 ) = W( 76 ) + a*JVS( 253 )
  a = -W( 59 ) / JVS( 489 )
  W( 59 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 490 )
  W( 69 ) = W( 69 ) + a*JVS( 491 )
  W( 71 ) = W( 71 ) + a*JVS( 492 )
  W( 72 ) = W( 72 ) + a*JVS( 493 )
  W( 74 ) = W( 74 ) + a*JVS( 494 )
  W( 75 ) = W( 75 ) + a*JVS( 495 )
  W( 76 ) = W( 76 ) + a*JVS( 496 )
  W( 77 ) = W( 77 ) + a*JVS( 497 )
  a = -W( 60 ) / JVS( 500 )
  W( 60 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 501 )
  W( 69 ) = W( 69 ) + a*JVS( 502 )
  W( 71 ) = W( 71 ) + a*JVS( 503 )
  W( 72 ) = W( 72 ) + a*JVS( 504 )
  W( 74 ) = W( 74 ) + a*JVS( 505 )
  W( 75 ) = W( 75 ) + a*JVS( 506 )
  W( 76 ) = W( 76 ) + a*JVS( 507 )
  W( 77 ) = W( 77 ) + a*JVS( 508 )
  a = -W( 61 ) / JVS( 517 )
  W( 61 ) = -a
  W( 62 ) = W( 62 ) + a*JVS( 518 )
  W( 68 ) = W( 68 ) + a*JVS( 519 )
  W( 69 ) = W( 69 ) + a*JVS( 520 )
  W( 71 ) = W( 71 ) + a*JVS( 521 )
  W( 72 ) = W( 72 ) + a*JVS( 522 )
  W( 74 ) = W( 74 ) + a*JVS( 523 )
  W( 75 ) = W( 75 ) + a*JVS( 524 )
  W( 76 ) = W( 76 ) + a*JVS( 525 )
  W( 77 ) = W( 77 ) + a*JVS( 526 )
  JVS( 527) = W( 27 )
  JVS( 528) = W( 34 )
  JVS( 529) = W( 36 )
  JVS( 530) = W( 37 )
  JVS( 531) = W( 42 )
  JVS( 532) = W( 59 )
  JVS( 533) = W( 60 )
  JVS( 534) = W( 61 )
  JVS( 535) = W( 62 )
  JVS( 536) = W( 68 )
  JVS( 537) = W( 69 )
  JVS( 538) = W( 71 )
  JVS( 539) = W( 72 )
  JVS( 540) = W( 74 )
  JVS( 541) = W( 75 )
  JVS( 542) = W( 76 )
  JVS( 543) = W( 77 )
  IF ( ABS( JVS( 573 )) < TINY(a) ) THEN
         IER = 63
         RETURN
  END IF
   W( 14 ) = JVS( 544 )
   W( 20 ) = JVS( 545 )
   W( 26 ) = JVS( 546 )
   W( 27 ) = JVS( 547 )
   W( 30 ) = JVS( 548 )
   W( 32 ) = JVS( 549 )
   W( 35 ) = JVS( 550 )
   W( 36 ) = JVS( 551 )
   W( 37 ) = JVS( 552 )
   W( 39 ) = JVS( 553 )
   W( 40 ) = JVS( 554 )
   W( 41 ) = JVS( 555 )
   W( 42 ) = JVS( 556 )
   W( 43 ) = JVS( 557 )
   W( 44 ) = JVS( 558 )
   W( 46 ) = JVS( 559 )
   W( 48 ) = JVS( 560 )
   W( 49 ) = JVS( 561 )
   W( 50 ) = JVS( 562 )
   W( 51 ) = JVS( 563 )
   W( 52 ) = JVS( 564 )
   W( 53 ) = JVS( 565 )
   W( 54 ) = JVS( 566 )
   W( 56 ) = JVS( 567 )
   W( 57 ) = JVS( 568 )
   W( 59 ) = JVS( 569 )
   W( 60 ) = JVS( 570 )
   W( 61 ) = JVS( 571 )
   W( 62 ) = JVS( 572 )
   W( 63 ) = JVS( 573 )
   W( 64 ) = JVS( 574 )
   W( 65 ) = JVS( 575 )
   W( 66 ) = JVS( 576 )
   W( 67 ) = JVS( 577 )
   W( 68 ) = JVS( 578 )
   W( 69 ) = JVS( 579 )
   W( 70 ) = JVS( 580 )
   W( 71 ) = JVS( 581 )
   W( 72 ) = JVS( 582 )
   W( 73 ) = JVS( 583 )
   W( 74 ) = JVS( 584 )
   W( 75 ) = JVS( 585 )
   W( 76 ) = JVS( 586 )
   W( 77 ) = JVS( 587 )
   W( 78 ) = JVS( 588 )
  a = -W( 14 ) / JVS( 61 )
  W( 14 ) = -a
  W( 76 ) = W( 76 ) + a*JVS( 62 )
  a = -W( 20 ) / JVS( 85 )
  W( 20 ) = -a
  W( 69 ) = W( 69 ) + a*JVS( 86 )
  W( 72 ) = W( 72 ) + a*JVS( 87 )
  W( 76 ) = W( 76 ) + a*JVS( 88 )
  a = -W( 26 ) / JVS( 123 )
  W( 26 ) = -a
  W( 40 ) = W( 40 ) + a*JVS( 124 )
  W( 56 ) = W( 56 ) + a*JVS( 125 )
  W( 67 ) = W( 67 ) + a*JVS( 126 )
  W( 72 ) = W( 72 ) + a*JVS( 127 )
  W( 76 ) = W( 76 ) + a*JVS( 128 )
  a = -W( 27 ) / JVS( 129 )
  W( 27 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 130 )
  W( 75 ) = W( 75 ) + a*JVS( 131 )
  W( 76 ) = W( 76 ) + a*JVS( 132 )
  a = -W( 30 ) / JVS( 143 )
  W( 30 ) = -a
  W( 64 ) = W( 64 ) + a*JVS( 144 )
  W( 68 ) = W( 68 ) + a*JVS( 145 )
  W( 69 ) = W( 69 ) + a*JVS( 146 )
  W( 75 ) = W( 75 ) + a*JVS( 147 )
  W( 76 ) = W( 76 ) + a*JVS( 148 )
  a = -W( 32 ) / JVS( 161 )
  W( 32 ) = -a
  W( 40 ) = W( 40 ) + a*JVS( 162 )
  W( 68 ) = W( 68 ) + a*JVS( 163 )
  W( 74 ) = W( 74 ) + a*JVS( 164 )
  W( 75 ) = W( 75 ) + a*JVS( 165 )
  W( 76 ) = W( 76 ) + a*JVS( 166 )
  W( 78 ) = W( 78 ) + a*JVS( 167 )
  a = -W( 35 ) / JVS( 197 )
  W( 35 ) = -a
  W( 63 ) = W( 63 ) + a*JVS( 198 )
  W( 69 ) = W( 69 ) + a*JVS( 199 )
  W( 75 ) = W( 75 ) + a*JVS( 200 )
  W( 76 ) = W( 76 ) + a*JVS( 201 )
  W( 77 ) = W( 77 ) + a*JVS( 202 )
  a = -W( 36 ) / JVS( 203 )
  W( 36 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 204 )
  W( 75 ) = W( 75 ) + a*JVS( 205 )
  W( 76 ) = W( 76 ) + a*JVS( 206 )
  a = -W( 37 ) / JVS( 207 )
  W( 37 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 208 )
  W( 75 ) = W( 75 ) + a*JVS( 209 )
  W( 76 ) = W( 76 ) + a*JVS( 210 )
  a = -W( 39 ) / JVS( 222 )
  W( 39 ) = -a
  W( 46 ) = W( 46 ) + a*JVS( 223 )
  W( 51 ) = W( 51 ) + a*JVS( 224 )
  W( 52 ) = W( 52 ) + a*JVS( 225 )
  W( 64 ) = W( 64 ) + a*JVS( 226 )
  W( 68 ) = W( 68 ) + a*JVS( 227 )
  W( 72 ) = W( 72 ) + a*JVS( 228 )
  W( 73 ) = W( 73 ) + a*JVS( 229 )
  W( 74 ) = W( 74 ) + a*JVS( 230 )
  W( 75 ) = W( 75 ) + a*JVS( 231 )
  W( 76 ) = W( 76 ) + a*JVS( 232 )
  W( 77 ) = W( 77 ) + a*JVS( 233 )
  a = -W( 40 ) / JVS( 234 )
  W( 40 ) = -a
  W( 65 ) = W( 65 ) + a*JVS( 235 )
  W( 74 ) = W( 74 ) + a*JVS( 236 )
  W( 75 ) = W( 75 ) + a*JVS( 237 )
  W( 76 ) = W( 76 ) + a*JVS( 238 )
  W( 78 ) = W( 78 ) + a*JVS( 239 )
  a = -W( 41 ) / JVS( 241 )
  W( 41 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 242 )
  W( 69 ) = W( 69 ) + a*JVS( 243 )
  W( 72 ) = W( 72 ) + a*JVS( 244 )
  W( 74 ) = W( 74 ) + a*JVS( 245 )
  W( 75 ) = W( 75 ) + a*JVS( 246 )
  W( 76 ) = W( 76 ) + a*JVS( 247 )
  W( 77 ) = W( 77 ) + a*JVS( 248 )
  a = -W( 42 ) / JVS( 249 )
  W( 42 ) = -a
  W( 71 ) = W( 71 ) + a*JVS( 250 )
  W( 74 ) = W( 74 ) + a*JVS( 251 )
  W( 75 ) = W( 75 ) + a*JVS( 252 )
  W( 76 ) = W( 76 ) + a*JVS( 253 )
  a = -W( 43 ) / JVS( 254 )
  W( 43 ) = -a
  W( 59 ) = W( 59 ) + a*JVS( 255 )
  W( 68 ) = W( 68 ) + a*JVS( 256 )
  W( 69 ) = W( 69 ) + a*JVS( 257 )
  W( 72 ) = W( 72 ) + a*JVS( 258 )
  W( 74 ) = W( 74 ) + a*JVS( 259 )
  W( 76 ) = W( 76 ) + a*JVS( 260 )
  W( 77 ) = W( 77 ) + a*JVS( 261 )
  a = -W( 44 ) / JVS( 262 )
  W( 44 ) = -a
  W( 60 ) = W( 60 ) + a*JVS( 263 )
  W( 68 ) = W( 68 ) + a*JVS( 264 )
  W( 69 ) = W( 69 ) + a*JVS( 265 )
  W( 72 ) = W( 72 ) + a*JVS( 266 )
  W( 74 ) = W( 74 ) + a*JVS( 267 )
  W( 76 ) = W( 76 ) + a*JVS( 268 )
  W( 77 ) = W( 77 ) + a*JVS( 269 )
  a = -W( 46 ) / JVS( 290 )
  W( 46 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 291 )
  W( 69 ) = W( 69 ) + a*JVS( 292 )
  W( 72 ) = W( 72 ) + a*JVS( 293 )
  W( 74 ) = W( 74 ) + a*JVS( 294 )
  W( 75 ) = W( 75 ) + a*JVS( 295 )
  W( 76 ) = W( 76 ) + a*JVS( 296 )
  W( 77 ) = W( 77 ) + a*JVS( 297 )
  W( 78 ) = W( 78 ) + a*JVS( 298 )
  a = -W( 48 ) / JVS( 325 )
  W( 48 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 326 )
  W( 69 ) = W( 69 ) + a*JVS( 327 )
  W( 72 ) = W( 72 ) + a*JVS( 328 )
  W( 74 ) = W( 74 ) + a*JVS( 329 )
  W( 75 ) = W( 75 ) + a*JVS( 330 )
  W( 76 ) = W( 76 ) + a*JVS( 331 )
  W( 77 ) = W( 77 ) + a*JVS( 332 )
  a = -W( 49 ) / JVS( 334 )
  W( 49 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 335 )
  W( 69 ) = W( 69 ) + a*JVS( 336 )
  W( 72 ) = W( 72 ) + a*JVS( 337 )
  W( 74 ) = W( 74 ) + a*JVS( 338 )
  W( 76 ) = W( 76 ) + a*JVS( 339 )
  W( 77 ) = W( 77 ) + a*JVS( 340 )
  a = -W( 50 ) / JVS( 342 )
  W( 50 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 343 )
  W( 69 ) = W( 69 ) + a*JVS( 344 )
  W( 72 ) = W( 72 ) + a*JVS( 345 )
  W( 74 ) = W( 74 ) + a*JVS( 346 )
  W( 76 ) = W( 76 ) + a*JVS( 347 )
  W( 77 ) = W( 77 ) + a*JVS( 348 )
  a = -W( 51 ) / JVS( 350 )
  W( 51 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 351 )
  W( 69 ) = W( 69 ) + a*JVS( 352 )
  W( 72 ) = W( 72 ) + a*JVS( 353 )
  W( 74 ) = W( 74 ) + a*JVS( 354 )
  W( 75 ) = W( 75 ) + a*JVS( 355 )
  W( 76 ) = W( 76 ) + a*JVS( 356 )
  W( 77 ) = W( 77 ) + a*JVS( 357 )
  W( 78 ) = W( 78 ) + a*JVS( 358 )
  a = -W( 52 ) / JVS( 360 )
  W( 52 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 361 )
  W( 69 ) = W( 69 ) + a*JVS( 362 )
  W( 72 ) = W( 72 ) + a*JVS( 363 )
  W( 74 ) = W( 74 ) + a*JVS( 364 )
  W( 75 ) = W( 75 ) + a*JVS( 365 )
  W( 76 ) = W( 76 ) + a*JVS( 366 )
  W( 77 ) = W( 77 ) + a*JVS( 367 )
  W( 78 ) = W( 78 ) + a*JVS( 368 )
  a = -W( 53 ) / JVS( 370 )
  W( 53 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 371 )
  W( 69 ) = W( 69 ) + a*JVS( 372 )
  W( 72 ) = W( 72 ) + a*JVS( 373 )
  W( 74 ) = W( 74 ) + a*JVS( 374 )
  W( 75 ) = W( 75 ) + a*JVS( 375 )
  W( 76 ) = W( 76 ) + a*JVS( 376 )
  W( 77 ) = W( 77 ) + a*JVS( 377 )
  a = -W( 54 ) / JVS( 380 )
  W( 54 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 381 )
  W( 69 ) = W( 69 ) + a*JVS( 382 )
  W( 71 ) = W( 71 ) + a*JVS( 383 )
  W( 72 ) = W( 72 ) + a*JVS( 384 )
  W( 74 ) = W( 74 ) + a*JVS( 385 )
  W( 75 ) = W( 75 ) + a*JVS( 386 )
  W( 76 ) = W( 76 ) + a*JVS( 387 )
  W( 77 ) = W( 77 ) + a*JVS( 388 )
  a = -W( 56 ) / JVS( 418 )
  W( 56 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 419 )
  W( 69 ) = W( 69 ) + a*JVS( 420 )
  W( 71 ) = W( 71 ) + a*JVS( 421 )
  W( 72 ) = W( 72 ) + a*JVS( 422 )
  W( 74 ) = W( 74 ) + a*JVS( 423 )
  W( 75 ) = W( 75 ) + a*JVS( 424 )
  W( 76 ) = W( 76 ) + a*JVS( 425 )
  W( 77 ) = W( 77 ) + a*JVS( 426 )
  a = -W( 57 ) / JVS( 438 )
  W( 57 ) = -a
  W( 64 ) = W( 64 ) + a*JVS( 439 )
  W( 65 ) = W( 65 ) + a*JVS( 440 )
  W( 67 ) = W( 67 ) + a*JVS( 441 )
  W( 68 ) = W( 68 ) + a*JVS( 442 )
  W( 69 ) = W( 69 ) + a*JVS( 443 )
  W( 70 ) = W( 70 ) + a*JVS( 444 )
  W( 71 ) = W( 71 ) + a*JVS( 445 )
  W( 72 ) = W( 72 ) + a*JVS( 446 )
  W( 73 ) = W( 73 ) + a*JVS( 447 )
  W( 74 ) = W( 74 ) + a*JVS( 448 )
  W( 75 ) = W( 75 ) + a*JVS( 449 )
  W( 76 ) = W( 76 ) + a*JVS( 450 )
  W( 77 ) = W( 77 ) + a*JVS( 451 )
  W( 78 ) = W( 78 ) + a*JVS( 452 )
  a = -W( 59 ) / JVS( 489 )
  W( 59 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 490 )
  W( 69 ) = W( 69 ) + a*JVS( 491 )
  W( 71 ) = W( 71 ) + a*JVS( 492 )
  W( 72 ) = W( 72 ) + a*JVS( 493 )
  W( 74 ) = W( 74 ) + a*JVS( 494 )
  W( 75 ) = W( 75 ) + a*JVS( 495 )
  W( 76 ) = W( 76 ) + a*JVS( 496 )
  W( 77 ) = W( 77 ) + a*JVS( 497 )
  a = -W( 60 ) / JVS( 500 )
  W( 60 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 501 )
  W( 69 ) = W( 69 ) + a*JVS( 502 )
  W( 71 ) = W( 71 ) + a*JVS( 503 )
  W( 72 ) = W( 72 ) + a*JVS( 504 )
  W( 74 ) = W( 74 ) + a*JVS( 505 )
  W( 75 ) = W( 75 ) + a*JVS( 506 )
  W( 76 ) = W( 76 ) + a*JVS( 507 )
  W( 77 ) = W( 77 ) + a*JVS( 508 )
  a = -W( 61 ) / JVS( 517 )
  W( 61 ) = -a
  W( 62 ) = W( 62 ) + a*JVS( 518 )
  W( 68 ) = W( 68 ) + a*JVS( 519 )
  W( 69 ) = W( 69 ) + a*JVS( 520 )
  W( 71 ) = W( 71 ) + a*JVS( 521 )
  W( 72 ) = W( 72 ) + a*JVS( 522 )
  W( 74 ) = W( 74 ) + a*JVS( 523 )
  W( 75 ) = W( 75 ) + a*JVS( 524 )
  W( 76 ) = W( 76 ) + a*JVS( 525 )
  W( 77 ) = W( 77 ) + a*JVS( 526 )
  a = -W( 62 ) / JVS( 535 )
  W( 62 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 536 )
  W( 69 ) = W( 69 ) + a*JVS( 537 )
  W( 71 ) = W( 71 ) + a*JVS( 538 )
  W( 72 ) = W( 72 ) + a*JVS( 539 )
  W( 74 ) = W( 74 ) + a*JVS( 540 )
  W( 75 ) = W( 75 ) + a*JVS( 541 )
  W( 76 ) = W( 76 ) + a*JVS( 542 )
  W( 77 ) = W( 77 ) + a*JVS( 543 )
  JVS( 544) = W( 14 )
  JVS( 545) = W( 20 )
  JVS( 546) = W( 26 )
  JVS( 547) = W( 27 )
  JVS( 548) = W( 30 )
  JVS( 549) = W( 32 )
  JVS( 550) = W( 35 )
  JVS( 551) = W( 36 )
  JVS( 552) = W( 37 )
  JVS( 553) = W( 39 )
  JVS( 554) = W( 40 )
  JVS( 555) = W( 41 )
  JVS( 556) = W( 42 )
  JVS( 557) = W( 43 )
  JVS( 558) = W( 44 )
  JVS( 559) = W( 46 )
  JVS( 560) = W( 48 )
  JVS( 561) = W( 49 )
  JVS( 562) = W( 50 )
  JVS( 563) = W( 51 )
  JVS( 564) = W( 52 )
  JVS( 565) = W( 53 )
  JVS( 566) = W( 54 )
  JVS( 567) = W( 56 )
  JVS( 568) = W( 57 )
  JVS( 569) = W( 59 )
  JVS( 570) = W( 60 )
  JVS( 571) = W( 61 )
  JVS( 572) = W( 62 )
  JVS( 573) = W( 63 )
  JVS( 574) = W( 64 )
  JVS( 575) = W( 65 )
  JVS( 576) = W( 66 )
  JVS( 577) = W( 67 )
  JVS( 578) = W( 68 )
  JVS( 579) = W( 69 )
  JVS( 580) = W( 70 )
  JVS( 581) = W( 71 )
  JVS( 582) = W( 72 )
  JVS( 583) = W( 73 )
  JVS( 584) = W( 74 )
  JVS( 585) = W( 75 )
  JVS( 586) = W( 76 )
  JVS( 587) = W( 77 )
  JVS( 588) = W( 78 )
  IF ( ABS( JVS( 592 )) < TINY(a) ) THEN
         IER = 64
         RETURN
  END IF
   W( 42 ) = JVS( 589 )
   W( 51 ) = JVS( 590 )
   W( 52 ) = JVS( 591 )
   W( 64 ) = JVS( 592 )
   W( 68 ) = JVS( 593 )
   W( 69 ) = JVS( 594 )
   W( 71 ) = JVS( 595 )
   W( 72 ) = JVS( 596 )
   W( 74 ) = JVS( 597 )
   W( 75 ) = JVS( 598 )
   W( 76 ) = JVS( 599 )
   W( 77 ) = JVS( 600 )
   W( 78 ) = JVS( 601 )
  a = -W( 42 ) / JVS( 249 )
  W( 42 ) = -a
  W( 71 ) = W( 71 ) + a*JVS( 250 )
  W( 74 ) = W( 74 ) + a*JVS( 251 )
  W( 75 ) = W( 75 ) + a*JVS( 252 )
  W( 76 ) = W( 76 ) + a*JVS( 253 )
  a = -W( 51 ) / JVS( 350 )
  W( 51 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 351 )
  W( 69 ) = W( 69 ) + a*JVS( 352 )
  W( 72 ) = W( 72 ) + a*JVS( 353 )
  W( 74 ) = W( 74 ) + a*JVS( 354 )
  W( 75 ) = W( 75 ) + a*JVS( 355 )
  W( 76 ) = W( 76 ) + a*JVS( 356 )
  W( 77 ) = W( 77 ) + a*JVS( 357 )
  W( 78 ) = W( 78 ) + a*JVS( 358 )
  a = -W( 52 ) / JVS( 360 )
  W( 52 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 361 )
  W( 69 ) = W( 69 ) + a*JVS( 362 )
  W( 72 ) = W( 72 ) + a*JVS( 363 )
  W( 74 ) = W( 74 ) + a*JVS( 364 )
  W( 75 ) = W( 75 ) + a*JVS( 365 )
  W( 76 ) = W( 76 ) + a*JVS( 366 )
  W( 77 ) = W( 77 ) + a*JVS( 367 )
  W( 78 ) = W( 78 ) + a*JVS( 368 )
  JVS( 589) = W( 42 )
  JVS( 590) = W( 51 )
  JVS( 591) = W( 52 )
  JVS( 592) = W( 64 )
  JVS( 593) = W( 68 )
  JVS( 594) = W( 69 )
  JVS( 595) = W( 71 )
  JVS( 596) = W( 72 )
  JVS( 597) = W( 74 )
  JVS( 598) = W( 75 )
  JVS( 599) = W( 76 )
  JVS( 600) = W( 77 )
  JVS( 601) = W( 78 )
  IF ( ABS( JVS( 605 )) < TINY(a) ) THEN
         IER = 65
         RETURN
  END IF
   W( 40 ) = JVS( 602 )
   W( 56 ) = JVS( 603 )
   W( 64 ) = JVS( 604 )
   W( 65 ) = JVS( 605 )
   W( 68 ) = JVS( 606 )
   W( 69 ) = JVS( 607 )
   W( 71 ) = JVS( 608 )
   W( 72 ) = JVS( 609 )
   W( 74 ) = JVS( 610 )
   W( 75 ) = JVS( 611 )
   W( 76 ) = JVS( 612 )
   W( 77 ) = JVS( 613 )
   W( 78 ) = JVS( 614 )
  a = -W( 40 ) / JVS( 234 )
  W( 40 ) = -a
  W( 65 ) = W( 65 ) + a*JVS( 235 )
  W( 74 ) = W( 74 ) + a*JVS( 236 )
  W( 75 ) = W( 75 ) + a*JVS( 237 )
  W( 76 ) = W( 76 ) + a*JVS( 238 )
  W( 78 ) = W( 78 ) + a*JVS( 239 )
  a = -W( 56 ) / JVS( 418 )
  W( 56 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 419 )
  W( 69 ) = W( 69 ) + a*JVS( 420 )
  W( 71 ) = W( 71 ) + a*JVS( 421 )
  W( 72 ) = W( 72 ) + a*JVS( 422 )
  W( 74 ) = W( 74 ) + a*JVS( 423 )
  W( 75 ) = W( 75 ) + a*JVS( 424 )
  W( 76 ) = W( 76 ) + a*JVS( 425 )
  W( 77 ) = W( 77 ) + a*JVS( 426 )
  a = -W( 64 ) / JVS( 592 )
  W( 64 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 593 )
  W( 69 ) = W( 69 ) + a*JVS( 594 )
  W( 71 ) = W( 71 ) + a*JVS( 595 )
  W( 72 ) = W( 72 ) + a*JVS( 596 )
  W( 74 ) = W( 74 ) + a*JVS( 597 )
  W( 75 ) = W( 75 ) + a*JVS( 598 )
  W( 76 ) = W( 76 ) + a*JVS( 599 )
  W( 77 ) = W( 77 ) + a*JVS( 600 )
  W( 78 ) = W( 78 ) + a*JVS( 601 )
  JVS( 602) = W( 40 )
  JVS( 603) = W( 56 )
  JVS( 604) = W( 64 )
  JVS( 605) = W( 65 )
  JVS( 606) = W( 68 )
  JVS( 607) = W( 69 )
  JVS( 608) = W( 71 )
  JVS( 609) = W( 72 )
  JVS( 610) = W( 74 )
  JVS( 611) = W( 75 )
  JVS( 612) = W( 76 )
  JVS( 613) = W( 77 )
  JVS( 614) = W( 78 )
  IF ( ABS( JVS( 629 )) < TINY(a) ) THEN
         IER = 66
         RETURN
  END IF
   W( 15 ) = JVS( 615 )
   W( 34 ) = JVS( 616 )
   W( 36 ) = JVS( 617 )
   W( 47 ) = JVS( 618 )
   W( 49 ) = JVS( 619 )
   W( 50 ) = JVS( 620 )
   W( 53 ) = JVS( 621 )
   W( 55 ) = JVS( 622 )
   W( 59 ) = JVS( 623 )
   W( 60 ) = JVS( 624 )
   W( 61 ) = JVS( 625 )
   W( 62 ) = JVS( 626 )
   W( 64 ) = JVS( 627 )
   W( 65 ) = JVS( 628 )
   W( 66 ) = JVS( 629 )
   W( 67 ) = JVS( 630 )
   W( 68 ) = JVS( 631 )
   W( 69 ) = JVS( 632 )
   W( 70 ) = JVS( 633 )
   W( 71 ) = JVS( 634 )
   W( 72 ) = JVS( 635 )
   W( 73 ) = JVS( 636 )
   W( 74 ) = JVS( 637 )
   W( 75 ) = JVS( 638 )
   W( 76 ) = JVS( 639 )
   W( 77 ) = JVS( 640 )
   W( 78 ) = JVS( 641 )
  a = -W( 15 ) / JVS( 63 )
  W( 15 ) = -a
  W( 59 ) = W( 59 ) + a*JVS( 64 )
  W( 60 ) = W( 60 ) + a*JVS( 65 )
  W( 75 ) = W( 75 ) + a*JVS( 66 )
  W( 76 ) = W( 76 ) + a*JVS( 67 )
  a = -W( 34 ) / JVS( 189 )
  W( 34 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 190 )
  W( 75 ) = W( 75 ) + a*JVS( 191 )
  W( 76 ) = W( 76 ) + a*JVS( 192 )
  a = -W( 36 ) / JVS( 203 )
  W( 36 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 204 )
  W( 75 ) = W( 75 ) + a*JVS( 205 )
  W( 76 ) = W( 76 ) + a*JVS( 206 )
  a = -W( 47 ) / JVS( 304 )
  W( 47 ) = -a
  W( 49 ) = W( 49 ) + a*JVS( 305 )
  W( 50 ) = W( 50 ) + a*JVS( 306 )
  W( 53 ) = W( 53 ) + a*JVS( 307 )
  W( 55 ) = W( 55 ) + a*JVS( 308 )
  W( 59 ) = W( 59 ) + a*JVS( 309 )
  W( 60 ) = W( 60 ) + a*JVS( 310 )
  W( 61 ) = W( 61 ) + a*JVS( 311 )
  W( 62 ) = W( 62 ) + a*JVS( 312 )
  W( 64 ) = W( 64 ) + a*JVS( 313 )
  W( 67 ) = W( 67 ) + a*JVS( 314 )
  W( 68 ) = W( 68 ) + a*JVS( 315 )
  W( 69 ) = W( 69 ) + a*JVS( 316 )
  W( 70 ) = W( 70 ) + a*JVS( 317 )
  W( 72 ) = W( 72 ) + a*JVS( 318 )
  W( 73 ) = W( 73 ) + a*JVS( 319 )
  W( 74 ) = W( 74 ) + a*JVS( 320 )
  W( 75 ) = W( 75 ) + a*JVS( 321 )
  W( 76 ) = W( 76 ) + a*JVS( 322 )
  W( 77 ) = W( 77 ) + a*JVS( 323 )
  a = -W( 49 ) / JVS( 334 )
  W( 49 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 335 )
  W( 69 ) = W( 69 ) + a*JVS( 336 )
  W( 72 ) = W( 72 ) + a*JVS( 337 )
  W( 74 ) = W( 74 ) + a*JVS( 338 )
  W( 76 ) = W( 76 ) + a*JVS( 339 )
  W( 77 ) = W( 77 ) + a*JVS( 340 )
  a = -W( 50 ) / JVS( 342 )
  W( 50 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 343 )
  W( 69 ) = W( 69 ) + a*JVS( 344 )
  W( 72 ) = W( 72 ) + a*JVS( 345 )
  W( 74 ) = W( 74 ) + a*JVS( 346 )
  W( 76 ) = W( 76 ) + a*JVS( 347 )
  W( 77 ) = W( 77 ) + a*JVS( 348 )
  a = -W( 53 ) / JVS( 370 )
  W( 53 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 371 )
  W( 69 ) = W( 69 ) + a*JVS( 372 )
  W( 72 ) = W( 72 ) + a*JVS( 373 )
  W( 74 ) = W( 74 ) + a*JVS( 374 )
  W( 75 ) = W( 75 ) + a*JVS( 375 )
  W( 76 ) = W( 76 ) + a*JVS( 376 )
  W( 77 ) = W( 77 ) + a*JVS( 377 )
  a = -W( 55 ) / JVS( 399 )
  W( 55 ) = -a
  W( 61 ) = W( 61 ) + a*JVS( 400 )
  W( 62 ) = W( 62 ) + a*JVS( 401 )
  W( 65 ) = W( 65 ) + a*JVS( 402 )
  W( 68 ) = W( 68 ) + a*JVS( 403 )
  W( 69 ) = W( 69 ) + a*JVS( 404 )
  W( 71 ) = W( 71 ) + a*JVS( 405 )
  W( 72 ) = W( 72 ) + a*JVS( 406 )
  W( 73 ) = W( 73 ) + a*JVS( 407 )
  W( 74 ) = W( 74 ) + a*JVS( 408 )
  W( 75 ) = W( 75 ) + a*JVS( 409 )
  W( 76 ) = W( 76 ) + a*JVS( 410 )
  W( 77 ) = W( 77 ) + a*JVS( 411 )
  W( 78 ) = W( 78 ) + a*JVS( 412 )
  a = -W( 59 ) / JVS( 489 )
  W( 59 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 490 )
  W( 69 ) = W( 69 ) + a*JVS( 491 )
  W( 71 ) = W( 71 ) + a*JVS( 492 )
  W( 72 ) = W( 72 ) + a*JVS( 493 )
  W( 74 ) = W( 74 ) + a*JVS( 494 )
  W( 75 ) = W( 75 ) + a*JVS( 495 )
  W( 76 ) = W( 76 ) + a*JVS( 496 )
  W( 77 ) = W( 77 ) + a*JVS( 497 )
  a = -W( 60 ) / JVS( 500 )
  W( 60 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 501 )
  W( 69 ) = W( 69 ) + a*JVS( 502 )
  W( 71 ) = W( 71 ) + a*JVS( 503 )
  W( 72 ) = W( 72 ) + a*JVS( 504 )
  W( 74 ) = W( 74 ) + a*JVS( 505 )
  W( 75 ) = W( 75 ) + a*JVS( 506 )
  W( 76 ) = W( 76 ) + a*JVS( 507 )
  W( 77 ) = W( 77 ) + a*JVS( 508 )
  a = -W( 61 ) / JVS( 517 )
  W( 61 ) = -a
  W( 62 ) = W( 62 ) + a*JVS( 518 )
  W( 68 ) = W( 68 ) + a*JVS( 519 )
  W( 69 ) = W( 69 ) + a*JVS( 520 )
  W( 71 ) = W( 71 ) + a*JVS( 521 )
  W( 72 ) = W( 72 ) + a*JVS( 522 )
  W( 74 ) = W( 74 ) + a*JVS( 523 )
  W( 75 ) = W( 75 ) + a*JVS( 524 )
  W( 76 ) = W( 76 ) + a*JVS( 525 )
  W( 77 ) = W( 77 ) + a*JVS( 526 )
  a = -W( 62 ) / JVS( 535 )
  W( 62 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 536 )
  W( 69 ) = W( 69 ) + a*JVS( 537 )
  W( 71 ) = W( 71 ) + a*JVS( 538 )
  W( 72 ) = W( 72 ) + a*JVS( 539 )
  W( 74 ) = W( 74 ) + a*JVS( 540 )
  W( 75 ) = W( 75 ) + a*JVS( 541 )
  W( 76 ) = W( 76 ) + a*JVS( 542 )
  W( 77 ) = W( 77 ) + a*JVS( 543 )
  a = -W( 64 ) / JVS( 592 )
  W( 64 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 593 )
  W( 69 ) = W( 69 ) + a*JVS( 594 )
  W( 71 ) = W( 71 ) + a*JVS( 595 )
  W( 72 ) = W( 72 ) + a*JVS( 596 )
  W( 74 ) = W( 74 ) + a*JVS( 597 )
  W( 75 ) = W( 75 ) + a*JVS( 598 )
  W( 76 ) = W( 76 ) + a*JVS( 599 )
  W( 77 ) = W( 77 ) + a*JVS( 600 )
  W( 78 ) = W( 78 ) + a*JVS( 601 )
  a = -W( 65 ) / JVS( 605 )
  W( 65 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 606 )
  W( 69 ) = W( 69 ) + a*JVS( 607 )
  W( 71 ) = W( 71 ) + a*JVS( 608 )
  W( 72 ) = W( 72 ) + a*JVS( 609 )
  W( 74 ) = W( 74 ) + a*JVS( 610 )
  W( 75 ) = W( 75 ) + a*JVS( 611 )
  W( 76 ) = W( 76 ) + a*JVS( 612 )
  W( 77 ) = W( 77 ) + a*JVS( 613 )
  W( 78 ) = W( 78 ) + a*JVS( 614 )
  JVS( 615) = W( 15 )
  JVS( 616) = W( 34 )
  JVS( 617) = W( 36 )
  JVS( 618) = W( 47 )
  JVS( 619) = W( 49 )
  JVS( 620) = W( 50 )
  JVS( 621) = W( 53 )
  JVS( 622) = W( 55 )
  JVS( 623) = W( 59 )
  JVS( 624) = W( 60 )
  JVS( 625) = W( 61 )
  JVS( 626) = W( 62 )
  JVS( 627) = W( 64 )
  JVS( 628) = W( 65 )
  JVS( 629) = W( 66 )
  JVS( 630) = W( 67 )
  JVS( 631) = W( 68 )
  JVS( 632) = W( 69 )
  JVS( 633) = W( 70 )
  JVS( 634) = W( 71 )
  JVS( 635) = W( 72 )
  JVS( 636) = W( 73 )
  JVS( 637) = W( 74 )
  JVS( 638) = W( 75 )
  JVS( 639) = W( 76 )
  JVS( 640) = W( 77 )
  JVS( 641) = W( 78 )
  IF ( ABS( JVS( 657 )) < TINY(a) ) THEN
         IER = 67
         RETURN
  END IF
   W( 34 ) = JVS( 642 )
   W( 36 ) = JVS( 643 )
   W( 37 ) = JVS( 644 )
   W( 42 ) = JVS( 645 )
   W( 47 ) = JVS( 646 )
   W( 49 ) = JVS( 647 )
   W( 50 ) = JVS( 648 )
   W( 53 ) = JVS( 649 )
   W( 55 ) = JVS( 650 )
   W( 59 ) = JVS( 651 )
   W( 60 ) = JVS( 652 )
   W( 61 ) = JVS( 653 )
   W( 62 ) = JVS( 654 )
   W( 64 ) = JVS( 655 )
   W( 65 ) = JVS( 656 )
   W( 67 ) = JVS( 657 )
   W( 68 ) = JVS( 658 )
   W( 69 ) = JVS( 659 )
   W( 70 ) = JVS( 660 )
   W( 71 ) = JVS( 661 )
   W( 72 ) = JVS( 662 )
   W( 73 ) = JVS( 663 )
   W( 74 ) = JVS( 664 )
   W( 75 ) = JVS( 665 )
   W( 76 ) = JVS( 666 )
   W( 77 ) = JVS( 667 )
   W( 78 ) = JVS( 668 )
  a = -W( 34 ) / JVS( 189 )
  W( 34 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 190 )
  W( 75 ) = W( 75 ) + a*JVS( 191 )
  W( 76 ) = W( 76 ) + a*JVS( 192 )
  a = -W( 36 ) / JVS( 203 )
  W( 36 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 204 )
  W( 75 ) = W( 75 ) + a*JVS( 205 )
  W( 76 ) = W( 76 ) + a*JVS( 206 )
  a = -W( 37 ) / JVS( 207 )
  W( 37 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 208 )
  W( 75 ) = W( 75 ) + a*JVS( 209 )
  W( 76 ) = W( 76 ) + a*JVS( 210 )
  a = -W( 42 ) / JVS( 249 )
  W( 42 ) = -a
  W( 71 ) = W( 71 ) + a*JVS( 250 )
  W( 74 ) = W( 74 ) + a*JVS( 251 )
  W( 75 ) = W( 75 ) + a*JVS( 252 )
  W( 76 ) = W( 76 ) + a*JVS( 253 )
  a = -W( 47 ) / JVS( 304 )
  W( 47 ) = -a
  W( 49 ) = W( 49 ) + a*JVS( 305 )
  W( 50 ) = W( 50 ) + a*JVS( 306 )
  W( 53 ) = W( 53 ) + a*JVS( 307 )
  W( 55 ) = W( 55 ) + a*JVS( 308 )
  W( 59 ) = W( 59 ) + a*JVS( 309 )
  W( 60 ) = W( 60 ) + a*JVS( 310 )
  W( 61 ) = W( 61 ) + a*JVS( 311 )
  W( 62 ) = W( 62 ) + a*JVS( 312 )
  W( 64 ) = W( 64 ) + a*JVS( 313 )
  W( 67 ) = W( 67 ) + a*JVS( 314 )
  W( 68 ) = W( 68 ) + a*JVS( 315 )
  W( 69 ) = W( 69 ) + a*JVS( 316 )
  W( 70 ) = W( 70 ) + a*JVS( 317 )
  W( 72 ) = W( 72 ) + a*JVS( 318 )
  W( 73 ) = W( 73 ) + a*JVS( 319 )
  W( 74 ) = W( 74 ) + a*JVS( 320 )
  W( 75 ) = W( 75 ) + a*JVS( 321 )
  W( 76 ) = W( 76 ) + a*JVS( 322 )
  W( 77 ) = W( 77 ) + a*JVS( 323 )
  a = -W( 49 ) / JVS( 334 )
  W( 49 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 335 )
  W( 69 ) = W( 69 ) + a*JVS( 336 )
  W( 72 ) = W( 72 ) + a*JVS( 337 )
  W( 74 ) = W( 74 ) + a*JVS( 338 )
  W( 76 ) = W( 76 ) + a*JVS( 339 )
  W( 77 ) = W( 77 ) + a*JVS( 340 )
  a = -W( 50 ) / JVS( 342 )
  W( 50 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 343 )
  W( 69 ) = W( 69 ) + a*JVS( 344 )
  W( 72 ) = W( 72 ) + a*JVS( 345 )
  W( 74 ) = W( 74 ) + a*JVS( 346 )
  W( 76 ) = W( 76 ) + a*JVS( 347 )
  W( 77 ) = W( 77 ) + a*JVS( 348 )
  a = -W( 53 ) / JVS( 370 )
  W( 53 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 371 )
  W( 69 ) = W( 69 ) + a*JVS( 372 )
  W( 72 ) = W( 72 ) + a*JVS( 373 )
  W( 74 ) = W( 74 ) + a*JVS( 374 )
  W( 75 ) = W( 75 ) + a*JVS( 375 )
  W( 76 ) = W( 76 ) + a*JVS( 376 )
  W( 77 ) = W( 77 ) + a*JVS( 377 )
  a = -W( 55 ) / JVS( 399 )
  W( 55 ) = -a
  W( 61 ) = W( 61 ) + a*JVS( 400 )
  W( 62 ) = W( 62 ) + a*JVS( 401 )
  W( 65 ) = W( 65 ) + a*JVS( 402 )
  W( 68 ) = W( 68 ) + a*JVS( 403 )
  W( 69 ) = W( 69 ) + a*JVS( 404 )
  W( 71 ) = W( 71 ) + a*JVS( 405 )
  W( 72 ) = W( 72 ) + a*JVS( 406 )
  W( 73 ) = W( 73 ) + a*JVS( 407 )
  W( 74 ) = W( 74 ) + a*JVS( 408 )
  W( 75 ) = W( 75 ) + a*JVS( 409 )
  W( 76 ) = W( 76 ) + a*JVS( 410 )
  W( 77 ) = W( 77 ) + a*JVS( 411 )
  W( 78 ) = W( 78 ) + a*JVS( 412 )
  a = -W( 59 ) / JVS( 489 )
  W( 59 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 490 )
  W( 69 ) = W( 69 ) + a*JVS( 491 )
  W( 71 ) = W( 71 ) + a*JVS( 492 )
  W( 72 ) = W( 72 ) + a*JVS( 493 )
  W( 74 ) = W( 74 ) + a*JVS( 494 )
  W( 75 ) = W( 75 ) + a*JVS( 495 )
  W( 76 ) = W( 76 ) + a*JVS( 496 )
  W( 77 ) = W( 77 ) + a*JVS( 497 )
  a = -W( 60 ) / JVS( 500 )
  W( 60 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 501 )
  W( 69 ) = W( 69 ) + a*JVS( 502 )
  W( 71 ) = W( 71 ) + a*JVS( 503 )
  W( 72 ) = W( 72 ) + a*JVS( 504 )
  W( 74 ) = W( 74 ) + a*JVS( 505 )
  W( 75 ) = W( 75 ) + a*JVS( 506 )
  W( 76 ) = W( 76 ) + a*JVS( 507 )
  W( 77 ) = W( 77 ) + a*JVS( 508 )
  a = -W( 61 ) / JVS( 517 )
  W( 61 ) = -a
  W( 62 ) = W( 62 ) + a*JVS( 518 )
  W( 68 ) = W( 68 ) + a*JVS( 519 )
  W( 69 ) = W( 69 ) + a*JVS( 520 )
  W( 71 ) = W( 71 ) + a*JVS( 521 )
  W( 72 ) = W( 72 ) + a*JVS( 522 )
  W( 74 ) = W( 74 ) + a*JVS( 523 )
  W( 75 ) = W( 75 ) + a*JVS( 524 )
  W( 76 ) = W( 76 ) + a*JVS( 525 )
  W( 77 ) = W( 77 ) + a*JVS( 526 )
  a = -W( 62 ) / JVS( 535 )
  W( 62 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 536 )
  W( 69 ) = W( 69 ) + a*JVS( 537 )
  W( 71 ) = W( 71 ) + a*JVS( 538 )
  W( 72 ) = W( 72 ) + a*JVS( 539 )
  W( 74 ) = W( 74 ) + a*JVS( 540 )
  W( 75 ) = W( 75 ) + a*JVS( 541 )
  W( 76 ) = W( 76 ) + a*JVS( 542 )
  W( 77 ) = W( 77 ) + a*JVS( 543 )
  a = -W( 64 ) / JVS( 592 )
  W( 64 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 593 )
  W( 69 ) = W( 69 ) + a*JVS( 594 )
  W( 71 ) = W( 71 ) + a*JVS( 595 )
  W( 72 ) = W( 72 ) + a*JVS( 596 )
  W( 74 ) = W( 74 ) + a*JVS( 597 )
  W( 75 ) = W( 75 ) + a*JVS( 598 )
  W( 76 ) = W( 76 ) + a*JVS( 599 )
  W( 77 ) = W( 77 ) + a*JVS( 600 )
  W( 78 ) = W( 78 ) + a*JVS( 601 )
  a = -W( 65 ) / JVS( 605 )
  W( 65 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 606 )
  W( 69 ) = W( 69 ) + a*JVS( 607 )
  W( 71 ) = W( 71 ) + a*JVS( 608 )
  W( 72 ) = W( 72 ) + a*JVS( 609 )
  W( 74 ) = W( 74 ) + a*JVS( 610 )
  W( 75 ) = W( 75 ) + a*JVS( 611 )
  W( 76 ) = W( 76 ) + a*JVS( 612 )
  W( 77 ) = W( 77 ) + a*JVS( 613 )
  W( 78 ) = W( 78 ) + a*JVS( 614 )
  JVS( 642) = W( 34 )
  JVS( 643) = W( 36 )
  JVS( 644) = W( 37 )
  JVS( 645) = W( 42 )
  JVS( 646) = W( 47 )
  JVS( 647) = W( 49 )
  JVS( 648) = W( 50 )
  JVS( 649) = W( 53 )
  JVS( 650) = W( 55 )
  JVS( 651) = W( 59 )
  JVS( 652) = W( 60 )
  JVS( 653) = W( 61 )
  JVS( 654) = W( 62 )
  JVS( 655) = W( 64 )
  JVS( 656) = W( 65 )
  JVS( 657) = W( 67 )
  JVS( 658) = W( 68 )
  JVS( 659) = W( 69 )
  JVS( 660) = W( 70 )
  JVS( 661) = W( 71 )
  JVS( 662) = W( 72 )
  JVS( 663) = W( 73 )
  JVS( 664) = W( 74 )
  JVS( 665) = W( 75 )
  JVS( 666) = W( 76 )
  JVS( 667) = W( 77 )
  JVS( 668) = W( 78 )
  IF ( ABS( JVS( 700 )) < TINY(a) ) THEN
         IER = 68
         RETURN
  END IF
   W( 26 ) = JVS( 669 )
   W( 30 ) = JVS( 670 )
   W( 32 ) = JVS( 671 )
   W( 37 ) = JVS( 672 )
   W( 40 ) = JVS( 673 )
   W( 41 ) = JVS( 674 )
   W( 42 ) = JVS( 675 )
   W( 43 ) = JVS( 676 )
   W( 44 ) = JVS( 677 )
   W( 45 ) = JVS( 678 )
   W( 46 ) = JVS( 679 )
   W( 47 ) = JVS( 680 )
   W( 48 ) = JVS( 681 )
   W( 49 ) = JVS( 682 )
   W( 50 ) = JVS( 683 )
   W( 51 ) = JVS( 684 )
   W( 52 ) = JVS( 685 )
   W( 53 ) = JVS( 686 )
   W( 54 ) = JVS( 687 )
   W( 55 ) = JVS( 688 )
   W( 56 ) = JVS( 689 )
   W( 57 ) = JVS( 690 )
   W( 58 ) = JVS( 691 )
   W( 59 ) = JVS( 692 )
   W( 60 ) = JVS( 693 )
   W( 61 ) = JVS( 694 )
   W( 62 ) = JVS( 695 )
   W( 64 ) = JVS( 696 )
   W( 65 ) = JVS( 697 )
   W( 66 ) = JVS( 698 )
   W( 67 ) = JVS( 699 )
   W( 68 ) = JVS( 700 )
   W( 69 ) = JVS( 701 )
   W( 70 ) = JVS( 702 )
   W( 71 ) = JVS( 703 )
   W( 72 ) = JVS( 704 )
   W( 73 ) = JVS( 705 )
   W( 74 ) = JVS( 706 )
   W( 75 ) = JVS( 707 )
   W( 76 ) = JVS( 708 )
   W( 77 ) = JVS( 709 )
   W( 78 ) = JVS( 710 )
  a = -W( 26 ) / JVS( 123 )
  W( 26 ) = -a
  W( 40 ) = W( 40 ) + a*JVS( 124 )
  W( 56 ) = W( 56 ) + a*JVS( 125 )
  W( 67 ) = W( 67 ) + a*JVS( 126 )
  W( 72 ) = W( 72 ) + a*JVS( 127 )
  W( 76 ) = W( 76 ) + a*JVS( 128 )
  a = -W( 30 ) / JVS( 143 )
  W( 30 ) = -a
  W( 64 ) = W( 64 ) + a*JVS( 144 )
  W( 68 ) = W( 68 ) + a*JVS( 145 )
  W( 69 ) = W( 69 ) + a*JVS( 146 )
  W( 75 ) = W( 75 ) + a*JVS( 147 )
  W( 76 ) = W( 76 ) + a*JVS( 148 )
  a = -W( 32 ) / JVS( 161 )
  W( 32 ) = -a
  W( 40 ) = W( 40 ) + a*JVS( 162 )
  W( 68 ) = W( 68 ) + a*JVS( 163 )
  W( 74 ) = W( 74 ) + a*JVS( 164 )
  W( 75 ) = W( 75 ) + a*JVS( 165 )
  W( 76 ) = W( 76 ) + a*JVS( 166 )
  W( 78 ) = W( 78 ) + a*JVS( 167 )
  a = -W( 37 ) / JVS( 207 )
  W( 37 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 208 )
  W( 75 ) = W( 75 ) + a*JVS( 209 )
  W( 76 ) = W( 76 ) + a*JVS( 210 )
  a = -W( 40 ) / JVS( 234 )
  W( 40 ) = -a
  W( 65 ) = W( 65 ) + a*JVS( 235 )
  W( 74 ) = W( 74 ) + a*JVS( 236 )
  W( 75 ) = W( 75 ) + a*JVS( 237 )
  W( 76 ) = W( 76 ) + a*JVS( 238 )
  W( 78 ) = W( 78 ) + a*JVS( 239 )
  a = -W( 41 ) / JVS( 241 )
  W( 41 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 242 )
  W( 69 ) = W( 69 ) + a*JVS( 243 )
  W( 72 ) = W( 72 ) + a*JVS( 244 )
  W( 74 ) = W( 74 ) + a*JVS( 245 )
  W( 75 ) = W( 75 ) + a*JVS( 246 )
  W( 76 ) = W( 76 ) + a*JVS( 247 )
  W( 77 ) = W( 77 ) + a*JVS( 248 )
  a = -W( 42 ) / JVS( 249 )
  W( 42 ) = -a
  W( 71 ) = W( 71 ) + a*JVS( 250 )
  W( 74 ) = W( 74 ) + a*JVS( 251 )
  W( 75 ) = W( 75 ) + a*JVS( 252 )
  W( 76 ) = W( 76 ) + a*JVS( 253 )
  a = -W( 43 ) / JVS( 254 )
  W( 43 ) = -a
  W( 59 ) = W( 59 ) + a*JVS( 255 )
  W( 68 ) = W( 68 ) + a*JVS( 256 )
  W( 69 ) = W( 69 ) + a*JVS( 257 )
  W( 72 ) = W( 72 ) + a*JVS( 258 )
  W( 74 ) = W( 74 ) + a*JVS( 259 )
  W( 76 ) = W( 76 ) + a*JVS( 260 )
  W( 77 ) = W( 77 ) + a*JVS( 261 )
  a = -W( 44 ) / JVS( 262 )
  W( 44 ) = -a
  W( 60 ) = W( 60 ) + a*JVS( 263 )
  W( 68 ) = W( 68 ) + a*JVS( 264 )
  W( 69 ) = W( 69 ) + a*JVS( 265 )
  W( 72 ) = W( 72 ) + a*JVS( 266 )
  W( 74 ) = W( 74 ) + a*JVS( 267 )
  W( 76 ) = W( 76 ) + a*JVS( 268 )
  W( 77 ) = W( 77 ) + a*JVS( 269 )
  a = -W( 45 ) / JVS( 272 )
  W( 45 ) = -a
  W( 46 ) = W( 46 ) + a*JVS( 273 )
  W( 51 ) = W( 51 ) + a*JVS( 274 )
  W( 52 ) = W( 52 ) + a*JVS( 275 )
  W( 56 ) = W( 56 ) + a*JVS( 276 )
  W( 64 ) = W( 64 ) + a*JVS( 277 )
  W( 65 ) = W( 65 ) + a*JVS( 278 )
  W( 67 ) = W( 67 ) + a*JVS( 279 )
  W( 68 ) = W( 68 ) + a*JVS( 280 )
  W( 72 ) = W( 72 ) + a*JVS( 281 )
  W( 73 ) = W( 73 ) + a*JVS( 282 )
  W( 74 ) = W( 74 ) + a*JVS( 283 )
  W( 75 ) = W( 75 ) + a*JVS( 284 )
  W( 76 ) = W( 76 ) + a*JVS( 285 )
  W( 77 ) = W( 77 ) + a*JVS( 286 )
  W( 78 ) = W( 78 ) + a*JVS( 287 )
  a = -W( 46 ) / JVS( 290 )
  W( 46 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 291 )
  W( 69 ) = W( 69 ) + a*JVS( 292 )
  W( 72 ) = W( 72 ) + a*JVS( 293 )
  W( 74 ) = W( 74 ) + a*JVS( 294 )
  W( 75 ) = W( 75 ) + a*JVS( 295 )
  W( 76 ) = W( 76 ) + a*JVS( 296 )
  W( 77 ) = W( 77 ) + a*JVS( 297 )
  W( 78 ) = W( 78 ) + a*JVS( 298 )
  a = -W( 47 ) / JVS( 304 )
  W( 47 ) = -a
  W( 49 ) = W( 49 ) + a*JVS( 305 )
  W( 50 ) = W( 50 ) + a*JVS( 306 )
  W( 53 ) = W( 53 ) + a*JVS( 307 )
  W( 55 ) = W( 55 ) + a*JVS( 308 )
  W( 59 ) = W( 59 ) + a*JVS( 309 )
  W( 60 ) = W( 60 ) + a*JVS( 310 )
  W( 61 ) = W( 61 ) + a*JVS( 311 )
  W( 62 ) = W( 62 ) + a*JVS( 312 )
  W( 64 ) = W( 64 ) + a*JVS( 313 )
  W( 67 ) = W( 67 ) + a*JVS( 314 )
  W( 68 ) = W( 68 ) + a*JVS( 315 )
  W( 69 ) = W( 69 ) + a*JVS( 316 )
  W( 70 ) = W( 70 ) + a*JVS( 317 )
  W( 72 ) = W( 72 ) + a*JVS( 318 )
  W( 73 ) = W( 73 ) + a*JVS( 319 )
  W( 74 ) = W( 74 ) + a*JVS( 320 )
  W( 75 ) = W( 75 ) + a*JVS( 321 )
  W( 76 ) = W( 76 ) + a*JVS( 322 )
  W( 77 ) = W( 77 ) + a*JVS( 323 )
  a = -W( 48 ) / JVS( 325 )
  W( 48 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 326 )
  W( 69 ) = W( 69 ) + a*JVS( 327 )
  W( 72 ) = W( 72 ) + a*JVS( 328 )
  W( 74 ) = W( 74 ) + a*JVS( 329 )
  W( 75 ) = W( 75 ) + a*JVS( 330 )
  W( 76 ) = W( 76 ) + a*JVS( 331 )
  W( 77 ) = W( 77 ) + a*JVS( 332 )
  a = -W( 49 ) / JVS( 334 )
  W( 49 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 335 )
  W( 69 ) = W( 69 ) + a*JVS( 336 )
  W( 72 ) = W( 72 ) + a*JVS( 337 )
  W( 74 ) = W( 74 ) + a*JVS( 338 )
  W( 76 ) = W( 76 ) + a*JVS( 339 )
  W( 77 ) = W( 77 ) + a*JVS( 340 )
  a = -W( 50 ) / JVS( 342 )
  W( 50 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 343 )
  W( 69 ) = W( 69 ) + a*JVS( 344 )
  W( 72 ) = W( 72 ) + a*JVS( 345 )
  W( 74 ) = W( 74 ) + a*JVS( 346 )
  W( 76 ) = W( 76 ) + a*JVS( 347 )
  W( 77 ) = W( 77 ) + a*JVS( 348 )
  a = -W( 51 ) / JVS( 350 )
  W( 51 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 351 )
  W( 69 ) = W( 69 ) + a*JVS( 352 )
  W( 72 ) = W( 72 ) + a*JVS( 353 )
  W( 74 ) = W( 74 ) + a*JVS( 354 )
  W( 75 ) = W( 75 ) + a*JVS( 355 )
  W( 76 ) = W( 76 ) + a*JVS( 356 )
  W( 77 ) = W( 77 ) + a*JVS( 357 )
  W( 78 ) = W( 78 ) + a*JVS( 358 )
  a = -W( 52 ) / JVS( 360 )
  W( 52 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 361 )
  W( 69 ) = W( 69 ) + a*JVS( 362 )
  W( 72 ) = W( 72 ) + a*JVS( 363 )
  W( 74 ) = W( 74 ) + a*JVS( 364 )
  W( 75 ) = W( 75 ) + a*JVS( 365 )
  W( 76 ) = W( 76 ) + a*JVS( 366 )
  W( 77 ) = W( 77 ) + a*JVS( 367 )
  W( 78 ) = W( 78 ) + a*JVS( 368 )
  a = -W( 53 ) / JVS( 370 )
  W( 53 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 371 )
  W( 69 ) = W( 69 ) + a*JVS( 372 )
  W( 72 ) = W( 72 ) + a*JVS( 373 )
  W( 74 ) = W( 74 ) + a*JVS( 374 )
  W( 75 ) = W( 75 ) + a*JVS( 375 )
  W( 76 ) = W( 76 ) + a*JVS( 376 )
  W( 77 ) = W( 77 ) + a*JVS( 377 )
  a = -W( 54 ) / JVS( 380 )
  W( 54 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 381 )
  W( 69 ) = W( 69 ) + a*JVS( 382 )
  W( 71 ) = W( 71 ) + a*JVS( 383 )
  W( 72 ) = W( 72 ) + a*JVS( 384 )
  W( 74 ) = W( 74 ) + a*JVS( 385 )
  W( 75 ) = W( 75 ) + a*JVS( 386 )
  W( 76 ) = W( 76 ) + a*JVS( 387 )
  W( 77 ) = W( 77 ) + a*JVS( 388 )
  a = -W( 55 ) / JVS( 399 )
  W( 55 ) = -a
  W( 61 ) = W( 61 ) + a*JVS( 400 )
  W( 62 ) = W( 62 ) + a*JVS( 401 )
  W( 65 ) = W( 65 ) + a*JVS( 402 )
  W( 68 ) = W( 68 ) + a*JVS( 403 )
  W( 69 ) = W( 69 ) + a*JVS( 404 )
  W( 71 ) = W( 71 ) + a*JVS( 405 )
  W( 72 ) = W( 72 ) + a*JVS( 406 )
  W( 73 ) = W( 73 ) + a*JVS( 407 )
  W( 74 ) = W( 74 ) + a*JVS( 408 )
  W( 75 ) = W( 75 ) + a*JVS( 409 )
  W( 76 ) = W( 76 ) + a*JVS( 410 )
  W( 77 ) = W( 77 ) + a*JVS( 411 )
  W( 78 ) = W( 78 ) + a*JVS( 412 )
  a = -W( 56 ) / JVS( 418 )
  W( 56 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 419 )
  W( 69 ) = W( 69 ) + a*JVS( 420 )
  W( 71 ) = W( 71 ) + a*JVS( 421 )
  W( 72 ) = W( 72 ) + a*JVS( 422 )
  W( 74 ) = W( 74 ) + a*JVS( 423 )
  W( 75 ) = W( 75 ) + a*JVS( 424 )
  W( 76 ) = W( 76 ) + a*JVS( 425 )
  W( 77 ) = W( 77 ) + a*JVS( 426 )
  a = -W( 57 ) / JVS( 438 )
  W( 57 ) = -a
  W( 64 ) = W( 64 ) + a*JVS( 439 )
  W( 65 ) = W( 65 ) + a*JVS( 440 )
  W( 67 ) = W( 67 ) + a*JVS( 441 )
  W( 68 ) = W( 68 ) + a*JVS( 442 )
  W( 69 ) = W( 69 ) + a*JVS( 443 )
  W( 70 ) = W( 70 ) + a*JVS( 444 )
  W( 71 ) = W( 71 ) + a*JVS( 445 )
  W( 72 ) = W( 72 ) + a*JVS( 446 )
  W( 73 ) = W( 73 ) + a*JVS( 447 )
  W( 74 ) = W( 74 ) + a*JVS( 448 )
  W( 75 ) = W( 75 ) + a*JVS( 449 )
  W( 76 ) = W( 76 ) + a*JVS( 450 )
  W( 77 ) = W( 77 ) + a*JVS( 451 )
  W( 78 ) = W( 78 ) + a*JVS( 452 )
  a = -W( 58 ) / JVS( 465 )
  W( 58 ) = -a
  W( 59 ) = W( 59 ) + a*JVS( 466 )
  W( 60 ) = W( 60 ) + a*JVS( 467 )
  W( 61 ) = W( 61 ) + a*JVS( 468 )
  W( 62 ) = W( 62 ) + a*JVS( 469 )
  W( 64 ) = W( 64 ) + a*JVS( 470 )
  W( 65 ) = W( 65 ) + a*JVS( 471 )
  W( 66 ) = W( 66 ) + a*JVS( 472 )
  W( 67 ) = W( 67 ) + a*JVS( 473 )
  W( 68 ) = W( 68 ) + a*JVS( 474 )
  W( 69 ) = W( 69 ) + a*JVS( 475 )
  W( 70 ) = W( 70 ) + a*JVS( 476 )
  W( 71 ) = W( 71 ) + a*JVS( 477 )
  W( 72 ) = W( 72 ) + a*JVS( 478 )
  W( 73 ) = W( 73 ) + a*JVS( 479 )
  W( 74 ) = W( 74 ) + a*JVS( 480 )
  W( 75 ) = W( 75 ) + a*JVS( 481 )
  W( 76 ) = W( 76 ) + a*JVS( 482 )
  W( 77 ) = W( 77 ) + a*JVS( 483 )
  W( 78 ) = W( 78 ) + a*JVS( 484 )
  a = -W( 59 ) / JVS( 489 )
  W( 59 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 490 )
  W( 69 ) = W( 69 ) + a*JVS( 491 )
  W( 71 ) = W( 71 ) + a*JVS( 492 )
  W( 72 ) = W( 72 ) + a*JVS( 493 )
  W( 74 ) = W( 74 ) + a*JVS( 494 )
  W( 75 ) = W( 75 ) + a*JVS( 495 )
  W( 76 ) = W( 76 ) + a*JVS( 496 )
  W( 77 ) = W( 77 ) + a*JVS( 497 )
  a = -W( 60 ) / JVS( 500 )
  W( 60 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 501 )
  W( 69 ) = W( 69 ) + a*JVS( 502 )
  W( 71 ) = W( 71 ) + a*JVS( 503 )
  W( 72 ) = W( 72 ) + a*JVS( 504 )
  W( 74 ) = W( 74 ) + a*JVS( 505 )
  W( 75 ) = W( 75 ) + a*JVS( 506 )
  W( 76 ) = W( 76 ) + a*JVS( 507 )
  W( 77 ) = W( 77 ) + a*JVS( 508 )
  a = -W( 61 ) / JVS( 517 )
  W( 61 ) = -a
  W( 62 ) = W( 62 ) + a*JVS( 518 )
  W( 68 ) = W( 68 ) + a*JVS( 519 )
  W( 69 ) = W( 69 ) + a*JVS( 520 )
  W( 71 ) = W( 71 ) + a*JVS( 521 )
  W( 72 ) = W( 72 ) + a*JVS( 522 )
  W( 74 ) = W( 74 ) + a*JVS( 523 )
  W( 75 ) = W( 75 ) + a*JVS( 524 )
  W( 76 ) = W( 76 ) + a*JVS( 525 )
  W( 77 ) = W( 77 ) + a*JVS( 526 )
  a = -W( 62 ) / JVS( 535 )
  W( 62 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 536 )
  W( 69 ) = W( 69 ) + a*JVS( 537 )
  W( 71 ) = W( 71 ) + a*JVS( 538 )
  W( 72 ) = W( 72 ) + a*JVS( 539 )
  W( 74 ) = W( 74 ) + a*JVS( 540 )
  W( 75 ) = W( 75 ) + a*JVS( 541 )
  W( 76 ) = W( 76 ) + a*JVS( 542 )
  W( 77 ) = W( 77 ) + a*JVS( 543 )
  a = -W( 64 ) / JVS( 592 )
  W( 64 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 593 )
  W( 69 ) = W( 69 ) + a*JVS( 594 )
  W( 71 ) = W( 71 ) + a*JVS( 595 )
  W( 72 ) = W( 72 ) + a*JVS( 596 )
  W( 74 ) = W( 74 ) + a*JVS( 597 )
  W( 75 ) = W( 75 ) + a*JVS( 598 )
  W( 76 ) = W( 76 ) + a*JVS( 599 )
  W( 77 ) = W( 77 ) + a*JVS( 600 )
  W( 78 ) = W( 78 ) + a*JVS( 601 )
  a = -W( 65 ) / JVS( 605 )
  W( 65 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 606 )
  W( 69 ) = W( 69 ) + a*JVS( 607 )
  W( 71 ) = W( 71 ) + a*JVS( 608 )
  W( 72 ) = W( 72 ) + a*JVS( 609 )
  W( 74 ) = W( 74 ) + a*JVS( 610 )
  W( 75 ) = W( 75 ) + a*JVS( 611 )
  W( 76 ) = W( 76 ) + a*JVS( 612 )
  W( 77 ) = W( 77 ) + a*JVS( 613 )
  W( 78 ) = W( 78 ) + a*JVS( 614 )
  a = -W( 66 ) / JVS( 629 )
  W( 66 ) = -a
  W( 67 ) = W( 67 ) + a*JVS( 630 )
  W( 68 ) = W( 68 ) + a*JVS( 631 )
  W( 69 ) = W( 69 ) + a*JVS( 632 )
  W( 70 ) = W( 70 ) + a*JVS( 633 )
  W( 71 ) = W( 71 ) + a*JVS( 634 )
  W( 72 ) = W( 72 ) + a*JVS( 635 )
  W( 73 ) = W( 73 ) + a*JVS( 636 )
  W( 74 ) = W( 74 ) + a*JVS( 637 )
  W( 75 ) = W( 75 ) + a*JVS( 638 )
  W( 76 ) = W( 76 ) + a*JVS( 639 )
  W( 77 ) = W( 77 ) + a*JVS( 640 )
  W( 78 ) = W( 78 ) + a*JVS( 641 )
  a = -W( 67 ) / JVS( 657 )
  W( 67 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 658 )
  W( 69 ) = W( 69 ) + a*JVS( 659 )
  W( 70 ) = W( 70 ) + a*JVS( 660 )
  W( 71 ) = W( 71 ) + a*JVS( 661 )
  W( 72 ) = W( 72 ) + a*JVS( 662 )
  W( 73 ) = W( 73 ) + a*JVS( 663 )
  W( 74 ) = W( 74 ) + a*JVS( 664 )
  W( 75 ) = W( 75 ) + a*JVS( 665 )
  W( 76 ) = W( 76 ) + a*JVS( 666 )
  W( 77 ) = W( 77 ) + a*JVS( 667 )
  W( 78 ) = W( 78 ) + a*JVS( 668 )
  JVS( 669) = W( 26 )
  JVS( 670) = W( 30 )
  JVS( 671) = W( 32 )
  JVS( 672) = W( 37 )
  JVS( 673) = W( 40 )
  JVS( 674) = W( 41 )
  JVS( 675) = W( 42 )
  JVS( 676) = W( 43 )
  JVS( 677) = W( 44 )
  JVS( 678) = W( 45 )
  JVS( 679) = W( 46 )
  JVS( 680) = W( 47 )
  JVS( 681) = W( 48 )
  JVS( 682) = W( 49 )
  JVS( 683) = W( 50 )
  JVS( 684) = W( 51 )
  JVS( 685) = W( 52 )
  JVS( 686) = W( 53 )
  JVS( 687) = W( 54 )
  JVS( 688) = W( 55 )
  JVS( 689) = W( 56 )
  JVS( 690) = W( 57 )
  JVS( 691) = W( 58 )
  JVS( 692) = W( 59 )
  JVS( 693) = W( 60 )
  JVS( 694) = W( 61 )
  JVS( 695) = W( 62 )
  JVS( 696) = W( 64 )
  JVS( 697) = W( 65 )
  JVS( 698) = W( 66 )
  JVS( 699) = W( 67 )
  JVS( 700) = W( 68 )
  JVS( 701) = W( 69 )
  JVS( 702) = W( 70 )
  JVS( 703) = W( 71 )
  JVS( 704) = W( 72 )
  JVS( 705) = W( 73 )
  JVS( 706) = W( 74 )
  JVS( 707) = W( 75 )
  JVS( 708) = W( 76 )
  JVS( 709) = W( 77 )
  JVS( 710) = W( 78 )
  IF ( ABS( JVS( 764 )) < TINY(a) ) THEN
         IER = 69
         RETURN
  END IF
   W( 6 ) = JVS( 711 )
   W( 9 ) = JVS( 712 )
   W( 10 ) = JVS( 713 )
   W( 11 ) = JVS( 714 )
   W( 13 ) = JVS( 715 )
   W( 14 ) = JVS( 716 )
   W( 16 ) = JVS( 717 )
   W( 19 ) = JVS( 718 )
   W( 20 ) = JVS( 719 )
   W( 22 ) = JVS( 720 )
   W( 23 ) = JVS( 721 )
   W( 24 ) = JVS( 722 )
   W( 25 ) = JVS( 723 )
   W( 26 ) = JVS( 724 )
   W( 27 ) = JVS( 725 )
   W( 28 ) = JVS( 726 )
   W( 29 ) = JVS( 727 )
   W( 30 ) = JVS( 728 )
   W( 33 ) = JVS( 729 )
   W( 34 ) = JVS( 730 )
   W( 35 ) = JVS( 731 )
   W( 36 ) = JVS( 732 )
   W( 37 ) = JVS( 733 )
   W( 38 ) = JVS( 734 )
   W( 39 ) = JVS( 735 )
   W( 40 ) = JVS( 736 )
   W( 41 ) = JVS( 737 )
   W( 42 ) = JVS( 738 )
   W( 43 ) = JVS( 739 )
   W( 44 ) = JVS( 740 )
   W( 45 ) = JVS( 741 )
   W( 46 ) = JVS( 742 )
   W( 48 ) = JVS( 743 )
   W( 49 ) = JVS( 744 )
   W( 50 ) = JVS( 745 )
   W( 51 ) = JVS( 746 )
   W( 52 ) = JVS( 747 )
   W( 53 ) = JVS( 748 )
   W( 54 ) = JVS( 749 )
   W( 55 ) = JVS( 750 )
   W( 56 ) = JVS( 751 )
   W( 57 ) = JVS( 752 )
   W( 58 ) = JVS( 753 )
   W( 59 ) = JVS( 754 )
   W( 60 ) = JVS( 755 )
   W( 61 ) = JVS( 756 )
   W( 62 ) = JVS( 757 )
   W( 63 ) = JVS( 758 )
   W( 64 ) = JVS( 759 )
   W( 65 ) = JVS( 760 )
   W( 66 ) = JVS( 761 )
   W( 67 ) = JVS( 762 )
   W( 68 ) = JVS( 763 )
   W( 69 ) = JVS( 764 )
   W( 70 ) = JVS( 765 )
   W( 71 ) = JVS( 766 )
   W( 72 ) = JVS( 767 )
   W( 73 ) = JVS( 768 )
   W( 74 ) = JVS( 769 )
   W( 75 ) = JVS( 770 )
   W( 76 ) = JVS( 771 )
   W( 77 ) = JVS( 772 )
   W( 78 ) = JVS( 773 )
  a = -W( 6 ) / JVS( 43 )
  W( 6 ) = -a
  W( 76 ) = W( 76 ) + a*JVS( 44 )
  a = -W( 9 ) / JVS( 50 )
  W( 9 ) = -a
  W( 76 ) = W( 76 ) + a*JVS( 51 )
  a = -W( 10 ) / JVS( 52 )
  W( 10 ) = -a
  W( 76 ) = W( 76 ) + a*JVS( 53 )
  a = -W( 11 ) / JVS( 54 )
  W( 11 ) = -a
  W( 76 ) = W( 76 ) + a*JVS( 55 )
  a = -W( 13 ) / JVS( 59 )
  W( 13 ) = -a
  W( 76 ) = W( 76 ) + a*JVS( 60 )
  a = -W( 14 ) / JVS( 61 )
  W( 14 ) = -a
  W( 76 ) = W( 76 ) + a*JVS( 62 )
  a = -W( 16 ) / JVS( 68 )
  W( 16 ) = -a
  W( 64 ) = W( 64 ) + a*JVS( 69 )
  W( 76 ) = W( 76 ) + a*JVS( 70 )
  a = -W( 19 ) / JVS( 81 )
  W( 19 ) = -a
  W( 69 ) = W( 69 ) + a*JVS( 82 )
  W( 76 ) = W( 76 ) + a*JVS( 83 )
  W( 78 ) = W( 78 ) + a*JVS( 84 )
  a = -W( 20 ) / JVS( 85 )
  W( 20 ) = -a
  W( 69 ) = W( 69 ) + a*JVS( 86 )
  W( 72 ) = W( 72 ) + a*JVS( 87 )
  W( 76 ) = W( 76 ) + a*JVS( 88 )
  a = -W( 22 ) / JVS( 96 )
  W( 22 ) = -a
  W( 34 ) = W( 34 ) + a*JVS( 97 )
  W( 36 ) = W( 36 ) + a*JVS( 98 )
  W( 37 ) = W( 37 ) + a*JVS( 99 )
  W( 42 ) = W( 42 ) + a*JVS( 100 )
  W( 59 ) = W( 59 ) + a*JVS( 101 )
  W( 60 ) = W( 60 ) + a*JVS( 102 )
  W( 69 ) = W( 69 ) + a*JVS( 103 )
  W( 75 ) = W( 75 ) + a*JVS( 104 )
  W( 76 ) = W( 76 ) + a*JVS( 105 )
  a = -W( 23 ) / JVS( 106 )
  W( 23 ) = -a
  W( 38 ) = W( 38 ) + a*JVS( 107 )
  W( 69 ) = W( 69 ) + a*JVS( 108 )
  W( 74 ) = W( 74 ) + a*JVS( 109 )
  W( 76 ) = W( 76 ) + a*JVS( 110 )
  W( 78 ) = W( 78 ) + a*JVS( 111 )
  a = -W( 24 ) / JVS( 113 )
  W( 24 ) = -a
  W( 75 ) = W( 75 ) + a*JVS( 114 )
  W( 76 ) = W( 76 ) + a*JVS( 115 )
  W( 78 ) = W( 78 ) + a*JVS( 116 )
  a = -W( 25 ) / JVS( 118 )
  W( 25 ) = -a
  W( 75 ) = W( 75 ) + a*JVS( 119 )
  W( 76 ) = W( 76 ) + a*JVS( 120 )
  W( 78 ) = W( 78 ) + a*JVS( 121 )
  a = -W( 26 ) / JVS( 123 )
  W( 26 ) = -a
  W( 40 ) = W( 40 ) + a*JVS( 124 )
  W( 56 ) = W( 56 ) + a*JVS( 125 )
  W( 67 ) = W( 67 ) + a*JVS( 126 )
  W( 72 ) = W( 72 ) + a*JVS( 127 )
  W( 76 ) = W( 76 ) + a*JVS( 128 )
  a = -W( 27 ) / JVS( 129 )
  W( 27 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 130 )
  W( 75 ) = W( 75 ) + a*JVS( 131 )
  W( 76 ) = W( 76 ) + a*JVS( 132 )
  a = -W( 28 ) / JVS( 133 )
  W( 28 ) = -a
  W( 38 ) = W( 38 ) + a*JVS( 134 )
  W( 75 ) = W( 75 ) + a*JVS( 135 )
  W( 76 ) = W( 76 ) + a*JVS( 136 )
  W( 78 ) = W( 78 ) + a*JVS( 137 )
  a = -W( 29 ) / JVS( 138 )
  W( 29 ) = -a
  W( 35 ) = W( 35 ) + a*JVS( 139 )
  W( 69 ) = W( 69 ) + a*JVS( 140 )
  W( 75 ) = W( 75 ) + a*JVS( 141 )
  W( 77 ) = W( 77 ) + a*JVS( 142 )
  a = -W( 30 ) / JVS( 143 )
  W( 30 ) = -a
  W( 64 ) = W( 64 ) + a*JVS( 144 )
  W( 68 ) = W( 68 ) + a*JVS( 145 )
  W( 69 ) = W( 69 ) + a*JVS( 146 )
  W( 75 ) = W( 75 ) + a*JVS( 147 )
  W( 76 ) = W( 76 ) + a*JVS( 148 )
  a = -W( 33 ) / JVS( 170 )
  W( 33 ) = -a
  W( 34 ) = W( 34 ) + a*JVS( 171 )
  W( 35 ) = W( 35 ) + a*JVS( 172 )
  W( 36 ) = W( 36 ) + a*JVS( 173 )
  W( 37 ) = W( 37 ) + a*JVS( 174 )
  W( 39 ) = W( 39 ) + a*JVS( 175 )
  W( 40 ) = W( 40 ) + a*JVS( 176 )
  W( 42 ) = W( 42 ) + a*JVS( 177 )
  W( 45 ) = W( 45 ) + a*JVS( 178 )
  W( 56 ) = W( 56 ) + a*JVS( 179 )
  W( 58 ) = W( 58 ) + a*JVS( 180 )
  W( 59 ) = W( 59 ) + a*JVS( 181 )
  W( 60 ) = W( 60 ) + a*JVS( 182 )
  W( 63 ) = W( 63 ) + a*JVS( 183 )
  W( 64 ) = W( 64 ) + a*JVS( 184 )
  W( 71 ) = W( 71 ) + a*JVS( 185 )
  W( 74 ) = W( 74 ) + a*JVS( 186 )
  W( 75 ) = W( 75 ) + a*JVS( 187 )
  W( 76 ) = W( 76 ) + a*JVS( 188 )
  a = -W( 34 ) / JVS( 189 )
  W( 34 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 190 )
  W( 75 ) = W( 75 ) + a*JVS( 191 )
  W( 76 ) = W( 76 ) + a*JVS( 192 )
  a = -W( 35 ) / JVS( 197 )
  W( 35 ) = -a
  W( 63 ) = W( 63 ) + a*JVS( 198 )
  W( 69 ) = W( 69 ) + a*JVS( 199 )
  W( 75 ) = W( 75 ) + a*JVS( 200 )
  W( 76 ) = W( 76 ) + a*JVS( 201 )
  W( 77 ) = W( 77 ) + a*JVS( 202 )
  a = -W( 36 ) / JVS( 203 )
  W( 36 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 204 )
  W( 75 ) = W( 75 ) + a*JVS( 205 )
  W( 76 ) = W( 76 ) + a*JVS( 206 )
  a = -W( 37 ) / JVS( 207 )
  W( 37 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 208 )
  W( 75 ) = W( 75 ) + a*JVS( 209 )
  W( 76 ) = W( 76 ) + a*JVS( 210 )
  a = -W( 38 ) / JVS( 215 )
  W( 38 ) = -a
  W( 69 ) = W( 69 ) + a*JVS( 216 )
  W( 74 ) = W( 74 ) + a*JVS( 217 )
  W( 75 ) = W( 75 ) + a*JVS( 218 )
  W( 76 ) = W( 76 ) + a*JVS( 219 )
  W( 78 ) = W( 78 ) + a*JVS( 220 )
  a = -W( 39 ) / JVS( 222 )
  W( 39 ) = -a
  W( 46 ) = W( 46 ) + a*JVS( 223 )
  W( 51 ) = W( 51 ) + a*JVS( 224 )
  W( 52 ) = W( 52 ) + a*JVS( 225 )
  W( 64 ) = W( 64 ) + a*JVS( 226 )
  W( 68 ) = W( 68 ) + a*JVS( 227 )
  W( 72 ) = W( 72 ) + a*JVS( 228 )
  W( 73 ) = W( 73 ) + a*JVS( 229 )
  W( 74 ) = W( 74 ) + a*JVS( 230 )
  W( 75 ) = W( 75 ) + a*JVS( 231 )
  W( 76 ) = W( 76 ) + a*JVS( 232 )
  W( 77 ) = W( 77 ) + a*JVS( 233 )
  a = -W( 40 ) / JVS( 234 )
  W( 40 ) = -a
  W( 65 ) = W( 65 ) + a*JVS( 235 )
  W( 74 ) = W( 74 ) + a*JVS( 236 )
  W( 75 ) = W( 75 ) + a*JVS( 237 )
  W( 76 ) = W( 76 ) + a*JVS( 238 )
  W( 78 ) = W( 78 ) + a*JVS( 239 )
  a = -W( 41 ) / JVS( 241 )
  W( 41 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 242 )
  W( 69 ) = W( 69 ) + a*JVS( 243 )
  W( 72 ) = W( 72 ) + a*JVS( 244 )
  W( 74 ) = W( 74 ) + a*JVS( 245 )
  W( 75 ) = W( 75 ) + a*JVS( 246 )
  W( 76 ) = W( 76 ) + a*JVS( 247 )
  W( 77 ) = W( 77 ) + a*JVS( 248 )
  a = -W( 42 ) / JVS( 249 )
  W( 42 ) = -a
  W( 71 ) = W( 71 ) + a*JVS( 250 )
  W( 74 ) = W( 74 ) + a*JVS( 251 )
  W( 75 ) = W( 75 ) + a*JVS( 252 )
  W( 76 ) = W( 76 ) + a*JVS( 253 )
  a = -W( 43 ) / JVS( 254 )
  W( 43 ) = -a
  W( 59 ) = W( 59 ) + a*JVS( 255 )
  W( 68 ) = W( 68 ) + a*JVS( 256 )
  W( 69 ) = W( 69 ) + a*JVS( 257 )
  W( 72 ) = W( 72 ) + a*JVS( 258 )
  W( 74 ) = W( 74 ) + a*JVS( 259 )
  W( 76 ) = W( 76 ) + a*JVS( 260 )
  W( 77 ) = W( 77 ) + a*JVS( 261 )
  a = -W( 44 ) / JVS( 262 )
  W( 44 ) = -a
  W( 60 ) = W( 60 ) + a*JVS( 263 )
  W( 68 ) = W( 68 ) + a*JVS( 264 )
  W( 69 ) = W( 69 ) + a*JVS( 265 )
  W( 72 ) = W( 72 ) + a*JVS( 266 )
  W( 74 ) = W( 74 ) + a*JVS( 267 )
  W( 76 ) = W( 76 ) + a*JVS( 268 )
  W( 77 ) = W( 77 ) + a*JVS( 269 )
  a = -W( 45 ) / JVS( 272 )
  W( 45 ) = -a
  W( 46 ) = W( 46 ) + a*JVS( 273 )
  W( 51 ) = W( 51 ) + a*JVS( 274 )
  W( 52 ) = W( 52 ) + a*JVS( 275 )
  W( 56 ) = W( 56 ) + a*JVS( 276 )
  W( 64 ) = W( 64 ) + a*JVS( 277 )
  W( 65 ) = W( 65 ) + a*JVS( 278 )
  W( 67 ) = W( 67 ) + a*JVS( 279 )
  W( 68 ) = W( 68 ) + a*JVS( 280 )
  W( 72 ) = W( 72 ) + a*JVS( 281 )
  W( 73 ) = W( 73 ) + a*JVS( 282 )
  W( 74 ) = W( 74 ) + a*JVS( 283 )
  W( 75 ) = W( 75 ) + a*JVS( 284 )
  W( 76 ) = W( 76 ) + a*JVS( 285 )
  W( 77 ) = W( 77 ) + a*JVS( 286 )
  W( 78 ) = W( 78 ) + a*JVS( 287 )
  a = -W( 46 ) / JVS( 290 )
  W( 46 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 291 )
  W( 69 ) = W( 69 ) + a*JVS( 292 )
  W( 72 ) = W( 72 ) + a*JVS( 293 )
  W( 74 ) = W( 74 ) + a*JVS( 294 )
  W( 75 ) = W( 75 ) + a*JVS( 295 )
  W( 76 ) = W( 76 ) + a*JVS( 296 )
  W( 77 ) = W( 77 ) + a*JVS( 297 )
  W( 78 ) = W( 78 ) + a*JVS( 298 )
  a = -W( 48 ) / JVS( 325 )
  W( 48 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 326 )
  W( 69 ) = W( 69 ) + a*JVS( 327 )
  W( 72 ) = W( 72 ) + a*JVS( 328 )
  W( 74 ) = W( 74 ) + a*JVS( 329 )
  W( 75 ) = W( 75 ) + a*JVS( 330 )
  W( 76 ) = W( 76 ) + a*JVS( 331 )
  W( 77 ) = W( 77 ) + a*JVS( 332 )
  a = -W( 49 ) / JVS( 334 )
  W( 49 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 335 )
  W( 69 ) = W( 69 ) + a*JVS( 336 )
  W( 72 ) = W( 72 ) + a*JVS( 337 )
  W( 74 ) = W( 74 ) + a*JVS( 338 )
  W( 76 ) = W( 76 ) + a*JVS( 339 )
  W( 77 ) = W( 77 ) + a*JVS( 340 )
  a = -W( 50 ) / JVS( 342 )
  W( 50 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 343 )
  W( 69 ) = W( 69 ) + a*JVS( 344 )
  W( 72 ) = W( 72 ) + a*JVS( 345 )
  W( 74 ) = W( 74 ) + a*JVS( 346 )
  W( 76 ) = W( 76 ) + a*JVS( 347 )
  W( 77 ) = W( 77 ) + a*JVS( 348 )
  a = -W( 51 ) / JVS( 350 )
  W( 51 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 351 )
  W( 69 ) = W( 69 ) + a*JVS( 352 )
  W( 72 ) = W( 72 ) + a*JVS( 353 )
  W( 74 ) = W( 74 ) + a*JVS( 354 )
  W( 75 ) = W( 75 ) + a*JVS( 355 )
  W( 76 ) = W( 76 ) + a*JVS( 356 )
  W( 77 ) = W( 77 ) + a*JVS( 357 )
  W( 78 ) = W( 78 ) + a*JVS( 358 )
  a = -W( 52 ) / JVS( 360 )
  W( 52 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 361 )
  W( 69 ) = W( 69 ) + a*JVS( 362 )
  W( 72 ) = W( 72 ) + a*JVS( 363 )
  W( 74 ) = W( 74 ) + a*JVS( 364 )
  W( 75 ) = W( 75 ) + a*JVS( 365 )
  W( 76 ) = W( 76 ) + a*JVS( 366 )
  W( 77 ) = W( 77 ) + a*JVS( 367 )
  W( 78 ) = W( 78 ) + a*JVS( 368 )
  a = -W( 53 ) / JVS( 370 )
  W( 53 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 371 )
  W( 69 ) = W( 69 ) + a*JVS( 372 )
  W( 72 ) = W( 72 ) + a*JVS( 373 )
  W( 74 ) = W( 74 ) + a*JVS( 374 )
  W( 75 ) = W( 75 ) + a*JVS( 375 )
  W( 76 ) = W( 76 ) + a*JVS( 376 )
  W( 77 ) = W( 77 ) + a*JVS( 377 )
  a = -W( 54 ) / JVS( 380 )
  W( 54 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 381 )
  W( 69 ) = W( 69 ) + a*JVS( 382 )
  W( 71 ) = W( 71 ) + a*JVS( 383 )
  W( 72 ) = W( 72 ) + a*JVS( 384 )
  W( 74 ) = W( 74 ) + a*JVS( 385 )
  W( 75 ) = W( 75 ) + a*JVS( 386 )
  W( 76 ) = W( 76 ) + a*JVS( 387 )
  W( 77 ) = W( 77 ) + a*JVS( 388 )
  a = -W( 55 ) / JVS( 399 )
  W( 55 ) = -a
  W( 61 ) = W( 61 ) + a*JVS( 400 )
  W( 62 ) = W( 62 ) + a*JVS( 401 )
  W( 65 ) = W( 65 ) + a*JVS( 402 )
  W( 68 ) = W( 68 ) + a*JVS( 403 )
  W( 69 ) = W( 69 ) + a*JVS( 404 )
  W( 71 ) = W( 71 ) + a*JVS( 405 )
  W( 72 ) = W( 72 ) + a*JVS( 406 )
  W( 73 ) = W( 73 ) + a*JVS( 407 )
  W( 74 ) = W( 74 ) + a*JVS( 408 )
  W( 75 ) = W( 75 ) + a*JVS( 409 )
  W( 76 ) = W( 76 ) + a*JVS( 410 )
  W( 77 ) = W( 77 ) + a*JVS( 411 )
  W( 78 ) = W( 78 ) + a*JVS( 412 )
  a = -W( 56 ) / JVS( 418 )
  W( 56 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 419 )
  W( 69 ) = W( 69 ) + a*JVS( 420 )
  W( 71 ) = W( 71 ) + a*JVS( 421 )
  W( 72 ) = W( 72 ) + a*JVS( 422 )
  W( 74 ) = W( 74 ) + a*JVS( 423 )
  W( 75 ) = W( 75 ) + a*JVS( 424 )
  W( 76 ) = W( 76 ) + a*JVS( 425 )
  W( 77 ) = W( 77 ) + a*JVS( 426 )
  a = -W( 57 ) / JVS( 438 )
  W( 57 ) = -a
  W( 64 ) = W( 64 ) + a*JVS( 439 )
  W( 65 ) = W( 65 ) + a*JVS( 440 )
  W( 67 ) = W( 67 ) + a*JVS( 441 )
  W( 68 ) = W( 68 ) + a*JVS( 442 )
  W( 69 ) = W( 69 ) + a*JVS( 443 )
  W( 70 ) = W( 70 ) + a*JVS( 444 )
  W( 71 ) = W( 71 ) + a*JVS( 445 )
  W( 72 ) = W( 72 ) + a*JVS( 446 )
  W( 73 ) = W( 73 ) + a*JVS( 447 )
  W( 74 ) = W( 74 ) + a*JVS( 448 )
  W( 75 ) = W( 75 ) + a*JVS( 449 )
  W( 76 ) = W( 76 ) + a*JVS( 450 )
  W( 77 ) = W( 77 ) + a*JVS( 451 )
  W( 78 ) = W( 78 ) + a*JVS( 452 )
  a = -W( 58 ) / JVS( 465 )
  W( 58 ) = -a
  W( 59 ) = W( 59 ) + a*JVS( 466 )
  W( 60 ) = W( 60 ) + a*JVS( 467 )
  W( 61 ) = W( 61 ) + a*JVS( 468 )
  W( 62 ) = W( 62 ) + a*JVS( 469 )
  W( 64 ) = W( 64 ) + a*JVS( 470 )
  W( 65 ) = W( 65 ) + a*JVS( 471 )
  W( 66 ) = W( 66 ) + a*JVS( 472 )
  W( 67 ) = W( 67 ) + a*JVS( 473 )
  W( 68 ) = W( 68 ) + a*JVS( 474 )
  W( 69 ) = W( 69 ) + a*JVS( 475 )
  W( 70 ) = W( 70 ) + a*JVS( 476 )
  W( 71 ) = W( 71 ) + a*JVS( 477 )
  W( 72 ) = W( 72 ) + a*JVS( 478 )
  W( 73 ) = W( 73 ) + a*JVS( 479 )
  W( 74 ) = W( 74 ) + a*JVS( 480 )
  W( 75 ) = W( 75 ) + a*JVS( 481 )
  W( 76 ) = W( 76 ) + a*JVS( 482 )
  W( 77 ) = W( 77 ) + a*JVS( 483 )
  W( 78 ) = W( 78 ) + a*JVS( 484 )
  a = -W( 59 ) / JVS( 489 )
  W( 59 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 490 )
  W( 69 ) = W( 69 ) + a*JVS( 491 )
  W( 71 ) = W( 71 ) + a*JVS( 492 )
  W( 72 ) = W( 72 ) + a*JVS( 493 )
  W( 74 ) = W( 74 ) + a*JVS( 494 )
  W( 75 ) = W( 75 ) + a*JVS( 495 )
  W( 76 ) = W( 76 ) + a*JVS( 496 )
  W( 77 ) = W( 77 ) + a*JVS( 497 )
  a = -W( 60 ) / JVS( 500 )
  W( 60 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 501 )
  W( 69 ) = W( 69 ) + a*JVS( 502 )
  W( 71 ) = W( 71 ) + a*JVS( 503 )
  W( 72 ) = W( 72 ) + a*JVS( 504 )
  W( 74 ) = W( 74 ) + a*JVS( 505 )
  W( 75 ) = W( 75 ) + a*JVS( 506 )
  W( 76 ) = W( 76 ) + a*JVS( 507 )
  W( 77 ) = W( 77 ) + a*JVS( 508 )
  a = -W( 61 ) / JVS( 517 )
  W( 61 ) = -a
  W( 62 ) = W( 62 ) + a*JVS( 518 )
  W( 68 ) = W( 68 ) + a*JVS( 519 )
  W( 69 ) = W( 69 ) + a*JVS( 520 )
  W( 71 ) = W( 71 ) + a*JVS( 521 )
  W( 72 ) = W( 72 ) + a*JVS( 522 )
  W( 74 ) = W( 74 ) + a*JVS( 523 )
  W( 75 ) = W( 75 ) + a*JVS( 524 )
  W( 76 ) = W( 76 ) + a*JVS( 525 )
  W( 77 ) = W( 77 ) + a*JVS( 526 )
  a = -W( 62 ) / JVS( 535 )
  W( 62 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 536 )
  W( 69 ) = W( 69 ) + a*JVS( 537 )
  W( 71 ) = W( 71 ) + a*JVS( 538 )
  W( 72 ) = W( 72 ) + a*JVS( 539 )
  W( 74 ) = W( 74 ) + a*JVS( 540 )
  W( 75 ) = W( 75 ) + a*JVS( 541 )
  W( 76 ) = W( 76 ) + a*JVS( 542 )
  W( 77 ) = W( 77 ) + a*JVS( 543 )
  a = -W( 63 ) / JVS( 573 )
  W( 63 ) = -a
  W( 64 ) = W( 64 ) + a*JVS( 574 )
  W( 65 ) = W( 65 ) + a*JVS( 575 )
  W( 66 ) = W( 66 ) + a*JVS( 576 )
  W( 67 ) = W( 67 ) + a*JVS( 577 )
  W( 68 ) = W( 68 ) + a*JVS( 578 )
  W( 69 ) = W( 69 ) + a*JVS( 579 )
  W( 70 ) = W( 70 ) + a*JVS( 580 )
  W( 71 ) = W( 71 ) + a*JVS( 581 )
  W( 72 ) = W( 72 ) + a*JVS( 582 )
  W( 73 ) = W( 73 ) + a*JVS( 583 )
  W( 74 ) = W( 74 ) + a*JVS( 584 )
  W( 75 ) = W( 75 ) + a*JVS( 585 )
  W( 76 ) = W( 76 ) + a*JVS( 586 )
  W( 77 ) = W( 77 ) + a*JVS( 587 )
  W( 78 ) = W( 78 ) + a*JVS( 588 )
  a = -W( 64 ) / JVS( 592 )
  W( 64 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 593 )
  W( 69 ) = W( 69 ) + a*JVS( 594 )
  W( 71 ) = W( 71 ) + a*JVS( 595 )
  W( 72 ) = W( 72 ) + a*JVS( 596 )
  W( 74 ) = W( 74 ) + a*JVS( 597 )
  W( 75 ) = W( 75 ) + a*JVS( 598 )
  W( 76 ) = W( 76 ) + a*JVS( 599 )
  W( 77 ) = W( 77 ) + a*JVS( 600 )
  W( 78 ) = W( 78 ) + a*JVS( 601 )
  a = -W( 65 ) / JVS( 605 )
  W( 65 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 606 )
  W( 69 ) = W( 69 ) + a*JVS( 607 )
  W( 71 ) = W( 71 ) + a*JVS( 608 )
  W( 72 ) = W( 72 ) + a*JVS( 609 )
  W( 74 ) = W( 74 ) + a*JVS( 610 )
  W( 75 ) = W( 75 ) + a*JVS( 611 )
  W( 76 ) = W( 76 ) + a*JVS( 612 )
  W( 77 ) = W( 77 ) + a*JVS( 613 )
  W( 78 ) = W( 78 ) + a*JVS( 614 )
  a = -W( 66 ) / JVS( 629 )
  W( 66 ) = -a
  W( 67 ) = W( 67 ) + a*JVS( 630 )
  W( 68 ) = W( 68 ) + a*JVS( 631 )
  W( 69 ) = W( 69 ) + a*JVS( 632 )
  W( 70 ) = W( 70 ) + a*JVS( 633 )
  W( 71 ) = W( 71 ) + a*JVS( 634 )
  W( 72 ) = W( 72 ) + a*JVS( 635 )
  W( 73 ) = W( 73 ) + a*JVS( 636 )
  W( 74 ) = W( 74 ) + a*JVS( 637 )
  W( 75 ) = W( 75 ) + a*JVS( 638 )
  W( 76 ) = W( 76 ) + a*JVS( 639 )
  W( 77 ) = W( 77 ) + a*JVS( 640 )
  W( 78 ) = W( 78 ) + a*JVS( 641 )
  a = -W( 67 ) / JVS( 657 )
  W( 67 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 658 )
  W( 69 ) = W( 69 ) + a*JVS( 659 )
  W( 70 ) = W( 70 ) + a*JVS( 660 )
  W( 71 ) = W( 71 ) + a*JVS( 661 )
  W( 72 ) = W( 72 ) + a*JVS( 662 )
  W( 73 ) = W( 73 ) + a*JVS( 663 )
  W( 74 ) = W( 74 ) + a*JVS( 664 )
  W( 75 ) = W( 75 ) + a*JVS( 665 )
  W( 76 ) = W( 76 ) + a*JVS( 666 )
  W( 77 ) = W( 77 ) + a*JVS( 667 )
  W( 78 ) = W( 78 ) + a*JVS( 668 )
  a = -W( 68 ) / JVS( 700 )
  W( 68 ) = -a
  W( 69 ) = W( 69 ) + a*JVS( 701 )
  W( 70 ) = W( 70 ) + a*JVS( 702 )
  W( 71 ) = W( 71 ) + a*JVS( 703 )
  W( 72 ) = W( 72 ) + a*JVS( 704 )
  W( 73 ) = W( 73 ) + a*JVS( 705 )
  W( 74 ) = W( 74 ) + a*JVS( 706 )
  W( 75 ) = W( 75 ) + a*JVS( 707 )
  W( 76 ) = W( 76 ) + a*JVS( 708 )
  W( 77 ) = W( 77 ) + a*JVS( 709 )
  W( 78 ) = W( 78 ) + a*JVS( 710 )
  JVS( 711) = W( 6 )
  JVS( 712) = W( 9 )
  JVS( 713) = W( 10 )
  JVS( 714) = W( 11 )
  JVS( 715) = W( 13 )
  JVS( 716) = W( 14 )
  JVS( 717) = W( 16 )
  JVS( 718) = W( 19 )
  JVS( 719) = W( 20 )
  JVS( 720) = W( 22 )
  JVS( 721) = W( 23 )
  JVS( 722) = W( 24 )
  JVS( 723) = W( 25 )
  JVS( 724) = W( 26 )
  JVS( 725) = W( 27 )
  JVS( 726) = W( 28 )
  JVS( 727) = W( 29 )
  JVS( 728) = W( 30 )
  JVS( 729) = W( 33 )
  JVS( 730) = W( 34 )
  JVS( 731) = W( 35 )
  JVS( 732) = W( 36 )
  JVS( 733) = W( 37 )
  JVS( 734) = W( 38 )
  JVS( 735) = W( 39 )
  JVS( 736) = W( 40 )
  JVS( 737) = W( 41 )
  JVS( 738) = W( 42 )
  JVS( 739) = W( 43 )
  JVS( 740) = W( 44 )
  JVS( 741) = W( 45 )
  JVS( 742) = W( 46 )
  JVS( 743) = W( 48 )
  JVS( 744) = W( 49 )
  JVS( 745) = W( 50 )
  JVS( 746) = W( 51 )
  JVS( 747) = W( 52 )
  JVS( 748) = W( 53 )
  JVS( 749) = W( 54 )
  JVS( 750) = W( 55 )
  JVS( 751) = W( 56 )
  JVS( 752) = W( 57 )
  JVS( 753) = W( 58 )
  JVS( 754) = W( 59 )
  JVS( 755) = W( 60 )
  JVS( 756) = W( 61 )
  JVS( 757) = W( 62 )
  JVS( 758) = W( 63 )
  JVS( 759) = W( 64 )
  JVS( 760) = W( 65 )
  JVS( 761) = W( 66 )
  JVS( 762) = W( 67 )
  JVS( 763) = W( 68 )
  JVS( 764) = W( 69 )
  JVS( 765) = W( 70 )
  JVS( 766) = W( 71 )
  JVS( 767) = W( 72 )
  JVS( 768) = W( 73 )
  JVS( 769) = W( 74 )
  JVS( 770) = W( 75 )
  JVS( 771) = W( 76 )
  JVS( 772) = W( 77 )
  JVS( 773) = W( 78 )
  IF ( ABS( JVS( 795 )) < TINY(a) ) THEN
         IER = 70
         RETURN
  END IF
   W( 41 ) = JVS( 774 )
   W( 43 ) = JVS( 775 )
   W( 44 ) = JVS( 776 )
   W( 46 ) = JVS( 777 )
   W( 48 ) = JVS( 778 )
   W( 49 ) = JVS( 779 )
   W( 50 ) = JVS( 780 )
   W( 51 ) = JVS( 781 )
   W( 52 ) = JVS( 782 )
   W( 53 ) = JVS( 783 )
   W( 54 ) = JVS( 784 )
   W( 56 ) = JVS( 785 )
   W( 57 ) = JVS( 786 )
   W( 59 ) = JVS( 787 )
   W( 60 ) = JVS( 788 )
   W( 64 ) = JVS( 789 )
   W( 65 ) = JVS( 790 )
   W( 66 ) = JVS( 791 )
   W( 67 ) = JVS( 792 )
   W( 68 ) = JVS( 793 )
   W( 69 ) = JVS( 794 )
   W( 70 ) = JVS( 795 )
   W( 71 ) = JVS( 796 )
   W( 72 ) = JVS( 797 )
   W( 73 ) = JVS( 798 )
   W( 74 ) = JVS( 799 )
   W( 75 ) = JVS( 800 )
   W( 76 ) = JVS( 801 )
   W( 77 ) = JVS( 802 )
   W( 78 ) = JVS( 803 )
  a = -W( 41 ) / JVS( 241 )
  W( 41 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 242 )
  W( 69 ) = W( 69 ) + a*JVS( 243 )
  W( 72 ) = W( 72 ) + a*JVS( 244 )
  W( 74 ) = W( 74 ) + a*JVS( 245 )
  W( 75 ) = W( 75 ) + a*JVS( 246 )
  W( 76 ) = W( 76 ) + a*JVS( 247 )
  W( 77 ) = W( 77 ) + a*JVS( 248 )
  a = -W( 43 ) / JVS( 254 )
  W( 43 ) = -a
  W( 59 ) = W( 59 ) + a*JVS( 255 )
  W( 68 ) = W( 68 ) + a*JVS( 256 )
  W( 69 ) = W( 69 ) + a*JVS( 257 )
  W( 72 ) = W( 72 ) + a*JVS( 258 )
  W( 74 ) = W( 74 ) + a*JVS( 259 )
  W( 76 ) = W( 76 ) + a*JVS( 260 )
  W( 77 ) = W( 77 ) + a*JVS( 261 )
  a = -W( 44 ) / JVS( 262 )
  W( 44 ) = -a
  W( 60 ) = W( 60 ) + a*JVS( 263 )
  W( 68 ) = W( 68 ) + a*JVS( 264 )
  W( 69 ) = W( 69 ) + a*JVS( 265 )
  W( 72 ) = W( 72 ) + a*JVS( 266 )
  W( 74 ) = W( 74 ) + a*JVS( 267 )
  W( 76 ) = W( 76 ) + a*JVS( 268 )
  W( 77 ) = W( 77 ) + a*JVS( 269 )
  a = -W( 46 ) / JVS( 290 )
  W( 46 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 291 )
  W( 69 ) = W( 69 ) + a*JVS( 292 )
  W( 72 ) = W( 72 ) + a*JVS( 293 )
  W( 74 ) = W( 74 ) + a*JVS( 294 )
  W( 75 ) = W( 75 ) + a*JVS( 295 )
  W( 76 ) = W( 76 ) + a*JVS( 296 )
  W( 77 ) = W( 77 ) + a*JVS( 297 )
  W( 78 ) = W( 78 ) + a*JVS( 298 )
  a = -W( 48 ) / JVS( 325 )
  W( 48 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 326 )
  W( 69 ) = W( 69 ) + a*JVS( 327 )
  W( 72 ) = W( 72 ) + a*JVS( 328 )
  W( 74 ) = W( 74 ) + a*JVS( 329 )
  W( 75 ) = W( 75 ) + a*JVS( 330 )
  W( 76 ) = W( 76 ) + a*JVS( 331 )
  W( 77 ) = W( 77 ) + a*JVS( 332 )
  a = -W( 49 ) / JVS( 334 )
  W( 49 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 335 )
  W( 69 ) = W( 69 ) + a*JVS( 336 )
  W( 72 ) = W( 72 ) + a*JVS( 337 )
  W( 74 ) = W( 74 ) + a*JVS( 338 )
  W( 76 ) = W( 76 ) + a*JVS( 339 )
  W( 77 ) = W( 77 ) + a*JVS( 340 )
  a = -W( 50 ) / JVS( 342 )
  W( 50 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 343 )
  W( 69 ) = W( 69 ) + a*JVS( 344 )
  W( 72 ) = W( 72 ) + a*JVS( 345 )
  W( 74 ) = W( 74 ) + a*JVS( 346 )
  W( 76 ) = W( 76 ) + a*JVS( 347 )
  W( 77 ) = W( 77 ) + a*JVS( 348 )
  a = -W( 51 ) / JVS( 350 )
  W( 51 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 351 )
  W( 69 ) = W( 69 ) + a*JVS( 352 )
  W( 72 ) = W( 72 ) + a*JVS( 353 )
  W( 74 ) = W( 74 ) + a*JVS( 354 )
  W( 75 ) = W( 75 ) + a*JVS( 355 )
  W( 76 ) = W( 76 ) + a*JVS( 356 )
  W( 77 ) = W( 77 ) + a*JVS( 357 )
  W( 78 ) = W( 78 ) + a*JVS( 358 )
  a = -W( 52 ) / JVS( 360 )
  W( 52 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 361 )
  W( 69 ) = W( 69 ) + a*JVS( 362 )
  W( 72 ) = W( 72 ) + a*JVS( 363 )
  W( 74 ) = W( 74 ) + a*JVS( 364 )
  W( 75 ) = W( 75 ) + a*JVS( 365 )
  W( 76 ) = W( 76 ) + a*JVS( 366 )
  W( 77 ) = W( 77 ) + a*JVS( 367 )
  W( 78 ) = W( 78 ) + a*JVS( 368 )
  a = -W( 53 ) / JVS( 370 )
  W( 53 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 371 )
  W( 69 ) = W( 69 ) + a*JVS( 372 )
  W( 72 ) = W( 72 ) + a*JVS( 373 )
  W( 74 ) = W( 74 ) + a*JVS( 374 )
  W( 75 ) = W( 75 ) + a*JVS( 375 )
  W( 76 ) = W( 76 ) + a*JVS( 376 )
  W( 77 ) = W( 77 ) + a*JVS( 377 )
  a = -W( 54 ) / JVS( 380 )
  W( 54 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 381 )
  W( 69 ) = W( 69 ) + a*JVS( 382 )
  W( 71 ) = W( 71 ) + a*JVS( 383 )
  W( 72 ) = W( 72 ) + a*JVS( 384 )
  W( 74 ) = W( 74 ) + a*JVS( 385 )
  W( 75 ) = W( 75 ) + a*JVS( 386 )
  W( 76 ) = W( 76 ) + a*JVS( 387 )
  W( 77 ) = W( 77 ) + a*JVS( 388 )
  a = -W( 56 ) / JVS( 418 )
  W( 56 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 419 )
  W( 69 ) = W( 69 ) + a*JVS( 420 )
  W( 71 ) = W( 71 ) + a*JVS( 421 )
  W( 72 ) = W( 72 ) + a*JVS( 422 )
  W( 74 ) = W( 74 ) + a*JVS( 423 )
  W( 75 ) = W( 75 ) + a*JVS( 424 )
  W( 76 ) = W( 76 ) + a*JVS( 425 )
  W( 77 ) = W( 77 ) + a*JVS( 426 )
  a = -W( 57 ) / JVS( 438 )
  W( 57 ) = -a
  W( 64 ) = W( 64 ) + a*JVS( 439 )
  W( 65 ) = W( 65 ) + a*JVS( 440 )
  W( 67 ) = W( 67 ) + a*JVS( 441 )
  W( 68 ) = W( 68 ) + a*JVS( 442 )
  W( 69 ) = W( 69 ) + a*JVS( 443 )
  W( 70 ) = W( 70 ) + a*JVS( 444 )
  W( 71 ) = W( 71 ) + a*JVS( 445 )
  W( 72 ) = W( 72 ) + a*JVS( 446 )
  W( 73 ) = W( 73 ) + a*JVS( 447 )
  W( 74 ) = W( 74 ) + a*JVS( 448 )
  W( 75 ) = W( 75 ) + a*JVS( 449 )
  W( 76 ) = W( 76 ) + a*JVS( 450 )
  W( 77 ) = W( 77 ) + a*JVS( 451 )
  W( 78 ) = W( 78 ) + a*JVS( 452 )
  a = -W( 59 ) / JVS( 489 )
  W( 59 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 490 )
  W( 69 ) = W( 69 ) + a*JVS( 491 )
  W( 71 ) = W( 71 ) + a*JVS( 492 )
  W( 72 ) = W( 72 ) + a*JVS( 493 )
  W( 74 ) = W( 74 ) + a*JVS( 494 )
  W( 75 ) = W( 75 ) + a*JVS( 495 )
  W( 76 ) = W( 76 ) + a*JVS( 496 )
  W( 77 ) = W( 77 ) + a*JVS( 497 )
  a = -W( 60 ) / JVS( 500 )
  W( 60 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 501 )
  W( 69 ) = W( 69 ) + a*JVS( 502 )
  W( 71 ) = W( 71 ) + a*JVS( 503 )
  W( 72 ) = W( 72 ) + a*JVS( 504 )
  W( 74 ) = W( 74 ) + a*JVS( 505 )
  W( 75 ) = W( 75 ) + a*JVS( 506 )
  W( 76 ) = W( 76 ) + a*JVS( 507 )
  W( 77 ) = W( 77 ) + a*JVS( 508 )
  a = -W( 64 ) / JVS( 592 )
  W( 64 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 593 )
  W( 69 ) = W( 69 ) + a*JVS( 594 )
  W( 71 ) = W( 71 ) + a*JVS( 595 )
  W( 72 ) = W( 72 ) + a*JVS( 596 )
  W( 74 ) = W( 74 ) + a*JVS( 597 )
  W( 75 ) = W( 75 ) + a*JVS( 598 )
  W( 76 ) = W( 76 ) + a*JVS( 599 )
  W( 77 ) = W( 77 ) + a*JVS( 600 )
  W( 78 ) = W( 78 ) + a*JVS( 601 )
  a = -W( 65 ) / JVS( 605 )
  W( 65 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 606 )
  W( 69 ) = W( 69 ) + a*JVS( 607 )
  W( 71 ) = W( 71 ) + a*JVS( 608 )
  W( 72 ) = W( 72 ) + a*JVS( 609 )
  W( 74 ) = W( 74 ) + a*JVS( 610 )
  W( 75 ) = W( 75 ) + a*JVS( 611 )
  W( 76 ) = W( 76 ) + a*JVS( 612 )
  W( 77 ) = W( 77 ) + a*JVS( 613 )
  W( 78 ) = W( 78 ) + a*JVS( 614 )
  a = -W( 66 ) / JVS( 629 )
  W( 66 ) = -a
  W( 67 ) = W( 67 ) + a*JVS( 630 )
  W( 68 ) = W( 68 ) + a*JVS( 631 )
  W( 69 ) = W( 69 ) + a*JVS( 632 )
  W( 70 ) = W( 70 ) + a*JVS( 633 )
  W( 71 ) = W( 71 ) + a*JVS( 634 )
  W( 72 ) = W( 72 ) + a*JVS( 635 )
  W( 73 ) = W( 73 ) + a*JVS( 636 )
  W( 74 ) = W( 74 ) + a*JVS( 637 )
  W( 75 ) = W( 75 ) + a*JVS( 638 )
  W( 76 ) = W( 76 ) + a*JVS( 639 )
  W( 77 ) = W( 77 ) + a*JVS( 640 )
  W( 78 ) = W( 78 ) + a*JVS( 641 )
  a = -W( 67 ) / JVS( 657 )
  W( 67 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 658 )
  W( 69 ) = W( 69 ) + a*JVS( 659 )
  W( 70 ) = W( 70 ) + a*JVS( 660 )
  W( 71 ) = W( 71 ) + a*JVS( 661 )
  W( 72 ) = W( 72 ) + a*JVS( 662 )
  W( 73 ) = W( 73 ) + a*JVS( 663 )
  W( 74 ) = W( 74 ) + a*JVS( 664 )
  W( 75 ) = W( 75 ) + a*JVS( 665 )
  W( 76 ) = W( 76 ) + a*JVS( 666 )
  W( 77 ) = W( 77 ) + a*JVS( 667 )
  W( 78 ) = W( 78 ) + a*JVS( 668 )
  a = -W( 68 ) / JVS( 700 )
  W( 68 ) = -a
  W( 69 ) = W( 69 ) + a*JVS( 701 )
  W( 70 ) = W( 70 ) + a*JVS( 702 )
  W( 71 ) = W( 71 ) + a*JVS( 703 )
  W( 72 ) = W( 72 ) + a*JVS( 704 )
  W( 73 ) = W( 73 ) + a*JVS( 705 )
  W( 74 ) = W( 74 ) + a*JVS( 706 )
  W( 75 ) = W( 75 ) + a*JVS( 707 )
  W( 76 ) = W( 76 ) + a*JVS( 708 )
  W( 77 ) = W( 77 ) + a*JVS( 709 )
  W( 78 ) = W( 78 ) + a*JVS( 710 )
  a = -W( 69 ) / JVS( 764 )
  W( 69 ) = -a
  W( 70 ) = W( 70 ) + a*JVS( 765 )
  W( 71 ) = W( 71 ) + a*JVS( 766 )
  W( 72 ) = W( 72 ) + a*JVS( 767 )
  W( 73 ) = W( 73 ) + a*JVS( 768 )
  W( 74 ) = W( 74 ) + a*JVS( 769 )
  W( 75 ) = W( 75 ) + a*JVS( 770 )
  W( 76 ) = W( 76 ) + a*JVS( 771 )
  W( 77 ) = W( 77 ) + a*JVS( 772 )
  W( 78 ) = W( 78 ) + a*JVS( 773 )
  JVS( 774) = W( 41 )
  JVS( 775) = W( 43 )
  JVS( 776) = W( 44 )
  JVS( 777) = W( 46 )
  JVS( 778) = W( 48 )
  JVS( 779) = W( 49 )
  JVS( 780) = W( 50 )
  JVS( 781) = W( 51 )
  JVS( 782) = W( 52 )
  JVS( 783) = W( 53 )
  JVS( 784) = W( 54 )
  JVS( 785) = W( 56 )
  JVS( 786) = W( 57 )
  JVS( 787) = W( 59 )
  JVS( 788) = W( 60 )
  JVS( 789) = W( 64 )
  JVS( 790) = W( 65 )
  JVS( 791) = W( 66 )
  JVS( 792) = W( 67 )
  JVS( 793) = W( 68 )
  JVS( 794) = W( 69 )
  JVS( 795) = W( 70 )
  JVS( 796) = W( 71 )
  JVS( 797) = W( 72 )
  JVS( 798) = W( 73 )
  JVS( 799) = W( 74 )
  JVS( 800) = W( 75 )
  JVS( 801) = W( 76 )
  JVS( 802) = W( 77 )
  JVS( 803) = W( 78 )
  IF ( ABS( JVS( 818 )) < TINY(a) ) THEN
         IER = 71
         RETURN
  END IF
   W( 7 ) = JVS( 804 )
   W( 29 ) = JVS( 805 )
   W( 35 ) = JVS( 806 )
   W( 37 ) = JVS( 807 )
   W( 42 ) = JVS( 808 )
   W( 56 ) = JVS( 809 )
   W( 63 ) = JVS( 810 )
   W( 64 ) = JVS( 811 )
   W( 65 ) = JVS( 812 )
   W( 66 ) = JVS( 813 )
   W( 67 ) = JVS( 814 )
   W( 68 ) = JVS( 815 )
   W( 69 ) = JVS( 816 )
   W( 70 ) = JVS( 817 )
   W( 71 ) = JVS( 818 )
   W( 72 ) = JVS( 819 )
   W( 73 ) = JVS( 820 )
   W( 74 ) = JVS( 821 )
   W( 75 ) = JVS( 822 )
   W( 76 ) = JVS( 823 )
   W( 77 ) = JVS( 824 )
   W( 78 ) = JVS( 825 )
  a = -W( 7 ) / JVS( 45 )
  W( 7 ) = -a
  W( 75 ) = W( 75 ) + a*JVS( 46 )
  a = -W( 29 ) / JVS( 138 )
  W( 29 ) = -a
  W( 35 ) = W( 35 ) + a*JVS( 139 )
  W( 69 ) = W( 69 ) + a*JVS( 140 )
  W( 75 ) = W( 75 ) + a*JVS( 141 )
  W( 77 ) = W( 77 ) + a*JVS( 142 )
  a = -W( 35 ) / JVS( 197 )
  W( 35 ) = -a
  W( 63 ) = W( 63 ) + a*JVS( 198 )
  W( 69 ) = W( 69 ) + a*JVS( 199 )
  W( 75 ) = W( 75 ) + a*JVS( 200 )
  W( 76 ) = W( 76 ) + a*JVS( 201 )
  W( 77 ) = W( 77 ) + a*JVS( 202 )
  a = -W( 37 ) / JVS( 207 )
  W( 37 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 208 )
  W( 75 ) = W( 75 ) + a*JVS( 209 )
  W( 76 ) = W( 76 ) + a*JVS( 210 )
  a = -W( 42 ) / JVS( 249 )
  W( 42 ) = -a
  W( 71 ) = W( 71 ) + a*JVS( 250 )
  W( 74 ) = W( 74 ) + a*JVS( 251 )
  W( 75 ) = W( 75 ) + a*JVS( 252 )
  W( 76 ) = W( 76 ) + a*JVS( 253 )
  a = -W( 56 ) / JVS( 418 )
  W( 56 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 419 )
  W( 69 ) = W( 69 ) + a*JVS( 420 )
  W( 71 ) = W( 71 ) + a*JVS( 421 )
  W( 72 ) = W( 72 ) + a*JVS( 422 )
  W( 74 ) = W( 74 ) + a*JVS( 423 )
  W( 75 ) = W( 75 ) + a*JVS( 424 )
  W( 76 ) = W( 76 ) + a*JVS( 425 )
  W( 77 ) = W( 77 ) + a*JVS( 426 )
  a = -W( 63 ) / JVS( 573 )
  W( 63 ) = -a
  W( 64 ) = W( 64 ) + a*JVS( 574 )
  W( 65 ) = W( 65 ) + a*JVS( 575 )
  W( 66 ) = W( 66 ) + a*JVS( 576 )
  W( 67 ) = W( 67 ) + a*JVS( 577 )
  W( 68 ) = W( 68 ) + a*JVS( 578 )
  W( 69 ) = W( 69 ) + a*JVS( 579 )
  W( 70 ) = W( 70 ) + a*JVS( 580 )
  W( 71 ) = W( 71 ) + a*JVS( 581 )
  W( 72 ) = W( 72 ) + a*JVS( 582 )
  W( 73 ) = W( 73 ) + a*JVS( 583 )
  W( 74 ) = W( 74 ) + a*JVS( 584 )
  W( 75 ) = W( 75 ) + a*JVS( 585 )
  W( 76 ) = W( 76 ) + a*JVS( 586 )
  W( 77 ) = W( 77 ) + a*JVS( 587 )
  W( 78 ) = W( 78 ) + a*JVS( 588 )
  a = -W( 64 ) / JVS( 592 )
  W( 64 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 593 )
  W( 69 ) = W( 69 ) + a*JVS( 594 )
  W( 71 ) = W( 71 ) + a*JVS( 595 )
  W( 72 ) = W( 72 ) + a*JVS( 596 )
  W( 74 ) = W( 74 ) + a*JVS( 597 )
  W( 75 ) = W( 75 ) + a*JVS( 598 )
  W( 76 ) = W( 76 ) + a*JVS( 599 )
  W( 77 ) = W( 77 ) + a*JVS( 600 )
  W( 78 ) = W( 78 ) + a*JVS( 601 )
  a = -W( 65 ) / JVS( 605 )
  W( 65 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 606 )
  W( 69 ) = W( 69 ) + a*JVS( 607 )
  W( 71 ) = W( 71 ) + a*JVS( 608 )
  W( 72 ) = W( 72 ) + a*JVS( 609 )
  W( 74 ) = W( 74 ) + a*JVS( 610 )
  W( 75 ) = W( 75 ) + a*JVS( 611 )
  W( 76 ) = W( 76 ) + a*JVS( 612 )
  W( 77 ) = W( 77 ) + a*JVS( 613 )
  W( 78 ) = W( 78 ) + a*JVS( 614 )
  a = -W( 66 ) / JVS( 629 )
  W( 66 ) = -a
  W( 67 ) = W( 67 ) + a*JVS( 630 )
  W( 68 ) = W( 68 ) + a*JVS( 631 )
  W( 69 ) = W( 69 ) + a*JVS( 632 )
  W( 70 ) = W( 70 ) + a*JVS( 633 )
  W( 71 ) = W( 71 ) + a*JVS( 634 )
  W( 72 ) = W( 72 ) + a*JVS( 635 )
  W( 73 ) = W( 73 ) + a*JVS( 636 )
  W( 74 ) = W( 74 ) + a*JVS( 637 )
  W( 75 ) = W( 75 ) + a*JVS( 638 )
  W( 76 ) = W( 76 ) + a*JVS( 639 )
  W( 77 ) = W( 77 ) + a*JVS( 640 )
  W( 78 ) = W( 78 ) + a*JVS( 641 )
  a = -W( 67 ) / JVS( 657 )
  W( 67 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 658 )
  W( 69 ) = W( 69 ) + a*JVS( 659 )
  W( 70 ) = W( 70 ) + a*JVS( 660 )
  W( 71 ) = W( 71 ) + a*JVS( 661 )
  W( 72 ) = W( 72 ) + a*JVS( 662 )
  W( 73 ) = W( 73 ) + a*JVS( 663 )
  W( 74 ) = W( 74 ) + a*JVS( 664 )
  W( 75 ) = W( 75 ) + a*JVS( 665 )
  W( 76 ) = W( 76 ) + a*JVS( 666 )
  W( 77 ) = W( 77 ) + a*JVS( 667 )
  W( 78 ) = W( 78 ) + a*JVS( 668 )
  a = -W( 68 ) / JVS( 700 )
  W( 68 ) = -a
  W( 69 ) = W( 69 ) + a*JVS( 701 )
  W( 70 ) = W( 70 ) + a*JVS( 702 )
  W( 71 ) = W( 71 ) + a*JVS( 703 )
  W( 72 ) = W( 72 ) + a*JVS( 704 )
  W( 73 ) = W( 73 ) + a*JVS( 705 )
  W( 74 ) = W( 74 ) + a*JVS( 706 )
  W( 75 ) = W( 75 ) + a*JVS( 707 )
  W( 76 ) = W( 76 ) + a*JVS( 708 )
  W( 77 ) = W( 77 ) + a*JVS( 709 )
  W( 78 ) = W( 78 ) + a*JVS( 710 )
  a = -W( 69 ) / JVS( 764 )
  W( 69 ) = -a
  W( 70 ) = W( 70 ) + a*JVS( 765 )
  W( 71 ) = W( 71 ) + a*JVS( 766 )
  W( 72 ) = W( 72 ) + a*JVS( 767 )
  W( 73 ) = W( 73 ) + a*JVS( 768 )
  W( 74 ) = W( 74 ) + a*JVS( 769 )
  W( 75 ) = W( 75 ) + a*JVS( 770 )
  W( 76 ) = W( 76 ) + a*JVS( 771 )
  W( 77 ) = W( 77 ) + a*JVS( 772 )
  W( 78 ) = W( 78 ) + a*JVS( 773 )
  a = -W( 70 ) / JVS( 795 )
  W( 70 ) = -a
  W( 71 ) = W( 71 ) + a*JVS( 796 )
  W( 72 ) = W( 72 ) + a*JVS( 797 )
  W( 73 ) = W( 73 ) + a*JVS( 798 )
  W( 74 ) = W( 74 ) + a*JVS( 799 )
  W( 75 ) = W( 75 ) + a*JVS( 800 )
  W( 76 ) = W( 76 ) + a*JVS( 801 )
  W( 77 ) = W( 77 ) + a*JVS( 802 )
  W( 78 ) = W( 78 ) + a*JVS( 803 )
  JVS( 804) = W( 7 )
  JVS( 805) = W( 29 )
  JVS( 806) = W( 35 )
  JVS( 807) = W( 37 )
  JVS( 808) = W( 42 )
  JVS( 809) = W( 56 )
  JVS( 810) = W( 63 )
  JVS( 811) = W( 64 )
  JVS( 812) = W( 65 )
  JVS( 813) = W( 66 )
  JVS( 814) = W( 67 )
  JVS( 815) = W( 68 )
  JVS( 816) = W( 69 )
  JVS( 817) = W( 70 )
  JVS( 818) = W( 71 )
  JVS( 819) = W( 72 )
  JVS( 820) = W( 73 )
  JVS( 821) = W( 74 )
  JVS( 822) = W( 75 )
  JVS( 823) = W( 76 )
  JVS( 824) = W( 77 )
  JVS( 825) = W( 78 )
  IF ( ABS( JVS( 856 )) < TINY(a) ) THEN
         IER = 72
         RETURN
  END IF
   W( 17 ) = JVS( 826 )
   W( 20 ) = JVS( 827 )
   W( 30 ) = JVS( 828 )
   W( 37 ) = JVS( 829 )
   W( 41 ) = JVS( 830 )
   W( 42 ) = JVS( 831 )
   W( 43 ) = JVS( 832 )
   W( 44 ) = JVS( 833 )
   W( 46 ) = JVS( 834 )
   W( 48 ) = JVS( 835 )
   W( 49 ) = JVS( 836 )
   W( 50 ) = JVS( 837 )
   W( 51 ) = JVS( 838 )
   W( 52 ) = JVS( 839 )
   W( 53 ) = JVS( 840 )
   W( 54 ) = JVS( 841 )
   W( 57 ) = JVS( 842 )
   W( 58 ) = JVS( 843 )
   W( 59 ) = JVS( 844 )
   W( 60 ) = JVS( 845 )
   W( 61 ) = JVS( 846 )
   W( 62 ) = JVS( 847 )
   W( 64 ) = JVS( 848 )
   W( 65 ) = JVS( 849 )
   W( 66 ) = JVS( 850 )
   W( 67 ) = JVS( 851 )
   W( 68 ) = JVS( 852 )
   W( 69 ) = JVS( 853 )
   W( 70 ) = JVS( 854 )
   W( 71 ) = JVS( 855 )
   W( 72 ) = JVS( 856 )
   W( 73 ) = JVS( 857 )
   W( 74 ) = JVS( 858 )
   W( 75 ) = JVS( 859 )
   W( 76 ) = JVS( 860 )
   W( 77 ) = JVS( 861 )
   W( 78 ) = JVS( 862 )
  a = -W( 17 ) / JVS( 71 )
  W( 17 ) = -a
  W( 59 ) = W( 59 ) + a*JVS( 72 )
  W( 60 ) = W( 60 ) + a*JVS( 73 )
  W( 75 ) = W( 75 ) + a*JVS( 74 )
  W( 76 ) = W( 76 ) + a*JVS( 75 )
  a = -W( 20 ) / JVS( 85 )
  W( 20 ) = -a
  W( 69 ) = W( 69 ) + a*JVS( 86 )
  W( 72 ) = W( 72 ) + a*JVS( 87 )
  W( 76 ) = W( 76 ) + a*JVS( 88 )
  a = -W( 30 ) / JVS( 143 )
  W( 30 ) = -a
  W( 64 ) = W( 64 ) + a*JVS( 144 )
  W( 68 ) = W( 68 ) + a*JVS( 145 )
  W( 69 ) = W( 69 ) + a*JVS( 146 )
  W( 75 ) = W( 75 ) + a*JVS( 147 )
  W( 76 ) = W( 76 ) + a*JVS( 148 )
  a = -W( 37 ) / JVS( 207 )
  W( 37 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 208 )
  W( 75 ) = W( 75 ) + a*JVS( 209 )
  W( 76 ) = W( 76 ) + a*JVS( 210 )
  a = -W( 41 ) / JVS( 241 )
  W( 41 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 242 )
  W( 69 ) = W( 69 ) + a*JVS( 243 )
  W( 72 ) = W( 72 ) + a*JVS( 244 )
  W( 74 ) = W( 74 ) + a*JVS( 245 )
  W( 75 ) = W( 75 ) + a*JVS( 246 )
  W( 76 ) = W( 76 ) + a*JVS( 247 )
  W( 77 ) = W( 77 ) + a*JVS( 248 )
  a = -W( 42 ) / JVS( 249 )
  W( 42 ) = -a
  W( 71 ) = W( 71 ) + a*JVS( 250 )
  W( 74 ) = W( 74 ) + a*JVS( 251 )
  W( 75 ) = W( 75 ) + a*JVS( 252 )
  W( 76 ) = W( 76 ) + a*JVS( 253 )
  a = -W( 43 ) / JVS( 254 )
  W( 43 ) = -a
  W( 59 ) = W( 59 ) + a*JVS( 255 )
  W( 68 ) = W( 68 ) + a*JVS( 256 )
  W( 69 ) = W( 69 ) + a*JVS( 257 )
  W( 72 ) = W( 72 ) + a*JVS( 258 )
  W( 74 ) = W( 74 ) + a*JVS( 259 )
  W( 76 ) = W( 76 ) + a*JVS( 260 )
  W( 77 ) = W( 77 ) + a*JVS( 261 )
  a = -W( 44 ) / JVS( 262 )
  W( 44 ) = -a
  W( 60 ) = W( 60 ) + a*JVS( 263 )
  W( 68 ) = W( 68 ) + a*JVS( 264 )
  W( 69 ) = W( 69 ) + a*JVS( 265 )
  W( 72 ) = W( 72 ) + a*JVS( 266 )
  W( 74 ) = W( 74 ) + a*JVS( 267 )
  W( 76 ) = W( 76 ) + a*JVS( 268 )
  W( 77 ) = W( 77 ) + a*JVS( 269 )
  a = -W( 46 ) / JVS( 290 )
  W( 46 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 291 )
  W( 69 ) = W( 69 ) + a*JVS( 292 )
  W( 72 ) = W( 72 ) + a*JVS( 293 )
  W( 74 ) = W( 74 ) + a*JVS( 294 )
  W( 75 ) = W( 75 ) + a*JVS( 295 )
  W( 76 ) = W( 76 ) + a*JVS( 296 )
  W( 77 ) = W( 77 ) + a*JVS( 297 )
  W( 78 ) = W( 78 ) + a*JVS( 298 )
  a = -W( 48 ) / JVS( 325 )
  W( 48 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 326 )
  W( 69 ) = W( 69 ) + a*JVS( 327 )
  W( 72 ) = W( 72 ) + a*JVS( 328 )
  W( 74 ) = W( 74 ) + a*JVS( 329 )
  W( 75 ) = W( 75 ) + a*JVS( 330 )
  W( 76 ) = W( 76 ) + a*JVS( 331 )
  W( 77 ) = W( 77 ) + a*JVS( 332 )
  a = -W( 49 ) / JVS( 334 )
  W( 49 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 335 )
  W( 69 ) = W( 69 ) + a*JVS( 336 )
  W( 72 ) = W( 72 ) + a*JVS( 337 )
  W( 74 ) = W( 74 ) + a*JVS( 338 )
  W( 76 ) = W( 76 ) + a*JVS( 339 )
  W( 77 ) = W( 77 ) + a*JVS( 340 )
  a = -W( 50 ) / JVS( 342 )
  W( 50 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 343 )
  W( 69 ) = W( 69 ) + a*JVS( 344 )
  W( 72 ) = W( 72 ) + a*JVS( 345 )
  W( 74 ) = W( 74 ) + a*JVS( 346 )
  W( 76 ) = W( 76 ) + a*JVS( 347 )
  W( 77 ) = W( 77 ) + a*JVS( 348 )
  a = -W( 51 ) / JVS( 350 )
  W( 51 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 351 )
  W( 69 ) = W( 69 ) + a*JVS( 352 )
  W( 72 ) = W( 72 ) + a*JVS( 353 )
  W( 74 ) = W( 74 ) + a*JVS( 354 )
  W( 75 ) = W( 75 ) + a*JVS( 355 )
  W( 76 ) = W( 76 ) + a*JVS( 356 )
  W( 77 ) = W( 77 ) + a*JVS( 357 )
  W( 78 ) = W( 78 ) + a*JVS( 358 )
  a = -W( 52 ) / JVS( 360 )
  W( 52 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 361 )
  W( 69 ) = W( 69 ) + a*JVS( 362 )
  W( 72 ) = W( 72 ) + a*JVS( 363 )
  W( 74 ) = W( 74 ) + a*JVS( 364 )
  W( 75 ) = W( 75 ) + a*JVS( 365 )
  W( 76 ) = W( 76 ) + a*JVS( 366 )
  W( 77 ) = W( 77 ) + a*JVS( 367 )
  W( 78 ) = W( 78 ) + a*JVS( 368 )
  a = -W( 53 ) / JVS( 370 )
  W( 53 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 371 )
  W( 69 ) = W( 69 ) + a*JVS( 372 )
  W( 72 ) = W( 72 ) + a*JVS( 373 )
  W( 74 ) = W( 74 ) + a*JVS( 374 )
  W( 75 ) = W( 75 ) + a*JVS( 375 )
  W( 76 ) = W( 76 ) + a*JVS( 376 )
  W( 77 ) = W( 77 ) + a*JVS( 377 )
  a = -W( 54 ) / JVS( 380 )
  W( 54 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 381 )
  W( 69 ) = W( 69 ) + a*JVS( 382 )
  W( 71 ) = W( 71 ) + a*JVS( 383 )
  W( 72 ) = W( 72 ) + a*JVS( 384 )
  W( 74 ) = W( 74 ) + a*JVS( 385 )
  W( 75 ) = W( 75 ) + a*JVS( 386 )
  W( 76 ) = W( 76 ) + a*JVS( 387 )
  W( 77 ) = W( 77 ) + a*JVS( 388 )
  a = -W( 57 ) / JVS( 438 )
  W( 57 ) = -a
  W( 64 ) = W( 64 ) + a*JVS( 439 )
  W( 65 ) = W( 65 ) + a*JVS( 440 )
  W( 67 ) = W( 67 ) + a*JVS( 441 )
  W( 68 ) = W( 68 ) + a*JVS( 442 )
  W( 69 ) = W( 69 ) + a*JVS( 443 )
  W( 70 ) = W( 70 ) + a*JVS( 444 )
  W( 71 ) = W( 71 ) + a*JVS( 445 )
  W( 72 ) = W( 72 ) + a*JVS( 446 )
  W( 73 ) = W( 73 ) + a*JVS( 447 )
  W( 74 ) = W( 74 ) + a*JVS( 448 )
  W( 75 ) = W( 75 ) + a*JVS( 449 )
  W( 76 ) = W( 76 ) + a*JVS( 450 )
  W( 77 ) = W( 77 ) + a*JVS( 451 )
  W( 78 ) = W( 78 ) + a*JVS( 452 )
  a = -W( 58 ) / JVS( 465 )
  W( 58 ) = -a
  W( 59 ) = W( 59 ) + a*JVS( 466 )
  W( 60 ) = W( 60 ) + a*JVS( 467 )
  W( 61 ) = W( 61 ) + a*JVS( 468 )
  W( 62 ) = W( 62 ) + a*JVS( 469 )
  W( 64 ) = W( 64 ) + a*JVS( 470 )
  W( 65 ) = W( 65 ) + a*JVS( 471 )
  W( 66 ) = W( 66 ) + a*JVS( 472 )
  W( 67 ) = W( 67 ) + a*JVS( 473 )
  W( 68 ) = W( 68 ) + a*JVS( 474 )
  W( 69 ) = W( 69 ) + a*JVS( 475 )
  W( 70 ) = W( 70 ) + a*JVS( 476 )
  W( 71 ) = W( 71 ) + a*JVS( 477 )
  W( 72 ) = W( 72 ) + a*JVS( 478 )
  W( 73 ) = W( 73 ) + a*JVS( 479 )
  W( 74 ) = W( 74 ) + a*JVS( 480 )
  W( 75 ) = W( 75 ) + a*JVS( 481 )
  W( 76 ) = W( 76 ) + a*JVS( 482 )
  W( 77 ) = W( 77 ) + a*JVS( 483 )
  W( 78 ) = W( 78 ) + a*JVS( 484 )
  a = -W( 59 ) / JVS( 489 )
  W( 59 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 490 )
  W( 69 ) = W( 69 ) + a*JVS( 491 )
  W( 71 ) = W( 71 ) + a*JVS( 492 )
  W( 72 ) = W( 72 ) + a*JVS( 493 )
  W( 74 ) = W( 74 ) + a*JVS( 494 )
  W( 75 ) = W( 75 ) + a*JVS( 495 )
  W( 76 ) = W( 76 ) + a*JVS( 496 )
  W( 77 ) = W( 77 ) + a*JVS( 497 )
  a = -W( 60 ) / JVS( 500 )
  W( 60 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 501 )
  W( 69 ) = W( 69 ) + a*JVS( 502 )
  W( 71 ) = W( 71 ) + a*JVS( 503 )
  W( 72 ) = W( 72 ) + a*JVS( 504 )
  W( 74 ) = W( 74 ) + a*JVS( 505 )
  W( 75 ) = W( 75 ) + a*JVS( 506 )
  W( 76 ) = W( 76 ) + a*JVS( 507 )
  W( 77 ) = W( 77 ) + a*JVS( 508 )
  a = -W( 61 ) / JVS( 517 )
  W( 61 ) = -a
  W( 62 ) = W( 62 ) + a*JVS( 518 )
  W( 68 ) = W( 68 ) + a*JVS( 519 )
  W( 69 ) = W( 69 ) + a*JVS( 520 )
  W( 71 ) = W( 71 ) + a*JVS( 521 )
  W( 72 ) = W( 72 ) + a*JVS( 522 )
  W( 74 ) = W( 74 ) + a*JVS( 523 )
  W( 75 ) = W( 75 ) + a*JVS( 524 )
  W( 76 ) = W( 76 ) + a*JVS( 525 )
  W( 77 ) = W( 77 ) + a*JVS( 526 )
  a = -W( 62 ) / JVS( 535 )
  W( 62 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 536 )
  W( 69 ) = W( 69 ) + a*JVS( 537 )
  W( 71 ) = W( 71 ) + a*JVS( 538 )
  W( 72 ) = W( 72 ) + a*JVS( 539 )
  W( 74 ) = W( 74 ) + a*JVS( 540 )
  W( 75 ) = W( 75 ) + a*JVS( 541 )
  W( 76 ) = W( 76 ) + a*JVS( 542 )
  W( 77 ) = W( 77 ) + a*JVS( 543 )
  a = -W( 64 ) / JVS( 592 )
  W( 64 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 593 )
  W( 69 ) = W( 69 ) + a*JVS( 594 )
  W( 71 ) = W( 71 ) + a*JVS( 595 )
  W( 72 ) = W( 72 ) + a*JVS( 596 )
  W( 74 ) = W( 74 ) + a*JVS( 597 )
  W( 75 ) = W( 75 ) + a*JVS( 598 )
  W( 76 ) = W( 76 ) + a*JVS( 599 )
  W( 77 ) = W( 77 ) + a*JVS( 600 )
  W( 78 ) = W( 78 ) + a*JVS( 601 )
  a = -W( 65 ) / JVS( 605 )
  W( 65 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 606 )
  W( 69 ) = W( 69 ) + a*JVS( 607 )
  W( 71 ) = W( 71 ) + a*JVS( 608 )
  W( 72 ) = W( 72 ) + a*JVS( 609 )
  W( 74 ) = W( 74 ) + a*JVS( 610 )
  W( 75 ) = W( 75 ) + a*JVS( 611 )
  W( 76 ) = W( 76 ) + a*JVS( 612 )
  W( 77 ) = W( 77 ) + a*JVS( 613 )
  W( 78 ) = W( 78 ) + a*JVS( 614 )
  a = -W( 66 ) / JVS( 629 )
  W( 66 ) = -a
  W( 67 ) = W( 67 ) + a*JVS( 630 )
  W( 68 ) = W( 68 ) + a*JVS( 631 )
  W( 69 ) = W( 69 ) + a*JVS( 632 )
  W( 70 ) = W( 70 ) + a*JVS( 633 )
  W( 71 ) = W( 71 ) + a*JVS( 634 )
  W( 72 ) = W( 72 ) + a*JVS( 635 )
  W( 73 ) = W( 73 ) + a*JVS( 636 )
  W( 74 ) = W( 74 ) + a*JVS( 637 )
  W( 75 ) = W( 75 ) + a*JVS( 638 )
  W( 76 ) = W( 76 ) + a*JVS( 639 )
  W( 77 ) = W( 77 ) + a*JVS( 640 )
  W( 78 ) = W( 78 ) + a*JVS( 641 )
  a = -W( 67 ) / JVS( 657 )
  W( 67 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 658 )
  W( 69 ) = W( 69 ) + a*JVS( 659 )
  W( 70 ) = W( 70 ) + a*JVS( 660 )
  W( 71 ) = W( 71 ) + a*JVS( 661 )
  W( 72 ) = W( 72 ) + a*JVS( 662 )
  W( 73 ) = W( 73 ) + a*JVS( 663 )
  W( 74 ) = W( 74 ) + a*JVS( 664 )
  W( 75 ) = W( 75 ) + a*JVS( 665 )
  W( 76 ) = W( 76 ) + a*JVS( 666 )
  W( 77 ) = W( 77 ) + a*JVS( 667 )
  W( 78 ) = W( 78 ) + a*JVS( 668 )
  a = -W( 68 ) / JVS( 700 )
  W( 68 ) = -a
  W( 69 ) = W( 69 ) + a*JVS( 701 )
  W( 70 ) = W( 70 ) + a*JVS( 702 )
  W( 71 ) = W( 71 ) + a*JVS( 703 )
  W( 72 ) = W( 72 ) + a*JVS( 704 )
  W( 73 ) = W( 73 ) + a*JVS( 705 )
  W( 74 ) = W( 74 ) + a*JVS( 706 )
  W( 75 ) = W( 75 ) + a*JVS( 707 )
  W( 76 ) = W( 76 ) + a*JVS( 708 )
  W( 77 ) = W( 77 ) + a*JVS( 709 )
  W( 78 ) = W( 78 ) + a*JVS( 710 )
  a = -W( 69 ) / JVS( 764 )
  W( 69 ) = -a
  W( 70 ) = W( 70 ) + a*JVS( 765 )
  W( 71 ) = W( 71 ) + a*JVS( 766 )
  W( 72 ) = W( 72 ) + a*JVS( 767 )
  W( 73 ) = W( 73 ) + a*JVS( 768 )
  W( 74 ) = W( 74 ) + a*JVS( 769 )
  W( 75 ) = W( 75 ) + a*JVS( 770 )
  W( 76 ) = W( 76 ) + a*JVS( 771 )
  W( 77 ) = W( 77 ) + a*JVS( 772 )
  W( 78 ) = W( 78 ) + a*JVS( 773 )
  a = -W( 70 ) / JVS( 795 )
  W( 70 ) = -a
  W( 71 ) = W( 71 ) + a*JVS( 796 )
  W( 72 ) = W( 72 ) + a*JVS( 797 )
  W( 73 ) = W( 73 ) + a*JVS( 798 )
  W( 74 ) = W( 74 ) + a*JVS( 799 )
  W( 75 ) = W( 75 ) + a*JVS( 800 )
  W( 76 ) = W( 76 ) + a*JVS( 801 )
  W( 77 ) = W( 77 ) + a*JVS( 802 )
  W( 78 ) = W( 78 ) + a*JVS( 803 )
  a = -W( 71 ) / JVS( 818 )
  W( 71 ) = -a
  W( 72 ) = W( 72 ) + a*JVS( 819 )
  W( 73 ) = W( 73 ) + a*JVS( 820 )
  W( 74 ) = W( 74 ) + a*JVS( 821 )
  W( 75 ) = W( 75 ) + a*JVS( 822 )
  W( 76 ) = W( 76 ) + a*JVS( 823 )
  W( 77 ) = W( 77 ) + a*JVS( 824 )
  W( 78 ) = W( 78 ) + a*JVS( 825 )
  JVS( 826) = W( 17 )
  JVS( 827) = W( 20 )
  JVS( 828) = W( 30 )
  JVS( 829) = W( 37 )
  JVS( 830) = W( 41 )
  JVS( 831) = W( 42 )
  JVS( 832) = W( 43 )
  JVS( 833) = W( 44 )
  JVS( 834) = W( 46 )
  JVS( 835) = W( 48 )
  JVS( 836) = W( 49 )
  JVS( 837) = W( 50 )
  JVS( 838) = W( 51 )
  JVS( 839) = W( 52 )
  JVS( 840) = W( 53 )
  JVS( 841) = W( 54 )
  JVS( 842) = W( 57 )
  JVS( 843) = W( 58 )
  JVS( 844) = W( 59 )
  JVS( 845) = W( 60 )
  JVS( 846) = W( 61 )
  JVS( 847) = W( 62 )
  JVS( 848) = W( 64 )
  JVS( 849) = W( 65 )
  JVS( 850) = W( 66 )
  JVS( 851) = W( 67 )
  JVS( 852) = W( 68 )
  JVS( 853) = W( 69 )
  JVS( 854) = W( 70 )
  JVS( 855) = W( 71 )
  JVS( 856) = W( 72 )
  JVS( 857) = W( 73 )
  JVS( 858) = W( 74 )
  JVS( 859) = W( 75 )
  JVS( 860) = W( 76 )
  JVS( 861) = W( 77 )
  JVS( 862) = W( 78 )
  IF ( ABS( JVS( 873 )) < TINY(a) ) THEN
         IER = 73
         RETURN
  END IF
   W( 14 ) = JVS( 863 )
   W( 55 ) = JVS( 864 )
   W( 61 ) = JVS( 865 )
   W( 62 ) = JVS( 866 )
   W( 65 ) = JVS( 867 )
   W( 68 ) = JVS( 868 )
   W( 69 ) = JVS( 869 )
   W( 70 ) = JVS( 870 )
   W( 71 ) = JVS( 871 )
   W( 72 ) = JVS( 872 )
   W( 73 ) = JVS( 873 )
   W( 74 ) = JVS( 874 )
   W( 75 ) = JVS( 875 )
   W( 76 ) = JVS( 876 )
   W( 77 ) = JVS( 877 )
   W( 78 ) = JVS( 878 )
  a = -W( 14 ) / JVS( 61 )
  W( 14 ) = -a
  W( 76 ) = W( 76 ) + a*JVS( 62 )
  a = -W( 55 ) / JVS( 399 )
  W( 55 ) = -a
  W( 61 ) = W( 61 ) + a*JVS( 400 )
  W( 62 ) = W( 62 ) + a*JVS( 401 )
  W( 65 ) = W( 65 ) + a*JVS( 402 )
  W( 68 ) = W( 68 ) + a*JVS( 403 )
  W( 69 ) = W( 69 ) + a*JVS( 404 )
  W( 71 ) = W( 71 ) + a*JVS( 405 )
  W( 72 ) = W( 72 ) + a*JVS( 406 )
  W( 73 ) = W( 73 ) + a*JVS( 407 )
  W( 74 ) = W( 74 ) + a*JVS( 408 )
  W( 75 ) = W( 75 ) + a*JVS( 409 )
  W( 76 ) = W( 76 ) + a*JVS( 410 )
  W( 77 ) = W( 77 ) + a*JVS( 411 )
  W( 78 ) = W( 78 ) + a*JVS( 412 )
  a = -W( 61 ) / JVS( 517 )
  W( 61 ) = -a
  W( 62 ) = W( 62 ) + a*JVS( 518 )
  W( 68 ) = W( 68 ) + a*JVS( 519 )
  W( 69 ) = W( 69 ) + a*JVS( 520 )
  W( 71 ) = W( 71 ) + a*JVS( 521 )
  W( 72 ) = W( 72 ) + a*JVS( 522 )
  W( 74 ) = W( 74 ) + a*JVS( 523 )
  W( 75 ) = W( 75 ) + a*JVS( 524 )
  W( 76 ) = W( 76 ) + a*JVS( 525 )
  W( 77 ) = W( 77 ) + a*JVS( 526 )
  a = -W( 62 ) / JVS( 535 )
  W( 62 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 536 )
  W( 69 ) = W( 69 ) + a*JVS( 537 )
  W( 71 ) = W( 71 ) + a*JVS( 538 )
  W( 72 ) = W( 72 ) + a*JVS( 539 )
  W( 74 ) = W( 74 ) + a*JVS( 540 )
  W( 75 ) = W( 75 ) + a*JVS( 541 )
  W( 76 ) = W( 76 ) + a*JVS( 542 )
  W( 77 ) = W( 77 ) + a*JVS( 543 )
  a = -W( 65 ) / JVS( 605 )
  W( 65 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 606 )
  W( 69 ) = W( 69 ) + a*JVS( 607 )
  W( 71 ) = W( 71 ) + a*JVS( 608 )
  W( 72 ) = W( 72 ) + a*JVS( 609 )
  W( 74 ) = W( 74 ) + a*JVS( 610 )
  W( 75 ) = W( 75 ) + a*JVS( 611 )
  W( 76 ) = W( 76 ) + a*JVS( 612 )
  W( 77 ) = W( 77 ) + a*JVS( 613 )
  W( 78 ) = W( 78 ) + a*JVS( 614 )
  a = -W( 68 ) / JVS( 700 )
  W( 68 ) = -a
  W( 69 ) = W( 69 ) + a*JVS( 701 )
  W( 70 ) = W( 70 ) + a*JVS( 702 )
  W( 71 ) = W( 71 ) + a*JVS( 703 )
  W( 72 ) = W( 72 ) + a*JVS( 704 )
  W( 73 ) = W( 73 ) + a*JVS( 705 )
  W( 74 ) = W( 74 ) + a*JVS( 706 )
  W( 75 ) = W( 75 ) + a*JVS( 707 )
  W( 76 ) = W( 76 ) + a*JVS( 708 )
  W( 77 ) = W( 77 ) + a*JVS( 709 )
  W( 78 ) = W( 78 ) + a*JVS( 710 )
  a = -W( 69 ) / JVS( 764 )
  W( 69 ) = -a
  W( 70 ) = W( 70 ) + a*JVS( 765 )
  W( 71 ) = W( 71 ) + a*JVS( 766 )
  W( 72 ) = W( 72 ) + a*JVS( 767 )
  W( 73 ) = W( 73 ) + a*JVS( 768 )
  W( 74 ) = W( 74 ) + a*JVS( 769 )
  W( 75 ) = W( 75 ) + a*JVS( 770 )
  W( 76 ) = W( 76 ) + a*JVS( 771 )
  W( 77 ) = W( 77 ) + a*JVS( 772 )
  W( 78 ) = W( 78 ) + a*JVS( 773 )
  a = -W( 70 ) / JVS( 795 )
  W( 70 ) = -a
  W( 71 ) = W( 71 ) + a*JVS( 796 )
  W( 72 ) = W( 72 ) + a*JVS( 797 )
  W( 73 ) = W( 73 ) + a*JVS( 798 )
  W( 74 ) = W( 74 ) + a*JVS( 799 )
  W( 75 ) = W( 75 ) + a*JVS( 800 )
  W( 76 ) = W( 76 ) + a*JVS( 801 )
  W( 77 ) = W( 77 ) + a*JVS( 802 )
  W( 78 ) = W( 78 ) + a*JVS( 803 )
  a = -W( 71 ) / JVS( 818 )
  W( 71 ) = -a
  W( 72 ) = W( 72 ) + a*JVS( 819 )
  W( 73 ) = W( 73 ) + a*JVS( 820 )
  W( 74 ) = W( 74 ) + a*JVS( 821 )
  W( 75 ) = W( 75 ) + a*JVS( 822 )
  W( 76 ) = W( 76 ) + a*JVS( 823 )
  W( 77 ) = W( 77 ) + a*JVS( 824 )
  W( 78 ) = W( 78 ) + a*JVS( 825 )
  a = -W( 72 ) / JVS( 856 )
  W( 72 ) = -a
  W( 73 ) = W( 73 ) + a*JVS( 857 )
  W( 74 ) = W( 74 ) + a*JVS( 858 )
  W( 75 ) = W( 75 ) + a*JVS( 859 )
  W( 76 ) = W( 76 ) + a*JVS( 860 )
  W( 77 ) = W( 77 ) + a*JVS( 861 )
  W( 78 ) = W( 78 ) + a*JVS( 862 )
  JVS( 863) = W( 14 )
  JVS( 864) = W( 55 )
  JVS( 865) = W( 61 )
  JVS( 866) = W( 62 )
  JVS( 867) = W( 65 )
  JVS( 868) = W( 68 )
  JVS( 869) = W( 69 )
  JVS( 870) = W( 70 )
  JVS( 871) = W( 71 )
  JVS( 872) = W( 72 )
  JVS( 873) = W( 73 )
  JVS( 874) = W( 74 )
  JVS( 875) = W( 75 )
  JVS( 876) = W( 76 )
  JVS( 877) = W( 77 )
  JVS( 878) = W( 78 )
  IF ( ABS( JVS( 921 )) < TINY(a) ) THEN
         IER = 74
         RETURN
  END IF
   W( 8 ) = JVS( 879 )
   W( 19 ) = JVS( 880 )
   W( 27 ) = JVS( 881 )
   W( 31 ) = JVS( 882 )
   W( 32 ) = JVS( 883 )
   W( 34 ) = JVS( 884 )
   W( 36 ) = JVS( 885 )
   W( 37 ) = JVS( 886 )
   W( 38 ) = JVS( 887 )
   W( 39 ) = JVS( 888 )
   W( 40 ) = JVS( 889 )
   W( 41 ) = JVS( 890 )
   W( 42 ) = JVS( 891 )
   W( 43 ) = JVS( 892 )
   W( 44 ) = JVS( 893 )
   W( 45 ) = JVS( 894 )
   W( 46 ) = JVS( 895 )
   W( 48 ) = JVS( 896 )
   W( 49 ) = JVS( 897 )
   W( 50 ) = JVS( 898 )
   W( 51 ) = JVS( 899 )
   W( 52 ) = JVS( 900 )
   W( 53 ) = JVS( 901 )
   W( 54 ) = JVS( 902 )
   W( 56 ) = JVS( 903 )
   W( 57 ) = JVS( 904 )
   W( 58 ) = JVS( 905 )
   W( 59 ) = JVS( 906 )
   W( 60 ) = JVS( 907 )
   W( 61 ) = JVS( 908 )
   W( 62 ) = JVS( 909 )
   W( 63 ) = JVS( 910 )
   W( 64 ) = JVS( 911 )
   W( 65 ) = JVS( 912 )
   W( 66 ) = JVS( 913 )
   W( 67 ) = JVS( 914 )
   W( 68 ) = JVS( 915 )
   W( 69 ) = JVS( 916 )
   W( 70 ) = JVS( 917 )
   W( 71 ) = JVS( 918 )
   W( 72 ) = JVS( 919 )
   W( 73 ) = JVS( 920 )
   W( 74 ) = JVS( 921 )
   W( 75 ) = JVS( 922 )
   W( 76 ) = JVS( 923 )
   W( 77 ) = JVS( 924 )
   W( 78 ) = JVS( 925 )
  a = -W( 8 ) / JVS( 47 )
  W( 8 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 48 )
  W( 78 ) = W( 78 ) + a*JVS( 49 )
  a = -W( 19 ) / JVS( 81 )
  W( 19 ) = -a
  W( 69 ) = W( 69 ) + a*JVS( 82 )
  W( 76 ) = W( 76 ) + a*JVS( 83 )
  W( 78 ) = W( 78 ) + a*JVS( 84 )
  a = -W( 27 ) / JVS( 129 )
  W( 27 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 130 )
  W( 75 ) = W( 75 ) + a*JVS( 131 )
  W( 76 ) = W( 76 ) + a*JVS( 132 )
  a = -W( 31 ) / JVS( 149 )
  W( 31 ) = -a
  W( 38 ) = W( 38 ) + a*JVS( 150 )
  W( 39 ) = W( 39 ) + a*JVS( 151 )
  W( 45 ) = W( 45 ) + a*JVS( 152 )
  W( 56 ) = W( 56 ) + a*JVS( 153 )
  W( 58 ) = W( 58 ) + a*JVS( 154 )
  W( 63 ) = W( 63 ) + a*JVS( 155 )
  W( 64 ) = W( 64 ) + a*JVS( 156 )
  W( 69 ) = W( 69 ) + a*JVS( 157 )
  W( 74 ) = W( 74 ) + a*JVS( 158 )
  W( 76 ) = W( 76 ) + a*JVS( 159 )
  W( 78 ) = W( 78 ) + a*JVS( 160 )
  a = -W( 32 ) / JVS( 161 )
  W( 32 ) = -a
  W( 40 ) = W( 40 ) + a*JVS( 162 )
  W( 68 ) = W( 68 ) + a*JVS( 163 )
  W( 74 ) = W( 74 ) + a*JVS( 164 )
  W( 75 ) = W( 75 ) + a*JVS( 165 )
  W( 76 ) = W( 76 ) + a*JVS( 166 )
  W( 78 ) = W( 78 ) + a*JVS( 167 )
  a = -W( 34 ) / JVS( 189 )
  W( 34 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 190 )
  W( 75 ) = W( 75 ) + a*JVS( 191 )
  W( 76 ) = W( 76 ) + a*JVS( 192 )
  a = -W( 36 ) / JVS( 203 )
  W( 36 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 204 )
  W( 75 ) = W( 75 ) + a*JVS( 205 )
  W( 76 ) = W( 76 ) + a*JVS( 206 )
  a = -W( 37 ) / JVS( 207 )
  W( 37 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 208 )
  W( 75 ) = W( 75 ) + a*JVS( 209 )
  W( 76 ) = W( 76 ) + a*JVS( 210 )
  a = -W( 38 ) / JVS( 215 )
  W( 38 ) = -a
  W( 69 ) = W( 69 ) + a*JVS( 216 )
  W( 74 ) = W( 74 ) + a*JVS( 217 )
  W( 75 ) = W( 75 ) + a*JVS( 218 )
  W( 76 ) = W( 76 ) + a*JVS( 219 )
  W( 78 ) = W( 78 ) + a*JVS( 220 )
  a = -W( 39 ) / JVS( 222 )
  W( 39 ) = -a
  W( 46 ) = W( 46 ) + a*JVS( 223 )
  W( 51 ) = W( 51 ) + a*JVS( 224 )
  W( 52 ) = W( 52 ) + a*JVS( 225 )
  W( 64 ) = W( 64 ) + a*JVS( 226 )
  W( 68 ) = W( 68 ) + a*JVS( 227 )
  W( 72 ) = W( 72 ) + a*JVS( 228 )
  W( 73 ) = W( 73 ) + a*JVS( 229 )
  W( 74 ) = W( 74 ) + a*JVS( 230 )
  W( 75 ) = W( 75 ) + a*JVS( 231 )
  W( 76 ) = W( 76 ) + a*JVS( 232 )
  W( 77 ) = W( 77 ) + a*JVS( 233 )
  a = -W( 40 ) / JVS( 234 )
  W( 40 ) = -a
  W( 65 ) = W( 65 ) + a*JVS( 235 )
  W( 74 ) = W( 74 ) + a*JVS( 236 )
  W( 75 ) = W( 75 ) + a*JVS( 237 )
  W( 76 ) = W( 76 ) + a*JVS( 238 )
  W( 78 ) = W( 78 ) + a*JVS( 239 )
  a = -W( 41 ) / JVS( 241 )
  W( 41 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 242 )
  W( 69 ) = W( 69 ) + a*JVS( 243 )
  W( 72 ) = W( 72 ) + a*JVS( 244 )
  W( 74 ) = W( 74 ) + a*JVS( 245 )
  W( 75 ) = W( 75 ) + a*JVS( 246 )
  W( 76 ) = W( 76 ) + a*JVS( 247 )
  W( 77 ) = W( 77 ) + a*JVS( 248 )
  a = -W( 42 ) / JVS( 249 )
  W( 42 ) = -a
  W( 71 ) = W( 71 ) + a*JVS( 250 )
  W( 74 ) = W( 74 ) + a*JVS( 251 )
  W( 75 ) = W( 75 ) + a*JVS( 252 )
  W( 76 ) = W( 76 ) + a*JVS( 253 )
  a = -W( 43 ) / JVS( 254 )
  W( 43 ) = -a
  W( 59 ) = W( 59 ) + a*JVS( 255 )
  W( 68 ) = W( 68 ) + a*JVS( 256 )
  W( 69 ) = W( 69 ) + a*JVS( 257 )
  W( 72 ) = W( 72 ) + a*JVS( 258 )
  W( 74 ) = W( 74 ) + a*JVS( 259 )
  W( 76 ) = W( 76 ) + a*JVS( 260 )
  W( 77 ) = W( 77 ) + a*JVS( 261 )
  a = -W( 44 ) / JVS( 262 )
  W( 44 ) = -a
  W( 60 ) = W( 60 ) + a*JVS( 263 )
  W( 68 ) = W( 68 ) + a*JVS( 264 )
  W( 69 ) = W( 69 ) + a*JVS( 265 )
  W( 72 ) = W( 72 ) + a*JVS( 266 )
  W( 74 ) = W( 74 ) + a*JVS( 267 )
  W( 76 ) = W( 76 ) + a*JVS( 268 )
  W( 77 ) = W( 77 ) + a*JVS( 269 )
  a = -W( 45 ) / JVS( 272 )
  W( 45 ) = -a
  W( 46 ) = W( 46 ) + a*JVS( 273 )
  W( 51 ) = W( 51 ) + a*JVS( 274 )
  W( 52 ) = W( 52 ) + a*JVS( 275 )
  W( 56 ) = W( 56 ) + a*JVS( 276 )
  W( 64 ) = W( 64 ) + a*JVS( 277 )
  W( 65 ) = W( 65 ) + a*JVS( 278 )
  W( 67 ) = W( 67 ) + a*JVS( 279 )
  W( 68 ) = W( 68 ) + a*JVS( 280 )
  W( 72 ) = W( 72 ) + a*JVS( 281 )
  W( 73 ) = W( 73 ) + a*JVS( 282 )
  W( 74 ) = W( 74 ) + a*JVS( 283 )
  W( 75 ) = W( 75 ) + a*JVS( 284 )
  W( 76 ) = W( 76 ) + a*JVS( 285 )
  W( 77 ) = W( 77 ) + a*JVS( 286 )
  W( 78 ) = W( 78 ) + a*JVS( 287 )
  a = -W( 46 ) / JVS( 290 )
  W( 46 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 291 )
  W( 69 ) = W( 69 ) + a*JVS( 292 )
  W( 72 ) = W( 72 ) + a*JVS( 293 )
  W( 74 ) = W( 74 ) + a*JVS( 294 )
  W( 75 ) = W( 75 ) + a*JVS( 295 )
  W( 76 ) = W( 76 ) + a*JVS( 296 )
  W( 77 ) = W( 77 ) + a*JVS( 297 )
  W( 78 ) = W( 78 ) + a*JVS( 298 )
  a = -W( 48 ) / JVS( 325 )
  W( 48 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 326 )
  W( 69 ) = W( 69 ) + a*JVS( 327 )
  W( 72 ) = W( 72 ) + a*JVS( 328 )
  W( 74 ) = W( 74 ) + a*JVS( 329 )
  W( 75 ) = W( 75 ) + a*JVS( 330 )
  W( 76 ) = W( 76 ) + a*JVS( 331 )
  W( 77 ) = W( 77 ) + a*JVS( 332 )
  a = -W( 49 ) / JVS( 334 )
  W( 49 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 335 )
  W( 69 ) = W( 69 ) + a*JVS( 336 )
  W( 72 ) = W( 72 ) + a*JVS( 337 )
  W( 74 ) = W( 74 ) + a*JVS( 338 )
  W( 76 ) = W( 76 ) + a*JVS( 339 )
  W( 77 ) = W( 77 ) + a*JVS( 340 )
  a = -W( 50 ) / JVS( 342 )
  W( 50 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 343 )
  W( 69 ) = W( 69 ) + a*JVS( 344 )
  W( 72 ) = W( 72 ) + a*JVS( 345 )
  W( 74 ) = W( 74 ) + a*JVS( 346 )
  W( 76 ) = W( 76 ) + a*JVS( 347 )
  W( 77 ) = W( 77 ) + a*JVS( 348 )
  a = -W( 51 ) / JVS( 350 )
  W( 51 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 351 )
  W( 69 ) = W( 69 ) + a*JVS( 352 )
  W( 72 ) = W( 72 ) + a*JVS( 353 )
  W( 74 ) = W( 74 ) + a*JVS( 354 )
  W( 75 ) = W( 75 ) + a*JVS( 355 )
  W( 76 ) = W( 76 ) + a*JVS( 356 )
  W( 77 ) = W( 77 ) + a*JVS( 357 )
  W( 78 ) = W( 78 ) + a*JVS( 358 )
  a = -W( 52 ) / JVS( 360 )
  W( 52 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 361 )
  W( 69 ) = W( 69 ) + a*JVS( 362 )
  W( 72 ) = W( 72 ) + a*JVS( 363 )
  W( 74 ) = W( 74 ) + a*JVS( 364 )
  W( 75 ) = W( 75 ) + a*JVS( 365 )
  W( 76 ) = W( 76 ) + a*JVS( 366 )
  W( 77 ) = W( 77 ) + a*JVS( 367 )
  W( 78 ) = W( 78 ) + a*JVS( 368 )
  a = -W( 53 ) / JVS( 370 )
  W( 53 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 371 )
  W( 69 ) = W( 69 ) + a*JVS( 372 )
  W( 72 ) = W( 72 ) + a*JVS( 373 )
  W( 74 ) = W( 74 ) + a*JVS( 374 )
  W( 75 ) = W( 75 ) + a*JVS( 375 )
  W( 76 ) = W( 76 ) + a*JVS( 376 )
  W( 77 ) = W( 77 ) + a*JVS( 377 )
  a = -W( 54 ) / JVS( 380 )
  W( 54 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 381 )
  W( 69 ) = W( 69 ) + a*JVS( 382 )
  W( 71 ) = W( 71 ) + a*JVS( 383 )
  W( 72 ) = W( 72 ) + a*JVS( 384 )
  W( 74 ) = W( 74 ) + a*JVS( 385 )
  W( 75 ) = W( 75 ) + a*JVS( 386 )
  W( 76 ) = W( 76 ) + a*JVS( 387 )
  W( 77 ) = W( 77 ) + a*JVS( 388 )
  a = -W( 56 ) / JVS( 418 )
  W( 56 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 419 )
  W( 69 ) = W( 69 ) + a*JVS( 420 )
  W( 71 ) = W( 71 ) + a*JVS( 421 )
  W( 72 ) = W( 72 ) + a*JVS( 422 )
  W( 74 ) = W( 74 ) + a*JVS( 423 )
  W( 75 ) = W( 75 ) + a*JVS( 424 )
  W( 76 ) = W( 76 ) + a*JVS( 425 )
  W( 77 ) = W( 77 ) + a*JVS( 426 )
  a = -W( 57 ) / JVS( 438 )
  W( 57 ) = -a
  W( 64 ) = W( 64 ) + a*JVS( 439 )
  W( 65 ) = W( 65 ) + a*JVS( 440 )
  W( 67 ) = W( 67 ) + a*JVS( 441 )
  W( 68 ) = W( 68 ) + a*JVS( 442 )
  W( 69 ) = W( 69 ) + a*JVS( 443 )
  W( 70 ) = W( 70 ) + a*JVS( 444 )
  W( 71 ) = W( 71 ) + a*JVS( 445 )
  W( 72 ) = W( 72 ) + a*JVS( 446 )
  W( 73 ) = W( 73 ) + a*JVS( 447 )
  W( 74 ) = W( 74 ) + a*JVS( 448 )
  W( 75 ) = W( 75 ) + a*JVS( 449 )
  W( 76 ) = W( 76 ) + a*JVS( 450 )
  W( 77 ) = W( 77 ) + a*JVS( 451 )
  W( 78 ) = W( 78 ) + a*JVS( 452 )
  a = -W( 58 ) / JVS( 465 )
  W( 58 ) = -a
  W( 59 ) = W( 59 ) + a*JVS( 466 )
  W( 60 ) = W( 60 ) + a*JVS( 467 )
  W( 61 ) = W( 61 ) + a*JVS( 468 )
  W( 62 ) = W( 62 ) + a*JVS( 469 )
  W( 64 ) = W( 64 ) + a*JVS( 470 )
  W( 65 ) = W( 65 ) + a*JVS( 471 )
  W( 66 ) = W( 66 ) + a*JVS( 472 )
  W( 67 ) = W( 67 ) + a*JVS( 473 )
  W( 68 ) = W( 68 ) + a*JVS( 474 )
  W( 69 ) = W( 69 ) + a*JVS( 475 )
  W( 70 ) = W( 70 ) + a*JVS( 476 )
  W( 71 ) = W( 71 ) + a*JVS( 477 )
  W( 72 ) = W( 72 ) + a*JVS( 478 )
  W( 73 ) = W( 73 ) + a*JVS( 479 )
  W( 74 ) = W( 74 ) + a*JVS( 480 )
  W( 75 ) = W( 75 ) + a*JVS( 481 )
  W( 76 ) = W( 76 ) + a*JVS( 482 )
  W( 77 ) = W( 77 ) + a*JVS( 483 )
  W( 78 ) = W( 78 ) + a*JVS( 484 )
  a = -W( 59 ) / JVS( 489 )
  W( 59 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 490 )
  W( 69 ) = W( 69 ) + a*JVS( 491 )
  W( 71 ) = W( 71 ) + a*JVS( 492 )
  W( 72 ) = W( 72 ) + a*JVS( 493 )
  W( 74 ) = W( 74 ) + a*JVS( 494 )
  W( 75 ) = W( 75 ) + a*JVS( 495 )
  W( 76 ) = W( 76 ) + a*JVS( 496 )
  W( 77 ) = W( 77 ) + a*JVS( 497 )
  a = -W( 60 ) / JVS( 500 )
  W( 60 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 501 )
  W( 69 ) = W( 69 ) + a*JVS( 502 )
  W( 71 ) = W( 71 ) + a*JVS( 503 )
  W( 72 ) = W( 72 ) + a*JVS( 504 )
  W( 74 ) = W( 74 ) + a*JVS( 505 )
  W( 75 ) = W( 75 ) + a*JVS( 506 )
  W( 76 ) = W( 76 ) + a*JVS( 507 )
  W( 77 ) = W( 77 ) + a*JVS( 508 )
  a = -W( 61 ) / JVS( 517 )
  W( 61 ) = -a
  W( 62 ) = W( 62 ) + a*JVS( 518 )
  W( 68 ) = W( 68 ) + a*JVS( 519 )
  W( 69 ) = W( 69 ) + a*JVS( 520 )
  W( 71 ) = W( 71 ) + a*JVS( 521 )
  W( 72 ) = W( 72 ) + a*JVS( 522 )
  W( 74 ) = W( 74 ) + a*JVS( 523 )
  W( 75 ) = W( 75 ) + a*JVS( 524 )
  W( 76 ) = W( 76 ) + a*JVS( 525 )
  W( 77 ) = W( 77 ) + a*JVS( 526 )
  a = -W( 62 ) / JVS( 535 )
  W( 62 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 536 )
  W( 69 ) = W( 69 ) + a*JVS( 537 )
  W( 71 ) = W( 71 ) + a*JVS( 538 )
  W( 72 ) = W( 72 ) + a*JVS( 539 )
  W( 74 ) = W( 74 ) + a*JVS( 540 )
  W( 75 ) = W( 75 ) + a*JVS( 541 )
  W( 76 ) = W( 76 ) + a*JVS( 542 )
  W( 77 ) = W( 77 ) + a*JVS( 543 )
  a = -W( 63 ) / JVS( 573 )
  W( 63 ) = -a
  W( 64 ) = W( 64 ) + a*JVS( 574 )
  W( 65 ) = W( 65 ) + a*JVS( 575 )
  W( 66 ) = W( 66 ) + a*JVS( 576 )
  W( 67 ) = W( 67 ) + a*JVS( 577 )
  W( 68 ) = W( 68 ) + a*JVS( 578 )
  W( 69 ) = W( 69 ) + a*JVS( 579 )
  W( 70 ) = W( 70 ) + a*JVS( 580 )
  W( 71 ) = W( 71 ) + a*JVS( 581 )
  W( 72 ) = W( 72 ) + a*JVS( 582 )
  W( 73 ) = W( 73 ) + a*JVS( 583 )
  W( 74 ) = W( 74 ) + a*JVS( 584 )
  W( 75 ) = W( 75 ) + a*JVS( 585 )
  W( 76 ) = W( 76 ) + a*JVS( 586 )
  W( 77 ) = W( 77 ) + a*JVS( 587 )
  W( 78 ) = W( 78 ) + a*JVS( 588 )
  a = -W( 64 ) / JVS( 592 )
  W( 64 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 593 )
  W( 69 ) = W( 69 ) + a*JVS( 594 )
  W( 71 ) = W( 71 ) + a*JVS( 595 )
  W( 72 ) = W( 72 ) + a*JVS( 596 )
  W( 74 ) = W( 74 ) + a*JVS( 597 )
  W( 75 ) = W( 75 ) + a*JVS( 598 )
  W( 76 ) = W( 76 ) + a*JVS( 599 )
  W( 77 ) = W( 77 ) + a*JVS( 600 )
  W( 78 ) = W( 78 ) + a*JVS( 601 )
  a = -W( 65 ) / JVS( 605 )
  W( 65 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 606 )
  W( 69 ) = W( 69 ) + a*JVS( 607 )
  W( 71 ) = W( 71 ) + a*JVS( 608 )
  W( 72 ) = W( 72 ) + a*JVS( 609 )
  W( 74 ) = W( 74 ) + a*JVS( 610 )
  W( 75 ) = W( 75 ) + a*JVS( 611 )
  W( 76 ) = W( 76 ) + a*JVS( 612 )
  W( 77 ) = W( 77 ) + a*JVS( 613 )
  W( 78 ) = W( 78 ) + a*JVS( 614 )
  a = -W( 66 ) / JVS( 629 )
  W( 66 ) = -a
  W( 67 ) = W( 67 ) + a*JVS( 630 )
  W( 68 ) = W( 68 ) + a*JVS( 631 )
  W( 69 ) = W( 69 ) + a*JVS( 632 )
  W( 70 ) = W( 70 ) + a*JVS( 633 )
  W( 71 ) = W( 71 ) + a*JVS( 634 )
  W( 72 ) = W( 72 ) + a*JVS( 635 )
  W( 73 ) = W( 73 ) + a*JVS( 636 )
  W( 74 ) = W( 74 ) + a*JVS( 637 )
  W( 75 ) = W( 75 ) + a*JVS( 638 )
  W( 76 ) = W( 76 ) + a*JVS( 639 )
  W( 77 ) = W( 77 ) + a*JVS( 640 )
  W( 78 ) = W( 78 ) + a*JVS( 641 )
  a = -W( 67 ) / JVS( 657 )
  W( 67 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 658 )
  W( 69 ) = W( 69 ) + a*JVS( 659 )
  W( 70 ) = W( 70 ) + a*JVS( 660 )
  W( 71 ) = W( 71 ) + a*JVS( 661 )
  W( 72 ) = W( 72 ) + a*JVS( 662 )
  W( 73 ) = W( 73 ) + a*JVS( 663 )
  W( 74 ) = W( 74 ) + a*JVS( 664 )
  W( 75 ) = W( 75 ) + a*JVS( 665 )
  W( 76 ) = W( 76 ) + a*JVS( 666 )
  W( 77 ) = W( 77 ) + a*JVS( 667 )
  W( 78 ) = W( 78 ) + a*JVS( 668 )
  a = -W( 68 ) / JVS( 700 )
  W( 68 ) = -a
  W( 69 ) = W( 69 ) + a*JVS( 701 )
  W( 70 ) = W( 70 ) + a*JVS( 702 )
  W( 71 ) = W( 71 ) + a*JVS( 703 )
  W( 72 ) = W( 72 ) + a*JVS( 704 )
  W( 73 ) = W( 73 ) + a*JVS( 705 )
  W( 74 ) = W( 74 ) + a*JVS( 706 )
  W( 75 ) = W( 75 ) + a*JVS( 707 )
  W( 76 ) = W( 76 ) + a*JVS( 708 )
  W( 77 ) = W( 77 ) + a*JVS( 709 )
  W( 78 ) = W( 78 ) + a*JVS( 710 )
  a = -W( 69 ) / JVS( 764 )
  W( 69 ) = -a
  W( 70 ) = W( 70 ) + a*JVS( 765 )
  W( 71 ) = W( 71 ) + a*JVS( 766 )
  W( 72 ) = W( 72 ) + a*JVS( 767 )
  W( 73 ) = W( 73 ) + a*JVS( 768 )
  W( 74 ) = W( 74 ) + a*JVS( 769 )
  W( 75 ) = W( 75 ) + a*JVS( 770 )
  W( 76 ) = W( 76 ) + a*JVS( 771 )
  W( 77 ) = W( 77 ) + a*JVS( 772 )
  W( 78 ) = W( 78 ) + a*JVS( 773 )
  a = -W( 70 ) / JVS( 795 )
  W( 70 ) = -a
  W( 71 ) = W( 71 ) + a*JVS( 796 )
  W( 72 ) = W( 72 ) + a*JVS( 797 )
  W( 73 ) = W( 73 ) + a*JVS( 798 )
  W( 74 ) = W( 74 ) + a*JVS( 799 )
  W( 75 ) = W( 75 ) + a*JVS( 800 )
  W( 76 ) = W( 76 ) + a*JVS( 801 )
  W( 77 ) = W( 77 ) + a*JVS( 802 )
  W( 78 ) = W( 78 ) + a*JVS( 803 )
  a = -W( 71 ) / JVS( 818 )
  W( 71 ) = -a
  W( 72 ) = W( 72 ) + a*JVS( 819 )
  W( 73 ) = W( 73 ) + a*JVS( 820 )
  W( 74 ) = W( 74 ) + a*JVS( 821 )
  W( 75 ) = W( 75 ) + a*JVS( 822 )
  W( 76 ) = W( 76 ) + a*JVS( 823 )
  W( 77 ) = W( 77 ) + a*JVS( 824 )
  W( 78 ) = W( 78 ) + a*JVS( 825 )
  a = -W( 72 ) / JVS( 856 )
  W( 72 ) = -a
  W( 73 ) = W( 73 ) + a*JVS( 857 )
  W( 74 ) = W( 74 ) + a*JVS( 858 )
  W( 75 ) = W( 75 ) + a*JVS( 859 )
  W( 76 ) = W( 76 ) + a*JVS( 860 )
  W( 77 ) = W( 77 ) + a*JVS( 861 )
  W( 78 ) = W( 78 ) + a*JVS( 862 )
  a = -W( 73 ) / JVS( 873 )
  W( 73 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 874 )
  W( 75 ) = W( 75 ) + a*JVS( 875 )
  W( 76 ) = W( 76 ) + a*JVS( 876 )
  W( 77 ) = W( 77 ) + a*JVS( 877 )
  W( 78 ) = W( 78 ) + a*JVS( 878 )
  JVS( 879) = W( 8 )
  JVS( 880) = W( 19 )
  JVS( 881) = W( 27 )
  JVS( 882) = W( 31 )
  JVS( 883) = W( 32 )
  JVS( 884) = W( 34 )
  JVS( 885) = W( 36 )
  JVS( 886) = W( 37 )
  JVS( 887) = W( 38 )
  JVS( 888) = W( 39 )
  JVS( 889) = W( 40 )
  JVS( 890) = W( 41 )
  JVS( 891) = W( 42 )
  JVS( 892) = W( 43 )
  JVS( 893) = W( 44 )
  JVS( 894) = W( 45 )
  JVS( 895) = W( 46 )
  JVS( 896) = W( 48 )
  JVS( 897) = W( 49 )
  JVS( 898) = W( 50 )
  JVS( 899) = W( 51 )
  JVS( 900) = W( 52 )
  JVS( 901) = W( 53 )
  JVS( 902) = W( 54 )
  JVS( 903) = W( 56 )
  JVS( 904) = W( 57 )
  JVS( 905) = W( 58 )
  JVS( 906) = W( 59 )
  JVS( 907) = W( 60 )
  JVS( 908) = W( 61 )
  JVS( 909) = W( 62 )
  JVS( 910) = W( 63 )
  JVS( 911) = W( 64 )
  JVS( 912) = W( 65 )
  JVS( 913) = W( 66 )
  JVS( 914) = W( 67 )
  JVS( 915) = W( 68 )
  JVS( 916) = W( 69 )
  JVS( 917) = W( 70 )
  JVS( 918) = W( 71 )
  JVS( 919) = W( 72 )
  JVS( 920) = W( 73 )
  JVS( 921) = W( 74 )
  JVS( 922) = W( 75 )
  JVS( 923) = W( 76 )
  JVS( 924) = W( 77 )
  JVS( 925) = W( 78 )
  IF ( ABS( JVS( 954 )) < TINY(a) ) THEN
         IER = 75
         RETURN
  END IF
   W( 7 ) = JVS( 926 )
   W( 24 ) = JVS( 927 )
   W( 25 ) = JVS( 928 )
   W( 27 ) = JVS( 929 )
   W( 28 ) = JVS( 930 )
   W( 29 ) = JVS( 931 )
   W( 34 ) = JVS( 932 )
   W( 35 ) = JVS( 933 )
   W( 36 ) = JVS( 934 )
   W( 37 ) = JVS( 935 )
   W( 38 ) = JVS( 936 )
   W( 40 ) = JVS( 937 )
   W( 42 ) = JVS( 938 )
   W( 56 ) = JVS( 939 )
   W( 59 ) = JVS( 940 )
   W( 60 ) = JVS( 941 )
   W( 63 ) = JVS( 942 )
   W( 64 ) = JVS( 943 )
   W( 65 ) = JVS( 944 )
   W( 66 ) = JVS( 945 )
   W( 67 ) = JVS( 946 )
   W( 68 ) = JVS( 947 )
   W( 69 ) = JVS( 948 )
   W( 70 ) = JVS( 949 )
   W( 71 ) = JVS( 950 )
   W( 72 ) = JVS( 951 )
   W( 73 ) = JVS( 952 )
   W( 74 ) = JVS( 953 )
   W( 75 ) = JVS( 954 )
   W( 76 ) = JVS( 955 )
   W( 77 ) = JVS( 956 )
   W( 78 ) = JVS( 957 )
  a = -W( 7 ) / JVS( 45 )
  W( 7 ) = -a
  W( 75 ) = W( 75 ) + a*JVS( 46 )
  a = -W( 24 ) / JVS( 113 )
  W( 24 ) = -a
  W( 75 ) = W( 75 ) + a*JVS( 114 )
  W( 76 ) = W( 76 ) + a*JVS( 115 )
  W( 78 ) = W( 78 ) + a*JVS( 116 )
  a = -W( 25 ) / JVS( 118 )
  W( 25 ) = -a
  W( 75 ) = W( 75 ) + a*JVS( 119 )
  W( 76 ) = W( 76 ) + a*JVS( 120 )
  W( 78 ) = W( 78 ) + a*JVS( 121 )
  a = -W( 27 ) / JVS( 129 )
  W( 27 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 130 )
  W( 75 ) = W( 75 ) + a*JVS( 131 )
  W( 76 ) = W( 76 ) + a*JVS( 132 )
  a = -W( 28 ) / JVS( 133 )
  W( 28 ) = -a
  W( 38 ) = W( 38 ) + a*JVS( 134 )
  W( 75 ) = W( 75 ) + a*JVS( 135 )
  W( 76 ) = W( 76 ) + a*JVS( 136 )
  W( 78 ) = W( 78 ) + a*JVS( 137 )
  a = -W( 29 ) / JVS( 138 )
  W( 29 ) = -a
  W( 35 ) = W( 35 ) + a*JVS( 139 )
  W( 69 ) = W( 69 ) + a*JVS( 140 )
  W( 75 ) = W( 75 ) + a*JVS( 141 )
  W( 77 ) = W( 77 ) + a*JVS( 142 )
  a = -W( 34 ) / JVS( 189 )
  W( 34 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 190 )
  W( 75 ) = W( 75 ) + a*JVS( 191 )
  W( 76 ) = W( 76 ) + a*JVS( 192 )
  a = -W( 35 ) / JVS( 197 )
  W( 35 ) = -a
  W( 63 ) = W( 63 ) + a*JVS( 198 )
  W( 69 ) = W( 69 ) + a*JVS( 199 )
  W( 75 ) = W( 75 ) + a*JVS( 200 )
  W( 76 ) = W( 76 ) + a*JVS( 201 )
  W( 77 ) = W( 77 ) + a*JVS( 202 )
  a = -W( 36 ) / JVS( 203 )
  W( 36 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 204 )
  W( 75 ) = W( 75 ) + a*JVS( 205 )
  W( 76 ) = W( 76 ) + a*JVS( 206 )
  a = -W( 37 ) / JVS( 207 )
  W( 37 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 208 )
  W( 75 ) = W( 75 ) + a*JVS( 209 )
  W( 76 ) = W( 76 ) + a*JVS( 210 )
  a = -W( 38 ) / JVS( 215 )
  W( 38 ) = -a
  W( 69 ) = W( 69 ) + a*JVS( 216 )
  W( 74 ) = W( 74 ) + a*JVS( 217 )
  W( 75 ) = W( 75 ) + a*JVS( 218 )
  W( 76 ) = W( 76 ) + a*JVS( 219 )
  W( 78 ) = W( 78 ) + a*JVS( 220 )
  a = -W( 40 ) / JVS( 234 )
  W( 40 ) = -a
  W( 65 ) = W( 65 ) + a*JVS( 235 )
  W( 74 ) = W( 74 ) + a*JVS( 236 )
  W( 75 ) = W( 75 ) + a*JVS( 237 )
  W( 76 ) = W( 76 ) + a*JVS( 238 )
  W( 78 ) = W( 78 ) + a*JVS( 239 )
  a = -W( 42 ) / JVS( 249 )
  W( 42 ) = -a
  W( 71 ) = W( 71 ) + a*JVS( 250 )
  W( 74 ) = W( 74 ) + a*JVS( 251 )
  W( 75 ) = W( 75 ) + a*JVS( 252 )
  W( 76 ) = W( 76 ) + a*JVS( 253 )
  a = -W( 56 ) / JVS( 418 )
  W( 56 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 419 )
  W( 69 ) = W( 69 ) + a*JVS( 420 )
  W( 71 ) = W( 71 ) + a*JVS( 421 )
  W( 72 ) = W( 72 ) + a*JVS( 422 )
  W( 74 ) = W( 74 ) + a*JVS( 423 )
  W( 75 ) = W( 75 ) + a*JVS( 424 )
  W( 76 ) = W( 76 ) + a*JVS( 425 )
  W( 77 ) = W( 77 ) + a*JVS( 426 )
  a = -W( 59 ) / JVS( 489 )
  W( 59 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 490 )
  W( 69 ) = W( 69 ) + a*JVS( 491 )
  W( 71 ) = W( 71 ) + a*JVS( 492 )
  W( 72 ) = W( 72 ) + a*JVS( 493 )
  W( 74 ) = W( 74 ) + a*JVS( 494 )
  W( 75 ) = W( 75 ) + a*JVS( 495 )
  W( 76 ) = W( 76 ) + a*JVS( 496 )
  W( 77 ) = W( 77 ) + a*JVS( 497 )
  a = -W( 60 ) / JVS( 500 )
  W( 60 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 501 )
  W( 69 ) = W( 69 ) + a*JVS( 502 )
  W( 71 ) = W( 71 ) + a*JVS( 503 )
  W( 72 ) = W( 72 ) + a*JVS( 504 )
  W( 74 ) = W( 74 ) + a*JVS( 505 )
  W( 75 ) = W( 75 ) + a*JVS( 506 )
  W( 76 ) = W( 76 ) + a*JVS( 507 )
  W( 77 ) = W( 77 ) + a*JVS( 508 )
  a = -W( 63 ) / JVS( 573 )
  W( 63 ) = -a
  W( 64 ) = W( 64 ) + a*JVS( 574 )
  W( 65 ) = W( 65 ) + a*JVS( 575 )
  W( 66 ) = W( 66 ) + a*JVS( 576 )
  W( 67 ) = W( 67 ) + a*JVS( 577 )
  W( 68 ) = W( 68 ) + a*JVS( 578 )
  W( 69 ) = W( 69 ) + a*JVS( 579 )
  W( 70 ) = W( 70 ) + a*JVS( 580 )
  W( 71 ) = W( 71 ) + a*JVS( 581 )
  W( 72 ) = W( 72 ) + a*JVS( 582 )
  W( 73 ) = W( 73 ) + a*JVS( 583 )
  W( 74 ) = W( 74 ) + a*JVS( 584 )
  W( 75 ) = W( 75 ) + a*JVS( 585 )
  W( 76 ) = W( 76 ) + a*JVS( 586 )
  W( 77 ) = W( 77 ) + a*JVS( 587 )
  W( 78 ) = W( 78 ) + a*JVS( 588 )
  a = -W( 64 ) / JVS( 592 )
  W( 64 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 593 )
  W( 69 ) = W( 69 ) + a*JVS( 594 )
  W( 71 ) = W( 71 ) + a*JVS( 595 )
  W( 72 ) = W( 72 ) + a*JVS( 596 )
  W( 74 ) = W( 74 ) + a*JVS( 597 )
  W( 75 ) = W( 75 ) + a*JVS( 598 )
  W( 76 ) = W( 76 ) + a*JVS( 599 )
  W( 77 ) = W( 77 ) + a*JVS( 600 )
  W( 78 ) = W( 78 ) + a*JVS( 601 )
  a = -W( 65 ) / JVS( 605 )
  W( 65 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 606 )
  W( 69 ) = W( 69 ) + a*JVS( 607 )
  W( 71 ) = W( 71 ) + a*JVS( 608 )
  W( 72 ) = W( 72 ) + a*JVS( 609 )
  W( 74 ) = W( 74 ) + a*JVS( 610 )
  W( 75 ) = W( 75 ) + a*JVS( 611 )
  W( 76 ) = W( 76 ) + a*JVS( 612 )
  W( 77 ) = W( 77 ) + a*JVS( 613 )
  W( 78 ) = W( 78 ) + a*JVS( 614 )
  a = -W( 66 ) / JVS( 629 )
  W( 66 ) = -a
  W( 67 ) = W( 67 ) + a*JVS( 630 )
  W( 68 ) = W( 68 ) + a*JVS( 631 )
  W( 69 ) = W( 69 ) + a*JVS( 632 )
  W( 70 ) = W( 70 ) + a*JVS( 633 )
  W( 71 ) = W( 71 ) + a*JVS( 634 )
  W( 72 ) = W( 72 ) + a*JVS( 635 )
  W( 73 ) = W( 73 ) + a*JVS( 636 )
  W( 74 ) = W( 74 ) + a*JVS( 637 )
  W( 75 ) = W( 75 ) + a*JVS( 638 )
  W( 76 ) = W( 76 ) + a*JVS( 639 )
  W( 77 ) = W( 77 ) + a*JVS( 640 )
  W( 78 ) = W( 78 ) + a*JVS( 641 )
  a = -W( 67 ) / JVS( 657 )
  W( 67 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 658 )
  W( 69 ) = W( 69 ) + a*JVS( 659 )
  W( 70 ) = W( 70 ) + a*JVS( 660 )
  W( 71 ) = W( 71 ) + a*JVS( 661 )
  W( 72 ) = W( 72 ) + a*JVS( 662 )
  W( 73 ) = W( 73 ) + a*JVS( 663 )
  W( 74 ) = W( 74 ) + a*JVS( 664 )
  W( 75 ) = W( 75 ) + a*JVS( 665 )
  W( 76 ) = W( 76 ) + a*JVS( 666 )
  W( 77 ) = W( 77 ) + a*JVS( 667 )
  W( 78 ) = W( 78 ) + a*JVS( 668 )
  a = -W( 68 ) / JVS( 700 )
  W( 68 ) = -a
  W( 69 ) = W( 69 ) + a*JVS( 701 )
  W( 70 ) = W( 70 ) + a*JVS( 702 )
  W( 71 ) = W( 71 ) + a*JVS( 703 )
  W( 72 ) = W( 72 ) + a*JVS( 704 )
  W( 73 ) = W( 73 ) + a*JVS( 705 )
  W( 74 ) = W( 74 ) + a*JVS( 706 )
  W( 75 ) = W( 75 ) + a*JVS( 707 )
  W( 76 ) = W( 76 ) + a*JVS( 708 )
  W( 77 ) = W( 77 ) + a*JVS( 709 )
  W( 78 ) = W( 78 ) + a*JVS( 710 )
  a = -W( 69 ) / JVS( 764 )
  W( 69 ) = -a
  W( 70 ) = W( 70 ) + a*JVS( 765 )
  W( 71 ) = W( 71 ) + a*JVS( 766 )
  W( 72 ) = W( 72 ) + a*JVS( 767 )
  W( 73 ) = W( 73 ) + a*JVS( 768 )
  W( 74 ) = W( 74 ) + a*JVS( 769 )
  W( 75 ) = W( 75 ) + a*JVS( 770 )
  W( 76 ) = W( 76 ) + a*JVS( 771 )
  W( 77 ) = W( 77 ) + a*JVS( 772 )
  W( 78 ) = W( 78 ) + a*JVS( 773 )
  a = -W( 70 ) / JVS( 795 )
  W( 70 ) = -a
  W( 71 ) = W( 71 ) + a*JVS( 796 )
  W( 72 ) = W( 72 ) + a*JVS( 797 )
  W( 73 ) = W( 73 ) + a*JVS( 798 )
  W( 74 ) = W( 74 ) + a*JVS( 799 )
  W( 75 ) = W( 75 ) + a*JVS( 800 )
  W( 76 ) = W( 76 ) + a*JVS( 801 )
  W( 77 ) = W( 77 ) + a*JVS( 802 )
  W( 78 ) = W( 78 ) + a*JVS( 803 )
  a = -W( 71 ) / JVS( 818 )
  W( 71 ) = -a
  W( 72 ) = W( 72 ) + a*JVS( 819 )
  W( 73 ) = W( 73 ) + a*JVS( 820 )
  W( 74 ) = W( 74 ) + a*JVS( 821 )
  W( 75 ) = W( 75 ) + a*JVS( 822 )
  W( 76 ) = W( 76 ) + a*JVS( 823 )
  W( 77 ) = W( 77 ) + a*JVS( 824 )
  W( 78 ) = W( 78 ) + a*JVS( 825 )
  a = -W( 72 ) / JVS( 856 )
  W( 72 ) = -a
  W( 73 ) = W( 73 ) + a*JVS( 857 )
  W( 74 ) = W( 74 ) + a*JVS( 858 )
  W( 75 ) = W( 75 ) + a*JVS( 859 )
  W( 76 ) = W( 76 ) + a*JVS( 860 )
  W( 77 ) = W( 77 ) + a*JVS( 861 )
  W( 78 ) = W( 78 ) + a*JVS( 862 )
  a = -W( 73 ) / JVS( 873 )
  W( 73 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 874 )
  W( 75 ) = W( 75 ) + a*JVS( 875 )
  W( 76 ) = W( 76 ) + a*JVS( 876 )
  W( 77 ) = W( 77 ) + a*JVS( 877 )
  W( 78 ) = W( 78 ) + a*JVS( 878 )
  a = -W( 74 ) / JVS( 921 )
  W( 74 ) = -a
  W( 75 ) = W( 75 ) + a*JVS( 922 )
  W( 76 ) = W( 76 ) + a*JVS( 923 )
  W( 77 ) = W( 77 ) + a*JVS( 924 )
  W( 78 ) = W( 78 ) + a*JVS( 925 )
  JVS( 926) = W( 7 )
  JVS( 927) = W( 24 )
  JVS( 928) = W( 25 )
  JVS( 929) = W( 27 )
  JVS( 930) = W( 28 )
  JVS( 931) = W( 29 )
  JVS( 932) = W( 34 )
  JVS( 933) = W( 35 )
  JVS( 934) = W( 36 )
  JVS( 935) = W( 37 )
  JVS( 936) = W( 38 )
  JVS( 937) = W( 40 )
  JVS( 938) = W( 42 )
  JVS( 939) = W( 56 )
  JVS( 940) = W( 59 )
  JVS( 941) = W( 60 )
  JVS( 942) = W( 63 )
  JVS( 943) = W( 64 )
  JVS( 944) = W( 65 )
  JVS( 945) = W( 66 )
  JVS( 946) = W( 67 )
  JVS( 947) = W( 68 )
  JVS( 948) = W( 69 )
  JVS( 949) = W( 70 )
  JVS( 950) = W( 71 )
  JVS( 951) = W( 72 )
  JVS( 952) = W( 73 )
  JVS( 953) = W( 74 )
  JVS( 954) = W( 75 )
  JVS( 955) = W( 76 )
  JVS( 956) = W( 77 )
  JVS( 957) = W( 78 )
  IF ( ABS( JVS( 1020 )) < TINY(a) ) THEN
         IER = 76
         RETURN
  END IF
   W( 6 ) = JVS( 958 )
   W( 7 ) = JVS( 959 )
   W( 9 ) = JVS( 960 )
   W( 10 ) = JVS( 961 )
   W( 11 ) = JVS( 962 )
   W( 12 ) = JVS( 963 )
   W( 13 ) = JVS( 964 )
   W( 14 ) = JVS( 965 )
   W( 15 ) = JVS( 966 )
   W( 16 ) = JVS( 967 )
   W( 17 ) = JVS( 968 )
   W( 18 ) = JVS( 969 )
   W( 19 ) = JVS( 970 )
   W( 20 ) = JVS( 971 )
   W( 21 ) = JVS( 972 )
   W( 22 ) = JVS( 973 )
   W( 24 ) = JVS( 974 )
   W( 25 ) = JVS( 975 )
   W( 26 ) = JVS( 976 )
   W( 27 ) = JVS( 977 )
   W( 28 ) = JVS( 978 )
   W( 29 ) = JVS( 979 )
   W( 30 ) = JVS( 980 )
   W( 31 ) = JVS( 981 )
   W( 32 ) = JVS( 982 )
   W( 33 ) = JVS( 983 )
   W( 34 ) = JVS( 984 )
   W( 35 ) = JVS( 985 )
   W( 36 ) = JVS( 986 )
   W( 37 ) = JVS( 987 )
   W( 38 ) = JVS( 988 )
   W( 39 ) = JVS( 989 )
   W( 40 ) = JVS( 990 )
   W( 42 ) = JVS( 991 )
   W( 45 ) = JVS( 992 )
   W( 46 ) = JVS( 993 )
   W( 47 ) = JVS( 994 )
   W( 49 ) = JVS( 995 )
   W( 50 ) = JVS( 996 )
   W( 51 ) = JVS( 997 )
   W( 52 ) = JVS( 998 )
   W( 53 ) = JVS( 999 )
   W( 55 ) = JVS( 1000 )
   W( 56 ) = JVS( 1001 )
   W( 58 ) = JVS( 1002 )
   W( 59 ) = JVS( 1003 )
   W( 60 ) = JVS( 1004 )
   W( 61 ) = JVS( 1005 )
   W( 62 ) = JVS( 1006 )
   W( 63 ) = JVS( 1007 )
   W( 64 ) = JVS( 1008 )
   W( 65 ) = JVS( 1009 )
   W( 66 ) = JVS( 1010 )
   W( 67 ) = JVS( 1011 )
   W( 68 ) = JVS( 1012 )
   W( 69 ) = JVS( 1013 )
   W( 70 ) = JVS( 1014 )
   W( 71 ) = JVS( 1015 )
   W( 72 ) = JVS( 1016 )
   W( 73 ) = JVS( 1017 )
   W( 74 ) = JVS( 1018 )
   W( 75 ) = JVS( 1019 )
   W( 76 ) = JVS( 1020 )
   W( 77 ) = JVS( 1021 )
   W( 78 ) = JVS( 1022 )
  a = -W( 6 ) / JVS( 43 )
  W( 6 ) = -a
  W( 76 ) = W( 76 ) + a*JVS( 44 )
  a = -W( 7 ) / JVS( 45 )
  W( 7 ) = -a
  W( 75 ) = W( 75 ) + a*JVS( 46 )
  a = -W( 9 ) / JVS( 50 )
  W( 9 ) = -a
  W( 76 ) = W( 76 ) + a*JVS( 51 )
  a = -W( 10 ) / JVS( 52 )
  W( 10 ) = -a
  W( 76 ) = W( 76 ) + a*JVS( 53 )
  a = -W( 11 ) / JVS( 54 )
  W( 11 ) = -a
  W( 76 ) = W( 76 ) + a*JVS( 55 )
  a = -W( 12 ) / JVS( 56 )
  W( 12 ) = -a
  W( 29 ) = W( 29 ) + a*JVS( 57 )
  W( 69 ) = W( 69 ) + a*JVS( 58 )
  a = -W( 13 ) / JVS( 59 )
  W( 13 ) = -a
  W( 76 ) = W( 76 ) + a*JVS( 60 )
  a = -W( 14 ) / JVS( 61 )
  W( 14 ) = -a
  W( 76 ) = W( 76 ) + a*JVS( 62 )
  a = -W( 15 ) / JVS( 63 )
  W( 15 ) = -a
  W( 59 ) = W( 59 ) + a*JVS( 64 )
  W( 60 ) = W( 60 ) + a*JVS( 65 )
  W( 75 ) = W( 75 ) + a*JVS( 66 )
  W( 76 ) = W( 76 ) + a*JVS( 67 )
  a = -W( 16 ) / JVS( 68 )
  W( 16 ) = -a
  W( 64 ) = W( 64 ) + a*JVS( 69 )
  W( 76 ) = W( 76 ) + a*JVS( 70 )
  a = -W( 17 ) / JVS( 71 )
  W( 17 ) = -a
  W( 59 ) = W( 59 ) + a*JVS( 72 )
  W( 60 ) = W( 60 ) + a*JVS( 73 )
  W( 75 ) = W( 75 ) + a*JVS( 74 )
  W( 76 ) = W( 76 ) + a*JVS( 75 )
  a = -W( 18 ) / JVS( 76 )
  W( 18 ) = -a
  W( 35 ) = W( 35 ) + a*JVS( 77 )
  W( 63 ) = W( 63 ) + a*JVS( 78 )
  W( 69 ) = W( 69 ) + a*JVS( 79 )
  W( 76 ) = W( 76 ) + a*JVS( 80 )
  a = -W( 19 ) / JVS( 81 )
  W( 19 ) = -a
  W( 69 ) = W( 69 ) + a*JVS( 82 )
  W( 76 ) = W( 76 ) + a*JVS( 83 )
  W( 78 ) = W( 78 ) + a*JVS( 84 )
  a = -W( 20 ) / JVS( 85 )
  W( 20 ) = -a
  W( 69 ) = W( 69 ) + a*JVS( 86 )
  W( 72 ) = W( 72 ) + a*JVS( 87 )
  W( 76 ) = W( 76 ) + a*JVS( 88 )
  a = -W( 21 ) / JVS( 89 )
  W( 21 ) = -a
  W( 24 ) = W( 24 ) + a*JVS( 90 )
  W( 25 ) = W( 25 ) + a*JVS( 91 )
  W( 28 ) = W( 28 ) + a*JVS( 92 )
  W( 76 ) = W( 76 ) + a*JVS( 93 )
  W( 77 ) = W( 77 ) + a*JVS( 94 )
  W( 78 ) = W( 78 ) + a*JVS( 95 )
  a = -W( 22 ) / JVS( 96 )
  W( 22 ) = -a
  W( 34 ) = W( 34 ) + a*JVS( 97 )
  W( 36 ) = W( 36 ) + a*JVS( 98 )
  W( 37 ) = W( 37 ) + a*JVS( 99 )
  W( 42 ) = W( 42 ) + a*JVS( 100 )
  W( 59 ) = W( 59 ) + a*JVS( 101 )
  W( 60 ) = W( 60 ) + a*JVS( 102 )
  W( 69 ) = W( 69 ) + a*JVS( 103 )
  W( 75 ) = W( 75 ) + a*JVS( 104 )
  W( 76 ) = W( 76 ) + a*JVS( 105 )
  a = -W( 24 ) / JVS( 113 )
  W( 24 ) = -a
  W( 75 ) = W( 75 ) + a*JVS( 114 )
  W( 76 ) = W( 76 ) + a*JVS( 115 )
  W( 78 ) = W( 78 ) + a*JVS( 116 )
  a = -W( 25 ) / JVS( 118 )
  W( 25 ) = -a
  W( 75 ) = W( 75 ) + a*JVS( 119 )
  W( 76 ) = W( 76 ) + a*JVS( 120 )
  W( 78 ) = W( 78 ) + a*JVS( 121 )
  a = -W( 26 ) / JVS( 123 )
  W( 26 ) = -a
  W( 40 ) = W( 40 ) + a*JVS( 124 )
  W( 56 ) = W( 56 ) + a*JVS( 125 )
  W( 67 ) = W( 67 ) + a*JVS( 126 )
  W( 72 ) = W( 72 ) + a*JVS( 127 )
  W( 76 ) = W( 76 ) + a*JVS( 128 )
  a = -W( 27 ) / JVS( 129 )
  W( 27 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 130 )
  W( 75 ) = W( 75 ) + a*JVS( 131 )
  W( 76 ) = W( 76 ) + a*JVS( 132 )
  a = -W( 28 ) / JVS( 133 )
  W( 28 ) = -a
  W( 38 ) = W( 38 ) + a*JVS( 134 )
  W( 75 ) = W( 75 ) + a*JVS( 135 )
  W( 76 ) = W( 76 ) + a*JVS( 136 )
  W( 78 ) = W( 78 ) + a*JVS( 137 )
  a = -W( 29 ) / JVS( 138 )
  W( 29 ) = -a
  W( 35 ) = W( 35 ) + a*JVS( 139 )
  W( 69 ) = W( 69 ) + a*JVS( 140 )
  W( 75 ) = W( 75 ) + a*JVS( 141 )
  W( 77 ) = W( 77 ) + a*JVS( 142 )
  a = -W( 30 ) / JVS( 143 )
  W( 30 ) = -a
  W( 64 ) = W( 64 ) + a*JVS( 144 )
  W( 68 ) = W( 68 ) + a*JVS( 145 )
  W( 69 ) = W( 69 ) + a*JVS( 146 )
  W( 75 ) = W( 75 ) + a*JVS( 147 )
  W( 76 ) = W( 76 ) + a*JVS( 148 )
  a = -W( 31 ) / JVS( 149 )
  W( 31 ) = -a
  W( 38 ) = W( 38 ) + a*JVS( 150 )
  W( 39 ) = W( 39 ) + a*JVS( 151 )
  W( 45 ) = W( 45 ) + a*JVS( 152 )
  W( 56 ) = W( 56 ) + a*JVS( 153 )
  W( 58 ) = W( 58 ) + a*JVS( 154 )
  W( 63 ) = W( 63 ) + a*JVS( 155 )
  W( 64 ) = W( 64 ) + a*JVS( 156 )
  W( 69 ) = W( 69 ) + a*JVS( 157 )
  W( 74 ) = W( 74 ) + a*JVS( 158 )
  W( 76 ) = W( 76 ) + a*JVS( 159 )
  W( 78 ) = W( 78 ) + a*JVS( 160 )
  a = -W( 32 ) / JVS( 161 )
  W( 32 ) = -a
  W( 40 ) = W( 40 ) + a*JVS( 162 )
  W( 68 ) = W( 68 ) + a*JVS( 163 )
  W( 74 ) = W( 74 ) + a*JVS( 164 )
  W( 75 ) = W( 75 ) + a*JVS( 165 )
  W( 76 ) = W( 76 ) + a*JVS( 166 )
  W( 78 ) = W( 78 ) + a*JVS( 167 )
  a = -W( 33 ) / JVS( 170 )
  W( 33 ) = -a
  W( 34 ) = W( 34 ) + a*JVS( 171 )
  W( 35 ) = W( 35 ) + a*JVS( 172 )
  W( 36 ) = W( 36 ) + a*JVS( 173 )
  W( 37 ) = W( 37 ) + a*JVS( 174 )
  W( 39 ) = W( 39 ) + a*JVS( 175 )
  W( 40 ) = W( 40 ) + a*JVS( 176 )
  W( 42 ) = W( 42 ) + a*JVS( 177 )
  W( 45 ) = W( 45 ) + a*JVS( 178 )
  W( 56 ) = W( 56 ) + a*JVS( 179 )
  W( 58 ) = W( 58 ) + a*JVS( 180 )
  W( 59 ) = W( 59 ) + a*JVS( 181 )
  W( 60 ) = W( 60 ) + a*JVS( 182 )
  W( 63 ) = W( 63 ) + a*JVS( 183 )
  W( 64 ) = W( 64 ) + a*JVS( 184 )
  W( 71 ) = W( 71 ) + a*JVS( 185 )
  W( 74 ) = W( 74 ) + a*JVS( 186 )
  W( 75 ) = W( 75 ) + a*JVS( 187 )
  W( 76 ) = W( 76 ) + a*JVS( 188 )
  a = -W( 34 ) / JVS( 189 )
  W( 34 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 190 )
  W( 75 ) = W( 75 ) + a*JVS( 191 )
  W( 76 ) = W( 76 ) + a*JVS( 192 )
  a = -W( 35 ) / JVS( 197 )
  W( 35 ) = -a
  W( 63 ) = W( 63 ) + a*JVS( 198 )
  W( 69 ) = W( 69 ) + a*JVS( 199 )
  W( 75 ) = W( 75 ) + a*JVS( 200 )
  W( 76 ) = W( 76 ) + a*JVS( 201 )
  W( 77 ) = W( 77 ) + a*JVS( 202 )
  a = -W( 36 ) / JVS( 203 )
  W( 36 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 204 )
  W( 75 ) = W( 75 ) + a*JVS( 205 )
  W( 76 ) = W( 76 ) + a*JVS( 206 )
  a = -W( 37 ) / JVS( 207 )
  W( 37 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 208 )
  W( 75 ) = W( 75 ) + a*JVS( 209 )
  W( 76 ) = W( 76 ) + a*JVS( 210 )
  a = -W( 38 ) / JVS( 215 )
  W( 38 ) = -a
  W( 69 ) = W( 69 ) + a*JVS( 216 )
  W( 74 ) = W( 74 ) + a*JVS( 217 )
  W( 75 ) = W( 75 ) + a*JVS( 218 )
  W( 76 ) = W( 76 ) + a*JVS( 219 )
  W( 78 ) = W( 78 ) + a*JVS( 220 )
  a = -W( 39 ) / JVS( 222 )
  W( 39 ) = -a
  W( 46 ) = W( 46 ) + a*JVS( 223 )
  W( 51 ) = W( 51 ) + a*JVS( 224 )
  W( 52 ) = W( 52 ) + a*JVS( 225 )
  W( 64 ) = W( 64 ) + a*JVS( 226 )
  W( 68 ) = W( 68 ) + a*JVS( 227 )
  W( 72 ) = W( 72 ) + a*JVS( 228 )
  W( 73 ) = W( 73 ) + a*JVS( 229 )
  W( 74 ) = W( 74 ) + a*JVS( 230 )
  W( 75 ) = W( 75 ) + a*JVS( 231 )
  W( 76 ) = W( 76 ) + a*JVS( 232 )
  W( 77 ) = W( 77 ) + a*JVS( 233 )
  a = -W( 40 ) / JVS( 234 )
  W( 40 ) = -a
  W( 65 ) = W( 65 ) + a*JVS( 235 )
  W( 74 ) = W( 74 ) + a*JVS( 236 )
  W( 75 ) = W( 75 ) + a*JVS( 237 )
  W( 76 ) = W( 76 ) + a*JVS( 238 )
  W( 78 ) = W( 78 ) + a*JVS( 239 )
  a = -W( 42 ) / JVS( 249 )
  W( 42 ) = -a
  W( 71 ) = W( 71 ) + a*JVS( 250 )
  W( 74 ) = W( 74 ) + a*JVS( 251 )
  W( 75 ) = W( 75 ) + a*JVS( 252 )
  W( 76 ) = W( 76 ) + a*JVS( 253 )
  a = -W( 45 ) / JVS( 272 )
  W( 45 ) = -a
  W( 46 ) = W( 46 ) + a*JVS( 273 )
  W( 51 ) = W( 51 ) + a*JVS( 274 )
  W( 52 ) = W( 52 ) + a*JVS( 275 )
  W( 56 ) = W( 56 ) + a*JVS( 276 )
  W( 64 ) = W( 64 ) + a*JVS( 277 )
  W( 65 ) = W( 65 ) + a*JVS( 278 )
  W( 67 ) = W( 67 ) + a*JVS( 279 )
  W( 68 ) = W( 68 ) + a*JVS( 280 )
  W( 72 ) = W( 72 ) + a*JVS( 281 )
  W( 73 ) = W( 73 ) + a*JVS( 282 )
  W( 74 ) = W( 74 ) + a*JVS( 283 )
  W( 75 ) = W( 75 ) + a*JVS( 284 )
  W( 76 ) = W( 76 ) + a*JVS( 285 )
  W( 77 ) = W( 77 ) + a*JVS( 286 )
  W( 78 ) = W( 78 ) + a*JVS( 287 )
  a = -W( 46 ) / JVS( 290 )
  W( 46 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 291 )
  W( 69 ) = W( 69 ) + a*JVS( 292 )
  W( 72 ) = W( 72 ) + a*JVS( 293 )
  W( 74 ) = W( 74 ) + a*JVS( 294 )
  W( 75 ) = W( 75 ) + a*JVS( 295 )
  W( 76 ) = W( 76 ) + a*JVS( 296 )
  W( 77 ) = W( 77 ) + a*JVS( 297 )
  W( 78 ) = W( 78 ) + a*JVS( 298 )
  a = -W( 47 ) / JVS( 304 )
  W( 47 ) = -a
  W( 49 ) = W( 49 ) + a*JVS( 305 )
  W( 50 ) = W( 50 ) + a*JVS( 306 )
  W( 53 ) = W( 53 ) + a*JVS( 307 )
  W( 55 ) = W( 55 ) + a*JVS( 308 )
  W( 59 ) = W( 59 ) + a*JVS( 309 )
  W( 60 ) = W( 60 ) + a*JVS( 310 )
  W( 61 ) = W( 61 ) + a*JVS( 311 )
  W( 62 ) = W( 62 ) + a*JVS( 312 )
  W( 64 ) = W( 64 ) + a*JVS( 313 )
  W( 67 ) = W( 67 ) + a*JVS( 314 )
  W( 68 ) = W( 68 ) + a*JVS( 315 )
  W( 69 ) = W( 69 ) + a*JVS( 316 )
  W( 70 ) = W( 70 ) + a*JVS( 317 )
  W( 72 ) = W( 72 ) + a*JVS( 318 )
  W( 73 ) = W( 73 ) + a*JVS( 319 )
  W( 74 ) = W( 74 ) + a*JVS( 320 )
  W( 75 ) = W( 75 ) + a*JVS( 321 )
  W( 76 ) = W( 76 ) + a*JVS( 322 )
  W( 77 ) = W( 77 ) + a*JVS( 323 )
  a = -W( 49 ) / JVS( 334 )
  W( 49 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 335 )
  W( 69 ) = W( 69 ) + a*JVS( 336 )
  W( 72 ) = W( 72 ) + a*JVS( 337 )
  W( 74 ) = W( 74 ) + a*JVS( 338 )
  W( 76 ) = W( 76 ) + a*JVS( 339 )
  W( 77 ) = W( 77 ) + a*JVS( 340 )
  a = -W( 50 ) / JVS( 342 )
  W( 50 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 343 )
  W( 69 ) = W( 69 ) + a*JVS( 344 )
  W( 72 ) = W( 72 ) + a*JVS( 345 )
  W( 74 ) = W( 74 ) + a*JVS( 346 )
  W( 76 ) = W( 76 ) + a*JVS( 347 )
  W( 77 ) = W( 77 ) + a*JVS( 348 )
  a = -W( 51 ) / JVS( 350 )
  W( 51 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 351 )
  W( 69 ) = W( 69 ) + a*JVS( 352 )
  W( 72 ) = W( 72 ) + a*JVS( 353 )
  W( 74 ) = W( 74 ) + a*JVS( 354 )
  W( 75 ) = W( 75 ) + a*JVS( 355 )
  W( 76 ) = W( 76 ) + a*JVS( 356 )
  W( 77 ) = W( 77 ) + a*JVS( 357 )
  W( 78 ) = W( 78 ) + a*JVS( 358 )
  a = -W( 52 ) / JVS( 360 )
  W( 52 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 361 )
  W( 69 ) = W( 69 ) + a*JVS( 362 )
  W( 72 ) = W( 72 ) + a*JVS( 363 )
  W( 74 ) = W( 74 ) + a*JVS( 364 )
  W( 75 ) = W( 75 ) + a*JVS( 365 )
  W( 76 ) = W( 76 ) + a*JVS( 366 )
  W( 77 ) = W( 77 ) + a*JVS( 367 )
  W( 78 ) = W( 78 ) + a*JVS( 368 )
  a = -W( 53 ) / JVS( 370 )
  W( 53 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 371 )
  W( 69 ) = W( 69 ) + a*JVS( 372 )
  W( 72 ) = W( 72 ) + a*JVS( 373 )
  W( 74 ) = W( 74 ) + a*JVS( 374 )
  W( 75 ) = W( 75 ) + a*JVS( 375 )
  W( 76 ) = W( 76 ) + a*JVS( 376 )
  W( 77 ) = W( 77 ) + a*JVS( 377 )
  a = -W( 55 ) / JVS( 399 )
  W( 55 ) = -a
  W( 61 ) = W( 61 ) + a*JVS( 400 )
  W( 62 ) = W( 62 ) + a*JVS( 401 )
  W( 65 ) = W( 65 ) + a*JVS( 402 )
  W( 68 ) = W( 68 ) + a*JVS( 403 )
  W( 69 ) = W( 69 ) + a*JVS( 404 )
  W( 71 ) = W( 71 ) + a*JVS( 405 )
  W( 72 ) = W( 72 ) + a*JVS( 406 )
  W( 73 ) = W( 73 ) + a*JVS( 407 )
  W( 74 ) = W( 74 ) + a*JVS( 408 )
  W( 75 ) = W( 75 ) + a*JVS( 409 )
  W( 76 ) = W( 76 ) + a*JVS( 410 )
  W( 77 ) = W( 77 ) + a*JVS( 411 )
  W( 78 ) = W( 78 ) + a*JVS( 412 )
  a = -W( 56 ) / JVS( 418 )
  W( 56 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 419 )
  W( 69 ) = W( 69 ) + a*JVS( 420 )
  W( 71 ) = W( 71 ) + a*JVS( 421 )
  W( 72 ) = W( 72 ) + a*JVS( 422 )
  W( 74 ) = W( 74 ) + a*JVS( 423 )
  W( 75 ) = W( 75 ) + a*JVS( 424 )
  W( 76 ) = W( 76 ) + a*JVS( 425 )
  W( 77 ) = W( 77 ) + a*JVS( 426 )
  a = -W( 58 ) / JVS( 465 )
  W( 58 ) = -a
  W( 59 ) = W( 59 ) + a*JVS( 466 )
  W( 60 ) = W( 60 ) + a*JVS( 467 )
  W( 61 ) = W( 61 ) + a*JVS( 468 )
  W( 62 ) = W( 62 ) + a*JVS( 469 )
  W( 64 ) = W( 64 ) + a*JVS( 470 )
  W( 65 ) = W( 65 ) + a*JVS( 471 )
  W( 66 ) = W( 66 ) + a*JVS( 472 )
  W( 67 ) = W( 67 ) + a*JVS( 473 )
  W( 68 ) = W( 68 ) + a*JVS( 474 )
  W( 69 ) = W( 69 ) + a*JVS( 475 )
  W( 70 ) = W( 70 ) + a*JVS( 476 )
  W( 71 ) = W( 71 ) + a*JVS( 477 )
  W( 72 ) = W( 72 ) + a*JVS( 478 )
  W( 73 ) = W( 73 ) + a*JVS( 479 )
  W( 74 ) = W( 74 ) + a*JVS( 480 )
  W( 75 ) = W( 75 ) + a*JVS( 481 )
  W( 76 ) = W( 76 ) + a*JVS( 482 )
  W( 77 ) = W( 77 ) + a*JVS( 483 )
  W( 78 ) = W( 78 ) + a*JVS( 484 )
  a = -W( 59 ) / JVS( 489 )
  W( 59 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 490 )
  W( 69 ) = W( 69 ) + a*JVS( 491 )
  W( 71 ) = W( 71 ) + a*JVS( 492 )
  W( 72 ) = W( 72 ) + a*JVS( 493 )
  W( 74 ) = W( 74 ) + a*JVS( 494 )
  W( 75 ) = W( 75 ) + a*JVS( 495 )
  W( 76 ) = W( 76 ) + a*JVS( 496 )
  W( 77 ) = W( 77 ) + a*JVS( 497 )
  a = -W( 60 ) / JVS( 500 )
  W( 60 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 501 )
  W( 69 ) = W( 69 ) + a*JVS( 502 )
  W( 71 ) = W( 71 ) + a*JVS( 503 )
  W( 72 ) = W( 72 ) + a*JVS( 504 )
  W( 74 ) = W( 74 ) + a*JVS( 505 )
  W( 75 ) = W( 75 ) + a*JVS( 506 )
  W( 76 ) = W( 76 ) + a*JVS( 507 )
  W( 77 ) = W( 77 ) + a*JVS( 508 )
  a = -W( 61 ) / JVS( 517 )
  W( 61 ) = -a
  W( 62 ) = W( 62 ) + a*JVS( 518 )
  W( 68 ) = W( 68 ) + a*JVS( 519 )
  W( 69 ) = W( 69 ) + a*JVS( 520 )
  W( 71 ) = W( 71 ) + a*JVS( 521 )
  W( 72 ) = W( 72 ) + a*JVS( 522 )
  W( 74 ) = W( 74 ) + a*JVS( 523 )
  W( 75 ) = W( 75 ) + a*JVS( 524 )
  W( 76 ) = W( 76 ) + a*JVS( 525 )
  W( 77 ) = W( 77 ) + a*JVS( 526 )
  a = -W( 62 ) / JVS( 535 )
  W( 62 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 536 )
  W( 69 ) = W( 69 ) + a*JVS( 537 )
  W( 71 ) = W( 71 ) + a*JVS( 538 )
  W( 72 ) = W( 72 ) + a*JVS( 539 )
  W( 74 ) = W( 74 ) + a*JVS( 540 )
  W( 75 ) = W( 75 ) + a*JVS( 541 )
  W( 76 ) = W( 76 ) + a*JVS( 542 )
  W( 77 ) = W( 77 ) + a*JVS( 543 )
  a = -W( 63 ) / JVS( 573 )
  W( 63 ) = -a
  W( 64 ) = W( 64 ) + a*JVS( 574 )
  W( 65 ) = W( 65 ) + a*JVS( 575 )
  W( 66 ) = W( 66 ) + a*JVS( 576 )
  W( 67 ) = W( 67 ) + a*JVS( 577 )
  W( 68 ) = W( 68 ) + a*JVS( 578 )
  W( 69 ) = W( 69 ) + a*JVS( 579 )
  W( 70 ) = W( 70 ) + a*JVS( 580 )
  W( 71 ) = W( 71 ) + a*JVS( 581 )
  W( 72 ) = W( 72 ) + a*JVS( 582 )
  W( 73 ) = W( 73 ) + a*JVS( 583 )
  W( 74 ) = W( 74 ) + a*JVS( 584 )
  W( 75 ) = W( 75 ) + a*JVS( 585 )
  W( 76 ) = W( 76 ) + a*JVS( 586 )
  W( 77 ) = W( 77 ) + a*JVS( 587 )
  W( 78 ) = W( 78 ) + a*JVS( 588 )
  a = -W( 64 ) / JVS( 592 )
  W( 64 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 593 )
  W( 69 ) = W( 69 ) + a*JVS( 594 )
  W( 71 ) = W( 71 ) + a*JVS( 595 )
  W( 72 ) = W( 72 ) + a*JVS( 596 )
  W( 74 ) = W( 74 ) + a*JVS( 597 )
  W( 75 ) = W( 75 ) + a*JVS( 598 )
  W( 76 ) = W( 76 ) + a*JVS( 599 )
  W( 77 ) = W( 77 ) + a*JVS( 600 )
  W( 78 ) = W( 78 ) + a*JVS( 601 )
  a = -W( 65 ) / JVS( 605 )
  W( 65 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 606 )
  W( 69 ) = W( 69 ) + a*JVS( 607 )
  W( 71 ) = W( 71 ) + a*JVS( 608 )
  W( 72 ) = W( 72 ) + a*JVS( 609 )
  W( 74 ) = W( 74 ) + a*JVS( 610 )
  W( 75 ) = W( 75 ) + a*JVS( 611 )
  W( 76 ) = W( 76 ) + a*JVS( 612 )
  W( 77 ) = W( 77 ) + a*JVS( 613 )
  W( 78 ) = W( 78 ) + a*JVS( 614 )
  a = -W( 66 ) / JVS( 629 )
  W( 66 ) = -a
  W( 67 ) = W( 67 ) + a*JVS( 630 )
  W( 68 ) = W( 68 ) + a*JVS( 631 )
  W( 69 ) = W( 69 ) + a*JVS( 632 )
  W( 70 ) = W( 70 ) + a*JVS( 633 )
  W( 71 ) = W( 71 ) + a*JVS( 634 )
  W( 72 ) = W( 72 ) + a*JVS( 635 )
  W( 73 ) = W( 73 ) + a*JVS( 636 )
  W( 74 ) = W( 74 ) + a*JVS( 637 )
  W( 75 ) = W( 75 ) + a*JVS( 638 )
  W( 76 ) = W( 76 ) + a*JVS( 639 )
  W( 77 ) = W( 77 ) + a*JVS( 640 )
  W( 78 ) = W( 78 ) + a*JVS( 641 )
  a = -W( 67 ) / JVS( 657 )
  W( 67 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 658 )
  W( 69 ) = W( 69 ) + a*JVS( 659 )
  W( 70 ) = W( 70 ) + a*JVS( 660 )
  W( 71 ) = W( 71 ) + a*JVS( 661 )
  W( 72 ) = W( 72 ) + a*JVS( 662 )
  W( 73 ) = W( 73 ) + a*JVS( 663 )
  W( 74 ) = W( 74 ) + a*JVS( 664 )
  W( 75 ) = W( 75 ) + a*JVS( 665 )
  W( 76 ) = W( 76 ) + a*JVS( 666 )
  W( 77 ) = W( 77 ) + a*JVS( 667 )
  W( 78 ) = W( 78 ) + a*JVS( 668 )
  a = -W( 68 ) / JVS( 700 )
  W( 68 ) = -a
  W( 69 ) = W( 69 ) + a*JVS( 701 )
  W( 70 ) = W( 70 ) + a*JVS( 702 )
  W( 71 ) = W( 71 ) + a*JVS( 703 )
  W( 72 ) = W( 72 ) + a*JVS( 704 )
  W( 73 ) = W( 73 ) + a*JVS( 705 )
  W( 74 ) = W( 74 ) + a*JVS( 706 )
  W( 75 ) = W( 75 ) + a*JVS( 707 )
  W( 76 ) = W( 76 ) + a*JVS( 708 )
  W( 77 ) = W( 77 ) + a*JVS( 709 )
  W( 78 ) = W( 78 ) + a*JVS( 710 )
  a = -W( 69 ) / JVS( 764 )
  W( 69 ) = -a
  W( 70 ) = W( 70 ) + a*JVS( 765 )
  W( 71 ) = W( 71 ) + a*JVS( 766 )
  W( 72 ) = W( 72 ) + a*JVS( 767 )
  W( 73 ) = W( 73 ) + a*JVS( 768 )
  W( 74 ) = W( 74 ) + a*JVS( 769 )
  W( 75 ) = W( 75 ) + a*JVS( 770 )
  W( 76 ) = W( 76 ) + a*JVS( 771 )
  W( 77 ) = W( 77 ) + a*JVS( 772 )
  W( 78 ) = W( 78 ) + a*JVS( 773 )
  a = -W( 70 ) / JVS( 795 )
  W( 70 ) = -a
  W( 71 ) = W( 71 ) + a*JVS( 796 )
  W( 72 ) = W( 72 ) + a*JVS( 797 )
  W( 73 ) = W( 73 ) + a*JVS( 798 )
  W( 74 ) = W( 74 ) + a*JVS( 799 )
  W( 75 ) = W( 75 ) + a*JVS( 800 )
  W( 76 ) = W( 76 ) + a*JVS( 801 )
  W( 77 ) = W( 77 ) + a*JVS( 802 )
  W( 78 ) = W( 78 ) + a*JVS( 803 )
  a = -W( 71 ) / JVS( 818 )
  W( 71 ) = -a
  W( 72 ) = W( 72 ) + a*JVS( 819 )
  W( 73 ) = W( 73 ) + a*JVS( 820 )
  W( 74 ) = W( 74 ) + a*JVS( 821 )
  W( 75 ) = W( 75 ) + a*JVS( 822 )
  W( 76 ) = W( 76 ) + a*JVS( 823 )
  W( 77 ) = W( 77 ) + a*JVS( 824 )
  W( 78 ) = W( 78 ) + a*JVS( 825 )
  a = -W( 72 ) / JVS( 856 )
  W( 72 ) = -a
  W( 73 ) = W( 73 ) + a*JVS( 857 )
  W( 74 ) = W( 74 ) + a*JVS( 858 )
  W( 75 ) = W( 75 ) + a*JVS( 859 )
  W( 76 ) = W( 76 ) + a*JVS( 860 )
  W( 77 ) = W( 77 ) + a*JVS( 861 )
  W( 78 ) = W( 78 ) + a*JVS( 862 )
  a = -W( 73 ) / JVS( 873 )
  W( 73 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 874 )
  W( 75 ) = W( 75 ) + a*JVS( 875 )
  W( 76 ) = W( 76 ) + a*JVS( 876 )
  W( 77 ) = W( 77 ) + a*JVS( 877 )
  W( 78 ) = W( 78 ) + a*JVS( 878 )
  a = -W( 74 ) / JVS( 921 )
  W( 74 ) = -a
  W( 75 ) = W( 75 ) + a*JVS( 922 )
  W( 76 ) = W( 76 ) + a*JVS( 923 )
  W( 77 ) = W( 77 ) + a*JVS( 924 )
  W( 78 ) = W( 78 ) + a*JVS( 925 )
  a = -W( 75 ) / JVS( 954 )
  W( 75 ) = -a
  W( 76 ) = W( 76 ) + a*JVS( 955 )
  W( 77 ) = W( 77 ) + a*JVS( 956 )
  W( 78 ) = W( 78 ) + a*JVS( 957 )
  JVS( 958) = W( 6 )
  JVS( 959) = W( 7 )
  JVS( 960) = W( 9 )
  JVS( 961) = W( 10 )
  JVS( 962) = W( 11 )
  JVS( 963) = W( 12 )
  JVS( 964) = W( 13 )
  JVS( 965) = W( 14 )
  JVS( 966) = W( 15 )
  JVS( 967) = W( 16 )
  JVS( 968) = W( 17 )
  JVS( 969) = W( 18 )
  JVS( 970) = W( 19 )
  JVS( 971) = W( 20 )
  JVS( 972) = W( 21 )
  JVS( 973) = W( 22 )
  JVS( 974) = W( 24 )
  JVS( 975) = W( 25 )
  JVS( 976) = W( 26 )
  JVS( 977) = W( 27 )
  JVS( 978) = W( 28 )
  JVS( 979) = W( 29 )
  JVS( 980) = W( 30 )
  JVS( 981) = W( 31 )
  JVS( 982) = W( 32 )
  JVS( 983) = W( 33 )
  JVS( 984) = W( 34 )
  JVS( 985) = W( 35 )
  JVS( 986) = W( 36 )
  JVS( 987) = W( 37 )
  JVS( 988) = W( 38 )
  JVS( 989) = W( 39 )
  JVS( 990) = W( 40 )
  JVS( 991) = W( 42 )
  JVS( 992) = W( 45 )
  JVS( 993) = W( 46 )
  JVS( 994) = W( 47 )
  JVS( 995) = W( 49 )
  JVS( 996) = W( 50 )
  JVS( 997) = W( 51 )
  JVS( 998) = W( 52 )
  JVS( 999) = W( 53 )
  JVS( 1000) = W( 55 )
  JVS( 1001) = W( 56 )
  JVS( 1002) = W( 58 )
  JVS( 1003) = W( 59 )
  JVS( 1004) = W( 60 )
  JVS( 1005) = W( 61 )
  JVS( 1006) = W( 62 )
  JVS( 1007) = W( 63 )
  JVS( 1008) = W( 64 )
  JVS( 1009) = W( 65 )
  JVS( 1010) = W( 66 )
  JVS( 1011) = W( 67 )
  JVS( 1012) = W( 68 )
  JVS( 1013) = W( 69 )
  JVS( 1014) = W( 70 )
  JVS( 1015) = W( 71 )
  JVS( 1016) = W( 72 )
  JVS( 1017) = W( 73 )
  JVS( 1018) = W( 74 )
  JVS( 1019) = W( 75 )
  JVS( 1020) = W( 76 )
  JVS( 1021) = W( 77 )
  JVS( 1022) = W( 78 )
  IF ( ABS( JVS( 1060 )) < TINY(a) ) THEN
         IER = 77
         RETURN
  END IF
   W( 21 ) = JVS( 1023 )
   W( 24 ) = JVS( 1024 )
   W( 25 ) = JVS( 1025 )
   W( 28 ) = JVS( 1026 )
   W( 29 ) = JVS( 1027 )
   W( 35 ) = JVS( 1028 )
   W( 38 ) = JVS( 1029 )
   W( 41 ) = JVS( 1030 )
   W( 43 ) = JVS( 1031 )
   W( 44 ) = JVS( 1032 )
   W( 46 ) = JVS( 1033 )
   W( 48 ) = JVS( 1034 )
   W( 49 ) = JVS( 1035 )
   W( 50 ) = JVS( 1036 )
   W( 51 ) = JVS( 1037 )
   W( 52 ) = JVS( 1038 )
   W( 53 ) = JVS( 1039 )
   W( 54 ) = JVS( 1040 )
   W( 57 ) = JVS( 1041 )
   W( 59 ) = JVS( 1042 )
   W( 60 ) = JVS( 1043 )
   W( 61 ) = JVS( 1044 )
   W( 62 ) = JVS( 1045 )
   W( 63 ) = JVS( 1046 )
   W( 64 ) = JVS( 1047 )
   W( 65 ) = JVS( 1048 )
   W( 66 ) = JVS( 1049 )
   W( 67 ) = JVS( 1050 )
   W( 68 ) = JVS( 1051 )
   W( 69 ) = JVS( 1052 )
   W( 70 ) = JVS( 1053 )
   W( 71 ) = JVS( 1054 )
   W( 72 ) = JVS( 1055 )
   W( 73 ) = JVS( 1056 )
   W( 74 ) = JVS( 1057 )
   W( 75 ) = JVS( 1058 )
   W( 76 ) = JVS( 1059 )
   W( 77 ) = JVS( 1060 )
   W( 78 ) = JVS( 1061 )
  a = -W( 21 ) / JVS( 89 )
  W( 21 ) = -a
  W( 24 ) = W( 24 ) + a*JVS( 90 )
  W( 25 ) = W( 25 ) + a*JVS( 91 )
  W( 28 ) = W( 28 ) + a*JVS( 92 )
  W( 76 ) = W( 76 ) + a*JVS( 93 )
  W( 77 ) = W( 77 ) + a*JVS( 94 )
  W( 78 ) = W( 78 ) + a*JVS( 95 )
  a = -W( 24 ) / JVS( 113 )
  W( 24 ) = -a
  W( 75 ) = W( 75 ) + a*JVS( 114 )
  W( 76 ) = W( 76 ) + a*JVS( 115 )
  W( 78 ) = W( 78 ) + a*JVS( 116 )
  a = -W( 25 ) / JVS( 118 )
  W( 25 ) = -a
  W( 75 ) = W( 75 ) + a*JVS( 119 )
  W( 76 ) = W( 76 ) + a*JVS( 120 )
  W( 78 ) = W( 78 ) + a*JVS( 121 )
  a = -W( 28 ) / JVS( 133 )
  W( 28 ) = -a
  W( 38 ) = W( 38 ) + a*JVS( 134 )
  W( 75 ) = W( 75 ) + a*JVS( 135 )
  W( 76 ) = W( 76 ) + a*JVS( 136 )
  W( 78 ) = W( 78 ) + a*JVS( 137 )
  a = -W( 29 ) / JVS( 138 )
  W( 29 ) = -a
  W( 35 ) = W( 35 ) + a*JVS( 139 )
  W( 69 ) = W( 69 ) + a*JVS( 140 )
  W( 75 ) = W( 75 ) + a*JVS( 141 )
  W( 77 ) = W( 77 ) + a*JVS( 142 )
  a = -W( 35 ) / JVS( 197 )
  W( 35 ) = -a
  W( 63 ) = W( 63 ) + a*JVS( 198 )
  W( 69 ) = W( 69 ) + a*JVS( 199 )
  W( 75 ) = W( 75 ) + a*JVS( 200 )
  W( 76 ) = W( 76 ) + a*JVS( 201 )
  W( 77 ) = W( 77 ) + a*JVS( 202 )
  a = -W( 38 ) / JVS( 215 )
  W( 38 ) = -a
  W( 69 ) = W( 69 ) + a*JVS( 216 )
  W( 74 ) = W( 74 ) + a*JVS( 217 )
  W( 75 ) = W( 75 ) + a*JVS( 218 )
  W( 76 ) = W( 76 ) + a*JVS( 219 )
  W( 78 ) = W( 78 ) + a*JVS( 220 )
  a = -W( 41 ) / JVS( 241 )
  W( 41 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 242 )
  W( 69 ) = W( 69 ) + a*JVS( 243 )
  W( 72 ) = W( 72 ) + a*JVS( 244 )
  W( 74 ) = W( 74 ) + a*JVS( 245 )
  W( 75 ) = W( 75 ) + a*JVS( 246 )
  W( 76 ) = W( 76 ) + a*JVS( 247 )
  W( 77 ) = W( 77 ) + a*JVS( 248 )
  a = -W( 43 ) / JVS( 254 )
  W( 43 ) = -a
  W( 59 ) = W( 59 ) + a*JVS( 255 )
  W( 68 ) = W( 68 ) + a*JVS( 256 )
  W( 69 ) = W( 69 ) + a*JVS( 257 )
  W( 72 ) = W( 72 ) + a*JVS( 258 )
  W( 74 ) = W( 74 ) + a*JVS( 259 )
  W( 76 ) = W( 76 ) + a*JVS( 260 )
  W( 77 ) = W( 77 ) + a*JVS( 261 )
  a = -W( 44 ) / JVS( 262 )
  W( 44 ) = -a
  W( 60 ) = W( 60 ) + a*JVS( 263 )
  W( 68 ) = W( 68 ) + a*JVS( 264 )
  W( 69 ) = W( 69 ) + a*JVS( 265 )
  W( 72 ) = W( 72 ) + a*JVS( 266 )
  W( 74 ) = W( 74 ) + a*JVS( 267 )
  W( 76 ) = W( 76 ) + a*JVS( 268 )
  W( 77 ) = W( 77 ) + a*JVS( 269 )
  a = -W( 46 ) / JVS( 290 )
  W( 46 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 291 )
  W( 69 ) = W( 69 ) + a*JVS( 292 )
  W( 72 ) = W( 72 ) + a*JVS( 293 )
  W( 74 ) = W( 74 ) + a*JVS( 294 )
  W( 75 ) = W( 75 ) + a*JVS( 295 )
  W( 76 ) = W( 76 ) + a*JVS( 296 )
  W( 77 ) = W( 77 ) + a*JVS( 297 )
  W( 78 ) = W( 78 ) + a*JVS( 298 )
  a = -W( 48 ) / JVS( 325 )
  W( 48 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 326 )
  W( 69 ) = W( 69 ) + a*JVS( 327 )
  W( 72 ) = W( 72 ) + a*JVS( 328 )
  W( 74 ) = W( 74 ) + a*JVS( 329 )
  W( 75 ) = W( 75 ) + a*JVS( 330 )
  W( 76 ) = W( 76 ) + a*JVS( 331 )
  W( 77 ) = W( 77 ) + a*JVS( 332 )
  a = -W( 49 ) / JVS( 334 )
  W( 49 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 335 )
  W( 69 ) = W( 69 ) + a*JVS( 336 )
  W( 72 ) = W( 72 ) + a*JVS( 337 )
  W( 74 ) = W( 74 ) + a*JVS( 338 )
  W( 76 ) = W( 76 ) + a*JVS( 339 )
  W( 77 ) = W( 77 ) + a*JVS( 340 )
  a = -W( 50 ) / JVS( 342 )
  W( 50 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 343 )
  W( 69 ) = W( 69 ) + a*JVS( 344 )
  W( 72 ) = W( 72 ) + a*JVS( 345 )
  W( 74 ) = W( 74 ) + a*JVS( 346 )
  W( 76 ) = W( 76 ) + a*JVS( 347 )
  W( 77 ) = W( 77 ) + a*JVS( 348 )
  a = -W( 51 ) / JVS( 350 )
  W( 51 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 351 )
  W( 69 ) = W( 69 ) + a*JVS( 352 )
  W( 72 ) = W( 72 ) + a*JVS( 353 )
  W( 74 ) = W( 74 ) + a*JVS( 354 )
  W( 75 ) = W( 75 ) + a*JVS( 355 )
  W( 76 ) = W( 76 ) + a*JVS( 356 )
  W( 77 ) = W( 77 ) + a*JVS( 357 )
  W( 78 ) = W( 78 ) + a*JVS( 358 )
  a = -W( 52 ) / JVS( 360 )
  W( 52 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 361 )
  W( 69 ) = W( 69 ) + a*JVS( 362 )
  W( 72 ) = W( 72 ) + a*JVS( 363 )
  W( 74 ) = W( 74 ) + a*JVS( 364 )
  W( 75 ) = W( 75 ) + a*JVS( 365 )
  W( 76 ) = W( 76 ) + a*JVS( 366 )
  W( 77 ) = W( 77 ) + a*JVS( 367 )
  W( 78 ) = W( 78 ) + a*JVS( 368 )
  a = -W( 53 ) / JVS( 370 )
  W( 53 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 371 )
  W( 69 ) = W( 69 ) + a*JVS( 372 )
  W( 72 ) = W( 72 ) + a*JVS( 373 )
  W( 74 ) = W( 74 ) + a*JVS( 374 )
  W( 75 ) = W( 75 ) + a*JVS( 375 )
  W( 76 ) = W( 76 ) + a*JVS( 376 )
  W( 77 ) = W( 77 ) + a*JVS( 377 )
  a = -W( 54 ) / JVS( 380 )
  W( 54 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 381 )
  W( 69 ) = W( 69 ) + a*JVS( 382 )
  W( 71 ) = W( 71 ) + a*JVS( 383 )
  W( 72 ) = W( 72 ) + a*JVS( 384 )
  W( 74 ) = W( 74 ) + a*JVS( 385 )
  W( 75 ) = W( 75 ) + a*JVS( 386 )
  W( 76 ) = W( 76 ) + a*JVS( 387 )
  W( 77 ) = W( 77 ) + a*JVS( 388 )
  a = -W( 57 ) / JVS( 438 )
  W( 57 ) = -a
  W( 64 ) = W( 64 ) + a*JVS( 439 )
  W( 65 ) = W( 65 ) + a*JVS( 440 )
  W( 67 ) = W( 67 ) + a*JVS( 441 )
  W( 68 ) = W( 68 ) + a*JVS( 442 )
  W( 69 ) = W( 69 ) + a*JVS( 443 )
  W( 70 ) = W( 70 ) + a*JVS( 444 )
  W( 71 ) = W( 71 ) + a*JVS( 445 )
  W( 72 ) = W( 72 ) + a*JVS( 446 )
  W( 73 ) = W( 73 ) + a*JVS( 447 )
  W( 74 ) = W( 74 ) + a*JVS( 448 )
  W( 75 ) = W( 75 ) + a*JVS( 449 )
  W( 76 ) = W( 76 ) + a*JVS( 450 )
  W( 77 ) = W( 77 ) + a*JVS( 451 )
  W( 78 ) = W( 78 ) + a*JVS( 452 )
  a = -W( 59 ) / JVS( 489 )
  W( 59 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 490 )
  W( 69 ) = W( 69 ) + a*JVS( 491 )
  W( 71 ) = W( 71 ) + a*JVS( 492 )
  W( 72 ) = W( 72 ) + a*JVS( 493 )
  W( 74 ) = W( 74 ) + a*JVS( 494 )
  W( 75 ) = W( 75 ) + a*JVS( 495 )
  W( 76 ) = W( 76 ) + a*JVS( 496 )
  W( 77 ) = W( 77 ) + a*JVS( 497 )
  a = -W( 60 ) / JVS( 500 )
  W( 60 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 501 )
  W( 69 ) = W( 69 ) + a*JVS( 502 )
  W( 71 ) = W( 71 ) + a*JVS( 503 )
  W( 72 ) = W( 72 ) + a*JVS( 504 )
  W( 74 ) = W( 74 ) + a*JVS( 505 )
  W( 75 ) = W( 75 ) + a*JVS( 506 )
  W( 76 ) = W( 76 ) + a*JVS( 507 )
  W( 77 ) = W( 77 ) + a*JVS( 508 )
  a = -W( 61 ) / JVS( 517 )
  W( 61 ) = -a
  W( 62 ) = W( 62 ) + a*JVS( 518 )
  W( 68 ) = W( 68 ) + a*JVS( 519 )
  W( 69 ) = W( 69 ) + a*JVS( 520 )
  W( 71 ) = W( 71 ) + a*JVS( 521 )
  W( 72 ) = W( 72 ) + a*JVS( 522 )
  W( 74 ) = W( 74 ) + a*JVS( 523 )
  W( 75 ) = W( 75 ) + a*JVS( 524 )
  W( 76 ) = W( 76 ) + a*JVS( 525 )
  W( 77 ) = W( 77 ) + a*JVS( 526 )
  a = -W( 62 ) / JVS( 535 )
  W( 62 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 536 )
  W( 69 ) = W( 69 ) + a*JVS( 537 )
  W( 71 ) = W( 71 ) + a*JVS( 538 )
  W( 72 ) = W( 72 ) + a*JVS( 539 )
  W( 74 ) = W( 74 ) + a*JVS( 540 )
  W( 75 ) = W( 75 ) + a*JVS( 541 )
  W( 76 ) = W( 76 ) + a*JVS( 542 )
  W( 77 ) = W( 77 ) + a*JVS( 543 )
  a = -W( 63 ) / JVS( 573 )
  W( 63 ) = -a
  W( 64 ) = W( 64 ) + a*JVS( 574 )
  W( 65 ) = W( 65 ) + a*JVS( 575 )
  W( 66 ) = W( 66 ) + a*JVS( 576 )
  W( 67 ) = W( 67 ) + a*JVS( 577 )
  W( 68 ) = W( 68 ) + a*JVS( 578 )
  W( 69 ) = W( 69 ) + a*JVS( 579 )
  W( 70 ) = W( 70 ) + a*JVS( 580 )
  W( 71 ) = W( 71 ) + a*JVS( 581 )
  W( 72 ) = W( 72 ) + a*JVS( 582 )
  W( 73 ) = W( 73 ) + a*JVS( 583 )
  W( 74 ) = W( 74 ) + a*JVS( 584 )
  W( 75 ) = W( 75 ) + a*JVS( 585 )
  W( 76 ) = W( 76 ) + a*JVS( 586 )
  W( 77 ) = W( 77 ) + a*JVS( 587 )
  W( 78 ) = W( 78 ) + a*JVS( 588 )
  a = -W( 64 ) / JVS( 592 )
  W( 64 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 593 )
  W( 69 ) = W( 69 ) + a*JVS( 594 )
  W( 71 ) = W( 71 ) + a*JVS( 595 )
  W( 72 ) = W( 72 ) + a*JVS( 596 )
  W( 74 ) = W( 74 ) + a*JVS( 597 )
  W( 75 ) = W( 75 ) + a*JVS( 598 )
  W( 76 ) = W( 76 ) + a*JVS( 599 )
  W( 77 ) = W( 77 ) + a*JVS( 600 )
  W( 78 ) = W( 78 ) + a*JVS( 601 )
  a = -W( 65 ) / JVS( 605 )
  W( 65 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 606 )
  W( 69 ) = W( 69 ) + a*JVS( 607 )
  W( 71 ) = W( 71 ) + a*JVS( 608 )
  W( 72 ) = W( 72 ) + a*JVS( 609 )
  W( 74 ) = W( 74 ) + a*JVS( 610 )
  W( 75 ) = W( 75 ) + a*JVS( 611 )
  W( 76 ) = W( 76 ) + a*JVS( 612 )
  W( 77 ) = W( 77 ) + a*JVS( 613 )
  W( 78 ) = W( 78 ) + a*JVS( 614 )
  a = -W( 66 ) / JVS( 629 )
  W( 66 ) = -a
  W( 67 ) = W( 67 ) + a*JVS( 630 )
  W( 68 ) = W( 68 ) + a*JVS( 631 )
  W( 69 ) = W( 69 ) + a*JVS( 632 )
  W( 70 ) = W( 70 ) + a*JVS( 633 )
  W( 71 ) = W( 71 ) + a*JVS( 634 )
  W( 72 ) = W( 72 ) + a*JVS( 635 )
  W( 73 ) = W( 73 ) + a*JVS( 636 )
  W( 74 ) = W( 74 ) + a*JVS( 637 )
  W( 75 ) = W( 75 ) + a*JVS( 638 )
  W( 76 ) = W( 76 ) + a*JVS( 639 )
  W( 77 ) = W( 77 ) + a*JVS( 640 )
  W( 78 ) = W( 78 ) + a*JVS( 641 )
  a = -W( 67 ) / JVS( 657 )
  W( 67 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 658 )
  W( 69 ) = W( 69 ) + a*JVS( 659 )
  W( 70 ) = W( 70 ) + a*JVS( 660 )
  W( 71 ) = W( 71 ) + a*JVS( 661 )
  W( 72 ) = W( 72 ) + a*JVS( 662 )
  W( 73 ) = W( 73 ) + a*JVS( 663 )
  W( 74 ) = W( 74 ) + a*JVS( 664 )
  W( 75 ) = W( 75 ) + a*JVS( 665 )
  W( 76 ) = W( 76 ) + a*JVS( 666 )
  W( 77 ) = W( 77 ) + a*JVS( 667 )
  W( 78 ) = W( 78 ) + a*JVS( 668 )
  a = -W( 68 ) / JVS( 700 )
  W( 68 ) = -a
  W( 69 ) = W( 69 ) + a*JVS( 701 )
  W( 70 ) = W( 70 ) + a*JVS( 702 )
  W( 71 ) = W( 71 ) + a*JVS( 703 )
  W( 72 ) = W( 72 ) + a*JVS( 704 )
  W( 73 ) = W( 73 ) + a*JVS( 705 )
  W( 74 ) = W( 74 ) + a*JVS( 706 )
  W( 75 ) = W( 75 ) + a*JVS( 707 )
  W( 76 ) = W( 76 ) + a*JVS( 708 )
  W( 77 ) = W( 77 ) + a*JVS( 709 )
  W( 78 ) = W( 78 ) + a*JVS( 710 )
  a = -W( 69 ) / JVS( 764 )
  W( 69 ) = -a
  W( 70 ) = W( 70 ) + a*JVS( 765 )
  W( 71 ) = W( 71 ) + a*JVS( 766 )
  W( 72 ) = W( 72 ) + a*JVS( 767 )
  W( 73 ) = W( 73 ) + a*JVS( 768 )
  W( 74 ) = W( 74 ) + a*JVS( 769 )
  W( 75 ) = W( 75 ) + a*JVS( 770 )
  W( 76 ) = W( 76 ) + a*JVS( 771 )
  W( 77 ) = W( 77 ) + a*JVS( 772 )
  W( 78 ) = W( 78 ) + a*JVS( 773 )
  a = -W( 70 ) / JVS( 795 )
  W( 70 ) = -a
  W( 71 ) = W( 71 ) + a*JVS( 796 )
  W( 72 ) = W( 72 ) + a*JVS( 797 )
  W( 73 ) = W( 73 ) + a*JVS( 798 )
  W( 74 ) = W( 74 ) + a*JVS( 799 )
  W( 75 ) = W( 75 ) + a*JVS( 800 )
  W( 76 ) = W( 76 ) + a*JVS( 801 )
  W( 77 ) = W( 77 ) + a*JVS( 802 )
  W( 78 ) = W( 78 ) + a*JVS( 803 )
  a = -W( 71 ) / JVS( 818 )
  W( 71 ) = -a
  W( 72 ) = W( 72 ) + a*JVS( 819 )
  W( 73 ) = W( 73 ) + a*JVS( 820 )
  W( 74 ) = W( 74 ) + a*JVS( 821 )
  W( 75 ) = W( 75 ) + a*JVS( 822 )
  W( 76 ) = W( 76 ) + a*JVS( 823 )
  W( 77 ) = W( 77 ) + a*JVS( 824 )
  W( 78 ) = W( 78 ) + a*JVS( 825 )
  a = -W( 72 ) / JVS( 856 )
  W( 72 ) = -a
  W( 73 ) = W( 73 ) + a*JVS( 857 )
  W( 74 ) = W( 74 ) + a*JVS( 858 )
  W( 75 ) = W( 75 ) + a*JVS( 859 )
  W( 76 ) = W( 76 ) + a*JVS( 860 )
  W( 77 ) = W( 77 ) + a*JVS( 861 )
  W( 78 ) = W( 78 ) + a*JVS( 862 )
  a = -W( 73 ) / JVS( 873 )
  W( 73 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 874 )
  W( 75 ) = W( 75 ) + a*JVS( 875 )
  W( 76 ) = W( 76 ) + a*JVS( 876 )
  W( 77 ) = W( 77 ) + a*JVS( 877 )
  W( 78 ) = W( 78 ) + a*JVS( 878 )
  a = -W( 74 ) / JVS( 921 )
  W( 74 ) = -a
  W( 75 ) = W( 75 ) + a*JVS( 922 )
  W( 76 ) = W( 76 ) + a*JVS( 923 )
  W( 77 ) = W( 77 ) + a*JVS( 924 )
  W( 78 ) = W( 78 ) + a*JVS( 925 )
  a = -W( 75 ) / JVS( 954 )
  W( 75 ) = -a
  W( 76 ) = W( 76 ) + a*JVS( 955 )
  W( 77 ) = W( 77 ) + a*JVS( 956 )
  W( 78 ) = W( 78 ) + a*JVS( 957 )
  a = -W( 76 ) / JVS( 1020 )
  W( 76 ) = -a
  W( 77 ) = W( 77 ) + a*JVS( 1021 )
  W( 78 ) = W( 78 ) + a*JVS( 1022 )
  JVS( 1023) = W( 21 )
  JVS( 1024) = W( 24 )
  JVS( 1025) = W( 25 )
  JVS( 1026) = W( 28 )
  JVS( 1027) = W( 29 )
  JVS( 1028) = W( 35 )
  JVS( 1029) = W( 38 )
  JVS( 1030) = W( 41 )
  JVS( 1031) = W( 43 )
  JVS( 1032) = W( 44 )
  JVS( 1033) = W( 46 )
  JVS( 1034) = W( 48 )
  JVS( 1035) = W( 49 )
  JVS( 1036) = W( 50 )
  JVS( 1037) = W( 51 )
  JVS( 1038) = W( 52 )
  JVS( 1039) = W( 53 )
  JVS( 1040) = W( 54 )
  JVS( 1041) = W( 57 )
  JVS( 1042) = W( 59 )
  JVS( 1043) = W( 60 )
  JVS( 1044) = W( 61 )
  JVS( 1045) = W( 62 )
  JVS( 1046) = W( 63 )
  JVS( 1047) = W( 64 )
  JVS( 1048) = W( 65 )
  JVS( 1049) = W( 66 )
  JVS( 1050) = W( 67 )
  JVS( 1051) = W( 68 )
  JVS( 1052) = W( 69 )
  JVS( 1053) = W( 70 )
  JVS( 1054) = W( 71 )
  JVS( 1055) = W( 72 )
  JVS( 1056) = W( 73 )
  JVS( 1057) = W( 74 )
  JVS( 1058) = W( 75 )
  JVS( 1059) = W( 76 )
  JVS( 1060) = W( 77 )
  JVS( 1061) = W( 78 )
  IF ( ABS( JVS( 1111 )) < TINY(a) ) THEN
         IER = 78
         RETURN
  END IF
   W( 8 ) = JVS( 1062 )
   W( 19 ) = JVS( 1063 )
   W( 21 ) = JVS( 1064 )
   W( 23 ) = JVS( 1065 )
   W( 24 ) = JVS( 1066 )
   W( 25 ) = JVS( 1067 )
   W( 28 ) = JVS( 1068 )
   W( 29 ) = JVS( 1069 )
   W( 31 ) = JVS( 1070 )
   W( 32 ) = JVS( 1071 )
   W( 35 ) = JVS( 1072 )
   W( 38 ) = JVS( 1073 )
   W( 39 ) = JVS( 1074 )
   W( 40 ) = JVS( 1075 )
   W( 41 ) = JVS( 1076 )
   W( 43 ) = JVS( 1077 )
   W( 44 ) = JVS( 1078 )
   W( 45 ) = JVS( 1079 )
   W( 46 ) = JVS( 1080 )
   W( 48 ) = JVS( 1081 )
   W( 49 ) = JVS( 1082 )
   W( 50 ) = JVS( 1083 )
   W( 51 ) = JVS( 1084 )
   W( 52 ) = JVS( 1085 )
   W( 53 ) = JVS( 1086 )
   W( 54 ) = JVS( 1087 )
   W( 55 ) = JVS( 1088 )
   W( 56 ) = JVS( 1089 )
   W( 57 ) = JVS( 1090 )
   W( 58 ) = JVS( 1091 )
   W( 59 ) = JVS( 1092 )
   W( 60 ) = JVS( 1093 )
   W( 61 ) = JVS( 1094 )
   W( 62 ) = JVS( 1095 )
   W( 63 ) = JVS( 1096 )
   W( 64 ) = JVS( 1097 )
   W( 65 ) = JVS( 1098 )
   W( 66 ) = JVS( 1099 )
   W( 67 ) = JVS( 1100 )
   W( 68 ) = JVS( 1101 )
   W( 69 ) = JVS( 1102 )
   W( 70 ) = JVS( 1103 )
   W( 71 ) = JVS( 1104 )
   W( 72 ) = JVS( 1105 )
   W( 73 ) = JVS( 1106 )
   W( 74 ) = JVS( 1107 )
   W( 75 ) = JVS( 1108 )
   W( 76 ) = JVS( 1109 )
   W( 77 ) = JVS( 1110 )
   W( 78 ) = JVS( 1111 )
  a = -W( 8 ) / JVS( 47 )
  W( 8 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 48 )
  W( 78 ) = W( 78 ) + a*JVS( 49 )
  a = -W( 19 ) / JVS( 81 )
  W( 19 ) = -a
  W( 69 ) = W( 69 ) + a*JVS( 82 )
  W( 76 ) = W( 76 ) + a*JVS( 83 )
  W( 78 ) = W( 78 ) + a*JVS( 84 )
  a = -W( 21 ) / JVS( 89 )
  W( 21 ) = -a
  W( 24 ) = W( 24 ) + a*JVS( 90 )
  W( 25 ) = W( 25 ) + a*JVS( 91 )
  W( 28 ) = W( 28 ) + a*JVS( 92 )
  W( 76 ) = W( 76 ) + a*JVS( 93 )
  W( 77 ) = W( 77 ) + a*JVS( 94 )
  W( 78 ) = W( 78 ) + a*JVS( 95 )
  a = -W( 23 ) / JVS( 106 )
  W( 23 ) = -a
  W( 38 ) = W( 38 ) + a*JVS( 107 )
  W( 69 ) = W( 69 ) + a*JVS( 108 )
  W( 74 ) = W( 74 ) + a*JVS( 109 )
  W( 76 ) = W( 76 ) + a*JVS( 110 )
  W( 78 ) = W( 78 ) + a*JVS( 111 )
  a = -W( 24 ) / JVS( 113 )
  W( 24 ) = -a
  W( 75 ) = W( 75 ) + a*JVS( 114 )
  W( 76 ) = W( 76 ) + a*JVS( 115 )
  W( 78 ) = W( 78 ) + a*JVS( 116 )
  a = -W( 25 ) / JVS( 118 )
  W( 25 ) = -a
  W( 75 ) = W( 75 ) + a*JVS( 119 )
  W( 76 ) = W( 76 ) + a*JVS( 120 )
  W( 78 ) = W( 78 ) + a*JVS( 121 )
  a = -W( 28 ) / JVS( 133 )
  W( 28 ) = -a
  W( 38 ) = W( 38 ) + a*JVS( 134 )
  W( 75 ) = W( 75 ) + a*JVS( 135 )
  W( 76 ) = W( 76 ) + a*JVS( 136 )
  W( 78 ) = W( 78 ) + a*JVS( 137 )
  a = -W( 29 ) / JVS( 138 )
  W( 29 ) = -a
  W( 35 ) = W( 35 ) + a*JVS( 139 )
  W( 69 ) = W( 69 ) + a*JVS( 140 )
  W( 75 ) = W( 75 ) + a*JVS( 141 )
  W( 77 ) = W( 77 ) + a*JVS( 142 )
  a = -W( 31 ) / JVS( 149 )
  W( 31 ) = -a
  W( 38 ) = W( 38 ) + a*JVS( 150 )
  W( 39 ) = W( 39 ) + a*JVS( 151 )
  W( 45 ) = W( 45 ) + a*JVS( 152 )
  W( 56 ) = W( 56 ) + a*JVS( 153 )
  W( 58 ) = W( 58 ) + a*JVS( 154 )
  W( 63 ) = W( 63 ) + a*JVS( 155 )
  W( 64 ) = W( 64 ) + a*JVS( 156 )
  W( 69 ) = W( 69 ) + a*JVS( 157 )
  W( 74 ) = W( 74 ) + a*JVS( 158 )
  W( 76 ) = W( 76 ) + a*JVS( 159 )
  W( 78 ) = W( 78 ) + a*JVS( 160 )
  a = -W( 32 ) / JVS( 161 )
  W( 32 ) = -a
  W( 40 ) = W( 40 ) + a*JVS( 162 )
  W( 68 ) = W( 68 ) + a*JVS( 163 )
  W( 74 ) = W( 74 ) + a*JVS( 164 )
  W( 75 ) = W( 75 ) + a*JVS( 165 )
  W( 76 ) = W( 76 ) + a*JVS( 166 )
  W( 78 ) = W( 78 ) + a*JVS( 167 )
  a = -W( 35 ) / JVS( 197 )
  W( 35 ) = -a
  W( 63 ) = W( 63 ) + a*JVS( 198 )
  W( 69 ) = W( 69 ) + a*JVS( 199 )
  W( 75 ) = W( 75 ) + a*JVS( 200 )
  W( 76 ) = W( 76 ) + a*JVS( 201 )
  W( 77 ) = W( 77 ) + a*JVS( 202 )
  a = -W( 38 ) / JVS( 215 )
  W( 38 ) = -a
  W( 69 ) = W( 69 ) + a*JVS( 216 )
  W( 74 ) = W( 74 ) + a*JVS( 217 )
  W( 75 ) = W( 75 ) + a*JVS( 218 )
  W( 76 ) = W( 76 ) + a*JVS( 219 )
  W( 78 ) = W( 78 ) + a*JVS( 220 )
  a = -W( 39 ) / JVS( 222 )
  W( 39 ) = -a
  W( 46 ) = W( 46 ) + a*JVS( 223 )
  W( 51 ) = W( 51 ) + a*JVS( 224 )
  W( 52 ) = W( 52 ) + a*JVS( 225 )
  W( 64 ) = W( 64 ) + a*JVS( 226 )
  W( 68 ) = W( 68 ) + a*JVS( 227 )
  W( 72 ) = W( 72 ) + a*JVS( 228 )
  W( 73 ) = W( 73 ) + a*JVS( 229 )
  W( 74 ) = W( 74 ) + a*JVS( 230 )
  W( 75 ) = W( 75 ) + a*JVS( 231 )
  W( 76 ) = W( 76 ) + a*JVS( 232 )
  W( 77 ) = W( 77 ) + a*JVS( 233 )
  a = -W( 40 ) / JVS( 234 )
  W( 40 ) = -a
  W( 65 ) = W( 65 ) + a*JVS( 235 )
  W( 74 ) = W( 74 ) + a*JVS( 236 )
  W( 75 ) = W( 75 ) + a*JVS( 237 )
  W( 76 ) = W( 76 ) + a*JVS( 238 )
  W( 78 ) = W( 78 ) + a*JVS( 239 )
  a = -W( 41 ) / JVS( 241 )
  W( 41 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 242 )
  W( 69 ) = W( 69 ) + a*JVS( 243 )
  W( 72 ) = W( 72 ) + a*JVS( 244 )
  W( 74 ) = W( 74 ) + a*JVS( 245 )
  W( 75 ) = W( 75 ) + a*JVS( 246 )
  W( 76 ) = W( 76 ) + a*JVS( 247 )
  W( 77 ) = W( 77 ) + a*JVS( 248 )
  a = -W( 43 ) / JVS( 254 )
  W( 43 ) = -a
  W( 59 ) = W( 59 ) + a*JVS( 255 )
  W( 68 ) = W( 68 ) + a*JVS( 256 )
  W( 69 ) = W( 69 ) + a*JVS( 257 )
  W( 72 ) = W( 72 ) + a*JVS( 258 )
  W( 74 ) = W( 74 ) + a*JVS( 259 )
  W( 76 ) = W( 76 ) + a*JVS( 260 )
  W( 77 ) = W( 77 ) + a*JVS( 261 )
  a = -W( 44 ) / JVS( 262 )
  W( 44 ) = -a
  W( 60 ) = W( 60 ) + a*JVS( 263 )
  W( 68 ) = W( 68 ) + a*JVS( 264 )
  W( 69 ) = W( 69 ) + a*JVS( 265 )
  W( 72 ) = W( 72 ) + a*JVS( 266 )
  W( 74 ) = W( 74 ) + a*JVS( 267 )
  W( 76 ) = W( 76 ) + a*JVS( 268 )
  W( 77 ) = W( 77 ) + a*JVS( 269 )
  a = -W( 45 ) / JVS( 272 )
  W( 45 ) = -a
  W( 46 ) = W( 46 ) + a*JVS( 273 )
  W( 51 ) = W( 51 ) + a*JVS( 274 )
  W( 52 ) = W( 52 ) + a*JVS( 275 )
  W( 56 ) = W( 56 ) + a*JVS( 276 )
  W( 64 ) = W( 64 ) + a*JVS( 277 )
  W( 65 ) = W( 65 ) + a*JVS( 278 )
  W( 67 ) = W( 67 ) + a*JVS( 279 )
  W( 68 ) = W( 68 ) + a*JVS( 280 )
  W( 72 ) = W( 72 ) + a*JVS( 281 )
  W( 73 ) = W( 73 ) + a*JVS( 282 )
  W( 74 ) = W( 74 ) + a*JVS( 283 )
  W( 75 ) = W( 75 ) + a*JVS( 284 )
  W( 76 ) = W( 76 ) + a*JVS( 285 )
  W( 77 ) = W( 77 ) + a*JVS( 286 )
  W( 78 ) = W( 78 ) + a*JVS( 287 )
  a = -W( 46 ) / JVS( 290 )
  W( 46 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 291 )
  W( 69 ) = W( 69 ) + a*JVS( 292 )
  W( 72 ) = W( 72 ) + a*JVS( 293 )
  W( 74 ) = W( 74 ) + a*JVS( 294 )
  W( 75 ) = W( 75 ) + a*JVS( 295 )
  W( 76 ) = W( 76 ) + a*JVS( 296 )
  W( 77 ) = W( 77 ) + a*JVS( 297 )
  W( 78 ) = W( 78 ) + a*JVS( 298 )
  a = -W( 48 ) / JVS( 325 )
  W( 48 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 326 )
  W( 69 ) = W( 69 ) + a*JVS( 327 )
  W( 72 ) = W( 72 ) + a*JVS( 328 )
  W( 74 ) = W( 74 ) + a*JVS( 329 )
  W( 75 ) = W( 75 ) + a*JVS( 330 )
  W( 76 ) = W( 76 ) + a*JVS( 331 )
  W( 77 ) = W( 77 ) + a*JVS( 332 )
  a = -W( 49 ) / JVS( 334 )
  W( 49 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 335 )
  W( 69 ) = W( 69 ) + a*JVS( 336 )
  W( 72 ) = W( 72 ) + a*JVS( 337 )
  W( 74 ) = W( 74 ) + a*JVS( 338 )
  W( 76 ) = W( 76 ) + a*JVS( 339 )
  W( 77 ) = W( 77 ) + a*JVS( 340 )
  a = -W( 50 ) / JVS( 342 )
  W( 50 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 343 )
  W( 69 ) = W( 69 ) + a*JVS( 344 )
  W( 72 ) = W( 72 ) + a*JVS( 345 )
  W( 74 ) = W( 74 ) + a*JVS( 346 )
  W( 76 ) = W( 76 ) + a*JVS( 347 )
  W( 77 ) = W( 77 ) + a*JVS( 348 )
  a = -W( 51 ) / JVS( 350 )
  W( 51 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 351 )
  W( 69 ) = W( 69 ) + a*JVS( 352 )
  W( 72 ) = W( 72 ) + a*JVS( 353 )
  W( 74 ) = W( 74 ) + a*JVS( 354 )
  W( 75 ) = W( 75 ) + a*JVS( 355 )
  W( 76 ) = W( 76 ) + a*JVS( 356 )
  W( 77 ) = W( 77 ) + a*JVS( 357 )
  W( 78 ) = W( 78 ) + a*JVS( 358 )
  a = -W( 52 ) / JVS( 360 )
  W( 52 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 361 )
  W( 69 ) = W( 69 ) + a*JVS( 362 )
  W( 72 ) = W( 72 ) + a*JVS( 363 )
  W( 74 ) = W( 74 ) + a*JVS( 364 )
  W( 75 ) = W( 75 ) + a*JVS( 365 )
  W( 76 ) = W( 76 ) + a*JVS( 366 )
  W( 77 ) = W( 77 ) + a*JVS( 367 )
  W( 78 ) = W( 78 ) + a*JVS( 368 )
  a = -W( 53 ) / JVS( 370 )
  W( 53 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 371 )
  W( 69 ) = W( 69 ) + a*JVS( 372 )
  W( 72 ) = W( 72 ) + a*JVS( 373 )
  W( 74 ) = W( 74 ) + a*JVS( 374 )
  W( 75 ) = W( 75 ) + a*JVS( 375 )
  W( 76 ) = W( 76 ) + a*JVS( 376 )
  W( 77 ) = W( 77 ) + a*JVS( 377 )
  a = -W( 54 ) / JVS( 380 )
  W( 54 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 381 )
  W( 69 ) = W( 69 ) + a*JVS( 382 )
  W( 71 ) = W( 71 ) + a*JVS( 383 )
  W( 72 ) = W( 72 ) + a*JVS( 384 )
  W( 74 ) = W( 74 ) + a*JVS( 385 )
  W( 75 ) = W( 75 ) + a*JVS( 386 )
  W( 76 ) = W( 76 ) + a*JVS( 387 )
  W( 77 ) = W( 77 ) + a*JVS( 388 )
  a = -W( 55 ) / JVS( 399 )
  W( 55 ) = -a
  W( 61 ) = W( 61 ) + a*JVS( 400 )
  W( 62 ) = W( 62 ) + a*JVS( 401 )
  W( 65 ) = W( 65 ) + a*JVS( 402 )
  W( 68 ) = W( 68 ) + a*JVS( 403 )
  W( 69 ) = W( 69 ) + a*JVS( 404 )
  W( 71 ) = W( 71 ) + a*JVS( 405 )
  W( 72 ) = W( 72 ) + a*JVS( 406 )
  W( 73 ) = W( 73 ) + a*JVS( 407 )
  W( 74 ) = W( 74 ) + a*JVS( 408 )
  W( 75 ) = W( 75 ) + a*JVS( 409 )
  W( 76 ) = W( 76 ) + a*JVS( 410 )
  W( 77 ) = W( 77 ) + a*JVS( 411 )
  W( 78 ) = W( 78 ) + a*JVS( 412 )
  a = -W( 56 ) / JVS( 418 )
  W( 56 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 419 )
  W( 69 ) = W( 69 ) + a*JVS( 420 )
  W( 71 ) = W( 71 ) + a*JVS( 421 )
  W( 72 ) = W( 72 ) + a*JVS( 422 )
  W( 74 ) = W( 74 ) + a*JVS( 423 )
  W( 75 ) = W( 75 ) + a*JVS( 424 )
  W( 76 ) = W( 76 ) + a*JVS( 425 )
  W( 77 ) = W( 77 ) + a*JVS( 426 )
  a = -W( 57 ) / JVS( 438 )
  W( 57 ) = -a
  W( 64 ) = W( 64 ) + a*JVS( 439 )
  W( 65 ) = W( 65 ) + a*JVS( 440 )
  W( 67 ) = W( 67 ) + a*JVS( 441 )
  W( 68 ) = W( 68 ) + a*JVS( 442 )
  W( 69 ) = W( 69 ) + a*JVS( 443 )
  W( 70 ) = W( 70 ) + a*JVS( 444 )
  W( 71 ) = W( 71 ) + a*JVS( 445 )
  W( 72 ) = W( 72 ) + a*JVS( 446 )
  W( 73 ) = W( 73 ) + a*JVS( 447 )
  W( 74 ) = W( 74 ) + a*JVS( 448 )
  W( 75 ) = W( 75 ) + a*JVS( 449 )
  W( 76 ) = W( 76 ) + a*JVS( 450 )
  W( 77 ) = W( 77 ) + a*JVS( 451 )
  W( 78 ) = W( 78 ) + a*JVS( 452 )
  a = -W( 58 ) / JVS( 465 )
  W( 58 ) = -a
  W( 59 ) = W( 59 ) + a*JVS( 466 )
  W( 60 ) = W( 60 ) + a*JVS( 467 )
  W( 61 ) = W( 61 ) + a*JVS( 468 )
  W( 62 ) = W( 62 ) + a*JVS( 469 )
  W( 64 ) = W( 64 ) + a*JVS( 470 )
  W( 65 ) = W( 65 ) + a*JVS( 471 )
  W( 66 ) = W( 66 ) + a*JVS( 472 )
  W( 67 ) = W( 67 ) + a*JVS( 473 )
  W( 68 ) = W( 68 ) + a*JVS( 474 )
  W( 69 ) = W( 69 ) + a*JVS( 475 )
  W( 70 ) = W( 70 ) + a*JVS( 476 )
  W( 71 ) = W( 71 ) + a*JVS( 477 )
  W( 72 ) = W( 72 ) + a*JVS( 478 )
  W( 73 ) = W( 73 ) + a*JVS( 479 )
  W( 74 ) = W( 74 ) + a*JVS( 480 )
  W( 75 ) = W( 75 ) + a*JVS( 481 )
  W( 76 ) = W( 76 ) + a*JVS( 482 )
  W( 77 ) = W( 77 ) + a*JVS( 483 )
  W( 78 ) = W( 78 ) + a*JVS( 484 )
  a = -W( 59 ) / JVS( 489 )
  W( 59 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 490 )
  W( 69 ) = W( 69 ) + a*JVS( 491 )
  W( 71 ) = W( 71 ) + a*JVS( 492 )
  W( 72 ) = W( 72 ) + a*JVS( 493 )
  W( 74 ) = W( 74 ) + a*JVS( 494 )
  W( 75 ) = W( 75 ) + a*JVS( 495 )
  W( 76 ) = W( 76 ) + a*JVS( 496 )
  W( 77 ) = W( 77 ) + a*JVS( 497 )
  a = -W( 60 ) / JVS( 500 )
  W( 60 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 501 )
  W( 69 ) = W( 69 ) + a*JVS( 502 )
  W( 71 ) = W( 71 ) + a*JVS( 503 )
  W( 72 ) = W( 72 ) + a*JVS( 504 )
  W( 74 ) = W( 74 ) + a*JVS( 505 )
  W( 75 ) = W( 75 ) + a*JVS( 506 )
  W( 76 ) = W( 76 ) + a*JVS( 507 )
  W( 77 ) = W( 77 ) + a*JVS( 508 )
  a = -W( 61 ) / JVS( 517 )
  W( 61 ) = -a
  W( 62 ) = W( 62 ) + a*JVS( 518 )
  W( 68 ) = W( 68 ) + a*JVS( 519 )
  W( 69 ) = W( 69 ) + a*JVS( 520 )
  W( 71 ) = W( 71 ) + a*JVS( 521 )
  W( 72 ) = W( 72 ) + a*JVS( 522 )
  W( 74 ) = W( 74 ) + a*JVS( 523 )
  W( 75 ) = W( 75 ) + a*JVS( 524 )
  W( 76 ) = W( 76 ) + a*JVS( 525 )
  W( 77 ) = W( 77 ) + a*JVS( 526 )
  a = -W( 62 ) / JVS( 535 )
  W( 62 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 536 )
  W( 69 ) = W( 69 ) + a*JVS( 537 )
  W( 71 ) = W( 71 ) + a*JVS( 538 )
  W( 72 ) = W( 72 ) + a*JVS( 539 )
  W( 74 ) = W( 74 ) + a*JVS( 540 )
  W( 75 ) = W( 75 ) + a*JVS( 541 )
  W( 76 ) = W( 76 ) + a*JVS( 542 )
  W( 77 ) = W( 77 ) + a*JVS( 543 )
  a = -W( 63 ) / JVS( 573 )
  W( 63 ) = -a
  W( 64 ) = W( 64 ) + a*JVS( 574 )
  W( 65 ) = W( 65 ) + a*JVS( 575 )
  W( 66 ) = W( 66 ) + a*JVS( 576 )
  W( 67 ) = W( 67 ) + a*JVS( 577 )
  W( 68 ) = W( 68 ) + a*JVS( 578 )
  W( 69 ) = W( 69 ) + a*JVS( 579 )
  W( 70 ) = W( 70 ) + a*JVS( 580 )
  W( 71 ) = W( 71 ) + a*JVS( 581 )
  W( 72 ) = W( 72 ) + a*JVS( 582 )
  W( 73 ) = W( 73 ) + a*JVS( 583 )
  W( 74 ) = W( 74 ) + a*JVS( 584 )
  W( 75 ) = W( 75 ) + a*JVS( 585 )
  W( 76 ) = W( 76 ) + a*JVS( 586 )
  W( 77 ) = W( 77 ) + a*JVS( 587 )
  W( 78 ) = W( 78 ) + a*JVS( 588 )
  a = -W( 64 ) / JVS( 592 )
  W( 64 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 593 )
  W( 69 ) = W( 69 ) + a*JVS( 594 )
  W( 71 ) = W( 71 ) + a*JVS( 595 )
  W( 72 ) = W( 72 ) + a*JVS( 596 )
  W( 74 ) = W( 74 ) + a*JVS( 597 )
  W( 75 ) = W( 75 ) + a*JVS( 598 )
  W( 76 ) = W( 76 ) + a*JVS( 599 )
  W( 77 ) = W( 77 ) + a*JVS( 600 )
  W( 78 ) = W( 78 ) + a*JVS( 601 )
  a = -W( 65 ) / JVS( 605 )
  W( 65 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 606 )
  W( 69 ) = W( 69 ) + a*JVS( 607 )
  W( 71 ) = W( 71 ) + a*JVS( 608 )
  W( 72 ) = W( 72 ) + a*JVS( 609 )
  W( 74 ) = W( 74 ) + a*JVS( 610 )
  W( 75 ) = W( 75 ) + a*JVS( 611 )
  W( 76 ) = W( 76 ) + a*JVS( 612 )
  W( 77 ) = W( 77 ) + a*JVS( 613 )
  W( 78 ) = W( 78 ) + a*JVS( 614 )
  a = -W( 66 ) / JVS( 629 )
  W( 66 ) = -a
  W( 67 ) = W( 67 ) + a*JVS( 630 )
  W( 68 ) = W( 68 ) + a*JVS( 631 )
  W( 69 ) = W( 69 ) + a*JVS( 632 )
  W( 70 ) = W( 70 ) + a*JVS( 633 )
  W( 71 ) = W( 71 ) + a*JVS( 634 )
  W( 72 ) = W( 72 ) + a*JVS( 635 )
  W( 73 ) = W( 73 ) + a*JVS( 636 )
  W( 74 ) = W( 74 ) + a*JVS( 637 )
  W( 75 ) = W( 75 ) + a*JVS( 638 )
  W( 76 ) = W( 76 ) + a*JVS( 639 )
  W( 77 ) = W( 77 ) + a*JVS( 640 )
  W( 78 ) = W( 78 ) + a*JVS( 641 )
  a = -W( 67 ) / JVS( 657 )
  W( 67 ) = -a
  W( 68 ) = W( 68 ) + a*JVS( 658 )
  W( 69 ) = W( 69 ) + a*JVS( 659 )
  W( 70 ) = W( 70 ) + a*JVS( 660 )
  W( 71 ) = W( 71 ) + a*JVS( 661 )
  W( 72 ) = W( 72 ) + a*JVS( 662 )
  W( 73 ) = W( 73 ) + a*JVS( 663 )
  W( 74 ) = W( 74 ) + a*JVS( 664 )
  W( 75 ) = W( 75 ) + a*JVS( 665 )
  W( 76 ) = W( 76 ) + a*JVS( 666 )
  W( 77 ) = W( 77 ) + a*JVS( 667 )
  W( 78 ) = W( 78 ) + a*JVS( 668 )
  a = -W( 68 ) / JVS( 700 )
  W( 68 ) = -a
  W( 69 ) = W( 69 ) + a*JVS( 701 )
  W( 70 ) = W( 70 ) + a*JVS( 702 )
  W( 71 ) = W( 71 ) + a*JVS( 703 )
  W( 72 ) = W( 72 ) + a*JVS( 704 )
  W( 73 ) = W( 73 ) + a*JVS( 705 )
  W( 74 ) = W( 74 ) + a*JVS( 706 )
  W( 75 ) = W( 75 ) + a*JVS( 707 )
  W( 76 ) = W( 76 ) + a*JVS( 708 )
  W( 77 ) = W( 77 ) + a*JVS( 709 )
  W( 78 ) = W( 78 ) + a*JVS( 710 )
  a = -W( 69 ) / JVS( 764 )
  W( 69 ) = -a
  W( 70 ) = W( 70 ) + a*JVS( 765 )
  W( 71 ) = W( 71 ) + a*JVS( 766 )
  W( 72 ) = W( 72 ) + a*JVS( 767 )
  W( 73 ) = W( 73 ) + a*JVS( 768 )
  W( 74 ) = W( 74 ) + a*JVS( 769 )
  W( 75 ) = W( 75 ) + a*JVS( 770 )
  W( 76 ) = W( 76 ) + a*JVS( 771 )
  W( 77 ) = W( 77 ) + a*JVS( 772 )
  W( 78 ) = W( 78 ) + a*JVS( 773 )
  a = -W( 70 ) / JVS( 795 )
  W( 70 ) = -a
  W( 71 ) = W( 71 ) + a*JVS( 796 )
  W( 72 ) = W( 72 ) + a*JVS( 797 )
  W( 73 ) = W( 73 ) + a*JVS( 798 )
  W( 74 ) = W( 74 ) + a*JVS( 799 )
  W( 75 ) = W( 75 ) + a*JVS( 800 )
  W( 76 ) = W( 76 ) + a*JVS( 801 )
  W( 77 ) = W( 77 ) + a*JVS( 802 )
  W( 78 ) = W( 78 ) + a*JVS( 803 )
  a = -W( 71 ) / JVS( 818 )
  W( 71 ) = -a
  W( 72 ) = W( 72 ) + a*JVS( 819 )
  W( 73 ) = W( 73 ) + a*JVS( 820 )
  W( 74 ) = W( 74 ) + a*JVS( 821 )
  W( 75 ) = W( 75 ) + a*JVS( 822 )
  W( 76 ) = W( 76 ) + a*JVS( 823 )
  W( 77 ) = W( 77 ) + a*JVS( 824 )
  W( 78 ) = W( 78 ) + a*JVS( 825 )
  a = -W( 72 ) / JVS( 856 )
  W( 72 ) = -a
  W( 73 ) = W( 73 ) + a*JVS( 857 )
  W( 74 ) = W( 74 ) + a*JVS( 858 )
  W( 75 ) = W( 75 ) + a*JVS( 859 )
  W( 76 ) = W( 76 ) + a*JVS( 860 )
  W( 77 ) = W( 77 ) + a*JVS( 861 )
  W( 78 ) = W( 78 ) + a*JVS( 862 )
  a = -W( 73 ) / JVS( 873 )
  W( 73 ) = -a
  W( 74 ) = W( 74 ) + a*JVS( 874 )
  W( 75 ) = W( 75 ) + a*JVS( 875 )
  W( 76 ) = W( 76 ) + a*JVS( 876 )
  W( 77 ) = W( 77 ) + a*JVS( 877 )
  W( 78 ) = W( 78 ) + a*JVS( 878 )
  a = -W( 74 ) / JVS( 921 )
  W( 74 ) = -a
  W( 75 ) = W( 75 ) + a*JVS( 922 )
  W( 76 ) = W( 76 ) + a*JVS( 923 )
  W( 77 ) = W( 77 ) + a*JVS( 924 )
  W( 78 ) = W( 78 ) + a*JVS( 925 )
  a = -W( 75 ) / JVS( 954 )
  W( 75 ) = -a
  W( 76 ) = W( 76 ) + a*JVS( 955 )
  W( 77 ) = W( 77 ) + a*JVS( 956 )
  W( 78 ) = W( 78 ) + a*JVS( 957 )
  a = -W( 76 ) / JVS( 1020 )
  W( 76 ) = -a
  W( 77 ) = W( 77 ) + a*JVS( 1021 )
  W( 78 ) = W( 78 ) + a*JVS( 1022 )
  a = -W( 77 ) / JVS( 1060 )
  W( 77 ) = -a
  W( 78 ) = W( 78 ) + a*JVS( 1061 )
  JVS( 1062) = W( 8 )
  JVS( 1063) = W( 19 )
  JVS( 1064) = W( 21 )
  JVS( 1065) = W( 23 )
  JVS( 1066) = W( 24 )
  JVS( 1067) = W( 25 )
  JVS( 1068) = W( 28 )
  JVS( 1069) = W( 29 )
  JVS( 1070) = W( 31 )
  JVS( 1071) = W( 32 )
  JVS( 1072) = W( 35 )
  JVS( 1073) = W( 38 )
  JVS( 1074) = W( 39 )
  JVS( 1075) = W( 40 )
  JVS( 1076) = W( 41 )
  JVS( 1077) = W( 43 )
  JVS( 1078) = W( 44 )
  JVS( 1079) = W( 45 )
  JVS( 1080) = W( 46 )
  JVS( 1081) = W( 48 )
  JVS( 1082) = W( 49 )
  JVS( 1083) = W( 50 )
  JVS( 1084) = W( 51 )
  JVS( 1085) = W( 52 )
  JVS( 1086) = W( 53 )
  JVS( 1087) = W( 54 )
  JVS( 1088) = W( 55 )
  JVS( 1089) = W( 56 )
  JVS( 1090) = W( 57 )
  JVS( 1091) = W( 58 )
  JVS( 1092) = W( 59 )
  JVS( 1093) = W( 60 )
  JVS( 1094) = W( 61 )
  JVS( 1095) = W( 62 )
  JVS( 1096) = W( 63 )
  JVS( 1097) = W( 64 )
  JVS( 1098) = W( 65 )
  JVS( 1099) = W( 66 )
  JVS( 1100) = W( 67 )
  JVS( 1101) = W( 68 )
  JVS( 1102) = W( 69 )
  JVS( 1103) = W( 70 )
  JVS( 1104) = W( 71 )
  JVS( 1105) = W( 72 )
  JVS( 1106) = W( 73 )
  JVS( 1107) = W( 74 )
  JVS( 1108) = W( 75 )
  JVS( 1109) = W( 76 )
  JVS( 1110) = W( 77 )
  JVS( 1111) = W( 78 )
   END SUBROUTINE decomp_racm
END MODULE racm_Integrator
